#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1908
#define LARGE_STATE_COUNT 252
#define SYMBOL_COUNT 243
#define ALIAS_COUNT 4
#define TOKEN_COUNT 106
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 28
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define PRODUCTION_ID_COUNT 146

enum ts_symbol_identifiers {
  anon_sym_LBRACE = 1,
  anon_sym_RBRACE = 2,
  anon_sym_impl = 3,
  anon_sym_of = 4,
  anon_sym_SEMI = 5,
  anon_sym_trait = 6,
  anon_sym_type = 7,
  anon_sym_COLON = 8,
  anon_sym_const = 9,
  anon_sym_EQ = 10,
  anon_sym_BANG = 11,
  anon_sym_POUND = 12,
  anon_sym_LBRACK = 13,
  anon_sym_RBRACK = 14,
  anon_sym_mod = 15,
  anon_sym_struct = 16,
  anon_sym_enum = 17,
  anon_sym_COMMA = 18,
  anon_sym_fn = 19,
  anon_sym_DASH_GT = 20,
  anon_sym_implicits = 21,
  anon_sym_let = 22,
  anon_sym_use = 23,
  anon_sym_COLON_COLON = 24,
  anon_sym_as = 25,
  anon_sym_STAR = 26,
  anon_sym_LPAREN = 27,
  anon_sym__ = 28,
  anon_sym_RPAREN = 29,
  anon_sym_u8 = 30,
  anon_sym_i8 = 31,
  anon_sym_u16 = 32,
  anon_sym_i16 = 33,
  anon_sym_u32 = 34,
  anon_sym_i32 = 35,
  anon_sym_u64 = 36,
  anon_sym_i64 = 37,
  anon_sym_u128 = 38,
  anon_sym_i128 = 39,
  anon_sym_usize = 40,
  anon_sym_bool = 41,
  anon_sym_ByteArray = 42,
  anon_sym_felt252 = 43,
  anon_sym_LT = 44,
  anon_sym_GT = 45,
  anon_sym_PLUS = 46,
  anon_sym_DASH = 47,
  anon_sym_SLASH = 48,
  anon_sym_PERCENT = 49,
  anon_sym_CARET = 50,
  anon_sym_TILDE = 51,
  anon_sym_AMP = 52,
  anon_sym_PIPE = 53,
  anon_sym_AMP_AMP = 54,
  anon_sym_PIPE_PIPE = 55,
  anon_sym_LT_LT = 56,
  anon_sym_GT_GT = 57,
  anon_sym_PLUS_EQ = 58,
  anon_sym_DASH_EQ = 59,
  anon_sym_STAR_EQ = 60,
  anon_sym_SLASH_EQ = 61,
  anon_sym_PERCENT_EQ = 62,
  anon_sym_CARET_EQ = 63,
  anon_sym_AMP_EQ = 64,
  anon_sym_PIPE_EQ = 65,
  anon_sym_EQ_EQ = 66,
  anon_sym_BANG_EQ = 67,
  anon_sym_GT_EQ = 68,
  anon_sym_LT_EQ = 69,
  anon_sym_AT = 70,
  anon_sym_DOT_DOT = 71,
  anon_sym_DOT = 72,
  anon_sym_EQ_GT = 73,
  anon_sym_QMARK = 74,
  anon_sym_break = 75,
  anon_sym_continue = 76,
  anon_sym_default = 77,
  anon_sym_if = 78,
  anon_sym_extern = 79,
  anon_sym_nopanic = 80,
  anon_sym_loop = 81,
  anon_sym_match = 82,
  anon_sym_pub = 83,
  anon_sym_return = 84,
  anon_sym_static = 85,
  anon_sym_while = 86,
  anon_sym_for = 87,
  sym_numeric_literal = 88,
  aux_sym_string_literal_token1 = 89,
  aux_sym_string_literal_token2 = 90,
  anon_sym_DQUOTE = 91,
  sym_shortstring_literal = 92,
  anon_sym_true = 93,
  anon_sym_false = 94,
  anon_sym_DOLLAR = 95,
  anon_sym_LT2 = 96,
  anon_sym_else = 97,
  anon_sym_move = 98,
  anon_sym_in = 99,
  anon_sym_ref = 100,
  sym_identifier = 101,
  sym_mutable_specifier = 102,
  sym_super = 103,
  sym_crate = 104,
  sym_line_comment = 105,
  sym_source_file = 106,
  sym__statement = 107,
  sym_declaration_list = 108,
  sym_impl_item = 109,
  sym_trait_item = 110,
  sym_associated_type = 111,
  sym_associated_impl = 112,
  sym_const_item = 113,
  sym_macro_invocation = 114,
  sym_empty_statement = 115,
  sym_attribute_item = 116,
  sym_inner_attribute_item = 117,
  sym_attribute = 118,
  sym_mod_item = 119,
  sym_struct_item = 120,
  sym_enum_item = 121,
  sym_enum_variant_list = 122,
  sym_enum_variant = 123,
  sym_field_declaration_list = 124,
  sym_field_declaration = 125,
  sym_type_item = 126,
  sym_extern_type = 127,
  sym_external_function_item = 128,
  sym_function_item = 129,
  sym_function_signature_item = 130,
  sym_function = 131,
  sym_let_declaration = 132,
  sym_use_declaration = 133,
  sym__use_clause = 134,
  sym_scoped_use_list = 135,
  sym_use_list = 136,
  sym_use_as_clause = 137,
  sym_use_wildcard = 138,
  sym_parameters = 139,
  sym_parameter = 140,
  sym__type = 141,
  sym_type_parameters = 142,
  sym_const_parameter = 143,
  sym_constrained_type_parameter = 144,
  sym_generic_type = 145,
  sym_generic_type_with_turbofish = 146,
  sym_array_type = 147,
  sym_delim_token_tree = 148,
  sym__delim_tokens = 149,
  sym__pattern = 150,
  sym_tuple_pattern = 151,
  sym_range_pattern = 152,
  sym_slice_pattern = 153,
  sym_struct_pattern = 154,
  sym_field_pattern = 155,
  sym_field_initializer_list = 156,
  sym_shorthand_field_initializer = 157,
  sym_field_initializer = 158,
  sym_base_field_initializer = 159,
  sym_mut_pattern = 160,
  sym_or_pattern = 161,
  sym__literal = 162,
  sym__literal_pattern = 163,
  sym_negative_literal = 164,
  sym_string_literal = 165,
  sym_boolean_literal = 166,
  sym__non_delim_token = 167,
  sym_scoped_identifier = 168,
  sym_scoped_type_identifier_in_expression_position = 169,
  sym_scoped_type_identifier = 170,
  sym_tuple_type = 171,
  sym_unit_type = 172,
  sym_type_arguments = 173,
  sym_expression_statement = 174,
  sym_expression = 175,
  sym_expression_except_range = 176,
  sym_generic_function = 177,
  sym_tuple_expression = 178,
  sym_return_expression = 179,
  sym_struct_expression = 180,
  sym_assignment_expression = 181,
  sym_break_expression = 182,
  sym_continue_expression = 183,
  sym_index_expression = 184,
  sym_array_expression = 185,
  sym_parenthesized_expression = 186,
  sym_unit_expression = 187,
  sym_compound_assignment_expr = 188,
  sym__expression_ending_with_block = 189,
  sym_unary_expression = 190,
  sym_range_expression = 191,
  sym_try_expression = 192,
  sym_field_expression = 193,
  sym_block = 194,
  sym_if_expression = 195,
  sym__condition = 196,
  sym_let_condition = 197,
  sym_else_clause = 198,
  sym_match_expression = 199,
  sym_match_block = 200,
  sym_match_arm = 201,
  sym_last_match_arm = 202,
  sym_tuple_enum_pattern = 203,
  sym_match_pattern = 204,
  sym_while_expression = 205,
  sym_closure_expression = 206,
  sym_closure_parameters = 207,
  sym_for_expression = 208,
  sym_loop_expression = 209,
  sym_binary_expression = 210,
  sym_snapshot_type = 211,
  sym_call_expression = 212,
  sym_arguments = 213,
  sym_named_argument = 214,
  sym_reference_expression = 215,
  sym_visibility_modifier = 216,
  sym_extern = 217,
  sym_nopanic = 218,
  sym_ref_specifier = 219,
  aux_sym_source_file_repeat1 = 220,
  aux_sym_declaration_list_repeat1 = 221,
  aux_sym_enum_variant_list_repeat1 = 222,
  aux_sym_enum_variant_list_repeat2 = 223,
  aux_sym_field_declaration_list_repeat1 = 224,
  aux_sym_function_repeat1 = 225,
  aux_sym_use_list_repeat1 = 226,
  aux_sym_parameters_repeat1 = 227,
  aux_sym_type_parameters_repeat1 = 228,
  aux_sym_constrained_type_parameter_repeat1 = 229,
  aux_sym_delim_token_tree_repeat1 = 230,
  aux_sym__non_special_token_repeat1 = 231,
  aux_sym_tuple_pattern_repeat1 = 232,
  aux_sym_slice_pattern_repeat1 = 233,
  aux_sym_struct_pattern_repeat1 = 234,
  aux_sym_field_initializer_list_repeat1 = 235,
  aux_sym_type_arguments_repeat1 = 236,
  aux_sym_tuple_expression_repeat1 = 237,
  aux_sym_array_expression_repeat1 = 238,
  aux_sym_match_block_repeat1 = 239,
  aux_sym_match_arm_repeat1 = 240,
  aux_sym_closure_parameters_repeat1 = 241,
  aux_sym_arguments_repeat1 = 242,
  alias_sym_field_identifier = 243,
  alias_sym_primitive_type = 244,
  alias_sym_shorthand_field_identifier = 245,
  alias_sym_type_identifier = 246,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_impl] = "impl",
  [anon_sym_of] = "of",
  [anon_sym_SEMI] = ";",
  [anon_sym_trait] = "trait",
  [anon_sym_type] = "type",
  [anon_sym_COLON] = ":",
  [anon_sym_const] = "const",
  [anon_sym_EQ] = "=",
  [anon_sym_BANG] = "!",
  [anon_sym_POUND] = "#",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_mod] = "mod",
  [anon_sym_struct] = "struct",
  [anon_sym_enum] = "enum",
  [anon_sym_COMMA] = ",",
  [anon_sym_fn] = "fn",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_implicits] = "implicits",
  [anon_sym_let] = "let",
  [anon_sym_use] = "use",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_as] = "as",
  [anon_sym_STAR] = "*",
  [anon_sym_LPAREN] = "(",
  [anon_sym__] = "_",
  [anon_sym_RPAREN] = ")",
  [anon_sym_u8] = "identifier",
  [anon_sym_i8] = "identifier",
  [anon_sym_u16] = "identifier",
  [anon_sym_i16] = "identifier",
  [anon_sym_u32] = "identifier",
  [anon_sym_i32] = "identifier",
  [anon_sym_u64] = "identifier",
  [anon_sym_i64] = "identifier",
  [anon_sym_u128] = "identifier",
  [anon_sym_i128] = "identifier",
  [anon_sym_usize] = "identifier",
  [anon_sym_bool] = "identifier",
  [anon_sym_ByteArray] = "identifier",
  [anon_sym_felt252] = "identifier",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_CARET] = "^",
  [anon_sym_TILDE] = "~",
  [anon_sym_AMP] = "&",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_AT] = "@",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_DOT] = ".",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_QMARK] = "\?",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_default] = "default",
  [anon_sym_if] = "if",
  [anon_sym_extern] = "extern",
  [anon_sym_nopanic] = "nopanic",
  [anon_sym_loop] = "loop",
  [anon_sym_match] = "match",
  [anon_sym_pub] = "pub",
  [anon_sym_return] = "return",
  [anon_sym_static] = "static",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [sym_numeric_literal] = "numeric_literal",
  [aux_sym_string_literal_token1] = "\"",
  [aux_sym_string_literal_token2] = "string_literal_token2",
  [anon_sym_DQUOTE] = "\"",
  [sym_shortstring_literal] = "shortstring_literal",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_LT2] = "<",
  [anon_sym_else] = "else",
  [anon_sym_move] = "move",
  [anon_sym_in] = "in",
  [anon_sym_ref] = "ref",
  [sym_identifier] = "identifier",
  [sym_mutable_specifier] = "mutable_specifier",
  [sym_super] = "super",
  [sym_crate] = "crate",
  [sym_line_comment] = "line_comment",
  [sym_source_file] = "source_file",
  [sym__statement] = "_statement",
  [sym_declaration_list] = "declaration_list",
  [sym_impl_item] = "impl_item",
  [sym_trait_item] = "trait_item",
  [sym_associated_type] = "associated_type",
  [sym_associated_impl] = "associated_impl",
  [sym_const_item] = "const_item",
  [sym_macro_invocation] = "macro_invocation",
  [sym_empty_statement] = "empty_statement",
  [sym_attribute_item] = "attribute_item",
  [sym_inner_attribute_item] = "inner_attribute_item",
  [sym_attribute] = "attribute",
  [sym_mod_item] = "mod_item",
  [sym_struct_item] = "struct_item",
  [sym_enum_item] = "enum_item",
  [sym_enum_variant_list] = "enum_variant_list",
  [sym_enum_variant] = "enum_variant",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym_field_declaration] = "field_declaration",
  [sym_type_item] = "type_item",
  [sym_extern_type] = "extern_type",
  [sym_external_function_item] = "external_function_item",
  [sym_function_item] = "function_item",
  [sym_function_signature_item] = "function_signature_item",
  [sym_function] = "function",
  [sym_let_declaration] = "let_declaration",
  [sym_use_declaration] = "use_declaration",
  [sym__use_clause] = "_use_clause",
  [sym_scoped_use_list] = "scoped_use_list",
  [sym_use_list] = "use_list",
  [sym_use_as_clause] = "use_as_clause",
  [sym_use_wildcard] = "use_wildcard",
  [sym_parameters] = "parameters",
  [sym_parameter] = "parameter",
  [sym__type] = "_type",
  [sym_type_parameters] = "type_parameters",
  [sym_const_parameter] = "const_parameter",
  [sym_constrained_type_parameter] = "constrained_type_parameter",
  [sym_generic_type] = "generic_type",
  [sym_generic_type_with_turbofish] = "generic_type_with_turbofish",
  [sym_array_type] = "array_type",
  [sym_delim_token_tree] = "token_tree",
  [sym__delim_tokens] = "_delim_tokens",
  [sym__pattern] = "_pattern",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_range_pattern] = "range_pattern",
  [sym_slice_pattern] = "slice_pattern",
  [sym_struct_pattern] = "struct_pattern",
  [sym_field_pattern] = "field_pattern",
  [sym_field_initializer_list] = "field_initializer_list",
  [sym_shorthand_field_initializer] = "shorthand_field_initializer",
  [sym_field_initializer] = "field_initializer",
  [sym_base_field_initializer] = "base_field_initializer",
  [sym_mut_pattern] = "mut_pattern",
  [sym_or_pattern] = "or_pattern",
  [sym__literal] = "_literal",
  [sym__literal_pattern] = "_literal_pattern",
  [sym_negative_literal] = "negative_literal",
  [sym_string_literal] = "string_literal",
  [sym_boolean_literal] = "boolean_literal",
  [sym__non_delim_token] = "_non_delim_token",
  [sym_scoped_identifier] = "scoped_identifier",
  [sym_scoped_type_identifier_in_expression_position] = "scoped_type_identifier",
  [sym_scoped_type_identifier] = "scoped_type_identifier",
  [sym_tuple_type] = "tuple_type",
  [sym_unit_type] = "unit_type",
  [sym_type_arguments] = "type_arguments",
  [sym_expression_statement] = "expression_statement",
  [sym_expression] = "expression",
  [sym_expression_except_range] = "expression_except_range",
  [sym_generic_function] = "generic_function",
  [sym_tuple_expression] = "tuple_expression",
  [sym_return_expression] = "return_expression",
  [sym_struct_expression] = "struct_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_break_expression] = "break_expression",
  [sym_continue_expression] = "continue_expression",
  [sym_index_expression] = "index_expression",
  [sym_array_expression] = "array_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_unit_expression] = "unit_expression",
  [sym_compound_assignment_expr] = "compound_assignment_expr",
  [sym__expression_ending_with_block] = "_expression_ending_with_block",
  [sym_unary_expression] = "unary_expression",
  [sym_range_expression] = "range_expression",
  [sym_try_expression] = "try_expression",
  [sym_field_expression] = "field_expression",
  [sym_block] = "block",
  [sym_if_expression] = "if_expression",
  [sym__condition] = "_condition",
  [sym_let_condition] = "let_condition",
  [sym_else_clause] = "else_clause",
  [sym_match_expression] = "match_expression",
  [sym_match_block] = "match_block",
  [sym_match_arm] = "match_arm",
  [sym_last_match_arm] = "match_arm",
  [sym_tuple_enum_pattern] = "tuple_enum_pattern",
  [sym_match_pattern] = "match_pattern",
  [sym_while_expression] = "while_expression",
  [sym_closure_expression] = "closure_expression",
  [sym_closure_parameters] = "closure_parameters",
  [sym_for_expression] = "for_expression",
  [sym_loop_expression] = "loop_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_snapshot_type] = "snapshot_type",
  [sym_call_expression] = "call_expression",
  [sym_arguments] = "arguments",
  [sym_named_argument] = "named_argument",
  [sym_reference_expression] = "reference_expression",
  [sym_visibility_modifier] = "visibility_modifier",
  [sym_extern] = "extern",
  [sym_nopanic] = "nopanic",
  [sym_ref_specifier] = "ref_specifier",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_declaration_list_repeat1] = "declaration_list_repeat1",
  [aux_sym_enum_variant_list_repeat1] = "enum_variant_list_repeat1",
  [aux_sym_enum_variant_list_repeat2] = "enum_variant_list_repeat2",
  [aux_sym_field_declaration_list_repeat1] = "field_declaration_list_repeat1",
  [aux_sym_function_repeat1] = "function_repeat1",
  [aux_sym_use_list_repeat1] = "use_list_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym_constrained_type_parameter_repeat1] = "constrained_type_parameter_repeat1",
  [aux_sym_delim_token_tree_repeat1] = "delim_token_tree_repeat1",
  [aux_sym__non_special_token_repeat1] = "_non_special_token_repeat1",
  [aux_sym_tuple_pattern_repeat1] = "tuple_pattern_repeat1",
  [aux_sym_slice_pattern_repeat1] = "slice_pattern_repeat1",
  [aux_sym_struct_pattern_repeat1] = "struct_pattern_repeat1",
  [aux_sym_field_initializer_list_repeat1] = "field_initializer_list_repeat1",
  [aux_sym_type_arguments_repeat1] = "type_arguments_repeat1",
  [aux_sym_tuple_expression_repeat1] = "tuple_expression_repeat1",
  [aux_sym_array_expression_repeat1] = "array_expression_repeat1",
  [aux_sym_match_block_repeat1] = "match_block_repeat1",
  [aux_sym_match_arm_repeat1] = "match_arm_repeat1",
  [aux_sym_closure_parameters_repeat1] = "closure_parameters_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [alias_sym_field_identifier] = "field_identifier",
  [alias_sym_primitive_type] = "primitive_type",
  [alias_sym_shorthand_field_identifier] = "shorthand_field_identifier",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_impl] = anon_sym_impl,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_trait] = anon_sym_trait,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_POUND] = anon_sym_POUND,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_mod] = anon_sym_mod,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_fn] = anon_sym_fn,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_implicits] = anon_sym_implicits,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_use] = anon_sym_use,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym__] = anon_sym__,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_u8] = sym_identifier,
  [anon_sym_i8] = sym_identifier,
  [anon_sym_u16] = sym_identifier,
  [anon_sym_i16] = sym_identifier,
  [anon_sym_u32] = sym_identifier,
  [anon_sym_i32] = sym_identifier,
  [anon_sym_u64] = sym_identifier,
  [anon_sym_i64] = sym_identifier,
  [anon_sym_u128] = sym_identifier,
  [anon_sym_i128] = sym_identifier,
  [anon_sym_usize] = sym_identifier,
  [anon_sym_bool] = sym_identifier,
  [anon_sym_ByteArray] = sym_identifier,
  [anon_sym_felt252] = sym_identifier,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_extern] = anon_sym_extern,
  [anon_sym_nopanic] = anon_sym_nopanic,
  [anon_sym_loop] = anon_sym_loop,
  [anon_sym_match] = anon_sym_match,
  [anon_sym_pub] = anon_sym_pub,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [sym_numeric_literal] = sym_numeric_literal,
  [aux_sym_string_literal_token1] = anon_sym_DQUOTE,
  [aux_sym_string_literal_token2] = aux_sym_string_literal_token2,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [sym_shortstring_literal] = sym_shortstring_literal,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_LT2] = anon_sym_LT,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_move] = anon_sym_move,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_ref] = anon_sym_ref,
  [sym_identifier] = sym_identifier,
  [sym_mutable_specifier] = sym_mutable_specifier,
  [sym_super] = sym_super,
  [sym_crate] = sym_crate,
  [sym_line_comment] = sym_line_comment,
  [sym_source_file] = sym_source_file,
  [sym__statement] = sym__statement,
  [sym_declaration_list] = sym_declaration_list,
  [sym_impl_item] = sym_impl_item,
  [sym_trait_item] = sym_trait_item,
  [sym_associated_type] = sym_associated_type,
  [sym_associated_impl] = sym_associated_impl,
  [sym_const_item] = sym_const_item,
  [sym_macro_invocation] = sym_macro_invocation,
  [sym_empty_statement] = sym_empty_statement,
  [sym_attribute_item] = sym_attribute_item,
  [sym_inner_attribute_item] = sym_inner_attribute_item,
  [sym_attribute] = sym_attribute,
  [sym_mod_item] = sym_mod_item,
  [sym_struct_item] = sym_struct_item,
  [sym_enum_item] = sym_enum_item,
  [sym_enum_variant_list] = sym_enum_variant_list,
  [sym_enum_variant] = sym_enum_variant,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym_field_declaration] = sym_field_declaration,
  [sym_type_item] = sym_type_item,
  [sym_extern_type] = sym_extern_type,
  [sym_external_function_item] = sym_external_function_item,
  [sym_function_item] = sym_function_item,
  [sym_function_signature_item] = sym_function_signature_item,
  [sym_function] = sym_function,
  [sym_let_declaration] = sym_let_declaration,
  [sym_use_declaration] = sym_use_declaration,
  [sym__use_clause] = sym__use_clause,
  [sym_scoped_use_list] = sym_scoped_use_list,
  [sym_use_list] = sym_use_list,
  [sym_use_as_clause] = sym_use_as_clause,
  [sym_use_wildcard] = sym_use_wildcard,
  [sym_parameters] = sym_parameters,
  [sym_parameter] = sym_parameter,
  [sym__type] = sym__type,
  [sym_type_parameters] = sym_type_parameters,
  [sym_const_parameter] = sym_const_parameter,
  [sym_constrained_type_parameter] = sym_constrained_type_parameter,
  [sym_generic_type] = sym_generic_type,
  [sym_generic_type_with_turbofish] = sym_generic_type_with_turbofish,
  [sym_array_type] = sym_array_type,
  [sym_delim_token_tree] = sym_delim_token_tree,
  [sym__delim_tokens] = sym__delim_tokens,
  [sym__pattern] = sym__pattern,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_range_pattern] = sym_range_pattern,
  [sym_slice_pattern] = sym_slice_pattern,
  [sym_struct_pattern] = sym_struct_pattern,
  [sym_field_pattern] = sym_field_pattern,
  [sym_field_initializer_list] = sym_field_initializer_list,
  [sym_shorthand_field_initializer] = sym_shorthand_field_initializer,
  [sym_field_initializer] = sym_field_initializer,
  [sym_base_field_initializer] = sym_base_field_initializer,
  [sym_mut_pattern] = sym_mut_pattern,
  [sym_or_pattern] = sym_or_pattern,
  [sym__literal] = sym__literal,
  [sym__literal_pattern] = sym__literal_pattern,
  [sym_negative_literal] = sym_negative_literal,
  [sym_string_literal] = sym_string_literal,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym__non_delim_token] = sym__non_delim_token,
  [sym_scoped_identifier] = sym_scoped_identifier,
  [sym_scoped_type_identifier_in_expression_position] = sym_scoped_type_identifier,
  [sym_scoped_type_identifier] = sym_scoped_type_identifier,
  [sym_tuple_type] = sym_tuple_type,
  [sym_unit_type] = sym_unit_type,
  [sym_type_arguments] = sym_type_arguments,
  [sym_expression_statement] = sym_expression_statement,
  [sym_expression] = sym_expression,
  [sym_expression_except_range] = sym_expression_except_range,
  [sym_generic_function] = sym_generic_function,
  [sym_tuple_expression] = sym_tuple_expression,
  [sym_return_expression] = sym_return_expression,
  [sym_struct_expression] = sym_struct_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_break_expression] = sym_break_expression,
  [sym_continue_expression] = sym_continue_expression,
  [sym_index_expression] = sym_index_expression,
  [sym_array_expression] = sym_array_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_unit_expression] = sym_unit_expression,
  [sym_compound_assignment_expr] = sym_compound_assignment_expr,
  [sym__expression_ending_with_block] = sym__expression_ending_with_block,
  [sym_unary_expression] = sym_unary_expression,
  [sym_range_expression] = sym_range_expression,
  [sym_try_expression] = sym_try_expression,
  [sym_field_expression] = sym_field_expression,
  [sym_block] = sym_block,
  [sym_if_expression] = sym_if_expression,
  [sym__condition] = sym__condition,
  [sym_let_condition] = sym_let_condition,
  [sym_else_clause] = sym_else_clause,
  [sym_match_expression] = sym_match_expression,
  [sym_match_block] = sym_match_block,
  [sym_match_arm] = sym_match_arm,
  [sym_last_match_arm] = sym_match_arm,
  [sym_tuple_enum_pattern] = sym_tuple_enum_pattern,
  [sym_match_pattern] = sym_match_pattern,
  [sym_while_expression] = sym_while_expression,
  [sym_closure_expression] = sym_closure_expression,
  [sym_closure_parameters] = sym_closure_parameters,
  [sym_for_expression] = sym_for_expression,
  [sym_loop_expression] = sym_loop_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_snapshot_type] = sym_snapshot_type,
  [sym_call_expression] = sym_call_expression,
  [sym_arguments] = sym_arguments,
  [sym_named_argument] = sym_named_argument,
  [sym_reference_expression] = sym_reference_expression,
  [sym_visibility_modifier] = sym_visibility_modifier,
  [sym_extern] = sym_extern,
  [sym_nopanic] = sym_nopanic,
  [sym_ref_specifier] = sym_ref_specifier,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_declaration_list_repeat1] = aux_sym_declaration_list_repeat1,
  [aux_sym_enum_variant_list_repeat1] = aux_sym_enum_variant_list_repeat1,
  [aux_sym_enum_variant_list_repeat2] = aux_sym_enum_variant_list_repeat2,
  [aux_sym_field_declaration_list_repeat1] = aux_sym_field_declaration_list_repeat1,
  [aux_sym_function_repeat1] = aux_sym_function_repeat1,
  [aux_sym_use_list_repeat1] = aux_sym_use_list_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym_constrained_type_parameter_repeat1] = aux_sym_constrained_type_parameter_repeat1,
  [aux_sym_delim_token_tree_repeat1] = aux_sym_delim_token_tree_repeat1,
  [aux_sym__non_special_token_repeat1] = aux_sym__non_special_token_repeat1,
  [aux_sym_tuple_pattern_repeat1] = aux_sym_tuple_pattern_repeat1,
  [aux_sym_slice_pattern_repeat1] = aux_sym_slice_pattern_repeat1,
  [aux_sym_struct_pattern_repeat1] = aux_sym_struct_pattern_repeat1,
  [aux_sym_field_initializer_list_repeat1] = aux_sym_field_initializer_list_repeat1,
  [aux_sym_type_arguments_repeat1] = aux_sym_type_arguments_repeat1,
  [aux_sym_tuple_expression_repeat1] = aux_sym_tuple_expression_repeat1,
  [aux_sym_array_expression_repeat1] = aux_sym_array_expression_repeat1,
  [aux_sym_match_block_repeat1] = aux_sym_match_block_repeat1,
  [aux_sym_match_arm_repeat1] = aux_sym_match_arm_repeat1,
  [aux_sym_closure_parameters_repeat1] = aux_sym_closure_parameters_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [alias_sym_field_identifier] = alias_sym_field_identifier,
  [alias_sym_primitive_type] = alias_sym_primitive_type,
  [alias_sym_shorthand_field_identifier] = alias_sym_shorthand_field_identifier,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_impl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_trait] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mod] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implicits] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_use] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_i8] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_u16] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_i16] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_u32] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_i32] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_u64] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_i64] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_u128] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_i128] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_usize] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ByteArray] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_felt252] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nopanic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_loop] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_match] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pub] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [sym_numeric_literal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_string_literal_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_shortstring_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_move] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ref] = {
    .visible = true,
    .named = false,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_mutable_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_super] = {
    .visible = true,
    .named = true,
  },
  [sym_crate] = {
    .visible = true,
    .named = true,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_impl_item] = {
    .visible = true,
    .named = true,
  },
  [sym_trait_item] = {
    .visible = true,
    .named = true,
  },
  [sym_associated_type] = {
    .visible = true,
    .named = true,
  },
  [sym_associated_impl] = {
    .visible = true,
    .named = true,
  },
  [sym_const_item] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_invocation] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_inner_attribute_item] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_mod_item] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_item] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_item] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_variant_list] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_variant] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_item] = {
    .visible = true,
    .named = true,
  },
  [sym_extern_type] = {
    .visible = true,
    .named = true,
  },
  [sym_external_function_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature_item] = {
    .visible = true,
    .named = true,
  },
  [sym_function] = {
    .visible = true,
    .named = true,
  },
  [sym_let_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_use_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__use_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_scoped_use_list] = {
    .visible = true,
    .named = true,
  },
  [sym_use_list] = {
    .visible = true,
    .named = true,
  },
  [sym_use_as_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_use_wildcard] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_const_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_constrained_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type_with_turbofish] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_delim_token_tree] = {
    .visible = true,
    .named = true,
  },
  [sym__delim_tokens] = {
    .visible = false,
    .named = true,
  },
  [sym__pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_range_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer_list] = {
    .visible = true,
    .named = true,
  },
  [sym_shorthand_field_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_base_field_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_mut_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__literal_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_negative_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__non_delim_token] = {
    .visible = false,
    .named = true,
  },
  [sym_scoped_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_scoped_type_identifier_in_expression_position] = {
    .visible = true,
    .named = true,
  },
  [sym_scoped_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_unit_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_expression_except_range] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_generic_function] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_return_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_break_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_array_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unit_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_assignment_expr] = {
    .visible = true,
    .named = true,
  },
  [sym__expression_ending_with_block] = {
    .visible = false,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_try_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_if_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__condition] = {
    .visible = false,
    .named = true,
  },
  [sym_let_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_match_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_match_block] = {
    .visible = true,
    .named = true,
  },
  [sym_match_arm] = {
    .visible = true,
    .named = true,
  },
  [sym_last_match_arm] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_enum_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_match_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_while_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_closure_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_closure_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_for_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_loop_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_snapshot_type] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_named_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_visibility_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_extern] = {
    .visible = true,
    .named = true,
  },
  [sym_nopanic] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_specifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_variant_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_variant_list_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_use_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constrained_type_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_delim_token_tree_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__non_special_token_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_slice_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_initializer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_match_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_match_arm_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_closure_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_shorthand_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_body = 5,
  field_bound = 6,
  field_condition = 7,
  field_consequence = 8,
  field_element = 9,
  field_field = 10,
  field_function = 11,
  field_implicit_arguments = 12,
  field_left = 13,
  field_length = 14,
  field_list = 15,
  field_macro = 16,
  field_name = 17,
  field_operator = 18,
  field_parameters = 19,
  field_path = 20,
  field_pattern = 21,
  field_return_type = 22,
  field_right = 23,
  field_type = 24,
  field_type_arguments = 25,
  field_type_parameters = 26,
  field_value = 27,
  field_variant = 28,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_bound] = "bound",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_element] = "element",
  [field_field] = "field",
  [field_function] = "function",
  [field_implicit_arguments] = "implicit_arguments",
  [field_left] = "left",
  [field_length] = "length",
  [field_list] = "list",
  [field_macro] = "macro",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_pattern] = "pattern",
  [field_return_type] = "return_type",
  [field_right] = "right",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_value] = "value",
  [field_variant] = "variant",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 0, .length = 1},
  [4] = {.index = 1, .length = 1},
  [5] = {.index = 2, .length = 1},
  [6] = {.index = 3, .length = 2},
  [7] = {.index = 3, .length = 2},
  [8] = {.index = 5, .length = 2},
  [9] = {.index = 7, .length = 2},
  [10] = {.index = 9, .length = 2},
  [11] = {.index = 9, .length = 2},
  [12] = {.index = 11, .length = 2},
  [13] = {.index = 13, .length = 2},
  [14] = {.index = 13, .length = 2},
  [15] = {.index = 15, .length = 1},
  [16] = {.index = 13, .length = 2},
  [17] = {.index = 16, .length = 1},
  [18] = {.index = 17, .length = 1},
  [19] = {.index = 18, .length = 2},
  [20] = {.index = 18, .length = 2},
  [21] = {.index = 20, .length = 1},
  [22] = {.index = 18, .length = 2},
  [23] = {.index = 18, .length = 2},
  [24] = {.index = 21, .length = 2},
  [25] = {.index = 23, .length = 2},
  [26] = {.index = 25, .length = 2},
  [27] = {.index = 27, .length = 2},
  [28] = {.index = 29, .length = 2},
  [29] = {.index = 31, .length = 1},
  [30] = {.index = 20, .length = 1},
  [31] = {.index = 21, .length = 2},
  [32] = {.index = 32, .length = 2},
  [33] = {.index = 18, .length = 2},
  [34] = {.index = 18, .length = 2},
  [35] = {.index = 21, .length = 2},
  [36] = {.index = 34, .length = 2},
  [37] = {.index = 36, .length = 3},
  [38] = {.index = 39, .length = 2},
  [39] = {.index = 39, .length = 2},
  [42] = {.index = 41, .length = 1},
  [43] = {.index = 42, .length = 2},
  [44] = {.index = 44, .length = 3},
  [45] = {.index = 47, .length = 2},
  [46] = {.index = 49, .length = 1},
  [47] = {.index = 49, .length = 1},
  [48] = {.index = 50, .length = 1},
  [49] = {.index = 51, .length = 3},
  [50] = {.index = 54, .length = 3},
  [53] = {.index = 57, .length = 1},
  [54] = {.index = 58, .length = 1},
  [55] = {.index = 57, .length = 1},
  [56] = {.index = 59, .length = 1},
  [57] = {.index = 57, .length = 1},
  [58] = {.index = 60, .length = 2},
  [59] = {.index = 62, .length = 2},
  [60] = {.index = 60, .length = 2},
  [61] = {.index = 62, .length = 2},
  [62] = {.index = 64, .length = 2},
  [63] = {.index = 66, .length = 3},
  [64] = {.index = 69, .length = 1},
  [65] = {.index = 70, .length = 3},
  [66] = {.index = 73, .length = 1},
  [67] = {.index = 74, .length = 2},
  [68] = {.index = 73, .length = 1},
  [69] = {.index = 74, .length = 2},
  [70] = {.index = 76, .length = 1},
  [71] = {.index = 77, .length = 1},
  [72] = {.index = 78, .length = 2},
  [74] = {.index = 80, .length = 3},
  [75] = {.index = 83, .length = 3},
  [76] = {.index = 78, .length = 2},
  [77] = {.index = 31, .length = 1},
  [78] = {.index = 86, .length = 1},
  [79] = {.index = 87, .length = 1},
  [80] = {.index = 88, .length = 3},
  [81] = {.index = 91, .length = 4},
  [82] = {.index = 95, .length = 4},
  [83] = {.index = 0, .length = 1},
  [84] = {.index = 99, .length = 2},
  [85] = {.index = 101, .length = 2},
  [87] = {.index = 103, .length = 3},
  [88] = {.index = 106, .length = 3},
  [89] = {.index = 109, .length = 2},
  [90] = {.index = 109, .length = 2},
  [91] = {.index = 111, .length = 1},
  [92] = {.index = 112, .length = 2},
  [93] = {.index = 114, .length = 3},
  [94] = {.index = 117, .length = 1},
  [96] = {.index = 118, .length = 1},
  [97] = {.index = 119, .length = 2},
  [98] = {.index = 121, .length = 3},
  [99] = {.index = 124, .length = 3},
  [100] = {.index = 127, .length = 4},
  [101] = {.index = 131, .length = 4},
  [102] = {.index = 135, .length = 1},
  [103] = {.index = 136, .length = 2},
  [104] = {.index = 138, .length = 4},
  [105] = {.index = 142, .length = 5},
  [106] = {.index = 147, .length = 4},
  [107] = {.index = 151, .length = 5},
  [108] = {.index = 156, .length = 2},
  [109] = {.index = 158, .length = 2},
  [110] = {.index = 160, .length = 2},
  [111] = {.index = 162, .length = 1},
  [112] = {.index = 163, .length = 2},
  [113] = {.index = 165, .length = 2},
  [114] = {.index = 165, .length = 2},
  [115] = {.index = 167, .length = 1},
  [116] = {.index = 168, .length = 2},
  [117] = {.index = 168, .length = 2},
  [118] = {.index = 170, .length = 2},
  [119] = {.index = 172, .length = 4},
  [120] = {.index = 176, .length = 4},
  [121] = {.index = 180, .length = 5},
  [122] = {.index = 185, .length = 4},
  [123] = {.index = 189, .length = 5},
  [124] = {.index = 194, .length = 3},
  [125] = {.index = 78, .length = 2},
  [126] = {.index = 197, .length = 5},
  [127] = {.index = 202, .length = 5},
  [128] = {.index = 207, .length = 6},
  [129] = {.index = 213, .length = 2},
  [130] = {.index = 215, .length = 3},
  [131] = {.index = 218, .length = 2},
  [132] = {.index = 220, .length = 1},
  [133] = {.index = 221, .length = 2},
  [134] = {.index = 223, .length = 3},
  [135] = {.index = 226, .length = 5},
  [136] = {.index = 231, .length = 5},
  [137] = {.index = 236, .length = 6},
  [138] = {.index = 242, .length = 6},
  [139] = {.index = 248, .length = 6},
  [140] = {.index = 254, .length = 3},
  [141] = {.index = 257, .length = 3},
  [142] = {.index = 260, .length = 6},
  [143] = {.index = 266, .length = 6},
  [144] = {.index = 272, .length = 7},
  [145] = {.index = 279, .length = 7},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 1},
  [1] =
    {field_body, 1},
  [2] =
    {field_value, 1},
  [3] =
    {field_body, 1},
    {field_name, 0},
  [5] =
    {field_arguments, 1},
    {field_function, 0},
  [7] =
    {field_body, 1},
    {field_parameters, 0},
  [9] =
    {field_body, 2},
    {field_name, 1},
  [11] =
    {field_name, 1},
    {field_parameters, 2},
  [13] =
    {field_type, 0},
    {field_type_arguments, 1},
  [15] =
    {field_pattern, 1},
  [16] =
    {field_list, 1},
  [17] =
    {field_argument, 1},
  [18] =
    {field_name, 2},
    {field_path, 0},
  [20] =
    {field_macro, 0},
  [21] =
    {field_type, 0},
    {field_type_arguments, 2},
  [23] =
    {field_condition, 1},
    {field_consequence, 2},
  [25] =
    {field_body, 2},
    {field_value, 1},
  [27] =
    {field_body, 2},
    {field_condition, 1},
  [29] =
    {field_body, 2},
    {field_parameters, 1},
  [31] =
    {field_value, 2},
  [32] =
    {field_function, 0},
    {field_type_arguments, 2},
  [34] =
    {field_left, 0},
    {field_right, 2},
  [36] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [39] =
    {field_field, 2},
    {field_value, 0},
  [41] =
    {field_body, 2},
  [42] =
    {field_name, 1},
    {field_type_parameters, 2},
  [44] =
    {field_body, 3},
    {field_name, 1},
    {field_type_parameters, 2},
  [47] =
    {field_name, 2},
    {field_parameters, 3},
  [49] =
    {field_arguments, 1},
  [50] =
    {field_variant, 0},
  [51] =
    {field_implicit_arguments, 3},
    {field_name, 1},
    {field_parameters, 2},
  [54] =
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [57] =
    {field_type, 0},
  [58] =
    {field_name, 0},
  [59] =
    {field_pattern, 2},
  [60] =
    {field_list, 2},
    {field_path, 0},
  [62] =
    {field_alias, 2},
    {field_path, 0},
  [64] =
    {field_pattern, 0},
    {field_type, 2},
  [66] =
    {field_alternative, 3},
    {field_condition, 1},
    {field_consequence, 2},
  [69] =
    {field_type, 1},
  [70] =
    {field_body, 3},
    {field_parameters, 0},
    {field_return_type, 2},
  [73] =
    {field_name, 2},
  [74] =
    {field_body, 3},
    {field_name, 2},
  [76] =
    {field_argument, 2},
  [77] =
    {field_body, 4},
  [78] =
    {field_name, 1},
    {field_type, 3},
  [80] =
    {field_implicit_arguments, 4},
    {field_name, 2},
    {field_parameters, 3},
  [83] =
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [86] =
    {field_length, 3},
  [87] =
    {field_variant, 1},
  [88] =
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [91] =
    {field_implicit_arguments, 3},
    {field_implicit_arguments, 4},
    {field_name, 1},
    {field_parameters, 2},
  [95] =
    {field_implicit_arguments, 4},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [99] =
    {field_pattern, 1},
    {field_type, 3},
  [101] =
    {field_pattern, 1},
    {field_value, 3},
  [103] =
    {field_body, 4},
    {field_pattern, 1},
    {field_value, 3},
  [106] =
    {field_body, 4},
    {field_parameters, 1},
    {field_return_type, 3},
  [109] =
    {field_field, 0},
    {field_value, 2},
  [111] =
    {field_element, 1},
  [112] =
    {field_name, 2},
    {field_type_parameters, 3},
  [114] =
    {field_body, 4},
    {field_name, 2},
    {field_type_parameters, 3},
  [117] =
    {field_name, 3},
  [118] =
    {field_type_parameters, 2},
  [119] =
    {field_body, 5},
    {field_type_parameters, 2},
  [121] =
    {field_name, 1},
    {field_type, 4},
    {field_type_parameters, 2},
  [124] =
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [127] =
    {field_implicit_arguments, 4},
    {field_implicit_arguments, 5},
    {field_name, 2},
    {field_parameters, 3},
  [131] =
    {field_implicit_arguments, 5},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [135] =
    {field_length, 4},
  [136] =
    {field_name, 0},
    {field_type, 2},
  [138] =
    {field_implicit_arguments, 5},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [142] =
    {field_implicit_arguments, 3},
    {field_implicit_arguments, 4},
    {field_implicit_arguments, 5},
    {field_name, 1},
    {field_parameters, 2},
  [147] =
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [151] =
    {field_implicit_arguments, 4},
    {field_implicit_arguments, 5},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [156] =
    {field_name, 0},
    {field_pattern, 2},
  [158] =
    {field_pattern, 2},
    {field_type, 4},
  [160] =
    {field_pattern, 2},
    {field_value, 4},
  [162] =
    {field_condition, 2},
  [163] =
    {field_pattern, 0},
    {field_value, 2},
  [165] =
    {field_field, 1},
    {field_value, 3},
  [167] =
    {field_body, 5},
  [168] =
    {field_name, 2},
    {field_type, 4},
  [170] =
    {field_name, 3},
    {field_type_parameters, 4},
  [172] =
    {field_bound, 3},
    {field_left, 0},
    {field_left, 1},
    {field_left, 2},
  [176] =
    {field_implicit_arguments, 6},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [180] =
    {field_implicit_arguments, 4},
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_name, 2},
    {field_parameters, 3},
  [185] =
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
  [189] =
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [194] =
    {field_name, 1},
    {field_type, 3},
    {field_value, 5},
  [197] =
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [202] =
    {field_implicit_arguments, 6},
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [207] =
    {field_implicit_arguments, 4},
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [213] =
    {field_name, 1},
    {field_pattern, 3},
  [215] =
    {field_pattern, 1},
    {field_type, 3},
    {field_value, 5},
  [218] =
    {field_element, 1},
    {field_length, 3},
  [220] =
    {field_type_parameters, 3},
  [221] =
    {field_body, 6},
    {field_type_parameters, 3},
  [223] =
    {field_name, 2},
    {field_type, 5},
    {field_type_parameters, 3},
  [226] =
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [231] =
    {field_implicit_arguments, 7},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
  [236] =
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_name, 2},
    {field_parameters, 4},
    {field_type_parameters, 3},
  [242] =
    {field_implicit_arguments, 5},
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_name, 1},
    {field_parameters, 2},
    {field_return_type, 4},
  [248] =
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [254] =
    {field_pattern, 2},
    {field_type, 4},
    {field_value, 6},
  [257] =
    {field_name, 2},
    {field_type, 4},
    {field_value, 6},
  [260] =
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_implicit_arguments, 8},
    {field_name, 2},
    {field_parameters, 3},
    {field_return_type, 5},
  [266] =
    {field_implicit_arguments, 7},
    {field_implicit_arguments, 8},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
  [272] =
    {field_implicit_arguments, 6},
    {field_implicit_arguments, 7},
    {field_implicit_arguments, 8},
    {field_name, 1},
    {field_parameters, 3},
    {field_return_type, 5},
    {field_type_parameters, 2},
  [279] =
    {field_implicit_arguments, 7},
    {field_implicit_arguments, 8},
    {field_implicit_arguments, 9},
    {field_name, 2},
    {field_parameters, 4},
    {field_return_type, 6},
    {field_type_parameters, 3},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_identifier,
  },
  [3] = {
    [1] = alias_sym_type_identifier,
  },
  [6] = {
    [0] = alias_sym_type_identifier,
  },
  [10] = {
    [1] = alias_sym_type_identifier,
  },
  [13] = {
    [0] = sym_identifier,
  },
  [14] = {
    [0] = alias_sym_type_identifier,
  },
  [20] = {
    [2] = alias_sym_type_identifier,
  },
  [21] = {
    [0] = sym_identifier,
  },
  [22] = {
    [0] = sym_identifier,
  },
  [23] = {
    [0] = sym_identifier,
    [2] = alias_sym_type_identifier,
  },
  [24] = {
    [0] = sym_identifier,
  },
  [31] = {
    [0] = alias_sym_type_identifier,
  },
  [33] = {
    [0] = sym_generic_type,
  },
  [34] = {
    [0] = sym_generic_type,
    [2] = alias_sym_type_identifier,
  },
  [39] = {
    [2] = alias_sym_field_identifier,
  },
  [40] = {
    [0] = alias_sym_primitive_type,
  },
  [41] = {
    [0] = alias_sym_type_identifier,
  },
  [43] = {
    [1] = alias_sym_type_identifier,
  },
  [44] = {
    [1] = alias_sym_type_identifier,
  },
  [47] = {
    [0] = sym_identifier,
  },
  [51] = {
    [2] = sym_identifier,
  },
  [52] = {
    [0] = sym_identifier,
    [2] = sym_identifier,
  },
  [53] = {
    [0] = alias_sym_type_identifier,
  },
  [54] = {
    [0] = alias_sym_shorthand_field_identifier,
  },
  [57] = {
    [0] = sym_generic_type,
  },
  [60] = {
    [0] = sym_identifier,
  },
  [61] = {
    [0] = sym_identifier,
  },
  [66] = {
    [2] = alias_sym_type_identifier,
  },
  [67] = {
    [2] = alias_sym_type_identifier,
  },
  [72] = {
    [1] = alias_sym_type_identifier,
  },
  [73] = {
    [1] = alias_sym_type_identifier,
  },
  [77] = {
    [0] = sym_identifier,
  },
  [83] = {
    [1] = alias_sym_shorthand_field_identifier,
  },
  [86] = {
    [3] = sym_identifier,
  },
  [90] = {
    [0] = alias_sym_field_identifier,
  },
  [92] = {
    [2] = alias_sym_type_identifier,
  },
  [93] = {
    [2] = alias_sym_type_identifier,
  },
  [94] = {
    [3] = alias_sym_type_identifier,
  },
  [95] = {
    [2] = alias_sym_type_identifier,
  },
  [98] = {
    [1] = alias_sym_type_identifier,
  },
  [103] = {
    [0] = alias_sym_field_identifier,
  },
  [108] = {
    [0] = alias_sym_field_identifier,
  },
  [114] = {
    [1] = alias_sym_field_identifier,
  },
  [116] = {
    [2] = alias_sym_type_identifier,
  },
  [118] = {
    [3] = alias_sym_type_identifier,
  },
  [119] = {
    [1] = alias_sym_type_identifier,
  },
  [125] = {
    [1] = alias_sym_field_identifier,
  },
  [129] = {
    [1] = alias_sym_field_identifier,
  },
  [134] = {
    [2] = alias_sym_type_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_generic_type_with_turbofish, 2,
    sym_generic_type_with_turbofish,
    sym_generic_type,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 3,
  [6] = 6,
  [7] = 2,
  [8] = 3,
  [9] = 6,
  [10] = 2,
  [11] = 3,
  [12] = 2,
  [13] = 3,
  [14] = 2,
  [15] = 3,
  [16] = 2,
  [17] = 3,
  [18] = 2,
  [19] = 3,
  [20] = 2,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 23,
  [25] = 25,
  [26] = 25,
  [27] = 23,
  [28] = 22,
  [29] = 21,
  [30] = 23,
  [31] = 25,
  [32] = 25,
  [33] = 25,
  [34] = 22,
  [35] = 21,
  [36] = 25,
  [37] = 23,
  [38] = 23,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 41,
  [45] = 45,
  [46] = 46,
  [47] = 40,
  [48] = 42,
  [49] = 43,
  [50] = 41,
  [51] = 46,
  [52] = 40,
  [53] = 45,
  [54] = 46,
  [55] = 40,
  [56] = 42,
  [57] = 43,
  [58] = 41,
  [59] = 45,
  [60] = 46,
  [61] = 40,
  [62] = 42,
  [63] = 43,
  [64] = 41,
  [65] = 45,
  [66] = 46,
  [67] = 40,
  [68] = 42,
  [69] = 43,
  [70] = 41,
  [71] = 45,
  [72] = 46,
  [73] = 42,
  [74] = 43,
  [75] = 45,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 86,
  [88] = 88,
  [89] = 89,
  [90] = 89,
  [91] = 91,
  [92] = 88,
  [93] = 91,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 95,
  [100] = 97,
  [101] = 101,
  [102] = 94,
  [103] = 96,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 104,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 110,
  [113] = 82,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 111,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 105,
  [124] = 124,
  [125] = 125,
  [126] = 109,
  [127] = 127,
  [128] = 128,
  [129] = 81,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 132,
  [136] = 133,
  [137] = 137,
  [138] = 132,
  [139] = 133,
  [140] = 132,
  [141] = 130,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 143,
  [147] = 147,
  [148] = 147,
  [149] = 147,
  [150] = 127,
  [151] = 144,
  [152] = 152,
  [153] = 124,
  [154] = 122,
  [155] = 155,
  [156] = 156,
  [157] = 145,
  [158] = 156,
  [159] = 143,
  [160] = 143,
  [161] = 155,
  [162] = 147,
  [163] = 163,
  [164] = 163,
  [165] = 165,
  [166] = 166,
  [167] = 163,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 172,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 166,
  [198] = 198,
  [199] = 179,
  [200] = 185,
  [201] = 188,
  [202] = 193,
  [203] = 194,
  [204] = 195,
  [205] = 196,
  [206] = 198,
  [207] = 168,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 208,
  [212] = 209,
  [213] = 173,
  [214] = 210,
  [215] = 179,
  [216] = 185,
  [217] = 188,
  [218] = 193,
  [219] = 194,
  [220] = 195,
  [221] = 196,
  [222] = 198,
  [223] = 168,
  [224] = 208,
  [225] = 209,
  [226] = 210,
  [227] = 227,
  [228] = 228,
  [229] = 172,
  [230] = 230,
  [231] = 228,
  [232] = 228,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 233,
  [238] = 187,
  [239] = 227,
  [240] = 230,
  [241] = 234,
  [242] = 170,
  [243] = 171,
  [244] = 177,
  [245] = 178,
  [246] = 183,
  [247] = 184,
  [248] = 189,
  [249] = 233,
  [250] = 234,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 115,
  [256] = 256,
  [257] = 124,
  [258] = 122,
  [259] = 81,
  [260] = 125,
  [261] = 82,
  [262] = 127,
  [263] = 124,
  [264] = 122,
  [265] = 127,
  [266] = 131,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 124,
  [351] = 122,
  [352] = 127,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 353,
  [357] = 357,
  [358] = 355,
  [359] = 359,
  [360] = 127,
  [361] = 361,
  [362] = 361,
  [363] = 363,
  [364] = 364,
  [365] = 361,
  [366] = 124,
  [367] = 120,
  [368] = 121,
  [369] = 106,
  [370] = 108,
  [371] = 117,
  [372] = 114,
  [373] = 116,
  [374] = 119,
  [375] = 122,
  [376] = 128,
  [377] = 377,
  [378] = 377,
  [379] = 379,
  [380] = 380,
  [381] = 377,
  [382] = 382,
  [383] = 382,
  [384] = 382,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 389,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 391,
  [395] = 395,
  [396] = 392,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 403,
  [406] = 402,
  [407] = 404,
  [408] = 408,
  [409] = 409,
  [410] = 326,
  [411] = 411,
  [412] = 412,
  [413] = 411,
  [414] = 414,
  [415] = 408,
  [416] = 414,
  [417] = 409,
  [418] = 418,
  [419] = 412,
  [420] = 418,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 421,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 425,
  [430] = 426,
  [431] = 425,
  [432] = 426,
  [433] = 433,
  [434] = 433,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 422,
  [439] = 439,
  [440] = 436,
  [441] = 427,
  [442] = 423,
  [443] = 433,
  [444] = 421,
  [445] = 428,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 448,
  [450] = 450,
  [451] = 450,
  [452] = 448,
  [453] = 450,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 455,
  [458] = 455,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 131,
  [473] = 473,
  [474] = 474,
  [475] = 122,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 124,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 127,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 80,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 78,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 79,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 539,
  [540] = 459,
  [541] = 541,
  [542] = 542,
  [543] = 543,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 299,
  [558] = 289,
  [559] = 290,
  [560] = 291,
  [561] = 292,
  [562] = 293,
  [563] = 473,
  [564] = 294,
  [565] = 295,
  [566] = 296,
  [567] = 297,
  [568] = 321,
  [569] = 298,
  [570] = 325,
  [571] = 283,
  [572] = 302,
  [573] = 303,
  [574] = 304,
  [575] = 305,
  [576] = 327,
  [577] = 467,
  [578] = 461,
  [579] = 469,
  [580] = 328,
  [581] = 471,
  [582] = 582,
  [583] = 329,
  [584] = 331,
  [585] = 333,
  [586] = 470,
  [587] = 306,
  [588] = 335,
  [589] = 307,
  [590] = 336,
  [591] = 308,
  [592] = 347,
  [593] = 312,
  [594] = 314,
  [595] = 317,
  [596] = 318,
  [597] = 337,
  [598] = 338,
  [599] = 339,
  [600] = 341,
  [601] = 284,
  [602] = 309,
  [603] = 272,
  [604] = 311,
  [605] = 313,
  [606] = 315,
  [607] = 316,
  [608] = 267,
  [609] = 268,
  [610] = 269,
  [611] = 270,
  [612] = 271,
  [613] = 273,
  [614] = 274,
  [615] = 275,
  [616] = 276,
  [617] = 326,
  [618] = 277,
  [619] = 278,
  [620] = 320,
  [621] = 300,
  [622] = 279,
  [623] = 285,
  [624] = 322,
  [625] = 330,
  [626] = 332,
  [627] = 334,
  [628] = 343,
  [629] = 344,
  [630] = 345,
  [631] = 346,
  [632] = 459,
  [633] = 310,
  [634] = 323,
  [635] = 286,
  [636] = 280,
  [637] = 281,
  [638] = 282,
  [639] = 324,
  [640] = 287,
  [641] = 301,
  [642] = 288,
  [643] = 342,
  [644] = 644,
  [645] = 474,
  [646] = 646,
  [647] = 461,
  [648] = 465,
  [649] = 484,
  [650] = 650,
  [651] = 466,
  [652] = 473,
  [653] = 650,
  [654] = 469,
  [655] = 471,
  [656] = 656,
  [657] = 474,
  [658] = 470,
  [659] = 659,
  [660] = 467,
  [661] = 464,
  [662] = 646,
  [663] = 663,
  [664] = 131,
  [665] = 665,
  [666] = 463,
  [667] = 462,
  [668] = 668,
  [669] = 460,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 671,
  [674] = 476,
  [675] = 468,
  [676] = 676,
  [677] = 659,
  [678] = 479,
  [679] = 676,
  [680] = 484,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 522,
  [700] = 478,
  [701] = 477,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 681,
  [706] = 476,
  [707] = 479,
  [708] = 480,
  [709] = 483,
  [710] = 695,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 695,
  [722] = 122,
  [723] = 127,
  [724] = 326,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 693,
  [729] = 695,
  [730] = 711,
  [731] = 720,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 522,
  [736] = 736,
  [737] = 713,
  [738] = 714,
  [739] = 715,
  [740] = 719,
  [741] = 736,
  [742] = 682,
  [743] = 689,
  [744] = 694,
  [745] = 703,
  [746] = 704,
  [747] = 717,
  [748] = 718,
  [749] = 725,
  [750] = 726,
  [751] = 727,
  [752] = 683,
  [753] = 684,
  [754] = 691,
  [755] = 695,
  [756] = 124,
  [757] = 556,
  [758] = 758,
  [759] = 505,
  [760] = 498,
  [761] = 504,
  [762] = 515,
  [763] = 486,
  [764] = 533,
  [765] = 529,
  [766] = 542,
  [767] = 553,
  [768] = 128,
  [769] = 555,
  [770] = 521,
  [771] = 524,
  [772] = 506,
  [773] = 773,
  [774] = 774,
  [775] = 492,
  [776] = 499,
  [777] = 500,
  [778] = 556,
  [779] = 538,
  [780] = 489,
  [781] = 120,
  [782] = 121,
  [783] = 511,
  [784] = 554,
  [785] = 513,
  [786] = 514,
  [787] = 787,
  [788] = 788,
  [789] = 541,
  [790] = 519,
  [791] = 543,
  [792] = 544,
  [793] = 545,
  [794] = 546,
  [795] = 547,
  [796] = 548,
  [797] = 549,
  [798] = 550,
  [799] = 551,
  [800] = 552,
  [801] = 523,
  [802] = 526,
  [803] = 490,
  [804] = 518,
  [805] = 106,
  [806] = 108,
  [807] = 535,
  [808] = 520,
  [809] = 530,
  [810] = 507,
  [811] = 811,
  [812] = 509,
  [813] = 512,
  [814] = 814,
  [815] = 517,
  [816] = 114,
  [817] = 116,
  [818] = 117,
  [819] = 531,
  [820] = 537,
  [821] = 496,
  [822] = 487,
  [823] = 488,
  [824] = 493,
  [825] = 119,
  [826] = 501,
  [827] = 502,
  [828] = 528,
  [829] = 495,
  [830] = 503,
  [831] = 831,
  [832] = 832,
  [833] = 554,
  [834] = 541,
  [835] = 543,
  [836] = 544,
  [837] = 545,
  [838] = 546,
  [839] = 547,
  [840] = 548,
  [841] = 549,
  [842] = 550,
  [843] = 551,
  [844] = 552,
  [845] = 299,
  [846] = 78,
  [847] = 556,
  [848] = 848,
  [849] = 554,
  [850] = 850,
  [851] = 79,
  [852] = 80,
  [853] = 853,
  [854] = 326,
  [855] = 855,
  [856] = 856,
  [857] = 831,
  [858] = 858,
  [859] = 542,
  [860] = 553,
  [861] = 788,
  [862] = 555,
  [863] = 811,
  [864] = 864,
  [865] = 865,
  [866] = 832,
  [867] = 848,
  [868] = 868,
  [869] = 869,
  [870] = 855,
  [871] = 831,
  [872] = 788,
  [873] = 811,
  [874] = 874,
  [875] = 848,
  [876] = 831,
  [877] = 811,
  [878] = 831,
  [879] = 811,
  [880] = 831,
  [881] = 811,
  [882] = 831,
  [883] = 811,
  [884] = 831,
  [885] = 811,
  [886] = 886,
  [887] = 858,
  [888] = 888,
  [889] = 869,
  [890] = 890,
  [891] = 539,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 893,
  [897] = 897,
  [898] = 895,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 892,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 906,
  [910] = 910,
  [911] = 894,
  [912] = 912,
  [913] = 908,
  [914] = 914,
  [915] = 914,
  [916] = 916,
  [917] = 910,
  [918] = 918,
  [919] = 919,
  [920] = 899,
  [921] = 905,
  [922] = 919,
  [923] = 900,
  [924] = 924,
  [925] = 918,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 930,
  [932] = 929,
  [933] = 401,
  [934] = 326,
  [935] = 935,
  [936] = 936,
  [937] = 936,
  [938] = 936,
  [939] = 936,
  [940] = 936,
  [941] = 936,
  [942] = 942,
  [943] = 942,
  [944] = 936,
  [945] = 936,
  [946] = 942,
  [947] = 947,
  [948] = 947,
  [949] = 949,
  [950] = 950,
  [951] = 464,
  [952] = 952,
  [953] = 462,
  [954] = 949,
  [955] = 955,
  [956] = 950,
  [957] = 957,
  [958] = 463,
  [959] = 460,
  [960] = 952,
  [961] = 955,
  [962] = 962,
  [963] = 82,
  [964] = 115,
  [965] = 125,
  [966] = 966,
  [967] = 81,
  [968] = 968,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 979,
  [980] = 950,
  [981] = 981,
  [982] = 955,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 952,
  [987] = 979,
  [988] = 949,
  [989] = 949,
  [990] = 990,
  [991] = 950,
  [992] = 952,
  [993] = 993,
  [994] = 994,
  [995] = 955,
  [996] = 79,
  [997] = 997,
  [998] = 998,
  [999] = 997,
  [1000] = 85,
  [1001] = 80,
  [1002] = 1002,
  [1003] = 998,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1013,
  [1015] = 1015,
  [1016] = 957,
  [1017] = 1017,
  [1018] = 997,
  [1019] = 1010,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1022,
  [1026] = 1026,
  [1027] = 1015,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 468,
  [1033] = 1033,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 465,
  [1037] = 466,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 957,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 949,
  [1048] = 955,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1054,
  [1057] = 1057,
  [1058] = 1039,
  [1059] = 1059,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1010,
  [1068] = 1068,
  [1069] = 1069,
  [1070] = 1033,
  [1071] = 1071,
  [1072] = 950,
  [1073] = 952,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1040,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 971,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 971,
  [1086] = 1083,
  [1087] = 1081,
  [1088] = 1084,
  [1089] = 1028,
  [1090] = 1080,
  [1091] = 971,
  [1092] = 971,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 990,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 464,
  [1102] = 990,
  [1103] = 463,
  [1104] = 462,
  [1105] = 971,
  [1106] = 460,
  [1107] = 1099,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 990,
  [1112] = 1112,
  [1113] = 990,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1114,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 990,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1010,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1146,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1011,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1114,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1142,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1157,
  [1175] = 1175,
  [1176] = 401,
  [1177] = 1177,
  [1178] = 1148,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 401,
  [1182] = 1143,
  [1183] = 1173,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1010,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1187,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1199,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1005,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1209,
  [1210] = 1020,
  [1211] = 1211,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1021,
  [1216] = 1006,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1008,
  [1221] = 1009,
  [1222] = 1218,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1012,
  [1227] = 1227,
  [1228] = 1007,
  [1229] = 1030,
  [1230] = 1026,
  [1231] = 79,
  [1232] = 1232,
  [1233] = 1017,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 80,
  [1240] = 1193,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1243,
  [1246] = 1202,
  [1247] = 1193,
  [1248] = 1195,
  [1249] = 1197,
  [1250] = 1203,
  [1251] = 1251,
  [1252] = 1252,
  [1253] = 1195,
  [1254] = 1218,
  [1255] = 1255,
  [1256] = 1028,
  [1257] = 1241,
  [1258] = 1244,
  [1259] = 1193,
  [1260] = 1195,
  [1261] = 1197,
  [1262] = 1262,
  [1263] = 1207,
  [1264] = 1241,
  [1265] = 1212,
  [1266] = 1208,
  [1267] = 1194,
  [1268] = 1241,
  [1269] = 1244,
  [1270] = 1193,
  [1271] = 1195,
  [1272] = 1197,
  [1273] = 1213,
  [1274] = 1209,
  [1275] = 1200,
  [1276] = 1193,
  [1277] = 1195,
  [1278] = 1197,
  [1279] = 1196,
  [1280] = 1280,
  [1281] = 1281,
  [1282] = 1282,
  [1283] = 1193,
  [1284] = 1195,
  [1285] = 1197,
  [1286] = 1193,
  [1287] = 1195,
  [1288] = 1197,
  [1289] = 1242,
  [1290] = 1198,
  [1291] = 1235,
  [1292] = 1011,
  [1293] = 1224,
  [1294] = 1294,
  [1295] = 1207,
  [1296] = 1208,
  [1297] = 1204,
  [1298] = 1232,
  [1299] = 1203,
  [1300] = 85,
  [1301] = 1206,
  [1302] = 1197,
  [1303] = 1209,
  [1304] = 1218,
  [1305] = 1241,
  [1306] = 1227,
  [1307] = 1234,
  [1308] = 1242,
  [1309] = 1193,
  [1310] = 1195,
  [1311] = 1197,
  [1312] = 1203,
  [1313] = 1313,
  [1314] = 1244,
  [1315] = 1243,
  [1316] = 1192,
  [1317] = 1202,
  [1318] = 1192,
  [1319] = 1294,
  [1320] = 1244,
  [1321] = 1236,
  [1322] = 1199,
  [1323] = 1238,
  [1324] = 1217,
  [1325] = 1203,
  [1326] = 1326,
  [1327] = 1194,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 115,
  [1334] = 125,
  [1335] = 1335,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 81,
  [1343] = 82,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 326,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1030,
  [1360] = 1061,
  [1361] = 1063,
  [1362] = 1034,
  [1363] = 1038,
  [1364] = 1050,
  [1365] = 1365,
  [1366] = 1062,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1335,
  [1372] = 1372,
  [1373] = 1354,
  [1374] = 1374,
  [1375] = 1375,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1340,
  [1385] = 972,
  [1386] = 1326,
  [1387] = 1382,
  [1388] = 1388,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1358,
  [1393] = 1332,
  [1394] = 1355,
  [1395] = 1388,
  [1396] = 1396,
  [1397] = 1396,
  [1398] = 1398,
  [1399] = 1399,
  [1400] = 1400,
  [1401] = 1052,
  [1402] = 1060,
  [1403] = 1403,
  [1404] = 1068,
  [1405] = 1065,
  [1406] = 1337,
  [1407] = 1057,
  [1408] = 1345,
  [1409] = 1069,
  [1410] = 1347,
  [1411] = 1350,
  [1412] = 1357,
  [1413] = 1370,
  [1414] = 1377,
  [1415] = 1415,
  [1416] = 1059,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 1423,
  [1424] = 1031,
  [1425] = 1425,
  [1426] = 1041,
  [1427] = 1427,
  [1428] = 1428,
  [1429] = 1429,
  [1430] = 1415,
  [1431] = 1431,
  [1432] = 1381,
  [1433] = 1433,
  [1434] = 1374,
  [1435] = 1348,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 974,
  [1439] = 1390,
  [1440] = 1440,
  [1441] = 973,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1440,
  [1446] = 1328,
  [1447] = 1043,
  [1448] = 1448,
  [1449] = 1449,
  [1450] = 1450,
  [1451] = 1045,
  [1452] = 1051,
  [1453] = 1398,
  [1454] = 1077,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1398,
  [1459] = 1418,
  [1460] = 1399,
  [1461] = 1425,
  [1462] = 1419,
  [1463] = 1463,
  [1464] = 1055,
  [1465] = 1420,
  [1466] = 1466,
  [1467] = 1421,
  [1468] = 1468,
  [1469] = 1422,
  [1470] = 1391,
  [1471] = 1029,
  [1472] = 1472,
  [1473] = 966,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1400,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1480,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1049,
  [1486] = 1436,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1437,
  [1491] = 976,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1352,
  [1495] = 1425,
  [1496] = 1352,
  [1497] = 1066,
  [1498] = 1351,
  [1499] = 1499,
  [1500] = 1344,
  [1501] = 1071,
  [1502] = 1349,
  [1503] = 1427,
  [1504] = 1369,
  [1505] = 1064,
  [1506] = 1042,
  [1507] = 1507,
  [1508] = 1429,
  [1509] = 1075,
  [1510] = 970,
  [1511] = 969,
  [1512] = 1512,
  [1513] = 975,
  [1514] = 1514,
  [1515] = 1431,
  [1516] = 968,
  [1517] = 1517,
  [1518] = 1518,
  [1519] = 1074,
  [1520] = 1368,
  [1521] = 1521,
  [1522] = 1522,
  [1523] = 1380,
  [1524] = 962,
  [1525] = 1433,
  [1526] = 1526,
  [1527] = 1046,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1530,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 326,
  [1535] = 1141,
  [1536] = 1536,
  [1537] = 1204,
  [1538] = 1538,
  [1539] = 1336,
  [1540] = 1053,
  [1541] = 978,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 1546,
  [1547] = 1547,
  [1548] = 1548,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1551,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 1554,
  [1555] = 1548,
  [1556] = 1556,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 1564,
  [1565] = 1565,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1569,
  [1570] = 1570,
  [1571] = 1571,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 983,
  [1577] = 1577,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 981,
  [1583] = 1583,
  [1584] = 1545,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1563,
  [1588] = 1588,
  [1589] = 1546,
  [1590] = 1559,
  [1591] = 1591,
  [1592] = 1580,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 994,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1546,
  [1600] = 1547,
  [1601] = 1563,
  [1602] = 1567,
  [1603] = 1572,
  [1604] = 1604,
  [1605] = 1002,
  [1606] = 1578,
  [1607] = 1607,
  [1608] = 1545,
  [1609] = 115,
  [1610] = 1610,
  [1611] = 1559,
  [1612] = 1612,
  [1613] = 1579,
  [1614] = 984,
  [1615] = 985,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1549,
  [1623] = 1623,
  [1624] = 125,
  [1625] = 1625,
  [1626] = 1547,
  [1627] = 1627,
  [1628] = 1563,
  [1629] = 1629,
  [1630] = 1578,
  [1631] = 1631,
  [1632] = 1632,
  [1633] = 1579,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1616,
  [1637] = 78,
  [1638] = 1604,
  [1639] = 972,
  [1640] = 1621,
  [1641] = 1641,
  [1642] = 1550,
  [1643] = 1579,
  [1644] = 1544,
  [1645] = 1563,
  [1646] = 1646,
  [1647] = 1597,
  [1648] = 1579,
  [1649] = 1616,
  [1650] = 1560,
  [1651] = 1651,
  [1652] = 1616,
  [1653] = 1578,
  [1654] = 1654,
  [1655] = 1655,
  [1656] = 1656,
  [1657] = 1563,
  [1658] = 1658,
  [1659] = 1579,
  [1660] = 1660,
  [1661] = 1551,
  [1662] = 1616,
  [1663] = 1552,
  [1664] = 1664,
  [1665] = 1618,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1572,
  [1669] = 1563,
  [1670] = 1579,
  [1671] = 1610,
  [1672] = 1616,
  [1673] = 1673,
  [1674] = 1616,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 993,
  [1678] = 1620,
  [1679] = 1679,
  [1680] = 977,
  [1681] = 1681,
  [1682] = 1567,
  [1683] = 1623,
  [1684] = 1684,
  [1685] = 1553,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1568,
  [1690] = 1621,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 81,
  [1694] = 1570,
  [1695] = 1695,
  [1696] = 82,
  [1697] = 1697,
  [1698] = 1567,
  [1699] = 1542,
  [1700] = 1612,
  [1701] = 1687,
  [1702] = 1568,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1686,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1547,
  [1709] = 1709,
  [1710] = 973,
  [1711] = 1621,
  [1712] = 1712,
  [1713] = 1558,
  [1714] = 1621,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 1567,
  [1719] = 1719,
  [1720] = 1720,
  [1721] = 1618,
  [1722] = 1598,
  [1723] = 1598,
  [1724] = 1724,
  [1725] = 1567,
  [1726] = 1581,
  [1727] = 1727,
  [1728] = 1593,
  [1729] = 1729,
  [1730] = 1730,
  [1731] = 1595,
  [1732] = 1635,
  [1733] = 1219,
  [1734] = 1577,
  [1735] = 1735,
  [1736] = 1557,
  [1737] = 1593,
  [1738] = 1595,
  [1739] = 1727,
  [1740] = 1740,
  [1741] = 1620,
  [1742] = 1742,
  [1743] = 1743,
  [1744] = 1744,
  [1745] = 1745,
  [1746] = 1746,
  [1747] = 1747,
  [1748] = 1748,
  [1749] = 1749,
  [1750] = 1745,
  [1751] = 1751,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1754,
  [1755] = 1755,
  [1756] = 1756,
  [1757] = 1757,
  [1758] = 1758,
  [1759] = 1759,
  [1760] = 1745,
  [1761] = 1749,
  [1762] = 1762,
  [1763] = 1763,
  [1764] = 1764,
  [1765] = 1765,
  [1766] = 1748,
  [1767] = 1767,
  [1768] = 1768,
  [1769] = 1769,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1772,
  [1773] = 1765,
  [1774] = 1768,
  [1775] = 1747,
  [1776] = 1776,
  [1777] = 1777,
  [1778] = 1778,
  [1779] = 1779,
  [1780] = 1780,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1785,
  [1786] = 1786,
  [1787] = 1787,
  [1788] = 1788,
  [1789] = 1789,
  [1790] = 1790,
  [1791] = 1747,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1794,
  [1795] = 1795,
  [1796] = 1790,
  [1797] = 1797,
  [1798] = 1751,
  [1799] = 1783,
  [1800] = 1800,
  [1801] = 1794,
  [1802] = 1797,
  [1803] = 1803,
  [1804] = 1762,
  [1805] = 1800,
  [1806] = 1745,
  [1807] = 1745,
  [1808] = 1769,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1777,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1755,
  [1815] = 1815,
  [1816] = 1816,
  [1817] = 1746,
  [1818] = 1769,
  [1819] = 1786,
  [1820] = 1820,
  [1821] = 1821,
  [1822] = 1758,
  [1823] = 1784,
  [1824] = 1824,
  [1825] = 1825,
  [1826] = 1751,
  [1827] = 1744,
  [1828] = 1747,
  [1829] = 1788,
  [1830] = 1825,
  [1831] = 1831,
  [1832] = 1781,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1757,
  [1837] = 1795,
  [1838] = 1820,
  [1839] = 1784,
  [1840] = 1840,
  [1841] = 1841,
  [1842] = 1821,
  [1843] = 1843,
  [1844] = 1844,
  [1845] = 1845,
  [1846] = 1846,
  [1847] = 1803,
  [1848] = 1841,
  [1849] = 1004,
  [1850] = 1813,
  [1851] = 1745,
  [1852] = 1852,
  [1853] = 1776,
  [1854] = 1777,
  [1855] = 1855,
  [1856] = 1856,
  [1857] = 1024,
  [1858] = 1858,
  [1859] = 1789,
  [1860] = 1776,
  [1861] = 1846,
  [1862] = 1862,
  [1863] = 1863,
  [1864] = 1803,
  [1865] = 1844,
  [1866] = 1866,
  [1867] = 1776,
  [1868] = 1759,
  [1869] = 1767,
  [1870] = 1831,
  [1871] = 1871,
  [1872] = 1776,
  [1873] = 1873,
  [1874] = 1874,
  [1875] = 1770,
  [1876] = 1023,
  [1877] = 1803,
  [1878] = 1745,
  [1879] = 1879,
  [1880] = 1873,
  [1881] = 1881,
  [1882] = 1882,
  [1883] = 1883,
  [1884] = 1879,
  [1885] = 1745,
  [1886] = 1764,
  [1887] = 1803,
  [1888] = 1779,
  [1889] = 1824,
  [1890] = 1890,
  [1891] = 1845,
  [1892] = 1793,
  [1893] = 1873,
  [1894] = 1881,
  [1895] = 1895,
  [1896] = 1881,
  [1897] = 1881,
  [1898] = 1883,
  [1899] = 1874,
  [1900] = 1789,
  [1901] = 1833,
  [1902] = 1902,
  [1903] = 1771,
  [1904] = 1810,
  [1905] = 1871,
  [1906] = 1881,
  [1907] = 1772,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(257);
      ADVANCE_MAP(
        '!', 276,
        '"', 418,
        '#', 277,
        '$', 425,
        '%', 342,
        '&', 347,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 339,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 426,
        '=', 274,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 214,
        '[', 278,
        ']', 279,
        '^', 344,
        '_', 300,
        'a', 187,
        'b', 25,
        'c', 24,
        'd', 129,
        'e', 155,
        'f', 100,
        'i', 69,
        'l', 130,
        'm', 105,
        'n', 171,
        'o', 137,
        'p', 208,
        'r', 116,
        's', 192,
        't', 180,
        'u', 70,
        'w', 141,
        '{', 258,
        '|', 349,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(253);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '#', 277,
        '$', 425,
        '%', 342,
        '&', 347,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 339,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 332,
        '=', 274,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '^', 344,
        '_', 301,
        'b', 435,
        'c', 437,
        'd', 490,
        'e', 540,
        'f', 469,
        'i', 440,
        'l', 504,
        'm', 479,
        'n', 551,
        'p', 588,
        'r', 511,
        's', 578,
        't', 558,
        'u', 445,
        'w', 516,
        '{', 258,
        '|', 349,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '^', 343,
        '_', 411,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 478,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 350,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        '*', 298,
        '+', 336,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        '<', 332,
        '=', 274,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 598,
        '[', 278,
        '^', 343,
        '_', 411,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 478,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 350,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 276,
        '%', 342,
        '&', 346,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        ';', 263,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        '[', 278,
        ']', 279,
        '^', 343,
        'a', 187,
        'e', 154,
        'i', 164,
        'n', 171,
        '{', 258,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(401);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '#', 277,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 297,
        ',', 286,
        '-', 337,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 331,
        '=', 272,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '_', 411,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 478,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 348,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '\'', 30,
        '(', 299,
        '*', 297,
        '-', 337,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 411,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 504,
        'm', 478,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 348,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '\'', 30,
        '(', 299,
        '*', 297,
        '-', 337,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 411,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 477,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 348,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '\'', 30,
        '(', 299,
        '*', 297,
        '-', 340,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 301,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 478,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 348,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '\'', 30,
        '(', 299,
        '*', 297,
        '-', 340,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 301,
        'b', 435,
        'c', 438,
        'd', 490,
        'f', 470,
        'i', 441,
        'l', 548,
        'm', 477,
        'r', 491,
        's', 590,
        't', 567,
        'u', 446,
        'w', 516,
        '{', 258,
        '|', 348,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 275,
        '(', 299,
        ')', 302,
        ',', 286,
        '-', 97,
        '.', 66,
        '/', 67,
        ':', 269,
        ';', 263,
        '<', 426,
        '=', 272,
        '>', 333,
        '[', 278,
        ']', 279,
        'i', 165,
        'n', 171,
        'o', 137,
        '{', 258,
        '|', 348,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 275,
        '(', 299,
        ')', 302,
        ',', 286,
        '.', 66,
        '/', 67,
        ':', 269,
        ';', 263,
        '<', 426,
        '=', 272,
        '>', 333,
        '[', 278,
        ']', 279,
        '{', 258,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 275,
        '(', 299,
        ',', 286,
        '.', 66,
        '/', 67,
        ':', 95,
        ';', 263,
        '<', 426,
        '=', 98,
        ']', 279,
        'i', 136,
        '{', 258,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 96,
        '"', 418,
        '#', 277,
        '%', 342,
        '&', 346,
        '(', 299,
        '*', 298,
        '+', 336,
        '-', 338,
        '.', 369,
        '/', 341,
        ':', 95,
        ';', 263,
        '<', 332,
        '=', 274,
        '>', 334,
        '?', 371,
        'B', 598,
        '[', 278,
        '^', 343,
        'b', 545,
        'c', 552,
        'd', 490,
        'e', 540,
        'f', 507,
        'i', 442,
        'l', 505,
        'm', 547,
        'p', 588,
        's', 580,
        't', 565,
        'u', 445,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 96,
        '"', 413,
        '#', 277,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        'B', 598,
        '[', 278,
        '^', 343,
        '_', 301,
        'b', 436,
        'c', 439,
        'd', 490,
        'e', 533,
        'f', 471,
        'i', 444,
        'm', 594,
        's', 590,
        't', 567,
        'u', 446,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 96,
        '"', 413,
        '#', 277,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        'B', 598,
        '[', 278,
        '^', 343,
        '_', 301,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 444,
        'm', 594,
        's', 590,
        't', 567,
        'u', 446,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 96,
        '#', 277,
        '%', 342,
        '&', 346,
        '(', 299,
        '*', 298,
        '+', 336,
        '-', 338,
        '.', 369,
        '/', 341,
        ':', 95,
        ';', 263,
        '<', 332,
        '=', 274,
        '>', 334,
        '?', 371,
        'B', 598,
        '[', 278,
        '^', 343,
        'b', 545,
        'c', 552,
        'd', 490,
        'e', 540,
        'f', 507,
        'i', 442,
        'l', 505,
        'm', 547,
        'p', 588,
        's', 580,
        't', 565,
        'u', 445,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 96,
        '%', 342,
        '&', 346,
        '(', 299,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        ':', 268,
        '<', 332,
        '=', 274,
        '>', 334,
        '?', 371,
        '[', 278,
        '^', 343,
        'e', 154,
        '|', 350,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '"', 413,
        '#', 277,
        '\'', 30,
        '(', 299,
        ')', 302,
        ',', 286,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '_', 301,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 444,
        'm', 594,
        's', 590,
        't', 567,
        'u', 446,
        '|', 348,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '"', 413,
        '#', 277,
        '\'', 30,
        '(', 299,
        ')', 302,
        ',', 286,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 301,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 444,
        'm', 594,
        'r', 506,
        's', 590,
        't', 567,
        'u', 446,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '"', 413,
        '\'', 30,
        '(', 299,
        ')', 302,
        ',', 286,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 269,
        ';', 263,
        '=', 272,
        '>', 333,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '_', 411,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 444,
        's', 590,
        't', 567,
        'u', 446,
        '{', 258,
        '|', 348,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '"', 413,
        '\'', 30,
        '(', 299,
        ')', 302,
        ',', 286,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        '_', 301,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 444,
        'm', 546,
        's', 590,
        't', 567,
        'u', 446,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '"', 413,
        '\'', 30,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 95,
        '=', 98,
        'B', 598,
        '_', 411,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 441,
        's', 590,
        't', 567,
        'u', 446,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '"', 413,
        '\'', 30,
        '-', 337,
        '/', 67,
        '0', 399,
        ':', 95,
        'B', 598,
        '_', 411,
        'b', 436,
        'c', 439,
        'd', 490,
        'f', 471,
        'i', 443,
        's', 590,
        't', 567,
        'u', 446,
        '|', 348,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 24:
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(166);
      if (lookahead == 'r') ADVANCE(108);
      END_STATE();
    case 25:
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(172);
      if (lookahead == 'r') ADVANCE(131);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '#', 277,
        '+', 335,
        '-', 337,
        '/', 67,
        ':', 95,
        '>', 333,
        'B', 598,
        'b', 545,
        'c', 552,
        'd', 490,
        'f', 508,
        'i', 442,
        's', 590,
        'u', 446,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 27:
      if (lookahead == '#') ADVANCE(277);
      if (lookahead == ',') ADVANCE(286);
      if (lookahead == '.') ADVANCE(66);
      if (lookahead == '/') ADVANCE(67);
      if (lookahead == '0') ADVANCE(399);
      if (lookahead == '_') ADVANCE(411);
      if (lookahead == '}') ADVANCE(259);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 28:
      if (lookahead == '#') ADVANCE(277);
      if (lookahead == ',') ADVANCE(286);
      if (lookahead == '/') ADVANCE(67);
      if (lookahead == 'p') ADVANCE(588);
      if (lookahead == '}') ADVANCE(259);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 29:
      if (lookahead == '\'') ADVANCE(420);
      END_STATE();
    case 30:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(252);
      if (lookahead != 0) ADVANCE(60);
      END_STATE();
    case 31:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(223);
      if (lookahead != 0) ADVANCE(32);
      END_STATE();
    case 32:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(221);
      if (lookahead != 0) ADVANCE(29);
      END_STATE();
    case 33:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(224);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 34:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(225);
      if (lookahead != 0) ADVANCE(33);
      END_STATE();
    case 35:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(226);
      if (lookahead != 0) ADVANCE(34);
      END_STATE();
    case 36:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(227);
      if (lookahead != 0) ADVANCE(35);
      END_STATE();
    case 37:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(228);
      if (lookahead != 0) ADVANCE(36);
      END_STATE();
    case 38:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(229);
      if (lookahead != 0) ADVANCE(37);
      END_STATE();
    case 39:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(230);
      if (lookahead != 0) ADVANCE(38);
      END_STATE();
    case 40:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(231);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 41:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(232);
      if (lookahead != 0) ADVANCE(40);
      END_STATE();
    case 42:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(233);
      if (lookahead != 0) ADVANCE(41);
      END_STATE();
    case 43:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(234);
      if (lookahead != 0) ADVANCE(42);
      END_STATE();
    case 44:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(235);
      if (lookahead != 0) ADVANCE(43);
      END_STATE();
    case 45:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(236);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 46:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(237);
      if (lookahead != 0) ADVANCE(45);
      END_STATE();
    case 47:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(238);
      if (lookahead != 0) ADVANCE(46);
      END_STATE();
    case 48:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(239);
      if (lookahead != 0) ADVANCE(47);
      END_STATE();
    case 49:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(240);
      if (lookahead != 0) ADVANCE(48);
      END_STATE();
    case 50:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(241);
      if (lookahead != 0) ADVANCE(49);
      END_STATE();
    case 51:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(242);
      if (lookahead != 0) ADVANCE(50);
      END_STATE();
    case 52:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(243);
      if (lookahead != 0) ADVANCE(51);
      END_STATE();
    case 53:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(244);
      if (lookahead != 0) ADVANCE(52);
      END_STATE();
    case 54:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(245);
      if (lookahead != 0) ADVANCE(53);
      END_STATE();
    case 55:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(246);
      if (lookahead != 0) ADVANCE(54);
      END_STATE();
    case 56:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(247);
      if (lookahead != 0) ADVANCE(55);
      END_STATE();
    case 57:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(248);
      if (lookahead != 0) ADVANCE(56);
      END_STATE();
    case 58:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(249);
      if (lookahead != 0) ADVANCE(57);
      END_STATE();
    case 59:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(250);
      if (lookahead != 0) ADVANCE(58);
      END_STATE();
    case 60:
      if (lookahead == '\'') ADVANCE(420);
      if (lookahead == '\\') ADVANCE(251);
      if (lookahead != 0) ADVANCE(59);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '(', 299,
        ')', 302,
        '*', 297,
        ',', 286,
        '/', 67,
        ':', 95,
        '@', 367,
        'B', 598,
        '[', 278,
        'b', 545,
        'd', 490,
        'f', 508,
        'i', 444,
        's', 590,
        'u', 446,
        '{', 258,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(61);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '(', 299,
        '/', 67,
        ':', 95,
        ';', 263,
        '@', 367,
        'B', 598,
        '[', 278,
        'b', 545,
        'd', 490,
        'f', 508,
        'i', 444,
        'n', 551,
        's', 590,
        'u', 446,
        '{', 258,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(62);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        ')', 302,
        ',', 286,
        '.', 66,
        '/', 67,
        ':', 268,
        ';', 263,
        '<', 331,
        '=', 272,
        '>', 333,
        '[', 278,
        ']', 279,
        'i', 165,
        'n', 171,
        'o', 137,
        '{', 258,
        '|', 348,
        '}', 259,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(63);
      END_STATE();
    case 64:
      if (lookahead == '*') ADVANCE(297);
      if (lookahead == '/') ADVANCE(67);
      if (lookahead == '<') ADVANCE(426);
      if (lookahead == 's') ADVANCE(590);
      if (lookahead == '{') ADVANCE(258);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 65:
      if (lookahead == ',') ADVANCE(286);
      if (lookahead == '/') ADVANCE(67);
      if (lookahead == 'm') ADVANCE(594);
      if (lookahead == '}') ADVANCE(259);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 66:
      if (lookahead == '.') ADVANCE(368);
      END_STATE();
    case 67:
      if (lookahead == '/') ADVANCE(608);
      END_STATE();
    case 68:
      if (lookahead == '/') ADVANCE(67);
      if (lookahead == 'f') ADVANCE(536);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 69:
      if (lookahead == '1') ADVANCE(73);
      if (lookahead == '3') ADVANCE(74);
      if (lookahead == '6') ADVANCE(84);
      if (lookahead == '8') ADVANCE(305);
      if (lookahead == 'f') ADVANCE(378);
      if (lookahead == 'm') ADVANCE(176);
      if (lookahead == 'n') ADVANCE(431);
      END_STATE();
    case 70:
      if (lookahead == '1') ADVANCE(79);
      if (lookahead == '3') ADVANCE(75);
      if (lookahead == '6') ADVANCE(85);
      if (lookahead == '8') ADVANCE(303);
      if (lookahead == 's') ADVANCE(117);
      END_STATE();
    case 71:
      if (lookahead == '1') ADVANCE(81);
      if (lookahead == '2') ADVANCE(87);
      if (lookahead == '3') ADVANCE(76);
      if (lookahead == '6') ADVANCE(86);
      if (lookahead == '8') ADVANCE(398);
      if (lookahead == 's') ADVANCE(150);
      END_STATE();
    case 72:
      if (lookahead == '1') ADVANCE(81);
      if (lookahead == '3') ADVANCE(76);
      if (lookahead == '6') ADVANCE(86);
      if (lookahead == '8') ADVANCE(398);
      END_STATE();
    case 73:
      if (lookahead == '2') ADVANCE(93);
      if (lookahead == '6') ADVANCE(309);
      END_STATE();
    case 74:
      if (lookahead == '2') ADVANCE(313);
      END_STATE();
    case 75:
      if (lookahead == '2') ADVANCE(311);
      END_STATE();
    case 76:
      if (lookahead == '2') ADVANCE(398);
      END_STATE();
    case 77:
      if (lookahead == '2') ADVANCE(329);
      END_STATE();
    case 78:
      if (lookahead == '2') ADVANCE(419);
      END_STATE();
    case 79:
      if (lookahead == '2') ADVANCE(94);
      if (lookahead == '6') ADVANCE(307);
      END_STATE();
    case 80:
      if (lookahead == '2') ADVANCE(89);
      END_STATE();
    case 81:
      if (lookahead == '2') ADVANCE(92);
      if (lookahead == '6') ADVANCE(398);
      END_STATE();
    case 82:
      if (lookahead == '2') ADVANCE(88);
      END_STATE();
    case 83:
      if (lookahead == '2') ADVANCE(90);
      END_STATE();
    case 84:
      if (lookahead == '4') ADVANCE(317);
      END_STATE();
    case 85:
      if (lookahead == '4') ADVANCE(315);
      END_STATE();
    case 86:
      if (lookahead == '4') ADVANCE(398);
      END_STATE();
    case 87:
      if (lookahead == '5') ADVANCE(91);
      END_STATE();
    case 88:
      if (lookahead == '5') ADVANCE(76);
      END_STATE();
    case 89:
      if (lookahead == '5') ADVANCE(77);
      END_STATE();
    case 90:
      if (lookahead == '5') ADVANCE(78);
      END_STATE();
    case 91:
      if (lookahead == '6') ADVANCE(398);
      END_STATE();
    case 92:
      if (lookahead == '8') ADVANCE(398);
      END_STATE();
    case 93:
      if (lookahead == '8') ADVANCE(321);
      END_STATE();
    case 94:
      if (lookahead == '8') ADVANCE(319);
      END_STATE();
    case 95:
      if (lookahead == ':') ADVANCE(295);
      END_STATE();
    case 96:
      if (lookahead == '=') ADVANCE(364);
      END_STATE();
    case 97:
      if (lookahead == '>') ADVANCE(289);
      END_STATE();
    case 98:
      if (lookahead == '>') ADVANCE(370);
      END_STATE();
    case 99:
      if (lookahead == 'A') ADVANCE(186);
      END_STATE();
    case 100:
      if (lookahead == 'a') ADVANCE(160);
      if (lookahead == 'e') ADVANCE(156);
      if (lookahead == 'n') ADVANCE(287);
      if (lookahead == 'o') ADVANCE(181);
      END_STATE();
    case 101:
      if (lookahead == 'a') ADVANCE(151);
      END_STATE();
    case 102:
      if (lookahead == 'a') ADVANCE(215);
      END_STATE();
    case 103:
      if (lookahead == 'a') ADVANCE(170);
      END_STATE();
    case 104:
      if (lookahead == 'a') ADVANCE(148);
      if (lookahead == 'u') ADVANCE(122);
      END_STATE();
    case 105:
      if (lookahead == 'a') ADVANCE(194);
      if (lookahead == 'o') ADVANCE(115);
      if (lookahead == 'u') ADVANCE(195);
      END_STATE();
    case 106:
      if (lookahead == 'a') ADVANCE(212);
      END_STATE();
    case 107:
      if (lookahead == 'a') ADVANCE(203);
      if (lookahead == 'r') ADVANCE(210);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(205);
      END_STATE();
    case 109:
      if (lookahead == 'b') ADVANCE(388);
      END_STATE();
    case 110:
      if (lookahead == 'c') ADVANCE(392);
      END_STATE();
    case 111:
      if (lookahead == 'c') ADVANCE(382);
      END_STATE();
    case 112:
      if (lookahead == 'c') ADVANCE(142);
      END_STATE();
    case 113:
      if (lookahead == 'c') ADVANCE(198);
      END_STATE();
    case 114:
      if (lookahead == 'c') ADVANCE(149);
      END_STATE();
    case 115:
      if (lookahead == 'd') ADVANCE(280);
      if (lookahead == 'v') ADVANCE(121);
      END_STATE();
    case 116:
      if (lookahead == 'e') ADVANCE(138);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(293);
      if (lookahead == 'i') ADVANCE(216);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(398);
      END_STATE();
    case 119:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 120:
      if (lookahead == 'e') ADVANCE(427);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(429);
      END_STATE();
    case 122:
      if (lookahead == 'e') ADVANCE(421);
      END_STATE();
    case 123:
      if (lookahead == 'e') ADVANCE(266);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(607);
      END_STATE();
    case 125:
      if (lookahead == 'e') ADVANCE(423);
      END_STATE();
    case 126:
      if (lookahead == 'e') ADVANCE(323);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 128:
      if (lookahead == 'e') ADVANCE(374);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(139);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(193);
      if (lookahead == 'o') ADVANCE(173);
      END_STATE();
    case 131:
      if (lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(183);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(182);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(161);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(162);
      END_STATE();
    case 136:
      if (lookahead == 'f') ADVANCE(378);
      END_STATE();
    case 137:
      if (lookahead == 'f') ADVANCE(262);
      END_STATE();
    case 138:
      if (lookahead == 'f') ADVANCE(433);
      if (lookahead == 't') ADVANCE(213);
      END_STATE();
    case 139:
      if (lookahead == 'f') ADVANCE(106);
      END_STATE();
    case 140:
      if (lookahead == 'f') ADVANCE(135);
      END_STATE();
    case 141:
      if (lookahead == 'h') ADVANCE(146);
      END_STATE();
    case 142:
      if (lookahead == 'h') ADVANCE(386);
      END_STATE();
    case 143:
      if (lookahead == 'i') ADVANCE(169);
      END_STATE();
    case 144:
      if (lookahead == 'i') ADVANCE(110);
      END_STATE();
    case 145:
      if (lookahead == 'i') ADVANCE(111);
      END_STATE();
    case 146:
      if (lookahead == 'i') ADVANCE(159);
      END_STATE();
    case 147:
      if (lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 148:
      if (lookahead == 'i') ADVANCE(197);
      END_STATE();
    case 149:
      if (lookahead == 'i') ADVANCE(200);
      END_STATE();
    case 150:
      if (lookahead == 'i') ADVANCE(217);
      END_STATE();
    case 151:
      if (lookahead == 'k') ADVANCE(372);
      END_STATE();
    case 152:
      if (lookahead == 'l') ADVANCE(325);
      END_STATE();
    case 153:
      if (lookahead == 'l') ADVANCE(260);
      END_STATE();
    case 154:
      if (lookahead == 'l') ADVANCE(189);
      END_STATE();
    case 155:
      if (lookahead == 'l') ADVANCE(189);
      if (lookahead == 'n') ADVANCE(209);
      if (lookahead == 'x') ADVANCE(204);
      END_STATE();
    case 156:
      if (lookahead == 'l') ADVANCE(201);
      END_STATE();
    case 157:
      if (lookahead == 'l') ADVANCE(147);
      END_STATE();
    case 158:
      if (lookahead == 'l') ADVANCE(199);
      END_STATE();
    case 159:
      if (lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 160:
      if (lookahead == 'l') ADVANCE(191);
      END_STATE();
    case 161:
      if (lookahead == 'l') ADVANCE(206);
      END_STATE();
    case 162:
      if (lookahead == 'l') ADVANCE(207);
      END_STATE();
    case 163:
      if (lookahead == 'm') ADVANCE(284);
      END_STATE();
    case 164:
      if (lookahead == 'm') ADVANCE(177);
      END_STATE();
    case 165:
      if (lookahead == 'm') ADVANCE(177);
      if (lookahead == 'n') ADVANCE(431);
      END_STATE();
    case 166:
      if (lookahead == 'n') ADVANCE(190);
      END_STATE();
    case 167:
      if (lookahead == 'n') ADVANCE(380);
      END_STATE();
    case 168:
      if (lookahead == 'n') ADVANCE(390);
      END_STATE();
    case 169:
      if (lookahead == 'n') ADVANCE(211);
      END_STATE();
    case 170:
      if (lookahead == 'n') ADVANCE(145);
      END_STATE();
    case 171:
      if (lookahead == 'o') ADVANCE(175);
      END_STATE();
    case 172:
      if (lookahead == 'o') ADVANCE(152);
      END_STATE();
    case 173:
      if (lookahead == 'o') ADVANCE(174);
      END_STATE();
    case 174:
      if (lookahead == 'p') ADVANCE(384);
      END_STATE();
    case 175:
      if (lookahead == 'p') ADVANCE(103);
      END_STATE();
    case 176:
      if (lookahead == 'p') ADVANCE(153);
      END_STATE();
    case 177:
      if (lookahead == 'p') ADVANCE(157);
      END_STATE();
    case 178:
      if (lookahead == 'p') ADVANCE(133);
      END_STATE();
    case 179:
      if (lookahead == 'p') ADVANCE(123);
      END_STATE();
    case 180:
      if (lookahead == 'r') ADVANCE(104);
      if (lookahead == 'y') ADVANCE(179);
      END_STATE();
    case 181:
      if (lookahead == 'r') ADVANCE(396);
      END_STATE();
    case 182:
      if (lookahead == 'r') ADVANCE(605);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(168);
      END_STATE();
    case 185:
      if (lookahead == 'r') ADVANCE(102);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(185);
      END_STATE();
    case 187:
      if (lookahead == 's') ADVANCE(296);
      END_STATE();
    case 188:
      if (lookahead == 's') ADVANCE(290);
      END_STATE();
    case 189:
      if (lookahead == 's') ADVANCE(120);
      END_STATE();
    case 190:
      if (lookahead == 's') ADVANCE(196);
      if (lookahead == 't') ADVANCE(143);
      END_STATE();
    case 191:
      if (lookahead == 's') ADVANCE(125);
      END_STATE();
    case 192:
      if (lookahead == 't') ADVANCE(107);
      if (lookahead == 'u') ADVANCE(178);
      END_STATE();
    case 193:
      if (lookahead == 't') ADVANCE(291);
      END_STATE();
    case 194:
      if (lookahead == 't') ADVANCE(112);
      END_STATE();
    case 195:
      if (lookahead == 't') ADVANCE(603);
      END_STATE();
    case 196:
      if (lookahead == 't') ADVANCE(270);
      END_STATE();
    case 197:
      if (lookahead == 't') ADVANCE(264);
      END_STATE();
    case 198:
      if (lookahead == 't') ADVANCE(282);
      END_STATE();
    case 199:
      if (lookahead == 't') ADVANCE(376);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(188);
      END_STATE();
    case 201:
      if (lookahead == 't') ADVANCE(80);
      END_STATE();
    case 202:
      if (lookahead == 't') ADVANCE(119);
      END_STATE();
    case 203:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 204:
      if (lookahead == 't') ADVANCE(132);
      END_STATE();
    case 205:
      if (lookahead == 't') ADVANCE(124);
      END_STATE();
    case 206:
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 207:
      if (lookahead == 't') ADVANCE(83);
      END_STATE();
    case 208:
      if (lookahead == 'u') ADVANCE(109);
      END_STATE();
    case 209:
      if (lookahead == 'u') ADVANCE(163);
      END_STATE();
    case 210:
      if (lookahead == 'u') ADVANCE(113);
      END_STATE();
    case 211:
      if (lookahead == 'u') ADVANCE(128);
      END_STATE();
    case 212:
      if (lookahead == 'u') ADVANCE(158);
      END_STATE();
    case 213:
      if (lookahead == 'u') ADVANCE(184);
      END_STATE();
    case 214:
      if (lookahead == 'y') ADVANCE(202);
      END_STATE();
    case 215:
      if (lookahead == 'y') ADVANCE(327);
      END_STATE();
    case 216:
      if (lookahead == 'z') ADVANCE(126);
      END_STATE();
    case 217:
      if (lookahead == 'z') ADVANCE(118);
      END_STATE();
    case 218:
      if (lookahead == '0' ||
          lookahead == '1' ||
          lookahead == '_') ADVANCE(403);
      END_STATE();
    case 219:
      if (('0' <= lookahead && lookahead <= '7') ||
          lookahead == '_') ADVANCE(405);
      END_STATE();
    case 220:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(409);
      END_STATE();
    case 221:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(29);
      END_STATE();
    case 222:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(417);
      END_STATE();
    case 223:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(32);
      END_STATE();
    case 224:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(31);
      END_STATE();
    case 225:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(33);
      END_STATE();
    case 226:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(34);
      END_STATE();
    case 227:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(35);
      END_STATE();
    case 228:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(36);
      END_STATE();
    case 229:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(37);
      END_STATE();
    case 230:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(38);
      END_STATE();
    case 231:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(39);
      END_STATE();
    case 232:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(40);
      END_STATE();
    case 233:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(41);
      END_STATE();
    case 234:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(42);
      END_STATE();
    case 235:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(43);
      END_STATE();
    case 236:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(44);
      END_STATE();
    case 237:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(45);
      END_STATE();
    case 238:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(46);
      END_STATE();
    case 239:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(47);
      END_STATE();
    case 240:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(48);
      END_STATE();
    case 241:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(49);
      END_STATE();
    case 242:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(50);
      END_STATE();
    case 243:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(51);
      END_STATE();
    case 244:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(52);
      END_STATE();
    case 245:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(53);
      END_STATE();
    case 246:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(54);
      END_STATE();
    case 247:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(55);
      END_STATE();
    case 248:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(56);
      END_STATE();
    case 249:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(57);
      END_STATE();
    case 250:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(58);
      END_STATE();
    case 251:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(59);
      END_STATE();
    case 252:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(60);
      END_STATE();
    case 253:
      if (eof) ADVANCE(257);
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '#', 277,
        '$', 425,
        '%', 342,
        '&', 347,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 339,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 426,
        '=', 274,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 214,
        '[', 278,
        ']', 279,
        '^', 344,
        '_', 300,
        'a', 187,
        'b', 25,
        'c', 24,
        'd', 129,
        'e', 155,
        'f', 100,
        'i', 69,
        'l', 130,
        'm', 105,
        'n', 171,
        'o', 137,
        'p', 208,
        'r', 116,
        's', 192,
        't', 180,
        'u', 70,
        'w', 141,
        '{', 258,
        '|', 349,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(253);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 254:
      if (eof) ADVANCE(257);
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '#', 277,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 298,
        '+', 336,
        ',', 286,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        ';', 263,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '^', 343,
        '_', 411,
        'b', 435,
        'c', 437,
        'd', 490,
        'e', 540,
        'f', 469,
        'i', 440,
        'l', 504,
        'm', 476,
        'p', 588,
        'r', 491,
        's', 580,
        't', 558,
        'u', 445,
        'w', 516,
        '{', 258,
        '|', 350,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(254);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 255:
      if (eof) ADVANCE(257);
      ADVANCE_MAP(
        '!', 276,
        '"', 413,
        '#', 277,
        '%', 342,
        '&', 346,
        '\'', 30,
        '(', 299,
        '*', 298,
        '+', 336,
        '-', 338,
        '.', 369,
        '/', 341,
        '0', 399,
        ':', 95,
        ';', 263,
        '<', 332,
        '=', 273,
        '>', 334,
        '?', 371,
        '@', 367,
        'B', 598,
        '[', 278,
        '^', 343,
        '_', 411,
        'b', 435,
        'c', 437,
        'd', 490,
        'e', 532,
        'f', 469,
        'i', 440,
        'l', 504,
        'm', 476,
        'p', 588,
        'r', 491,
        's', 580,
        't', 558,
        'u', 445,
        'w', 516,
        '{', 258,
        '|', 350,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(255);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 256:
      if (eof) ADVANCE(257);
      ADVANCE_MAP(
        '!', 275,
        '"', 413,
        '#', 277,
        '\'', 30,
        '(', 299,
        ')', 302,
        '*', 297,
        ',', 286,
        '-', 337,
        '.', 66,
        '/', 67,
        '0', 399,
        ':', 269,
        ';', 263,
        '<', 426,
        '=', 272,
        '>', 333,
        '@', 367,
        'B', 598,
        '[', 278,
        ']', 279,
        '_', 411,
        'b', 435,
        'c', 437,
        'd', 490,
        'e', 540,
        'f', 469,
        'i', 440,
        'l', 504,
        'm', 476,
        'p', 588,
        'r', 491,
        's', 580,
        't', 558,
        'u', 445,
        'w', 516,
        '{', 258,
        '|', 348,
        '}', 259,
        '~', 345,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(256);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(401);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_impl);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_impl);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_trait);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(anon_sym_trait);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(anon_sym_type);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(295);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_const);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(363);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(363);
      if (lookahead == '>') ADVANCE(370);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(364);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_mod);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_mod);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(anon_sym_struct);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_enum);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(anon_sym_fn);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(anon_sym_fn);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(anon_sym_implicits);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(anon_sym_let);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_use);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_use);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(357);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(400);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym__);
      if (lookahead == '_') ADVANCE(410);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(411);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_u8);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_u8);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(anon_sym_i8);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(anon_sym_i8);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(anon_sym_u16);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(anon_sym_u16);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(anon_sym_i16);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(anon_sym_i16);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(anon_sym_u32);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(anon_sym_u32);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_i32);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_i32);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(anon_sym_u64);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_u64);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(anon_sym_i64);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_i64);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(anon_sym_u128);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(anon_sym_u128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(anon_sym_i128);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(anon_sym_i128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_usize);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(anon_sym_usize);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(anon_sym_bool);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(anon_sym_ByteArray);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_ByteArray);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_felt252);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(anon_sym_felt252);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(353);
      if (lookahead == '=') ADVANCE(366);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(365);
      if (lookahead == '>') ADVANCE(354);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(355);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(356);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(356);
      if (lookahead == '>') ADVANCE(289);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(289);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(608);
      if (lookahead == '=') ADVANCE(358);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(359);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(360);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(351);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(351);
      if (lookahead == '=') ADVANCE(361);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(362);
      if (lookahead == '|') ADVANCE(352);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(352);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(368);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_break);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_continue);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(anon_sym_default);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_extern);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_extern);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(anon_sym_nopanic);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_nopanic);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_loop);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(anon_sym_loop);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(anon_sym_match);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(anon_sym_match);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_pub);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_pub);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_return);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_static);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_while);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_for);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(sym_numeric_literal);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(400);
      if (lookahead == 'b') ADVANCE(218);
      if (lookahead == 'o') ADVANCE(219);
      if (lookahead == 'x') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(400);
      if (lookahead == 'f') ADVANCE(134);
      if (lookahead == 'i') ADVANCE(72);
      if (lookahead == 'u') ADVANCE(71);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(400);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(401);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(402);
      if (lookahead == 'f') ADVANCE(134);
      if (lookahead == 'i') ADVANCE(72);
      if (lookahead == 'u') ADVANCE(71);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(403);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(402);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(403);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(404);
      if (lookahead == 'f') ADVANCE(134);
      if (lookahead == 'i') ADVANCE(72);
      if (lookahead == 'u') ADVANCE(71);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(405);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(404);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(405);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(407);
      if (lookahead == 'e') ADVANCE(408);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(409);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(407);
      if (lookahead == 'f') ADVANCE(406);
      if (lookahead == 'i') ADVANCE(72);
      if (lookahead == 'u') ADVANCE(71);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'e')) ADVANCE(409);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(407);
      if (lookahead == 'l') ADVANCE(206);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(409);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(407);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(409);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(410);
      if (lookahead == 'f') ADVANCE(512);
      if (lookahead == 'i') ADVANCE(448);
      if (lookahead == 'u') ADVANCE(447);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(411);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '_') ADVANCE(410);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(411);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '\n') ADVANCE(417);
      if (lookahead == '"') ADVANCE(608);
      if (lookahead == '\\') ADVANCE(609);
      if (lookahead != 0) ADVANCE(414);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '/') ADVANCE(416);
      if (lookahead == '\\') ADVANCE(222);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(415);
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(417);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '/') ADVANCE(414);
      if (lookahead == '\\') ADVANCE(222);
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(417);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '\\') ADVANCE(222);
      if (lookahead != 0 &&
          lookahead != '"') ADVANCE(417);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(sym_shortstring_literal);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(sym_shortstring_literal);
      if (lookahead == '_') ADVANCE(140);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_true);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_false);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_LT2);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_else);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_move);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_move);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(anon_sym_in);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(anon_sym_ref);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(anon_sym_ref);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(549);
      if (lookahead == 'r') ADVANCE(492);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(549);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(537);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (lookahead == 'o') ADVANCE(544);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(413);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(449);
      if (lookahead == '3') ADVANCE(450);
      if (lookahead == '6') ADVANCE(458);
      if (lookahead == '8') ADVANCE(306);
      if (lookahead == 'f') ADVANCE(379);
      if (lookahead == 'm') ADVANCE(554);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(449);
      if (lookahead == '3') ADVANCE(450);
      if (lookahead == '6') ADVANCE(458);
      if (lookahead == '8') ADVANCE(306);
      if (lookahead == 'f') ADVANCE(379);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(449);
      if (lookahead == '3') ADVANCE(450);
      if (lookahead == '6') ADVANCE(458);
      if (lookahead == '8') ADVANCE(306);
      if (lookahead == 'm') ADVANCE(554);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(449);
      if (lookahead == '3') ADVANCE(450);
      if (lookahead == '6') ADVANCE(458);
      if (lookahead == '8') ADVANCE(306);
      if (lookahead == 'n') ADVANCE(432);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(449);
      if (lookahead == '3') ADVANCE(450);
      if (lookahead == '6') ADVANCE(458);
      if (lookahead == '8') ADVANCE(306);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(454);
      if (lookahead == '3') ADVANCE(451);
      if (lookahead == '6') ADVANCE(459);
      if (lookahead == '8') ADVANCE(304);
      if (lookahead == 's') ADVANCE(493);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(454);
      if (lookahead == '3') ADVANCE(451);
      if (lookahead == '6') ADVANCE(459);
      if (lookahead == '8') ADVANCE(304);
      if (lookahead == 's') ADVANCE(518);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(456);
      if (lookahead == '2') ADVANCE(461);
      if (lookahead == '3') ADVANCE(452);
      if (lookahead == '6') ADVANCE(460);
      if (lookahead == '8') ADVANCE(412);
      if (lookahead == 's') ADVANCE(524);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(456);
      if (lookahead == '3') ADVANCE(452);
      if (lookahead == '6') ADVANCE(460);
      if (lookahead == '8') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(466);
      if (lookahead == '6') ADVANCE(310);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(312);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(330);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(467);
      if (lookahead == '6') ADVANCE(308);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(463);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(465);
      if (lookahead == '6') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(462);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '4') ADVANCE(318);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '4') ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '4') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '5') ADVANCE(464);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '5') ADVANCE(452);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '5') ADVANCE(453);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '8') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '8') ADVANCE(322);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '8') ADVANCE(320);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(526);
      if (lookahead == 'e') ADVANCE(529);
      if (lookahead == 'n') ADVANCE(288);
      if (lookahead == 'o') ADVANCE(559);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(526);
      if (lookahead == 'e') ADVANCE(529);
      if (lookahead == 'o') ADVANCE(559);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(526);
      if (lookahead == 'e') ADVANCE(529);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(525);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(599);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(523);
      if (lookahead == 'u') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(523);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(573);
      if (lookahead == 'o') ADVANCE(488);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(573);
      if (lookahead == 'o') ADVANCE(597);
      if (lookahead == 'u') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(573);
      if (lookahead == 'o') ADVANCE(597);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(573);
      if (lookahead == 'o') ADVANCE(489);
      if (lookahead == 'u') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(596);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(543);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(585);
      if (lookahead == 'r') ADVANCE(591);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(389);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(393);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(383);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(517);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(576);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(281);
      if (lookahead == 'v') ADVANCE(496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(515);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(513);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(472);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(294);
      if (lookahead == 'i') ADVANCE(600);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(468);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(412);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(430);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(267);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(424);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(324);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(395);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(375);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(428);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(572);
      if (lookahead == 'o') ADVANCE(550);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(572);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(529);
      if (lookahead == 'n') ADVANCE(288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(529);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(561);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(560);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(581);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(534);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(434);
      if (lookahead == 't') ADVANCE(592);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(434);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(480);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(522);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(387);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(600);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(542);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(484);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(531);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(575);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(601);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(373);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(570);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(326);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(261);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(583);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(577);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(501);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(571);
      if (lookahead == 'n') ADVANCE(589);
      if (lookahead == 'x') ADVANCE(586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(571);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(587);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(285);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(568);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(381);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(589);
      if (lookahead == 'x') ADVANCE(586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(569);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(595);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(521);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(584);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(549);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(597);
      if (lookahead == 'u') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(489);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(550);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(527);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(555);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(541);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(385);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(528);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(481);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(510);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(498);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(474);
      if (lookahead == 'y') ADVANCE(557);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(397);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(538);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(473);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(591);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(539);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(475);
      if (lookahead == 'y') ADVANCE(557);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(562);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(593);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(574);
      if (lookahead == 't') ADVANCE(519);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(574);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(499);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(503);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(292);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(486);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(265);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(283);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(377);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(482);
      if (lookahead == 'u') ADVANCE(556);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(604);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(563);
      if (lookahead == 'u') ADVANCE(556);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(592);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(494);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(455);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(519);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(520);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(509);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(457);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(483);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(535);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(556);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(487);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(564);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(502);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(530);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'v') ADVANCE(496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(582);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(328);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'z') ADVANCE(500);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(602);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'z') ADVANCE(495);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(602);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_mutable_specifier);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_mutable_specifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_super);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym_super);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(602);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym_crate);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(608);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(414);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 256},
  [2] = {.lex_state = 256},
  [3] = {.lex_state = 256},
  [4] = {.lex_state = 256},
  [5] = {.lex_state = 256},
  [6] = {.lex_state = 256},
  [7] = {.lex_state = 256},
  [8] = {.lex_state = 256},
  [9] = {.lex_state = 256},
  [10] = {.lex_state = 256},
  [11] = {.lex_state = 256},
  [12] = {.lex_state = 256},
  [13] = {.lex_state = 256},
  [14] = {.lex_state = 256},
  [15] = {.lex_state = 256},
  [16] = {.lex_state = 256},
  [17] = {.lex_state = 256},
  [18] = {.lex_state = 256},
  [19] = {.lex_state = 256},
  [20] = {.lex_state = 256},
  [21] = {.lex_state = 2},
  [22] = {.lex_state = 2},
  [23] = {.lex_state = 2},
  [24] = {.lex_state = 2},
  [25] = {.lex_state = 2},
  [26] = {.lex_state = 2},
  [27] = {.lex_state = 3},
  [28] = {.lex_state = 3},
  [29] = {.lex_state = 3},
  [30] = {.lex_state = 3},
  [31] = {.lex_state = 3},
  [32] = {.lex_state = 3},
  [33] = {.lex_state = 2},
  [34] = {.lex_state = 2},
  [35] = {.lex_state = 2},
  [36] = {.lex_state = 2},
  [37] = {.lex_state = 2},
  [38] = {.lex_state = 2},
  [39] = {.lex_state = 1},
  [40] = {.lex_state = 1},
  [41] = {.lex_state = 1},
  [42] = {.lex_state = 1},
  [43] = {.lex_state = 1},
  [44] = {.lex_state = 1},
  [45] = {.lex_state = 1},
  [46] = {.lex_state = 1},
  [47] = {.lex_state = 1},
  [48] = {.lex_state = 1},
  [49] = {.lex_state = 1},
  [50] = {.lex_state = 1},
  [51] = {.lex_state = 1},
  [52] = {.lex_state = 1},
  [53] = {.lex_state = 1},
  [54] = {.lex_state = 1},
  [55] = {.lex_state = 1},
  [56] = {.lex_state = 1},
  [57] = {.lex_state = 1},
  [58] = {.lex_state = 1},
  [59] = {.lex_state = 1},
  [60] = {.lex_state = 1},
  [61] = {.lex_state = 1},
  [62] = {.lex_state = 1},
  [63] = {.lex_state = 1},
  [64] = {.lex_state = 1},
  [65] = {.lex_state = 1},
  [66] = {.lex_state = 1},
  [67] = {.lex_state = 1},
  [68] = {.lex_state = 1},
  [69] = {.lex_state = 1},
  [70] = {.lex_state = 1},
  [71] = {.lex_state = 1},
  [72] = {.lex_state = 1},
  [73] = {.lex_state = 1},
  [74] = {.lex_state = 1},
  [75] = {.lex_state = 1},
  [76] = {.lex_state = 1},
  [77] = {.lex_state = 1},
  [78] = {.lex_state = 1},
  [79] = {.lex_state = 1},
  [80] = {.lex_state = 1},
  [81] = {.lex_state = 1},
  [82] = {.lex_state = 1},
  [83] = {.lex_state = 1},
  [84] = {.lex_state = 1},
  [85] = {.lex_state = 1},
  [86] = {.lex_state = 5},
  [87] = {.lex_state = 5},
  [88] = {.lex_state = 5},
  [89] = {.lex_state = 5},
  [90] = {.lex_state = 5},
  [91] = {.lex_state = 5},
  [92] = {.lex_state = 5},
  [93] = {.lex_state = 5},
  [94] = {.lex_state = 5},
  [95] = {.lex_state = 5},
  [96] = {.lex_state = 5},
  [97] = {.lex_state = 5},
  [98] = {.lex_state = 5},
  [99] = {.lex_state = 5},
  [100] = {.lex_state = 5},
  [101] = {.lex_state = 5},
  [102] = {.lex_state = 5},
  [103] = {.lex_state = 5},
  [104] = {.lex_state = 5},
  [105] = {.lex_state = 5},
  [106] = {.lex_state = 254},
  [107] = {.lex_state = 5},
  [108] = {.lex_state = 254},
  [109] = {.lex_state = 5},
  [110] = {.lex_state = 5},
  [111] = {.lex_state = 5},
  [112] = {.lex_state = 5},
  [113] = {.lex_state = 254},
  [114] = {.lex_state = 254},
  [115] = {.lex_state = 254},
  [116] = {.lex_state = 254},
  [117] = {.lex_state = 254},
  [118] = {.lex_state = 5},
  [119] = {.lex_state = 254},
  [120] = {.lex_state = 254},
  [121] = {.lex_state = 254},
  [122] = {.lex_state = 254},
  [123] = {.lex_state = 5},
  [124] = {.lex_state = 254},
  [125] = {.lex_state = 254},
  [126] = {.lex_state = 5},
  [127] = {.lex_state = 254},
  [128] = {.lex_state = 254},
  [129] = {.lex_state = 254},
  [130] = {.lex_state = 5},
  [131] = {.lex_state = 255},
  [132] = {.lex_state = 6},
  [133] = {.lex_state = 6},
  [134] = {.lex_state = 5},
  [135] = {.lex_state = 6},
  [136] = {.lex_state = 6},
  [137] = {.lex_state = 6},
  [138] = {.lex_state = 6},
  [139] = {.lex_state = 6},
  [140] = {.lex_state = 6},
  [141] = {.lex_state = 5},
  [142] = {.lex_state = 5},
  [143] = {.lex_state = 8},
  [144] = {.lex_state = 5},
  [145] = {.lex_state = 5},
  [146] = {.lex_state = 8},
  [147] = {.lex_state = 8},
  [148] = {.lex_state = 8},
  [149] = {.lex_state = 8},
  [150] = {.lex_state = 255},
  [151] = {.lex_state = 5},
  [152] = {.lex_state = 5},
  [153] = {.lex_state = 255},
  [154] = {.lex_state = 255},
  [155] = {.lex_state = 5},
  [156] = {.lex_state = 5},
  [157] = {.lex_state = 5},
  [158] = {.lex_state = 5},
  [159] = {.lex_state = 8},
  [160] = {.lex_state = 8},
  [161] = {.lex_state = 5},
  [162] = {.lex_state = 8},
  [163] = {.lex_state = 7},
  [164] = {.lex_state = 7},
  [165] = {.lex_state = 254},
  [166] = {.lex_state = 254},
  [167] = {.lex_state = 7},
  [168] = {.lex_state = 5},
  [169] = {.lex_state = 5},
  [170] = {.lex_state = 5},
  [171] = {.lex_state = 5},
  [172] = {.lex_state = 5},
  [173] = {.lex_state = 5},
  [174] = {.lex_state = 5},
  [175] = {.lex_state = 5},
  [176] = {.lex_state = 5},
  [177] = {.lex_state = 5},
  [178] = {.lex_state = 5},
  [179] = {.lex_state = 5},
  [180] = {.lex_state = 5},
  [181] = {.lex_state = 5},
  [182] = {.lex_state = 5},
  [183] = {.lex_state = 5},
  [184] = {.lex_state = 5},
  [185] = {.lex_state = 5},
  [186] = {.lex_state = 5},
  [187] = {.lex_state = 5},
  [188] = {.lex_state = 5},
  [189] = {.lex_state = 5},
  [190] = {.lex_state = 5},
  [191] = {.lex_state = 5},
  [192] = {.lex_state = 5},
  [193] = {.lex_state = 5},
  [194] = {.lex_state = 5},
  [195] = {.lex_state = 5},
  [196] = {.lex_state = 5},
  [197] = {.lex_state = 254},
  [198] = {.lex_state = 5},
  [199] = {.lex_state = 5},
  [200] = {.lex_state = 5},
  [201] = {.lex_state = 5},
  [202] = {.lex_state = 5},
  [203] = {.lex_state = 5},
  [204] = {.lex_state = 5},
  [205] = {.lex_state = 5},
  [206] = {.lex_state = 5},
  [207] = {.lex_state = 5},
  [208] = {.lex_state = 5},
  [209] = {.lex_state = 5},
  [210] = {.lex_state = 5},
  [211] = {.lex_state = 5},
  [212] = {.lex_state = 5},
  [213] = {.lex_state = 5},
  [214] = {.lex_state = 5},
  [215] = {.lex_state = 5},
  [216] = {.lex_state = 5},
  [217] = {.lex_state = 5},
  [218] = {.lex_state = 5},
  [219] = {.lex_state = 5},
  [220] = {.lex_state = 5},
  [221] = {.lex_state = 5},
  [222] = {.lex_state = 5},
  [223] = {.lex_state = 5},
  [224] = {.lex_state = 5},
  [225] = {.lex_state = 5},
  [226] = {.lex_state = 5},
  [227] = {.lex_state = 5},
  [228] = {.lex_state = 5},
  [229] = {.lex_state = 5},
  [230] = {.lex_state = 5},
  [231] = {.lex_state = 5},
  [232] = {.lex_state = 5},
  [233] = {.lex_state = 5},
  [234] = {.lex_state = 5},
  [235] = {.lex_state = 5},
  [236] = {.lex_state = 5},
  [237] = {.lex_state = 5},
  [238] = {.lex_state = 5},
  [239] = {.lex_state = 5},
  [240] = {.lex_state = 5},
  [241] = {.lex_state = 5},
  [242] = {.lex_state = 5},
  [243] = {.lex_state = 5},
  [244] = {.lex_state = 5},
  [245] = {.lex_state = 5},
  [246] = {.lex_state = 5},
  [247] = {.lex_state = 5},
  [248] = {.lex_state = 5},
  [249] = {.lex_state = 5},
  [250] = {.lex_state = 5},
  [251] = {.lex_state = 5},
  [252] = {.lex_state = 9},
  [253] = {.lex_state = 9},
  [254] = {.lex_state = 9},
  [255] = {.lex_state = 13},
  [256] = {.lex_state = 9},
  [257] = {.lex_state = 13},
  [258] = {.lex_state = 13},
  [259] = {.lex_state = 13},
  [260] = {.lex_state = 13},
  [261] = {.lex_state = 13},
  [262] = {.lex_state = 13},
  [263] = {.lex_state = 256},
  [264] = {.lex_state = 256},
  [265] = {.lex_state = 256},
  [266] = {.lex_state = 14},
  [267] = {.lex_state = 256},
  [268] = {.lex_state = 256},
  [269] = {.lex_state = 256},
  [270] = {.lex_state = 256},
  [271] = {.lex_state = 256},
  [272] = {.lex_state = 256},
  [273] = {.lex_state = 256},
  [274] = {.lex_state = 256},
  [275] = {.lex_state = 256},
  [276] = {.lex_state = 256},
  [277] = {.lex_state = 256},
  [278] = {.lex_state = 256},
  [279] = {.lex_state = 256},
  [280] = {.lex_state = 256},
  [281] = {.lex_state = 256},
  [282] = {.lex_state = 256},
  [283] = {.lex_state = 256},
  [284] = {.lex_state = 256},
  [285] = {.lex_state = 256},
  [286] = {.lex_state = 256},
  [287] = {.lex_state = 256},
  [288] = {.lex_state = 256},
  [289] = {.lex_state = 256},
  [290] = {.lex_state = 256},
  [291] = {.lex_state = 256},
  [292] = {.lex_state = 256},
  [293] = {.lex_state = 256},
  [294] = {.lex_state = 256},
  [295] = {.lex_state = 256},
  [296] = {.lex_state = 256},
  [297] = {.lex_state = 256},
  [298] = {.lex_state = 256},
  [299] = {.lex_state = 256},
  [300] = {.lex_state = 256},
  [301] = {.lex_state = 256},
  [302] = {.lex_state = 256},
  [303] = {.lex_state = 256},
  [304] = {.lex_state = 256},
  [305] = {.lex_state = 256},
  [306] = {.lex_state = 256},
  [307] = {.lex_state = 256},
  [308] = {.lex_state = 256},
  [309] = {.lex_state = 256},
  [310] = {.lex_state = 256},
  [311] = {.lex_state = 256},
  [312] = {.lex_state = 256},
  [313] = {.lex_state = 256},
  [314] = {.lex_state = 256},
  [315] = {.lex_state = 256},
  [316] = {.lex_state = 256},
  [317] = {.lex_state = 256},
  [318] = {.lex_state = 256},
  [319] = {.lex_state = 19},
  [320] = {.lex_state = 256},
  [321] = {.lex_state = 256},
  [322] = {.lex_state = 256},
  [323] = {.lex_state = 256},
  [324] = {.lex_state = 256},
  [325] = {.lex_state = 256},
  [326] = {.lex_state = 256},
  [327] = {.lex_state = 256},
  [328] = {.lex_state = 256},
  [329] = {.lex_state = 256},
  [330] = {.lex_state = 256},
  [331] = {.lex_state = 256},
  [332] = {.lex_state = 256},
  [333] = {.lex_state = 256},
  [334] = {.lex_state = 256},
  [335] = {.lex_state = 256},
  [336] = {.lex_state = 256},
  [337] = {.lex_state = 256},
  [338] = {.lex_state = 256},
  [339] = {.lex_state = 256},
  [340] = {.lex_state = 256},
  [341] = {.lex_state = 256},
  [342] = {.lex_state = 256},
  [343] = {.lex_state = 256},
  [344] = {.lex_state = 256},
  [345] = {.lex_state = 256},
  [346] = {.lex_state = 256},
  [347] = {.lex_state = 256},
  [348] = {.lex_state = 19},
  [349] = {.lex_state = 19},
  [350] = {.lex_state = 14},
  [351] = {.lex_state = 14},
  [352] = {.lex_state = 14},
  [353] = {.lex_state = 13},
  [354] = {.lex_state = 13},
  [355] = {.lex_state = 13},
  [356] = {.lex_state = 13},
  [357] = {.lex_state = 19},
  [358] = {.lex_state = 13},
  [359] = {.lex_state = 15},
  [360] = {.lex_state = 15},
  [361] = {.lex_state = 21},
  [362] = {.lex_state = 21},
  [363] = {.lex_state = 15},
  [364] = {.lex_state = 19},
  [365] = {.lex_state = 21},
  [366] = {.lex_state = 15},
  [367] = {.lex_state = 15},
  [368] = {.lex_state = 15},
  [369] = {.lex_state = 15},
  [370] = {.lex_state = 15},
  [371] = {.lex_state = 15},
  [372] = {.lex_state = 15},
  [373] = {.lex_state = 15},
  [374] = {.lex_state = 15},
  [375] = {.lex_state = 15},
  [376] = {.lex_state = 15},
  [377] = {.lex_state = 18},
  [378] = {.lex_state = 18},
  [379] = {.lex_state = 19},
  [380] = {.lex_state = 19},
  [381] = {.lex_state = 18},
  [382] = {.lex_state = 18},
  [383] = {.lex_state = 18},
  [384] = {.lex_state = 18},
  [385] = {.lex_state = 18},
  [386] = {.lex_state = 18},
  [387] = {.lex_state = 18},
  [388] = {.lex_state = 18},
  [389] = {.lex_state = 21},
  [390] = {.lex_state = 21},
  [391] = {.lex_state = 21},
  [392] = {.lex_state = 21},
  [393] = {.lex_state = 19},
  [394] = {.lex_state = 21},
  [395] = {.lex_state = 19},
  [396] = {.lex_state = 21},
  [397] = {.lex_state = 19},
  [398] = {.lex_state = 19},
  [399] = {.lex_state = 21},
  [400] = {.lex_state = 19},
  [401] = {.lex_state = 5},
  [402] = {.lex_state = 18},
  [403] = {.lex_state = 18},
  [404] = {.lex_state = 18},
  [405] = {.lex_state = 18},
  [406] = {.lex_state = 18},
  [407] = {.lex_state = 18},
  [408] = {.lex_state = 18},
  [409] = {.lex_state = 18},
  [410] = {.lex_state = 5},
  [411] = {.lex_state = 18},
  [412] = {.lex_state = 18},
  [413] = {.lex_state = 18},
  [414] = {.lex_state = 18},
  [415] = {.lex_state = 18},
  [416] = {.lex_state = 18},
  [417] = {.lex_state = 18},
  [418] = {.lex_state = 18},
  [419] = {.lex_state = 18},
  [420] = {.lex_state = 18},
  [421] = {.lex_state = 18},
  [422] = {.lex_state = 18},
  [423] = {.lex_state = 18},
  [424] = {.lex_state = 18},
  [425] = {.lex_state = 18},
  [426] = {.lex_state = 18},
  [427] = {.lex_state = 18},
  [428] = {.lex_state = 18},
  [429] = {.lex_state = 18},
  [430] = {.lex_state = 18},
  [431] = {.lex_state = 18},
  [432] = {.lex_state = 18},
  [433] = {.lex_state = 18},
  [434] = {.lex_state = 18},
  [435] = {.lex_state = 18},
  [436] = {.lex_state = 18},
  [437] = {.lex_state = 18},
  [438] = {.lex_state = 18},
  [439] = {.lex_state = 18},
  [440] = {.lex_state = 18},
  [441] = {.lex_state = 18},
  [442] = {.lex_state = 18},
  [443] = {.lex_state = 18},
  [444] = {.lex_state = 18},
  [445] = {.lex_state = 18},
  [446] = {.lex_state = 8},
  [447] = {.lex_state = 8},
  [448] = {.lex_state = 20},
  [449] = {.lex_state = 20},
  [450] = {.lex_state = 20},
  [451] = {.lex_state = 20},
  [452] = {.lex_state = 20},
  [453] = {.lex_state = 20},
  [454] = {.lex_state = 5},
  [455] = {.lex_state = 20},
  [456] = {.lex_state = 20},
  [457] = {.lex_state = 20},
  [458] = {.lex_state = 20},
  [459] = {.lex_state = 2},
  [460] = {.lex_state = 4},
  [461] = {.lex_state = 20},
  [462] = {.lex_state = 4},
  [463] = {.lex_state = 4},
  [464] = {.lex_state = 4},
  [465] = {.lex_state = 4},
  [466] = {.lex_state = 4},
  [467] = {.lex_state = 20},
  [468] = {.lex_state = 4},
  [469] = {.lex_state = 2},
  [470] = {.lex_state = 2},
  [471] = {.lex_state = 2},
  [472] = {.lex_state = 4},
  [473] = {.lex_state = 2},
  [474] = {.lex_state = 2},
  [475] = {.lex_state = 4},
  [476] = {.lex_state = 2},
  [477] = {.lex_state = 2},
  [478] = {.lex_state = 2},
  [479] = {.lex_state = 2},
  [480] = {.lex_state = 2},
  [481] = {.lex_state = 4},
  [482] = {.lex_state = 2},
  [483] = {.lex_state = 2},
  [484] = {.lex_state = 2},
  [485] = {.lex_state = 4},
  [486] = {.lex_state = 2},
  [487] = {.lex_state = 2},
  [488] = {.lex_state = 2},
  [489] = {.lex_state = 2},
  [490] = {.lex_state = 2},
  [491] = {.lex_state = 62},
  [492] = {.lex_state = 2},
  [493] = {.lex_state = 2},
  [494] = {.lex_state = 62},
  [495] = {.lex_state = 2},
  [496] = {.lex_state = 2},
  [497] = {.lex_state = 62},
  [498] = {.lex_state = 2},
  [499] = {.lex_state = 2},
  [500] = {.lex_state = 2},
  [501] = {.lex_state = 2},
  [502] = {.lex_state = 2},
  [503] = {.lex_state = 2},
  [504] = {.lex_state = 2},
  [505] = {.lex_state = 2},
  [506] = {.lex_state = 2},
  [507] = {.lex_state = 2},
  [508] = {.lex_state = 62},
  [509] = {.lex_state = 2},
  [510] = {.lex_state = 2},
  [511] = {.lex_state = 2},
  [512] = {.lex_state = 2},
  [513] = {.lex_state = 2},
  [514] = {.lex_state = 2},
  [515] = {.lex_state = 2},
  [516] = {.lex_state = 2},
  [517] = {.lex_state = 2},
  [518] = {.lex_state = 2},
  [519] = {.lex_state = 2},
  [520] = {.lex_state = 2},
  [521] = {.lex_state = 2},
  [522] = {.lex_state = 2},
  [523] = {.lex_state = 2},
  [524] = {.lex_state = 2},
  [525] = {.lex_state = 62},
  [526] = {.lex_state = 2},
  [527] = {.lex_state = 62},
  [528] = {.lex_state = 2},
  [529] = {.lex_state = 2},
  [530] = {.lex_state = 2},
  [531] = {.lex_state = 2},
  [532] = {.lex_state = 2},
  [533] = {.lex_state = 2},
  [534] = {.lex_state = 62},
  [535] = {.lex_state = 2},
  [536] = {.lex_state = 62},
  [537] = {.lex_state = 2},
  [538] = {.lex_state = 2},
  [539] = {.lex_state = 2},
  [540] = {.lex_state = 3},
  [541] = {.lex_state = 2},
  [542] = {.lex_state = 2},
  [543] = {.lex_state = 2},
  [544] = {.lex_state = 2},
  [545] = {.lex_state = 2},
  [546] = {.lex_state = 2},
  [547] = {.lex_state = 2},
  [548] = {.lex_state = 2},
  [549] = {.lex_state = 2},
  [550] = {.lex_state = 2},
  [551] = {.lex_state = 2},
  [552] = {.lex_state = 2},
  [553] = {.lex_state = 2},
  [554] = {.lex_state = 2},
  [555] = {.lex_state = 2},
  [556] = {.lex_state = 2},
  [557] = {.lex_state = 13},
  [558] = {.lex_state = 13},
  [559] = {.lex_state = 13},
  [560] = {.lex_state = 13},
  [561] = {.lex_state = 13},
  [562] = {.lex_state = 13},
  [563] = {.lex_state = 3},
  [564] = {.lex_state = 13},
  [565] = {.lex_state = 13},
  [566] = {.lex_state = 13},
  [567] = {.lex_state = 13},
  [568] = {.lex_state = 13},
  [569] = {.lex_state = 13},
  [570] = {.lex_state = 13},
  [571] = {.lex_state = 13},
  [572] = {.lex_state = 13},
  [573] = {.lex_state = 13},
  [574] = {.lex_state = 13},
  [575] = {.lex_state = 13},
  [576] = {.lex_state = 13},
  [577] = {.lex_state = 22},
  [578] = {.lex_state = 22},
  [579] = {.lex_state = 3},
  [580] = {.lex_state = 13},
  [581] = {.lex_state = 3},
  [582] = {.lex_state = 18},
  [583] = {.lex_state = 13},
  [584] = {.lex_state = 13},
  [585] = {.lex_state = 13},
  [586] = {.lex_state = 3},
  [587] = {.lex_state = 13},
  [588] = {.lex_state = 13},
  [589] = {.lex_state = 13},
  [590] = {.lex_state = 13},
  [591] = {.lex_state = 13},
  [592] = {.lex_state = 13},
  [593] = {.lex_state = 13},
  [594] = {.lex_state = 13},
  [595] = {.lex_state = 13},
  [596] = {.lex_state = 13},
  [597] = {.lex_state = 13},
  [598] = {.lex_state = 13},
  [599] = {.lex_state = 13},
  [600] = {.lex_state = 13},
  [601] = {.lex_state = 13},
  [602] = {.lex_state = 13},
  [603] = {.lex_state = 13},
  [604] = {.lex_state = 13},
  [605] = {.lex_state = 13},
  [606] = {.lex_state = 13},
  [607] = {.lex_state = 13},
  [608] = {.lex_state = 13},
  [609] = {.lex_state = 13},
  [610] = {.lex_state = 13},
  [611] = {.lex_state = 13},
  [612] = {.lex_state = 13},
  [613] = {.lex_state = 13},
  [614] = {.lex_state = 13},
  [615] = {.lex_state = 13},
  [616] = {.lex_state = 13},
  [617] = {.lex_state = 13},
  [618] = {.lex_state = 13},
  [619] = {.lex_state = 13},
  [620] = {.lex_state = 13},
  [621] = {.lex_state = 13},
  [622] = {.lex_state = 13},
  [623] = {.lex_state = 13},
  [624] = {.lex_state = 13},
  [625] = {.lex_state = 13},
  [626] = {.lex_state = 13},
  [627] = {.lex_state = 13},
  [628] = {.lex_state = 13},
  [629] = {.lex_state = 13},
  [630] = {.lex_state = 13},
  [631] = {.lex_state = 13},
  [632] = {.lex_state = 2},
  [633] = {.lex_state = 13},
  [634] = {.lex_state = 13},
  [635] = {.lex_state = 13},
  [636] = {.lex_state = 13},
  [637] = {.lex_state = 13},
  [638] = {.lex_state = 13},
  [639] = {.lex_state = 13},
  [640] = {.lex_state = 13},
  [641] = {.lex_state = 13},
  [642] = {.lex_state = 13},
  [643] = {.lex_state = 13},
  [644] = {.lex_state = 26},
  [645] = {.lex_state = 2},
  [646] = {.lex_state = 61},
  [647] = {.lex_state = 23},
  [648] = {.lex_state = 3},
  [649] = {.lex_state = 2},
  [650] = {.lex_state = 2},
  [651] = {.lex_state = 3},
  [652] = {.lex_state = 2},
  [653] = {.lex_state = 2},
  [654] = {.lex_state = 2},
  [655] = {.lex_state = 2},
  [656] = {.lex_state = 26},
  [657] = {.lex_state = 3},
  [658] = {.lex_state = 2},
  [659] = {.lex_state = 61},
  [660] = {.lex_state = 23},
  [661] = {.lex_state = 3},
  [662] = {.lex_state = 61},
  [663] = {.lex_state = 26},
  [664] = {.lex_state = 17},
  [665] = {.lex_state = 26},
  [666] = {.lex_state = 3},
  [667] = {.lex_state = 3},
  [668] = {.lex_state = 26},
  [669] = {.lex_state = 3},
  [670] = {.lex_state = 26},
  [671] = {.lex_state = 61},
  [672] = {.lex_state = 26},
  [673] = {.lex_state = 61},
  [674] = {.lex_state = 3},
  [675] = {.lex_state = 3},
  [676] = {.lex_state = 2},
  [677] = {.lex_state = 61},
  [678] = {.lex_state = 3},
  [679] = {.lex_state = 2},
  [680] = {.lex_state = 3},
  [681] = {.lex_state = 61},
  [682] = {.lex_state = 61},
  [683] = {.lex_state = 61},
  [684] = {.lex_state = 61},
  [685] = {.lex_state = 61},
  [686] = {.lex_state = 61},
  [687] = {.lex_state = 26},
  [688] = {.lex_state = 61},
  [689] = {.lex_state = 61},
  [690] = {.lex_state = 61},
  [691] = {.lex_state = 61},
  [692] = {.lex_state = 26},
  [693] = {.lex_state = 2},
  [694] = {.lex_state = 61},
  [695] = {.lex_state = 61},
  [696] = {.lex_state = 18},
  [697] = {.lex_state = 61},
  [698] = {.lex_state = 18},
  [699] = {.lex_state = 3},
  [700] = {.lex_state = 3},
  [701] = {.lex_state = 3},
  [702] = {.lex_state = 26},
  [703] = {.lex_state = 61},
  [704] = {.lex_state = 61},
  [705] = {.lex_state = 61},
  [706] = {.lex_state = 2},
  [707] = {.lex_state = 2},
  [708] = {.lex_state = 3},
  [709] = {.lex_state = 3},
  [710] = {.lex_state = 61},
  [711] = {.lex_state = 2},
  [712] = {.lex_state = 61},
  [713] = {.lex_state = 61},
  [714] = {.lex_state = 61},
  [715] = {.lex_state = 61},
  [716] = {.lex_state = 26},
  [717] = {.lex_state = 61},
  [718] = {.lex_state = 61},
  [719] = {.lex_state = 61},
  [720] = {.lex_state = 2},
  [721] = {.lex_state = 61},
  [722] = {.lex_state = 17},
  [723] = {.lex_state = 17},
  [724] = {.lex_state = 19},
  [725] = {.lex_state = 61},
  [726] = {.lex_state = 61},
  [727] = {.lex_state = 61},
  [728] = {.lex_state = 2},
  [729] = {.lex_state = 61},
  [730] = {.lex_state = 2},
  [731] = {.lex_state = 2},
  [732] = {.lex_state = 61},
  [733] = {.lex_state = 61},
  [734] = {.lex_state = 61},
  [735] = {.lex_state = 2},
  [736] = {.lex_state = 61},
  [737] = {.lex_state = 61},
  [738] = {.lex_state = 61},
  [739] = {.lex_state = 61},
  [740] = {.lex_state = 61},
  [741] = {.lex_state = 61},
  [742] = {.lex_state = 61},
  [743] = {.lex_state = 61},
  [744] = {.lex_state = 61},
  [745] = {.lex_state = 61},
  [746] = {.lex_state = 61},
  [747] = {.lex_state = 61},
  [748] = {.lex_state = 61},
  [749] = {.lex_state = 61},
  [750] = {.lex_state = 61},
  [751] = {.lex_state = 61},
  [752] = {.lex_state = 61},
  [753] = {.lex_state = 61},
  [754] = {.lex_state = 61},
  [755] = {.lex_state = 61},
  [756] = {.lex_state = 17},
  [757] = {.lex_state = 2},
  [758] = {.lex_state = 18},
  [759] = {.lex_state = 3},
  [760] = {.lex_state = 3},
  [761] = {.lex_state = 3},
  [762] = {.lex_state = 3},
  [763] = {.lex_state = 3},
  [764] = {.lex_state = 3},
  [765] = {.lex_state = 3},
  [766] = {.lex_state = 3},
  [767] = {.lex_state = 3},
  [768] = {.lex_state = 3},
  [769] = {.lex_state = 3},
  [770] = {.lex_state = 3},
  [771] = {.lex_state = 3},
  [772] = {.lex_state = 3},
  [773] = {.lex_state = 2},
  [774] = {.lex_state = 2},
  [775] = {.lex_state = 3},
  [776] = {.lex_state = 3},
  [777] = {.lex_state = 3},
  [778] = {.lex_state = 2},
  [779] = {.lex_state = 3},
  [780] = {.lex_state = 3},
  [781] = {.lex_state = 3},
  [782] = {.lex_state = 3},
  [783] = {.lex_state = 3},
  [784] = {.lex_state = 2},
  [785] = {.lex_state = 3},
  [786] = {.lex_state = 3},
  [787] = {.lex_state = 2},
  [788] = {.lex_state = 2},
  [789] = {.lex_state = 2},
  [790] = {.lex_state = 3},
  [791] = {.lex_state = 2},
  [792] = {.lex_state = 2},
  [793] = {.lex_state = 2},
  [794] = {.lex_state = 2},
  [795] = {.lex_state = 2},
  [796] = {.lex_state = 2},
  [797] = {.lex_state = 2},
  [798] = {.lex_state = 2},
  [799] = {.lex_state = 2},
  [800] = {.lex_state = 2},
  [801] = {.lex_state = 3},
  [802] = {.lex_state = 3},
  [803] = {.lex_state = 3},
  [804] = {.lex_state = 3},
  [805] = {.lex_state = 3},
  [806] = {.lex_state = 3},
  [807] = {.lex_state = 3},
  [808] = {.lex_state = 3},
  [809] = {.lex_state = 3},
  [810] = {.lex_state = 3},
  [811] = {.lex_state = 2},
  [812] = {.lex_state = 3},
  [813] = {.lex_state = 3},
  [814] = {.lex_state = 2},
  [815] = {.lex_state = 3},
  [816] = {.lex_state = 3},
  [817] = {.lex_state = 3},
  [818] = {.lex_state = 3},
  [819] = {.lex_state = 3},
  [820] = {.lex_state = 3},
  [821] = {.lex_state = 3},
  [822] = {.lex_state = 3},
  [823] = {.lex_state = 3},
  [824] = {.lex_state = 3},
  [825] = {.lex_state = 3},
  [826] = {.lex_state = 3},
  [827] = {.lex_state = 3},
  [828] = {.lex_state = 3},
  [829] = {.lex_state = 3},
  [830] = {.lex_state = 3},
  [831] = {.lex_state = 2},
  [832] = {.lex_state = 2},
  [833] = {.lex_state = 2},
  [834] = {.lex_state = 3},
  [835] = {.lex_state = 3},
  [836] = {.lex_state = 3},
  [837] = {.lex_state = 3},
  [838] = {.lex_state = 3},
  [839] = {.lex_state = 3},
  [840] = {.lex_state = 3},
  [841] = {.lex_state = 3},
  [842] = {.lex_state = 3},
  [843] = {.lex_state = 3},
  [844] = {.lex_state = 3},
  [845] = {.lex_state = 18},
  [846] = {.lex_state = 3},
  [847] = {.lex_state = 3},
  [848] = {.lex_state = 2},
  [849] = {.lex_state = 3},
  [850] = {.lex_state = 2},
  [851] = {.lex_state = 3},
  [852] = {.lex_state = 3},
  [853] = {.lex_state = 2},
  [854] = {.lex_state = 18},
  [855] = {.lex_state = 2},
  [856] = {.lex_state = 2},
  [857] = {.lex_state = 2},
  [858] = {.lex_state = 2},
  [859] = {.lex_state = 2},
  [860] = {.lex_state = 2},
  [861] = {.lex_state = 2},
  [862] = {.lex_state = 2},
  [863] = {.lex_state = 2},
  [864] = {.lex_state = 2},
  [865] = {.lex_state = 2},
  [866] = {.lex_state = 2},
  [867] = {.lex_state = 2},
  [868] = {.lex_state = 2},
  [869] = {.lex_state = 2},
  [870] = {.lex_state = 2},
  [871] = {.lex_state = 2},
  [872] = {.lex_state = 2},
  [873] = {.lex_state = 2},
  [874] = {.lex_state = 2},
  [875] = {.lex_state = 2},
  [876] = {.lex_state = 2},
  [877] = {.lex_state = 2},
  [878] = {.lex_state = 2},
  [879] = {.lex_state = 2},
  [880] = {.lex_state = 2},
  [881] = {.lex_state = 2},
  [882] = {.lex_state = 2},
  [883] = {.lex_state = 2},
  [884] = {.lex_state = 2},
  [885] = {.lex_state = 2},
  [886] = {.lex_state = 2},
  [887] = {.lex_state = 2},
  [888] = {.lex_state = 2},
  [889] = {.lex_state = 2},
  [890] = {.lex_state = 18},
  [891] = {.lex_state = 3},
  [892] = {.lex_state = 2},
  [893] = {.lex_state = 2},
  [894] = {.lex_state = 2},
  [895] = {.lex_state = 2},
  [896] = {.lex_state = 2},
  [897] = {.lex_state = 2},
  [898] = {.lex_state = 2},
  [899] = {.lex_state = 2},
  [900] = {.lex_state = 2},
  [901] = {.lex_state = 2},
  [902] = {.lex_state = 3},
  [903] = {.lex_state = 2},
  [904] = {.lex_state = 61},
  [905] = {.lex_state = 2},
  [906] = {.lex_state = 2},
  [907] = {.lex_state = 18},
  [908] = {.lex_state = 2},
  [909] = {.lex_state = 2},
  [910] = {.lex_state = 3},
  [911] = {.lex_state = 2},
  [912] = {.lex_state = 2},
  [913] = {.lex_state = 2},
  [914] = {.lex_state = 2},
  [915] = {.lex_state = 2},
  [916] = {.lex_state = 2},
  [917] = {.lex_state = 2},
  [918] = {.lex_state = 2},
  [919] = {.lex_state = 2},
  [920] = {.lex_state = 2},
  [921] = {.lex_state = 2},
  [922] = {.lex_state = 2},
  [923] = {.lex_state = 2},
  [924] = {.lex_state = 2},
  [925] = {.lex_state = 2},
  [926] = {.lex_state = 61},
  [927] = {.lex_state = 61},
  [928] = {.lex_state = 61},
  [929] = {.lex_state = 61},
  [930] = {.lex_state = 61},
  [931] = {.lex_state = 61},
  [932] = {.lex_state = 61},
  [933] = {.lex_state = 26},
  [934] = {.lex_state = 26},
  [935] = {.lex_state = 61},
  [936] = {.lex_state = 61},
  [937] = {.lex_state = 61},
  [938] = {.lex_state = 61},
  [939] = {.lex_state = 61},
  [940] = {.lex_state = 61},
  [941] = {.lex_state = 61},
  [942] = {.lex_state = 61},
  [943] = {.lex_state = 61},
  [944] = {.lex_state = 61},
  [945] = {.lex_state = 61},
  [946] = {.lex_state = 61},
  [947] = {.lex_state = 61},
  [948] = {.lex_state = 61},
  [949] = {.lex_state = 10},
  [950] = {.lex_state = 10},
  [951] = {.lex_state = 10},
  [952] = {.lex_state = 10},
  [953] = {.lex_state = 10},
  [954] = {.lex_state = 10},
  [955] = {.lex_state = 10},
  [956] = {.lex_state = 10},
  [957] = {.lex_state = 256},
  [958] = {.lex_state = 10},
  [959] = {.lex_state = 10},
  [960] = {.lex_state = 10},
  [961] = {.lex_state = 10},
  [962] = {.lex_state = 10},
  [963] = {.lex_state = 63},
  [964] = {.lex_state = 63},
  [965] = {.lex_state = 63},
  [966] = {.lex_state = 10},
  [967] = {.lex_state = 63},
  [968] = {.lex_state = 10},
  [969] = {.lex_state = 10},
  [970] = {.lex_state = 10},
  [971] = {.lex_state = 256},
  [972] = {.lex_state = 10},
  [973] = {.lex_state = 10},
  [974] = {.lex_state = 10},
  [975] = {.lex_state = 10},
  [976] = {.lex_state = 10},
  [977] = {.lex_state = 10},
  [978] = {.lex_state = 10},
  [979] = {.lex_state = 0},
  [980] = {.lex_state = 11},
  [981] = {.lex_state = 10},
  [982] = {.lex_state = 11},
  [983] = {.lex_state = 10},
  [984] = {.lex_state = 10},
  [985] = {.lex_state = 10},
  [986] = {.lex_state = 12},
  [987] = {.lex_state = 0},
  [988] = {.lex_state = 11},
  [989] = {.lex_state = 12},
  [990] = {.lex_state = 256},
  [991] = {.lex_state = 12},
  [992] = {.lex_state = 11},
  [993] = {.lex_state = 10},
  [994] = {.lex_state = 10},
  [995] = {.lex_state = 12},
  [996] = {.lex_state = 63},
  [997] = {.lex_state = 256},
  [998] = {.lex_state = 27},
  [999] = {.lex_state = 256},
  [1000] = {.lex_state = 63},
  [1001] = {.lex_state = 63},
  [1002] = {.lex_state = 0},
  [1003] = {.lex_state = 27},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 10},
  [1006] = {.lex_state = 10},
  [1007] = {.lex_state = 63},
  [1008] = {.lex_state = 10},
  [1009] = {.lex_state = 10},
  [1010] = {.lex_state = 256},
  [1011] = {.lex_state = 256},
  [1012] = {.lex_state = 10},
  [1013] = {.lex_state = 28},
  [1014] = {.lex_state = 28},
  [1015] = {.lex_state = 27},
  [1016] = {.lex_state = 12},
  [1017] = {.lex_state = 10},
  [1018] = {.lex_state = 256},
  [1019] = {.lex_state = 256},
  [1020] = {.lex_state = 10},
  [1021] = {.lex_state = 10},
  [1022] = {.lex_state = 27},
  [1023] = {.lex_state = 0},
  [1024] = {.lex_state = 0},
  [1025] = {.lex_state = 27},
  [1026] = {.lex_state = 63},
  [1027] = {.lex_state = 27},
  [1028] = {.lex_state = 10},
  [1029] = {.lex_state = 63},
  [1030] = {.lex_state = 63},
  [1031] = {.lex_state = 63},
  [1032] = {.lex_state = 11},
  [1033] = {.lex_state = 28},
  [1034] = {.lex_state = 63},
  [1035] = {.lex_state = 27},
  [1036] = {.lex_state = 11},
  [1037] = {.lex_state = 11},
  [1038] = {.lex_state = 63},
  [1039] = {.lex_state = 28},
  [1040] = {.lex_state = 28},
  [1041] = {.lex_state = 63},
  [1042] = {.lex_state = 63},
  [1043] = {.lex_state = 63},
  [1044] = {.lex_state = 10},
  [1045] = {.lex_state = 63},
  [1046] = {.lex_state = 63},
  [1047] = {.lex_state = 256},
  [1048] = {.lex_state = 256},
  [1049] = {.lex_state = 63},
  [1050] = {.lex_state = 63},
  [1051] = {.lex_state = 63},
  [1052] = {.lex_state = 63},
  [1053] = {.lex_state = 63},
  [1054] = {.lex_state = 28},
  [1055] = {.lex_state = 63},
  [1056] = {.lex_state = 28},
  [1057] = {.lex_state = 63},
  [1058] = {.lex_state = 28},
  [1059] = {.lex_state = 63},
  [1060] = {.lex_state = 63},
  [1061] = {.lex_state = 63},
  [1062] = {.lex_state = 63},
  [1063] = {.lex_state = 63},
  [1064] = {.lex_state = 63},
  [1065] = {.lex_state = 63},
  [1066] = {.lex_state = 63},
  [1067] = {.lex_state = 10},
  [1068] = {.lex_state = 63},
  [1069] = {.lex_state = 63},
  [1070] = {.lex_state = 28},
  [1071] = {.lex_state = 63},
  [1072] = {.lex_state = 256},
  [1073] = {.lex_state = 256},
  [1074] = {.lex_state = 63},
  [1075] = {.lex_state = 63},
  [1076] = {.lex_state = 28},
  [1077] = {.lex_state = 63},
  [1078] = {.lex_state = 28},
  [1079] = {.lex_state = 256},
  [1080] = {.lex_state = 28},
  [1081] = {.lex_state = 28},
  [1082] = {.lex_state = 28},
  [1083] = {.lex_state = 28},
  [1084] = {.lex_state = 28},
  [1085] = {.lex_state = 12},
  [1086] = {.lex_state = 28},
  [1087] = {.lex_state = 28},
  [1088] = {.lex_state = 28},
  [1089] = {.lex_state = 256},
  [1090] = {.lex_state = 28},
  [1091] = {.lex_state = 256},
  [1092] = {.lex_state = 10},
  [1093] = {.lex_state = 64},
  [1094] = {.lex_state = 256},
  [1095] = {.lex_state = 256},
  [1096] = {.lex_state = 64},
  [1097] = {.lex_state = 28},
  [1098] = {.lex_state = 28},
  [1099] = {.lex_state = 28},
  [1100] = {.lex_state = 256},
  [1101] = {.lex_state = 12},
  [1102] = {.lex_state = 12},
  [1103] = {.lex_state = 12},
  [1104] = {.lex_state = 12},
  [1105] = {.lex_state = 256},
  [1106] = {.lex_state = 12},
  [1107] = {.lex_state = 28},
  [1108] = {.lex_state = 256},
  [1109] = {.lex_state = 64},
  [1110] = {.lex_state = 256},
  [1111] = {.lex_state = 256},
  [1112] = {.lex_state = 256},
  [1113] = {.lex_state = 10},
  [1114] = {.lex_state = 256},
  [1115] = {.lex_state = 0},
  [1116] = {.lex_state = 0},
  [1117] = {.lex_state = 256},
  [1118] = {.lex_state = 0},
  [1119] = {.lex_state = 0},
  [1120] = {.lex_state = 0},
  [1121] = {.lex_state = 0},
  [1122] = {.lex_state = 0},
  [1123] = {.lex_state = 0},
  [1124] = {.lex_state = 0},
  [1125] = {.lex_state = 10},
  [1126] = {.lex_state = 10},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 256},
  [1129] = {.lex_state = 256},
  [1130] = {.lex_state = 0},
  [1131] = {.lex_state = 10},
  [1132] = {.lex_state = 256},
  [1133] = {.lex_state = 0},
  [1134] = {.lex_state = 0},
  [1135] = {.lex_state = 0},
  [1136] = {.lex_state = 10},
  [1137] = {.lex_state = 256},
  [1138] = {.lex_state = 0},
  [1139] = {.lex_state = 0},
  [1140] = {.lex_state = 11},
  [1141] = {.lex_state = 0},
  [1142] = {.lex_state = 65},
  [1143] = {.lex_state = 65},
  [1144] = {.lex_state = 10},
  [1145] = {.lex_state = 63},
  [1146] = {.lex_state = 5},
  [1147] = {.lex_state = 5},
  [1148] = {.lex_state = 5},
  [1149] = {.lex_state = 10},
  [1150] = {.lex_state = 0},
  [1151] = {.lex_state = 10},
  [1152] = {.lex_state = 10},
  [1153] = {.lex_state = 12},
  [1154] = {.lex_state = 4},
  [1155] = {.lex_state = 10},
  [1156] = {.lex_state = 4},
  [1157] = {.lex_state = 5},
  [1158] = {.lex_state = 10},
  [1159] = {.lex_state = 0},
  [1160] = {.lex_state = 256},
  [1161] = {.lex_state = 10},
  [1162] = {.lex_state = 256},
  [1163] = {.lex_state = 256},
  [1164] = {.lex_state = 65},
  [1165] = {.lex_state = 10},
  [1166] = {.lex_state = 0},
  [1167] = {.lex_state = 10},
  [1168] = {.lex_state = 10},
  [1169] = {.lex_state = 4},
  [1170] = {.lex_state = 63},
  [1171] = {.lex_state = 4},
  [1172] = {.lex_state = 10},
  [1173] = {.lex_state = 5},
  [1174] = {.lex_state = 5},
  [1175] = {.lex_state = 10},
  [1176] = {.lex_state = 28},
  [1177] = {.lex_state = 64},
  [1178] = {.lex_state = 5},
  [1179] = {.lex_state = 0},
  [1180] = {.lex_state = 10},
  [1181] = {.lex_state = 27},
  [1182] = {.lex_state = 65},
  [1183] = {.lex_state = 5},
  [1184] = {.lex_state = 27},
  [1185] = {.lex_state = 10},
  [1186] = {.lex_state = 256},
  [1187] = {.lex_state = 63},
  [1188] = {.lex_state = 63},
  [1189] = {.lex_state = 10},
  [1190] = {.lex_state = 63},
  [1191] = {.lex_state = 0},
  [1192] = {.lex_state = 0},
  [1193] = {.lex_state = 64},
  [1194] = {.lex_state = 256},
  [1195] = {.lex_state = 64},
  [1196] = {.lex_state = 63},
  [1197] = {.lex_state = 64},
  [1198] = {.lex_state = 0},
  [1199] = {.lex_state = 256},
  [1200] = {.lex_state = 5},
  [1201] = {.lex_state = 5},
  [1202] = {.lex_state = 64},
  [1203] = {.lex_state = 256},
  [1204] = {.lex_state = 256},
  [1205] = {.lex_state = 12},
  [1206] = {.lex_state = 5},
  [1207] = {.lex_state = 64},
  [1208] = {.lex_state = 64},
  [1209] = {.lex_state = 64},
  [1210] = {.lex_state = 12},
  [1211] = {.lex_state = 256},
  [1212] = {.lex_state = 256},
  [1213] = {.lex_state = 256},
  [1214] = {.lex_state = 256},
  [1215] = {.lex_state = 12},
  [1216] = {.lex_state = 12},
  [1217] = {.lex_state = 256},
  [1218] = {.lex_state = 0},
  [1219] = {.lex_state = 63},
  [1220] = {.lex_state = 12},
  [1221] = {.lex_state = 12},
  [1222] = {.lex_state = 0},
  [1223] = {.lex_state = 256},
  [1224] = {.lex_state = 65},
  [1225] = {.lex_state = 256},
  [1226] = {.lex_state = 12},
  [1227] = {.lex_state = 65},
  [1228] = {.lex_state = 12},
  [1229] = {.lex_state = 12},
  [1230] = {.lex_state = 12},
  [1231] = {.lex_state = 12},
  [1232] = {.lex_state = 63},
  [1233] = {.lex_state = 12},
  [1234] = {.lex_state = 65},
  [1235] = {.lex_state = 5},
  [1236] = {.lex_state = 65},
  [1237] = {.lex_state = 63},
  [1238] = {.lex_state = 63},
  [1239] = {.lex_state = 12},
  [1240] = {.lex_state = 64},
  [1241] = {.lex_state = 0},
  [1242] = {.lex_state = 64},
  [1243] = {.lex_state = 64},
  [1244] = {.lex_state = 0},
  [1245] = {.lex_state = 64},
  [1246] = {.lex_state = 64},
  [1247] = {.lex_state = 64},
  [1248] = {.lex_state = 64},
  [1249] = {.lex_state = 64},
  [1250] = {.lex_state = 256},
  [1251] = {.lex_state = 256},
  [1252] = {.lex_state = 63},
  [1253] = {.lex_state = 64},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 256},
  [1256] = {.lex_state = 11},
  [1257] = {.lex_state = 0},
  [1258] = {.lex_state = 0},
  [1259] = {.lex_state = 64},
  [1260] = {.lex_state = 64},
  [1261] = {.lex_state = 64},
  [1262] = {.lex_state = 5},
  [1263] = {.lex_state = 64},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 256},
  [1266] = {.lex_state = 64},
  [1267] = {.lex_state = 63},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 0},
  [1270] = {.lex_state = 64},
  [1271] = {.lex_state = 64},
  [1272] = {.lex_state = 64},
  [1273] = {.lex_state = 256},
  [1274] = {.lex_state = 64},
  [1275] = {.lex_state = 5},
  [1276] = {.lex_state = 64},
  [1277] = {.lex_state = 64},
  [1278] = {.lex_state = 64},
  [1279] = {.lex_state = 63},
  [1280] = {.lex_state = 64},
  [1281] = {.lex_state = 256},
  [1282] = {.lex_state = 0},
  [1283] = {.lex_state = 64},
  [1284] = {.lex_state = 64},
  [1285] = {.lex_state = 64},
  [1286] = {.lex_state = 64},
  [1287] = {.lex_state = 64},
  [1288] = {.lex_state = 64},
  [1289] = {.lex_state = 64},
  [1290] = {.lex_state = 0},
  [1291] = {.lex_state = 5},
  [1292] = {.lex_state = 10},
  [1293] = {.lex_state = 65},
  [1294] = {.lex_state = 0},
  [1295] = {.lex_state = 64},
  [1296] = {.lex_state = 64},
  [1297] = {.lex_state = 63},
  [1298] = {.lex_state = 63},
  [1299] = {.lex_state = 256},
  [1300] = {.lex_state = 12},
  [1301] = {.lex_state = 5},
  [1302] = {.lex_state = 64},
  [1303] = {.lex_state = 64},
  [1304] = {.lex_state = 0},
  [1305] = {.lex_state = 0},
  [1306] = {.lex_state = 65},
  [1307] = {.lex_state = 65},
  [1308] = {.lex_state = 64},
  [1309] = {.lex_state = 64},
  [1310] = {.lex_state = 64},
  [1311] = {.lex_state = 64},
  [1312] = {.lex_state = 256},
  [1313] = {.lex_state = 63},
  [1314] = {.lex_state = 0},
  [1315] = {.lex_state = 64},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 64},
  [1318] = {.lex_state = 0},
  [1319] = {.lex_state = 0},
  [1320] = {.lex_state = 0},
  [1321] = {.lex_state = 65},
  [1322] = {.lex_state = 256},
  [1323] = {.lex_state = 63},
  [1324] = {.lex_state = 256},
  [1325] = {.lex_state = 256},
  [1326] = {.lex_state = 5},
  [1327] = {.lex_state = 256},
  [1328] = {.lex_state = 0},
  [1329] = {.lex_state = 0},
  [1330] = {.lex_state = 12},
  [1331] = {.lex_state = 17},
  [1332] = {.lex_state = 0},
  [1333] = {.lex_state = 12},
  [1334] = {.lex_state = 12},
  [1335] = {.lex_state = 0},
  [1336] = {.lex_state = 5},
  [1337] = {.lex_state = 0},
  [1338] = {.lex_state = 17},
  [1339] = {.lex_state = 0},
  [1340] = {.lex_state = 0},
  [1341] = {.lex_state = 11},
  [1342] = {.lex_state = 12},
  [1343] = {.lex_state = 12},
  [1344] = {.lex_state = 256},
  [1345] = {.lex_state = 0},
  [1346] = {.lex_state = 28},
  [1347] = {.lex_state = 0},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 0},
  [1350] = {.lex_state = 0},
  [1351] = {.lex_state = 0},
  [1352] = {.lex_state = 0},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 0},
  [1355] = {.lex_state = 0},
  [1356] = {.lex_state = 256},
  [1357] = {.lex_state = 0},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 10},
  [1360] = {.lex_state = 12},
  [1361] = {.lex_state = 12},
  [1362] = {.lex_state = 12},
  [1363] = {.lex_state = 12},
  [1364] = {.lex_state = 12},
  [1365] = {.lex_state = 11},
  [1366] = {.lex_state = 12},
  [1367] = {.lex_state = 0},
  [1368] = {.lex_state = 0},
  [1369] = {.lex_state = 0},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 0},
  [1372] = {.lex_state = 11},
  [1373] = {.lex_state = 0},
  [1374] = {.lex_state = 0},
  [1375] = {.lex_state = 256},
  [1376] = {.lex_state = 256},
  [1377] = {.lex_state = 5},
  [1378] = {.lex_state = 0},
  [1379] = {.lex_state = 256},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 0},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 0},
  [1384] = {.lex_state = 0},
  [1385] = {.lex_state = 11},
  [1386] = {.lex_state = 5},
  [1387] = {.lex_state = 0},
  [1388] = {.lex_state = 0},
  [1389] = {.lex_state = 11},
  [1390] = {.lex_state = 0},
  [1391] = {.lex_state = 0},
  [1392] = {.lex_state = 0},
  [1393] = {.lex_state = 0},
  [1394] = {.lex_state = 0},
  [1395] = {.lex_state = 0},
  [1396] = {.lex_state = 0},
  [1397] = {.lex_state = 0},
  [1398] = {.lex_state = 256},
  [1399] = {.lex_state = 0},
  [1400] = {.lex_state = 0},
  [1401] = {.lex_state = 12},
  [1402] = {.lex_state = 12},
  [1403] = {.lex_state = 256},
  [1404] = {.lex_state = 12},
  [1405] = {.lex_state = 12},
  [1406] = {.lex_state = 0},
  [1407] = {.lex_state = 12},
  [1408] = {.lex_state = 0},
  [1409] = {.lex_state = 12},
  [1410] = {.lex_state = 0},
  [1411] = {.lex_state = 0},
  [1412] = {.lex_state = 0},
  [1413] = {.lex_state = 0},
  [1414] = {.lex_state = 5},
  [1415] = {.lex_state = 0},
  [1416] = {.lex_state = 12},
  [1417] = {.lex_state = 256},
  [1418] = {.lex_state = 0},
  [1419] = {.lex_state = 0},
  [1420] = {.lex_state = 0},
  [1421] = {.lex_state = 0},
  [1422] = {.lex_state = 0},
  [1423] = {.lex_state = 256},
  [1424] = {.lex_state = 12},
  [1425] = {.lex_state = 256},
  [1426] = {.lex_state = 12},
  [1427] = {.lex_state = 0},
  [1428] = {.lex_state = 256},
  [1429] = {.lex_state = 0},
  [1430] = {.lex_state = 0},
  [1431] = {.lex_state = 0},
  [1432] = {.lex_state = 0},
  [1433] = {.lex_state = 0},
  [1434] = {.lex_state = 0},
  [1435] = {.lex_state = 0},
  [1436] = {.lex_state = 0},
  [1437] = {.lex_state = 0},
  [1438] = {.lex_state = 11},
  [1439] = {.lex_state = 0},
  [1440] = {.lex_state = 0},
  [1441] = {.lex_state = 11},
  [1442] = {.lex_state = 256},
  [1443] = {.lex_state = 256},
  [1444] = {.lex_state = 0},
  [1445] = {.lex_state = 0},
  [1446] = {.lex_state = 0},
  [1447] = {.lex_state = 12},
  [1448] = {.lex_state = 0},
  [1449] = {.lex_state = 0},
  [1450] = {.lex_state = 256},
  [1451] = {.lex_state = 12},
  [1452] = {.lex_state = 12},
  [1453] = {.lex_state = 256},
  [1454] = {.lex_state = 12},
  [1455] = {.lex_state = 0},
  [1456] = {.lex_state = 256},
  [1457] = {.lex_state = 17},
  [1458] = {.lex_state = 256},
  [1459] = {.lex_state = 0},
  [1460] = {.lex_state = 0},
  [1461] = {.lex_state = 256},
  [1462] = {.lex_state = 0},
  [1463] = {.lex_state = 11},
  [1464] = {.lex_state = 12},
  [1465] = {.lex_state = 0},
  [1466] = {.lex_state = 256},
  [1467] = {.lex_state = 0},
  [1468] = {.lex_state = 17},
  [1469] = {.lex_state = 0},
  [1470] = {.lex_state = 0},
  [1471] = {.lex_state = 12},
  [1472] = {.lex_state = 256},
  [1473] = {.lex_state = 11},
  [1474] = {.lex_state = 65},
  [1475] = {.lex_state = 0},
  [1476] = {.lex_state = 0},
  [1477] = {.lex_state = 0},
  [1478] = {.lex_state = 0},
  [1479] = {.lex_state = 0},
  [1480] = {.lex_state = 0},
  [1481] = {.lex_state = 0},
  [1482] = {.lex_state = 0},
  [1483] = {.lex_state = 0},
  [1484] = {.lex_state = 0},
  [1485] = {.lex_state = 12},
  [1486] = {.lex_state = 0},
  [1487] = {.lex_state = 256},
  [1488] = {.lex_state = 0},
  [1489] = {.lex_state = 256},
  [1490] = {.lex_state = 0},
  [1491] = {.lex_state = 11},
  [1492] = {.lex_state = 256},
  [1493] = {.lex_state = 0},
  [1494] = {.lex_state = 0},
  [1495] = {.lex_state = 256},
  [1496] = {.lex_state = 0},
  [1497] = {.lex_state = 12},
  [1498] = {.lex_state = 0},
  [1499] = {.lex_state = 17},
  [1500] = {.lex_state = 256},
  [1501] = {.lex_state = 12},
  [1502] = {.lex_state = 0},
  [1503] = {.lex_state = 0},
  [1504] = {.lex_state = 0},
  [1505] = {.lex_state = 12},
  [1506] = {.lex_state = 12},
  [1507] = {.lex_state = 0},
  [1508] = {.lex_state = 0},
  [1509] = {.lex_state = 12},
  [1510] = {.lex_state = 11},
  [1511] = {.lex_state = 11},
  [1512] = {.lex_state = 63},
  [1513] = {.lex_state = 11},
  [1514] = {.lex_state = 17},
  [1515] = {.lex_state = 0},
  [1516] = {.lex_state = 11},
  [1517] = {.lex_state = 256},
  [1518] = {.lex_state = 256},
  [1519] = {.lex_state = 12},
  [1520] = {.lex_state = 0},
  [1521] = {.lex_state = 256},
  [1522] = {.lex_state = 256},
  [1523] = {.lex_state = 0},
  [1524] = {.lex_state = 11},
  [1525] = {.lex_state = 0},
  [1526] = {.lex_state = 0},
  [1527] = {.lex_state = 12},
  [1528] = {.lex_state = 11},
  [1529] = {.lex_state = 0},
  [1530] = {.lex_state = 0},
  [1531] = {.lex_state = 256},
  [1532] = {.lex_state = 11},
  [1533] = {.lex_state = 0},
  [1534] = {.lex_state = 27},
  [1535] = {.lex_state = 0},
  [1536] = {.lex_state = 0},
  [1537] = {.lex_state = 256},
  [1538] = {.lex_state = 0},
  [1539] = {.lex_state = 5},
  [1540] = {.lex_state = 12},
  [1541] = {.lex_state = 11},
  [1542] = {.lex_state = 68},
  [1543] = {.lex_state = 0},
  [1544] = {.lex_state = 256},
  [1545] = {.lex_state = 0},
  [1546] = {.lex_state = 0},
  [1547] = {.lex_state = 256},
  [1548] = {.lex_state = 0},
  [1549] = {.lex_state = 0},
  [1550] = {.lex_state = 0},
  [1551] = {.lex_state = 0},
  [1552] = {.lex_state = 0},
  [1553] = {.lex_state = 0},
  [1554] = {.lex_state = 0},
  [1555] = {.lex_state = 0},
  [1556] = {.lex_state = 0},
  [1557] = {.lex_state = 10},
  [1558] = {.lex_state = 0},
  [1559] = {.lex_state = 64},
  [1560] = {.lex_state = 0},
  [1561] = {.lex_state = 256},
  [1562] = {.lex_state = 0},
  [1563] = {.lex_state = 64},
  [1564] = {.lex_state = 0},
  [1565] = {.lex_state = 63},
  [1566] = {.lex_state = 0},
  [1567] = {.lex_state = 0},
  [1568] = {.lex_state = 64},
  [1569] = {.lex_state = 0},
  [1570] = {.lex_state = 256},
  [1571] = {.lex_state = 0},
  [1572] = {.lex_state = 64},
  [1573] = {.lex_state = 0},
  [1574] = {.lex_state = 256},
  [1575] = {.lex_state = 0},
  [1576] = {.lex_state = 11},
  [1577] = {.lex_state = 63},
  [1578] = {.lex_state = 0},
  [1579] = {.lex_state = 64},
  [1580] = {.lex_state = 27},
  [1581] = {.lex_state = 256},
  [1582] = {.lex_state = 11},
  [1583] = {.lex_state = 0},
  [1584] = {.lex_state = 0},
  [1585] = {.lex_state = 0},
  [1586] = {.lex_state = 0},
  [1587] = {.lex_state = 64},
  [1588] = {.lex_state = 0},
  [1589] = {.lex_state = 0},
  [1590] = {.lex_state = 64},
  [1591] = {.lex_state = 0},
  [1592] = {.lex_state = 27},
  [1593] = {.lex_state = 256},
  [1594] = {.lex_state = 0},
  [1595] = {.lex_state = 10},
  [1596] = {.lex_state = 11},
  [1597] = {.lex_state = 256},
  [1598] = {.lex_state = 64},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 256},
  [1601] = {.lex_state = 64},
  [1602] = {.lex_state = 0},
  [1603] = {.lex_state = 64},
  [1604] = {.lex_state = 0},
  [1605] = {.lex_state = 11},
  [1606] = {.lex_state = 0},
  [1607] = {.lex_state = 256},
  [1608] = {.lex_state = 0},
  [1609] = {.lex_state = 11},
  [1610] = {.lex_state = 256},
  [1611] = {.lex_state = 64},
  [1612] = {.lex_state = 256},
  [1613] = {.lex_state = 64},
  [1614] = {.lex_state = 11},
  [1615] = {.lex_state = 11},
  [1616] = {.lex_state = 64},
  [1617] = {.lex_state = 0},
  [1618] = {.lex_state = 64},
  [1619] = {.lex_state = 0},
  [1620] = {.lex_state = 64},
  [1621] = {.lex_state = 256},
  [1622] = {.lex_state = 0},
  [1623] = {.lex_state = 0},
  [1624] = {.lex_state = 11},
  [1625] = {.lex_state = 0},
  [1626] = {.lex_state = 256},
  [1627] = {.lex_state = 256},
  [1628] = {.lex_state = 64},
  [1629] = {.lex_state = 256},
  [1630] = {.lex_state = 0},
  [1631] = {.lex_state = 0},
  [1632] = {.lex_state = 0},
  [1633] = {.lex_state = 64},
  [1634] = {.lex_state = 0},
  [1635] = {.lex_state = 10},
  [1636] = {.lex_state = 64},
  [1637] = {.lex_state = 256},
  [1638] = {.lex_state = 0},
  [1639] = {.lex_state = 0},
  [1640] = {.lex_state = 256},
  [1641] = {.lex_state = 256},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 64},
  [1644] = {.lex_state = 256},
  [1645] = {.lex_state = 64},
  [1646] = {.lex_state = 11},
  [1647] = {.lex_state = 256},
  [1648] = {.lex_state = 64},
  [1649] = {.lex_state = 64},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 0},
  [1652] = {.lex_state = 64},
  [1653] = {.lex_state = 0},
  [1654] = {.lex_state = 0},
  [1655] = {.lex_state = 256},
  [1656] = {.lex_state = 256},
  [1657] = {.lex_state = 64},
  [1658] = {.lex_state = 256},
  [1659] = {.lex_state = 64},
  [1660] = {.lex_state = 0},
  [1661] = {.lex_state = 0},
  [1662] = {.lex_state = 64},
  [1663] = {.lex_state = 0},
  [1664] = {.lex_state = 0},
  [1665] = {.lex_state = 64},
  [1666] = {.lex_state = 0},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 64},
  [1669] = {.lex_state = 64},
  [1670] = {.lex_state = 64},
  [1671] = {.lex_state = 256},
  [1672] = {.lex_state = 64},
  [1673] = {.lex_state = 0},
  [1674] = {.lex_state = 64},
  [1675] = {.lex_state = 0},
  [1676] = {.lex_state = 0},
  [1677] = {.lex_state = 11},
  [1678] = {.lex_state = 64},
  [1679] = {.lex_state = 0},
  [1680] = {.lex_state = 11},
  [1681] = {.lex_state = 0},
  [1682] = {.lex_state = 0},
  [1683] = {.lex_state = 0},
  [1684] = {.lex_state = 0},
  [1685] = {.lex_state = 0},
  [1686] = {.lex_state = 0},
  [1687] = {.lex_state = 256},
  [1688] = {.lex_state = 0},
  [1689] = {.lex_state = 64},
  [1690] = {.lex_state = 256},
  [1691] = {.lex_state = 256},
  [1692] = {.lex_state = 0},
  [1693] = {.lex_state = 11},
  [1694] = {.lex_state = 256},
  [1695] = {.lex_state = 256},
  [1696] = {.lex_state = 11},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 0},
  [1699] = {.lex_state = 68},
  [1700] = {.lex_state = 256},
  [1701] = {.lex_state = 256},
  [1702] = {.lex_state = 64},
  [1703] = {.lex_state = 0},
  [1704] = {.lex_state = 0},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 0},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 256},
  [1709] = {.lex_state = 0},
  [1710] = {.lex_state = 0},
  [1711] = {.lex_state = 256},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 0},
  [1714] = {.lex_state = 256},
  [1715] = {.lex_state = 0},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 256},
  [1718] = {.lex_state = 0},
  [1719] = {.lex_state = 256},
  [1720] = {.lex_state = 0},
  [1721] = {.lex_state = 64},
  [1722] = {.lex_state = 64},
  [1723] = {.lex_state = 64},
  [1724] = {.lex_state = 256},
  [1725] = {.lex_state = 0},
  [1726] = {.lex_state = 256},
  [1727] = {.lex_state = 68},
  [1728] = {.lex_state = 256},
  [1729] = {.lex_state = 256},
  [1730] = {.lex_state = 0},
  [1731] = {.lex_state = 10},
  [1732] = {.lex_state = 10},
  [1733] = {.lex_state = 63},
  [1734] = {.lex_state = 63},
  [1735] = {.lex_state = 0},
  [1736] = {.lex_state = 10},
  [1737] = {.lex_state = 256},
  [1738] = {.lex_state = 10},
  [1739] = {.lex_state = 68},
  [1740] = {.lex_state = 0},
  [1741] = {.lex_state = 64},
  [1742] = {.lex_state = 0},
  [1743] = {.lex_state = 11},
  [1744] = {.lex_state = 0},
  [1745] = {.lex_state = 0},
  [1746] = {.lex_state = 0},
  [1747] = {.lex_state = 0},
  [1748] = {.lex_state = 11},
  [1749] = {.lex_state = 0},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 0},
  [1752] = {.lex_state = 11},
  [1753] = {.lex_state = 0},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 0},
  [1756] = {.lex_state = 11},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 0},
  [1759] = {.lex_state = 0},
  [1760] = {.lex_state = 0},
  [1761] = {.lex_state = 0},
  [1762] = {.lex_state = 0},
  [1763] = {.lex_state = 17},
  [1764] = {.lex_state = 11},
  [1765] = {.lex_state = 11},
  [1766] = {.lex_state = 11},
  [1767] = {.lex_state = 11},
  [1768] = {.lex_state = 11},
  [1769] = {.lex_state = 0},
  [1770] = {.lex_state = 4},
  [1771] = {.lex_state = 11},
  [1772] = {.lex_state = 0},
  [1773] = {.lex_state = 11},
  [1774] = {.lex_state = 11},
  [1775] = {.lex_state = 0},
  [1776] = {.lex_state = 415},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 11},
  [1779] = {.lex_state = 0},
  [1780] = {.lex_state = 17},
  [1781] = {.lex_state = 0},
  [1782] = {.lex_state = 0},
  [1783] = {.lex_state = 0},
  [1784] = {.lex_state = 0},
  [1785] = {.lex_state = 0},
  [1786] = {.lex_state = 11},
  [1787] = {.lex_state = 0},
  [1788] = {.lex_state = 0},
  [1789] = {.lex_state = 0},
  [1790] = {.lex_state = 11},
  [1791] = {.lex_state = 0},
  [1792] = {.lex_state = 17},
  [1793] = {.lex_state = 0},
  [1794] = {.lex_state = 11},
  [1795] = {.lex_state = 11},
  [1796] = {.lex_state = 11},
  [1797] = {.lex_state = 11},
  [1798] = {.lex_state = 0},
  [1799] = {.lex_state = 0},
  [1800] = {.lex_state = 11},
  [1801] = {.lex_state = 11},
  [1802] = {.lex_state = 11},
  [1803] = {.lex_state = 13},
  [1804] = {.lex_state = 0},
  [1805] = {.lex_state = 11},
  [1806] = {.lex_state = 0},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 0},
  [1810] = {.lex_state = 11},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 0},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 0},
  [1816] = {.lex_state = 0},
  [1817] = {.lex_state = 0},
  [1818] = {.lex_state = 0},
  [1819] = {.lex_state = 11},
  [1820] = {.lex_state = 0},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 0},
  [1823] = {.lex_state = 0},
  [1824] = {.lex_state = 17},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 0},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 0},
  [1829] = {.lex_state = 0},
  [1830] = {.lex_state = 0},
  [1831] = {.lex_state = 11},
  [1832] = {.lex_state = 0},
  [1833] = {.lex_state = 0},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 17},
  [1836] = {.lex_state = 0},
  [1837] = {.lex_state = 11},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 11},
  [1841] = {.lex_state = 0},
  [1842] = {.lex_state = 0},
  [1843] = {.lex_state = 0},
  [1844] = {.lex_state = 0},
  [1845] = {.lex_state = 256},
  [1846] = {.lex_state = 0},
  [1847] = {.lex_state = 13},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 11},
  [1850] = {.lex_state = 0},
  [1851] = {.lex_state = 0},
  [1852] = {.lex_state = 11},
  [1853] = {.lex_state = 415},
  [1854] = {.lex_state = 0},
  [1855] = {.lex_state = 17},
  [1856] = {.lex_state = 17},
  [1857] = {.lex_state = 11},
  [1858] = {.lex_state = 0},
  [1859] = {.lex_state = 0},
  [1860] = {.lex_state = 415},
  [1861] = {.lex_state = 0},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 256},
  [1864] = {.lex_state = 13},
  [1865] = {.lex_state = 0},
  [1866] = {.lex_state = 0},
  [1867] = {.lex_state = 415},
  [1868] = {.lex_state = 0},
  [1869] = {.lex_state = 11},
  [1870] = {.lex_state = 11},
  [1871] = {.lex_state = 0},
  [1872] = {.lex_state = 415},
  [1873] = {.lex_state = 0},
  [1874] = {.lex_state = 0},
  [1875] = {.lex_state = 4},
  [1876] = {.lex_state = 11},
  [1877] = {.lex_state = 13},
  [1878] = {.lex_state = 0},
  [1879] = {.lex_state = 17},
  [1880] = {.lex_state = 0},
  [1881] = {.lex_state = 0},
  [1882] = {.lex_state = 11},
  [1883] = {.lex_state = 11},
  [1884] = {.lex_state = 17},
  [1885] = {.lex_state = 0},
  [1886] = {.lex_state = 11},
  [1887] = {.lex_state = 13},
  [1888] = {.lex_state = 0},
  [1889] = {.lex_state = 17},
  [1890] = {.lex_state = 11},
  [1891] = {.lex_state = 256},
  [1892] = {.lex_state = 0},
  [1893] = {.lex_state = 0},
  [1894] = {.lex_state = 0},
  [1895] = {.lex_state = 17},
  [1896] = {.lex_state = 0},
  [1897] = {.lex_state = 0},
  [1898] = {.lex_state = 11},
  [1899] = {.lex_state = 0},
  [1900] = {.lex_state = 0},
  [1901] = {.lex_state = 0},
  [1902] = {.lex_state = 11},
  [1903] = {.lex_state = 11},
  [1904] = {.lex_state = 11},
  [1905] = {.lex_state = 0},
  [1906] = {.lex_state = 0},
  [1907] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_impl] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_trait] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_mod] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_fn] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_use] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym__] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_u8] = ACTIONS(1),
    [anon_sym_i8] = ACTIONS(1),
    [anon_sym_u16] = ACTIONS(1),
    [anon_sym_i16] = ACTIONS(1),
    [anon_sym_u32] = ACTIONS(1),
    [anon_sym_i32] = ACTIONS(1),
    [anon_sym_u64] = ACTIONS(1),
    [anon_sym_i64] = ACTIONS(1),
    [anon_sym_u128] = ACTIONS(1),
    [anon_sym_i128] = ACTIONS(1),
    [anon_sym_usize] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_ByteArray] = ACTIONS(1),
    [anon_sym_felt252] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_extern] = ACTIONS(1),
    [anon_sym_nopanic] = ACTIONS(1),
    [anon_sym_loop] = ACTIONS(1),
    [anon_sym_match] = ACTIONS(1),
    [anon_sym_pub] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [sym_numeric_literal] = ACTIONS(1),
    [aux_sym_string_literal_token1] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_shortstring_literal] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_LT2] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_move] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_ref] = ACTIONS(1),
    [sym_mutable_specifier] = ACTIONS(1),
    [sym_super] = ACTIONS(1),
    [sym_crate] = ACTIONS(1),
    [sym_line_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_source_file] = STATE(1785),
    [sym__statement] = STATE(4),
    [sym_impl_item] = STATE(4),
    [sym_trait_item] = STATE(4),
    [sym_associated_type] = STATE(4),
    [sym_associated_impl] = STATE(4),
    [sym_const_item] = STATE(4),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(4),
    [sym_attribute_item] = STATE(4),
    [sym_inner_attribute_item] = STATE(4),
    [sym_mod_item] = STATE(4),
    [sym_struct_item] = STATE(4),
    [sym_enum_item] = STATE(4),
    [sym_type_item] = STATE(4),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(4),
    [sym_function_item] = STATE(4),
    [sym_function_signature_item] = STATE(4),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(4),
    [sym_use_declaration] = STATE(4),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(4),
    [sym_expression] = STATE(916),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(4),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [2] = {
    [sym__statement] = STATE(5),
    [sym_impl_item] = STATE(5),
    [sym_trait_item] = STATE(5),
    [sym_associated_type] = STATE(5),
    [sym_associated_impl] = STATE(5),
    [sym_const_item] = STATE(5),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(5),
    [sym_attribute_item] = STATE(5),
    [sym_inner_attribute_item] = STATE(5),
    [sym_mod_item] = STATE(5),
    [sym_struct_item] = STATE(5),
    [sym_enum_item] = STATE(5),
    [sym_type_item] = STATE(5),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(5),
    [sym_function_item] = STATE(5),
    [sym_function_signature_item] = STATE(5),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(5),
    [sym_use_declaration] = STATE(5),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(5),
    [sym_expression] = STATE(831),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(5),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(87),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [3] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(885),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(89),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__statement] = STATE(6),
    [sym_impl_item] = STATE(6),
    [sym_trait_item] = STATE(6),
    [sym_associated_type] = STATE(6),
    [sym_associated_impl] = STATE(6),
    [sym_const_item] = STATE(6),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(6),
    [sym_attribute_item] = STATE(6),
    [sym_inner_attribute_item] = STATE(6),
    [sym_mod_item] = STATE(6),
    [sym_struct_item] = STATE(6),
    [sym_enum_item] = STATE(6),
    [sym_type_item] = STATE(6),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(6),
    [sym_function_item] = STATE(6),
    [sym_function_signature_item] = STATE(6),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(6),
    [sym_use_declaration] = STATE(6),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(6),
    [sym_expression] = STATE(916),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(6),
    [ts_builtin_sym_end] = ACTIONS(91),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(811),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__statement] = STATE(6),
    [sym_impl_item] = STATE(6),
    [sym_trait_item] = STATE(6),
    [sym_associated_type] = STATE(6),
    [sym_associated_impl] = STATE(6),
    [sym_const_item] = STATE(6),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(6),
    [sym_attribute_item] = STATE(6),
    [sym_inner_attribute_item] = STATE(6),
    [sym_mod_item] = STATE(6),
    [sym_struct_item] = STATE(6),
    [sym_enum_item] = STATE(6),
    [sym_type_item] = STATE(6),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(6),
    [sym_function_item] = STATE(6),
    [sym_function_signature_item] = STATE(6),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(6),
    [sym_use_declaration] = STATE(6),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(6),
    [sym_expression] = STATE(916),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(6),
    [ts_builtin_sym_end] = ACTIONS(95),
    [anon_sym_LBRACE] = ACTIONS(97),
    [anon_sym_impl] = ACTIONS(100),
    [anon_sym_SEMI] = ACTIONS(103),
    [anon_sym_trait] = ACTIONS(106),
    [anon_sym_type] = ACTIONS(109),
    [anon_sym_const] = ACTIONS(112),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_POUND] = ACTIONS(118),
    [anon_sym_LBRACK] = ACTIONS(121),
    [anon_sym_mod] = ACTIONS(124),
    [anon_sym_struct] = ACTIONS(127),
    [anon_sym_enum] = ACTIONS(130),
    [anon_sym_fn] = ACTIONS(133),
    [anon_sym_let] = ACTIONS(136),
    [anon_sym_use] = ACTIONS(139),
    [anon_sym_COLON_COLON] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_LPAREN] = ACTIONS(145),
    [anon_sym_u8] = ACTIONS(148),
    [anon_sym_i8] = ACTIONS(148),
    [anon_sym_u16] = ACTIONS(148),
    [anon_sym_i16] = ACTIONS(148),
    [anon_sym_u32] = ACTIONS(148),
    [anon_sym_i32] = ACTIONS(148),
    [anon_sym_u64] = ACTIONS(148),
    [anon_sym_i64] = ACTIONS(148),
    [anon_sym_u128] = ACTIONS(148),
    [anon_sym_i128] = ACTIONS(148),
    [anon_sym_usize] = ACTIONS(148),
    [anon_sym_bool] = ACTIONS(148),
    [anon_sym_ByteArray] = ACTIONS(148),
    [anon_sym_felt252] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_PIPE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(115),
    [anon_sym_DOT_DOT] = ACTIONS(157),
    [anon_sym_break] = ACTIONS(160),
    [anon_sym_continue] = ACTIONS(163),
    [anon_sym_default] = ACTIONS(166),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_extern] = ACTIONS(172),
    [anon_sym_loop] = ACTIONS(175),
    [anon_sym_match] = ACTIONS(178),
    [anon_sym_pub] = ACTIONS(181),
    [anon_sym_return] = ACTIONS(184),
    [anon_sym_while] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(190),
    [sym_numeric_literal] = ACTIONS(193),
    [aux_sym_string_literal_token1] = ACTIONS(196),
    [sym_shortstring_literal] = ACTIONS(199),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_move] = ACTIONS(205),
    [anon_sym_ref] = ACTIONS(208),
    [sym_identifier] = ACTIONS(211),
    [sym_super] = ACTIONS(214),
    [sym_line_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__statement] = STATE(8),
    [sym_impl_item] = STATE(8),
    [sym_trait_item] = STATE(8),
    [sym_associated_type] = STATE(8),
    [sym_associated_impl] = STATE(8),
    [sym_const_item] = STATE(8),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(8),
    [sym_attribute_item] = STATE(8),
    [sym_inner_attribute_item] = STATE(8),
    [sym_mod_item] = STATE(8),
    [sym_struct_item] = STATE(8),
    [sym_enum_item] = STATE(8),
    [sym_type_item] = STATE(8),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(8),
    [sym_function_item] = STATE(8),
    [sym_function_signature_item] = STATE(8),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(8),
    [sym_use_declaration] = STATE(8),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(8),
    [sym_expression] = STATE(857),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(8),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(217),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(863),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(219),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(197),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(916),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(97),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_impl] = ACTIONS(100),
    [anon_sym_SEMI] = ACTIONS(103),
    [anon_sym_trait] = ACTIONS(106),
    [anon_sym_type] = ACTIONS(109),
    [anon_sym_const] = ACTIONS(112),
    [anon_sym_BANG] = ACTIONS(115),
    [anon_sym_POUND] = ACTIONS(118),
    [anon_sym_LBRACK] = ACTIONS(121),
    [anon_sym_mod] = ACTIONS(124),
    [anon_sym_struct] = ACTIONS(127),
    [anon_sym_enum] = ACTIONS(130),
    [anon_sym_fn] = ACTIONS(133),
    [anon_sym_let] = ACTIONS(136),
    [anon_sym_use] = ACTIONS(139),
    [anon_sym_COLON_COLON] = ACTIONS(142),
    [anon_sym_STAR] = ACTIONS(115),
    [anon_sym_LPAREN] = ACTIONS(145),
    [anon_sym_u8] = ACTIONS(148),
    [anon_sym_i8] = ACTIONS(148),
    [anon_sym_u16] = ACTIONS(148),
    [anon_sym_i16] = ACTIONS(148),
    [anon_sym_u32] = ACTIONS(148),
    [anon_sym_i32] = ACTIONS(148),
    [anon_sym_u64] = ACTIONS(148),
    [anon_sym_i64] = ACTIONS(148),
    [anon_sym_u128] = ACTIONS(148),
    [anon_sym_i128] = ACTIONS(148),
    [anon_sym_usize] = ACTIONS(148),
    [anon_sym_bool] = ACTIONS(148),
    [anon_sym_ByteArray] = ACTIONS(148),
    [anon_sym_felt252] = ACTIONS(148),
    [anon_sym_DASH] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_PIPE] = ACTIONS(154),
    [anon_sym_AT] = ACTIONS(115),
    [anon_sym_DOT_DOT] = ACTIONS(157),
    [anon_sym_break] = ACTIONS(160),
    [anon_sym_continue] = ACTIONS(163),
    [anon_sym_default] = ACTIONS(166),
    [anon_sym_if] = ACTIONS(169),
    [anon_sym_extern] = ACTIONS(172),
    [anon_sym_loop] = ACTIONS(175),
    [anon_sym_match] = ACTIONS(178),
    [anon_sym_pub] = ACTIONS(181),
    [anon_sym_return] = ACTIONS(184),
    [anon_sym_while] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(190),
    [sym_numeric_literal] = ACTIONS(193),
    [aux_sym_string_literal_token1] = ACTIONS(196),
    [sym_shortstring_literal] = ACTIONS(199),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_move] = ACTIONS(205),
    [anon_sym_ref] = ACTIONS(208),
    [sym_identifier] = ACTIONS(211),
    [sym_super] = ACTIONS(214),
    [sym_line_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__statement] = STATE(11),
    [sym_impl_item] = STATE(11),
    [sym_trait_item] = STATE(11),
    [sym_associated_type] = STATE(11),
    [sym_associated_impl] = STATE(11),
    [sym_const_item] = STATE(11),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(11),
    [sym_attribute_item] = STATE(11),
    [sym_inner_attribute_item] = STATE(11),
    [sym_mod_item] = STATE(11),
    [sym_struct_item] = STATE(11),
    [sym_enum_item] = STATE(11),
    [sym_type_item] = STATE(11),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(11),
    [sym_function_item] = STATE(11),
    [sym_function_signature_item] = STATE(11),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(11),
    [sym_use_declaration] = STATE(11),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(11),
    [sym_expression] = STATE(871),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(11),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(221),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(873),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__statement] = STATE(13),
    [sym_impl_item] = STATE(13),
    [sym_trait_item] = STATE(13),
    [sym_associated_type] = STATE(13),
    [sym_associated_impl] = STATE(13),
    [sym_const_item] = STATE(13),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(13),
    [sym_attribute_item] = STATE(13),
    [sym_inner_attribute_item] = STATE(13),
    [sym_mod_item] = STATE(13),
    [sym_struct_item] = STATE(13),
    [sym_enum_item] = STATE(13),
    [sym_type_item] = STATE(13),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(13),
    [sym_function_item] = STATE(13),
    [sym_function_signature_item] = STATE(13),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(13),
    [sym_use_declaration] = STATE(13),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(13),
    [sym_expression] = STATE(876),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(13),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [13] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(877),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(227),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [14] = {
    [sym__statement] = STATE(15),
    [sym_impl_item] = STATE(15),
    [sym_trait_item] = STATE(15),
    [sym_associated_type] = STATE(15),
    [sym_associated_impl] = STATE(15),
    [sym_const_item] = STATE(15),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(15),
    [sym_attribute_item] = STATE(15),
    [sym_inner_attribute_item] = STATE(15),
    [sym_mod_item] = STATE(15),
    [sym_struct_item] = STATE(15),
    [sym_enum_item] = STATE(15),
    [sym_type_item] = STATE(15),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(15),
    [sym_function_item] = STATE(15),
    [sym_function_signature_item] = STATE(15),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(15),
    [sym_use_declaration] = STATE(15),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(15),
    [sym_expression] = STATE(878),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(15),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(229),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [15] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(879),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(231),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [16] = {
    [sym__statement] = STATE(17),
    [sym_impl_item] = STATE(17),
    [sym_trait_item] = STATE(17),
    [sym_associated_type] = STATE(17),
    [sym_associated_impl] = STATE(17),
    [sym_const_item] = STATE(17),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(17),
    [sym_attribute_item] = STATE(17),
    [sym_inner_attribute_item] = STATE(17),
    [sym_mod_item] = STATE(17),
    [sym_struct_item] = STATE(17),
    [sym_enum_item] = STATE(17),
    [sym_type_item] = STATE(17),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(17),
    [sym_function_item] = STATE(17),
    [sym_function_signature_item] = STATE(17),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(17),
    [sym_use_declaration] = STATE(17),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(17),
    [sym_expression] = STATE(880),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(17),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(233),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [17] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(881),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(235),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [18] = {
    [sym__statement] = STATE(19),
    [sym_impl_item] = STATE(19),
    [sym_trait_item] = STATE(19),
    [sym_associated_type] = STATE(19),
    [sym_associated_impl] = STATE(19),
    [sym_const_item] = STATE(19),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(19),
    [sym_attribute_item] = STATE(19),
    [sym_inner_attribute_item] = STATE(19),
    [sym_mod_item] = STATE(19),
    [sym_struct_item] = STATE(19),
    [sym_enum_item] = STATE(19),
    [sym_type_item] = STATE(19),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(19),
    [sym_function_item] = STATE(19),
    [sym_function_signature_item] = STATE(19),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(19),
    [sym_use_declaration] = STATE(19),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(19),
    [sym_expression] = STATE(882),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(19),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(237),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [19] = {
    [sym__statement] = STATE(9),
    [sym_impl_item] = STATE(9),
    [sym_trait_item] = STATE(9),
    [sym_associated_type] = STATE(9),
    [sym_associated_impl] = STATE(9),
    [sym_const_item] = STATE(9),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(9),
    [sym_attribute_item] = STATE(9),
    [sym_inner_attribute_item] = STATE(9),
    [sym_mod_item] = STATE(9),
    [sym_struct_item] = STATE(9),
    [sym_enum_item] = STATE(9),
    [sym_type_item] = STATE(9),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(9),
    [sym_function_item] = STATE(9),
    [sym_function_signature_item] = STATE(9),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(9),
    [sym_use_declaration] = STATE(9),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(9),
    [sym_expression] = STATE(883),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(9),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(239),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [20] = {
    [sym__statement] = STATE(3),
    [sym_impl_item] = STATE(3),
    [sym_trait_item] = STATE(3),
    [sym_associated_type] = STATE(3),
    [sym_associated_impl] = STATE(3),
    [sym_const_item] = STATE(3),
    [sym_macro_invocation] = STATE(166),
    [sym_empty_statement] = STATE(3),
    [sym_attribute_item] = STATE(3),
    [sym_inner_attribute_item] = STATE(3),
    [sym_mod_item] = STATE(3),
    [sym_struct_item] = STATE(3),
    [sym_enum_item] = STATE(3),
    [sym_type_item] = STATE(3),
    [sym_extern_type] = STATE(301),
    [sym_external_function_item] = STATE(3),
    [sym_function_item] = STATE(3),
    [sym_function_signature_item] = STATE(3),
    [sym_function] = STATE(1498),
    [sym_let_declaration] = STATE(3),
    [sym_use_declaration] = STATE(3),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression_statement] = STATE(3),
    [sym_expression] = STATE(884),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(165),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(165),
    [sym_if_expression] = STATE(165),
    [sym_match_expression] = STATE(165),
    [sym_while_expression] = STATE(165),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(165),
    [sym_loop_expression] = STATE(165),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [sym_visibility_modifier] = STATE(979),
    [sym_extern] = STATE(1198),
    [aux_sym_source_file_repeat1] = STATE(3),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(241),
    [anon_sym_impl] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_trait] = ACTIONS(13),
    [anon_sym_type] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_mod] = ACTIONS(25),
    [anon_sym_struct] = ACTIONS(27),
    [anon_sym_enum] = ACTIONS(29),
    [anon_sym_fn] = ACTIONS(31),
    [anon_sym_let] = ACTIONS(33),
    [anon_sym_use] = ACTIONS(35),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(55),
    [anon_sym_extern] = ACTIONS(57),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_pub] = ACTIONS(63),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(553),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(243),
    [anon_sym_SEMI] = ACTIONS(243),
    [anon_sym_EQ] = ACTIONS(245),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_RBRACK] = ACTIONS(243),
    [anon_sym_COMMA] = ACTIONS(243),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(243),
    [anon_sym_RPAREN] = ACTIONS(243),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(245),
    [anon_sym_GT] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(245),
    [anon_sym_DASH] = ACTIONS(245),
    [anon_sym_SLASH] = ACTIONS(245),
    [anon_sym_PERCENT] = ACTIONS(245),
    [anon_sym_CARET] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(245),
    [anon_sym_PIPE] = ACTIONS(245),
    [anon_sym_AMP_AMP] = ACTIONS(243),
    [anon_sym_PIPE_PIPE] = ACTIONS(243),
    [anon_sym_LT_LT] = ACTIONS(243),
    [anon_sym_GT_GT] = ACTIONS(243),
    [anon_sym_PLUS_EQ] = ACTIONS(243),
    [anon_sym_DASH_EQ] = ACTIONS(243),
    [anon_sym_STAR_EQ] = ACTIONS(243),
    [anon_sym_SLASH_EQ] = ACTIONS(243),
    [anon_sym_PERCENT_EQ] = ACTIONS(243),
    [anon_sym_EQ_EQ] = ACTIONS(243),
    [anon_sym_BANG_EQ] = ACTIONS(243),
    [anon_sym_GT_EQ] = ACTIONS(243),
    [anon_sym_LT_EQ] = ACTIONS(243),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(243),
    [anon_sym_DOT] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(555),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_SEMI] = ACTIONS(251),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(251),
    [anon_sym_COMMA] = ACTIONS(251),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(247),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(251),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(255),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_PERCENT] = ACTIONS(253),
    [anon_sym_CARET] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(253),
    [anon_sym_PIPE] = ACTIONS(257),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_LT_LT] = ACTIONS(251),
    [anon_sym_GT_GT] = ACTIONS(251),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_SLASH_EQ] = ACTIONS(251),
    [anon_sym_PERCENT_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_DOT] = ACTIONS(253),
    [anon_sym_QMARK] = ACTIONS(251),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [23] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(552),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_SEMI] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_RBRACK] = ACTIONS(261),
    [anon_sym_COMMA] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(261),
    [anon_sym_RPAREN] = ACTIONS(261),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(552),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_SEMI] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_RBRACK] = ACTIONS(261),
    [anon_sym_COMMA] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(261),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(542),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(265),
    [anon_sym_SEMI] = ACTIONS(265),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_RBRACK] = ACTIONS(265),
    [anon_sym_COMMA] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [anon_sym_RPAREN] = ACTIONS(265),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [26] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(542),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_RBRACE] = ACTIONS(265),
    [anon_sym_SEMI] = ACTIONS(265),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_RBRACK] = ACTIONS(265),
    [anon_sym_COMMA] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(265),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [27] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(844),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(261),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_EQ_GT] = ACTIONS(261),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [28] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(769),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(271),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(317),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_PERCENT] = ACTIONS(253),
    [anon_sym_CARET] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(253),
    [anon_sym_PIPE] = ACTIONS(257),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_LT_LT] = ACTIONS(251),
    [anon_sym_GT_GT] = ACTIONS(251),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_SLASH_EQ] = ACTIONS(251),
    [anon_sym_PERCENT_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_DOT] = ACTIONS(253),
    [anon_sym_EQ_GT] = ACTIONS(251),
    [anon_sym_QMARK] = ACTIONS(251),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [29] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(767),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(245),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(243),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(245),
    [anon_sym_GT] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(245),
    [anon_sym_DASH] = ACTIONS(245),
    [anon_sym_SLASH] = ACTIONS(245),
    [anon_sym_PERCENT] = ACTIONS(245),
    [anon_sym_CARET] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(245),
    [anon_sym_PIPE] = ACTIONS(245),
    [anon_sym_AMP_AMP] = ACTIONS(243),
    [anon_sym_PIPE_PIPE] = ACTIONS(243),
    [anon_sym_LT_LT] = ACTIONS(243),
    [anon_sym_GT_GT] = ACTIONS(243),
    [anon_sym_PLUS_EQ] = ACTIONS(243),
    [anon_sym_DASH_EQ] = ACTIONS(243),
    [anon_sym_STAR_EQ] = ACTIONS(243),
    [anon_sym_SLASH_EQ] = ACTIONS(243),
    [anon_sym_PERCENT_EQ] = ACTIONS(243),
    [anon_sym_EQ_EQ] = ACTIONS(243),
    [anon_sym_BANG_EQ] = ACTIONS(243),
    [anon_sym_GT_EQ] = ACTIONS(243),
    [anon_sym_LT_EQ] = ACTIONS(243),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(243),
    [anon_sym_DOT] = ACTIONS(245),
    [anon_sym_EQ_GT] = ACTIONS(243),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [30] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(844),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_EQ_GT] = ACTIONS(261),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [31] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(766),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_EQ_GT] = ACTIONS(265),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [32] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(766),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(271),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_EQ_GT] = ACTIONS(265),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [33] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(859),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(265),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [34] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(862),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_EQ] = ACTIONS(253),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(321),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(253),
    [anon_sym_GT] = ACTIONS(253),
    [anon_sym_PLUS] = ACTIONS(253),
    [anon_sym_DASH] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(253),
    [anon_sym_PERCENT] = ACTIONS(253),
    [anon_sym_CARET] = ACTIONS(251),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(253),
    [anon_sym_PIPE] = ACTIONS(257),
    [anon_sym_AMP_AMP] = ACTIONS(251),
    [anon_sym_PIPE_PIPE] = ACTIONS(251),
    [anon_sym_LT_LT] = ACTIONS(251),
    [anon_sym_GT_GT] = ACTIONS(251),
    [anon_sym_PLUS_EQ] = ACTIONS(251),
    [anon_sym_DASH_EQ] = ACTIONS(251),
    [anon_sym_STAR_EQ] = ACTIONS(251),
    [anon_sym_SLASH_EQ] = ACTIONS(251),
    [anon_sym_PERCENT_EQ] = ACTIONS(251),
    [anon_sym_EQ_EQ] = ACTIONS(251),
    [anon_sym_BANG_EQ] = ACTIONS(251),
    [anon_sym_GT_EQ] = ACTIONS(251),
    [anon_sym_LT_EQ] = ACTIONS(251),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(253),
    [anon_sym_QMARK] = ACTIONS(251),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [35] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(860),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(243),
    [anon_sym_EQ] = ACTIONS(245),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(243),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(243),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(245),
    [anon_sym_GT] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(245),
    [anon_sym_DASH] = ACTIONS(245),
    [anon_sym_SLASH] = ACTIONS(245),
    [anon_sym_PERCENT] = ACTIONS(245),
    [anon_sym_CARET] = ACTIONS(243),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(245),
    [anon_sym_PIPE] = ACTIONS(245),
    [anon_sym_AMP_AMP] = ACTIONS(243),
    [anon_sym_PIPE_PIPE] = ACTIONS(243),
    [anon_sym_LT_LT] = ACTIONS(243),
    [anon_sym_GT_GT] = ACTIONS(243),
    [anon_sym_PLUS_EQ] = ACTIONS(243),
    [anon_sym_DASH_EQ] = ACTIONS(243),
    [anon_sym_STAR_EQ] = ACTIONS(243),
    [anon_sym_SLASH_EQ] = ACTIONS(243),
    [anon_sym_PERCENT_EQ] = ACTIONS(243),
    [anon_sym_EQ_EQ] = ACTIONS(243),
    [anon_sym_BANG_EQ] = ACTIONS(243),
    [anon_sym_GT_EQ] = ACTIONS(243),
    [anon_sym_LT_EQ] = ACTIONS(243),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(243),
    [anon_sym_DOT] = ACTIONS(245),
    [anon_sym_QMARK] = ACTIONS(243),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [36] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(859),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(265),
    [anon_sym_EQ] = ACTIONS(267),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(265),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(267),
    [anon_sym_LPAREN] = ACTIONS(265),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(267),
    [anon_sym_GT] = ACTIONS(267),
    [anon_sym_PLUS] = ACTIONS(267),
    [anon_sym_DASH] = ACTIONS(267),
    [anon_sym_SLASH] = ACTIONS(267),
    [anon_sym_PERCENT] = ACTIONS(267),
    [anon_sym_CARET] = ACTIONS(265),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(267),
    [anon_sym_PIPE] = ACTIONS(267),
    [anon_sym_AMP_AMP] = ACTIONS(265),
    [anon_sym_PIPE_PIPE] = ACTIONS(265),
    [anon_sym_LT_LT] = ACTIONS(265),
    [anon_sym_GT_GT] = ACTIONS(265),
    [anon_sym_PLUS_EQ] = ACTIONS(265),
    [anon_sym_DASH_EQ] = ACTIONS(265),
    [anon_sym_STAR_EQ] = ACTIONS(265),
    [anon_sym_SLASH_EQ] = ACTIONS(265),
    [anon_sym_PERCENT_EQ] = ACTIONS(265),
    [anon_sym_EQ_EQ] = ACTIONS(265),
    [anon_sym_BANG_EQ] = ACTIONS(265),
    [anon_sym_GT_EQ] = ACTIONS(265),
    [anon_sym_LT_EQ] = ACTIONS(265),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(265),
    [anon_sym_DOT] = ACTIONS(267),
    [anon_sym_QMARK] = ACTIONS(265),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [37] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(800),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [38] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(800),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(261),
    [anon_sym_EQ] = ACTIONS(263),
    [anon_sym_BANG] = ACTIONS(321),
    [anon_sym_LBRACK] = ACTIONS(261),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(263),
    [anon_sym_LPAREN] = ACTIONS(261),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_LT] = ACTIONS(263),
    [anon_sym_GT] = ACTIONS(263),
    [anon_sym_PLUS] = ACTIONS(263),
    [anon_sym_DASH] = ACTIONS(263),
    [anon_sym_SLASH] = ACTIONS(263),
    [anon_sym_PERCENT] = ACTIONS(263),
    [anon_sym_CARET] = ACTIONS(261),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_AMP] = ACTIONS(263),
    [anon_sym_PIPE] = ACTIONS(263),
    [anon_sym_AMP_AMP] = ACTIONS(261),
    [anon_sym_PIPE_PIPE] = ACTIONS(261),
    [anon_sym_LT_LT] = ACTIONS(261),
    [anon_sym_GT_GT] = ACTIONS(261),
    [anon_sym_PLUS_EQ] = ACTIONS(261),
    [anon_sym_DASH_EQ] = ACTIONS(261),
    [anon_sym_STAR_EQ] = ACTIONS(261),
    [anon_sym_SLASH_EQ] = ACTIONS(261),
    [anon_sym_PERCENT_EQ] = ACTIONS(261),
    [anon_sym_EQ_EQ] = ACTIONS(261),
    [anon_sym_BANG_EQ] = ACTIONS(261),
    [anon_sym_GT_EQ] = ACTIONS(261),
    [anon_sym_LT_EQ] = ACTIONS(261),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(261),
    [anon_sym_DOT] = ACTIONS(263),
    [anon_sym_QMARK] = ACTIONS(261),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [39] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(347),
    [anon_sym_RBRACE] = ACTIONS(350),
    [anon_sym_impl] = ACTIONS(352),
    [anon_sym_SEMI] = ACTIONS(355),
    [anon_sym_trait] = ACTIONS(352),
    [anon_sym_type] = ACTIONS(352),
    [anon_sym_COLON] = ACTIONS(358),
    [anon_sym_const] = ACTIONS(352),
    [anon_sym_EQ] = ACTIONS(358),
    [anon_sym_BANG] = ACTIONS(358),
    [anon_sym_POUND] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(361),
    [anon_sym_RBRACK] = ACTIONS(350),
    [anon_sym_mod] = ACTIONS(352),
    [anon_sym_struct] = ACTIONS(352),
    [anon_sym_enum] = ACTIONS(352),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_fn] = ACTIONS(352),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_let] = ACTIONS(352),
    [anon_sym_use] = ACTIONS(352),
    [anon_sym_COLON_COLON] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(358),
    [anon_sym_LPAREN] = ACTIONS(364),
    [anon_sym__] = ACTIONS(358),
    [anon_sym_RPAREN] = ACTIONS(350),
    [anon_sym_u8] = ACTIONS(367),
    [anon_sym_i8] = ACTIONS(367),
    [anon_sym_u16] = ACTIONS(367),
    [anon_sym_i16] = ACTIONS(367),
    [anon_sym_u32] = ACTIONS(367),
    [anon_sym_i32] = ACTIONS(367),
    [anon_sym_u64] = ACTIONS(367),
    [anon_sym_i64] = ACTIONS(367),
    [anon_sym_u128] = ACTIONS(367),
    [anon_sym_i128] = ACTIONS(367),
    [anon_sym_usize] = ACTIONS(367),
    [anon_sym_bool] = ACTIONS(367),
    [anon_sym_ByteArray] = ACTIONS(367),
    [anon_sym_felt252] = ACTIONS(367),
    [anon_sym_LT] = ACTIONS(358),
    [anon_sym_GT] = ACTIONS(358),
    [anon_sym_PLUS] = ACTIONS(358),
    [anon_sym_DASH] = ACTIONS(370),
    [anon_sym_SLASH] = ACTIONS(358),
    [anon_sym_PERCENT] = ACTIONS(358),
    [anon_sym_CARET] = ACTIONS(358),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_AMP] = ACTIONS(358),
    [anon_sym_PIPE] = ACTIONS(358),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_LT_LT] = ACTIONS(355),
    [anon_sym_GT_GT] = ACTIONS(355),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_SLASH_EQ] = ACTIONS(355),
    [anon_sym_PERCENT_EQ] = ACTIONS(355),
    [anon_sym_CARET_EQ] = ACTIONS(355),
    [anon_sym_AMP_EQ] = ACTIONS(355),
    [anon_sym_PIPE_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(355),
    [anon_sym_DOT_DOT] = ACTIONS(355),
    [anon_sym_DOT] = ACTIONS(358),
    [anon_sym_EQ_GT] = ACTIONS(355),
    [anon_sym_QMARK] = ACTIONS(355),
    [anon_sym_break] = ACTIONS(352),
    [anon_sym_continue] = ACTIONS(352),
    [anon_sym_default] = ACTIONS(352),
    [anon_sym_if] = ACTIONS(352),
    [anon_sym_extern] = ACTIONS(352),
    [anon_sym_nopanic] = ACTIONS(352),
    [anon_sym_loop] = ACTIONS(352),
    [anon_sym_match] = ACTIONS(352),
    [anon_sym_pub] = ACTIONS(352),
    [anon_sym_return] = ACTIONS(352),
    [anon_sym_static] = ACTIONS(352),
    [anon_sym_while] = ACTIONS(352),
    [anon_sym_for] = ACTIONS(352),
    [sym_numeric_literal] = ACTIONS(373),
    [aux_sym_string_literal_token1] = ACTIONS(376),
    [sym_shortstring_literal] = ACTIONS(379),
    [anon_sym_true] = ACTIONS(382),
    [anon_sym_false] = ACTIONS(382),
    [anon_sym_DOLLAR] = ACTIONS(385),
    [sym_identifier] = ACTIONS(352),
    [sym_mutable_specifier] = ACTIONS(352),
    [sym_super] = ACTIONS(352),
    [sym_line_comment] = ACTIONS(3),
  },
  [40] = {
    [sym_delim_token_tree] = STATE(41),
    [sym__delim_tokens] = STATE(41),
    [sym__literal] = STATE(41),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(41),
    [aux_sym_delim_token_tree_repeat1] = STATE(41),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(390),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(390),
    [anon_sym_type] = ACTIONS(390),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(390),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(390),
    [anon_sym_struct] = ACTIONS(390),
    [anon_sym_enum] = ACTIONS(390),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(390),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(390),
    [anon_sym_use] = ACTIONS(390),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(400),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(390),
    [anon_sym_continue] = ACTIONS(390),
    [anon_sym_default] = ACTIONS(390),
    [anon_sym_if] = ACTIONS(390),
    [anon_sym_extern] = ACTIONS(390),
    [anon_sym_nopanic] = ACTIONS(390),
    [anon_sym_loop] = ACTIONS(390),
    [anon_sym_match] = ACTIONS(390),
    [anon_sym_pub] = ACTIONS(390),
    [anon_sym_return] = ACTIONS(390),
    [anon_sym_static] = ACTIONS(390),
    [anon_sym_while] = ACTIONS(390),
    [anon_sym_for] = ACTIONS(390),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(414),
    [sym_identifier] = ACTIONS(390),
    [sym_mutable_specifier] = ACTIONS(390),
    [sym_super] = ACTIONS(390),
    [sym_line_comment] = ACTIONS(3),
  },
  [41] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(418),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [42] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(422),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [43] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(422),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [44] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(422),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [45] = {
    [sym_delim_token_tree] = STATE(48),
    [sym__delim_tokens] = STATE(48),
    [sym__literal] = STATE(48),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(48),
    [aux_sym_delim_token_tree_repeat1] = STATE(48),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(424),
    [anon_sym_impl] = ACTIONS(426),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(426),
    [anon_sym_type] = ACTIONS(426),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(426),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(426),
    [anon_sym_struct] = ACTIONS(426),
    [anon_sym_enum] = ACTIONS(426),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(426),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(426),
    [anon_sym_use] = ACTIONS(426),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(426),
    [anon_sym_continue] = ACTIONS(426),
    [anon_sym_default] = ACTIONS(426),
    [anon_sym_if] = ACTIONS(426),
    [anon_sym_extern] = ACTIONS(426),
    [anon_sym_nopanic] = ACTIONS(426),
    [anon_sym_loop] = ACTIONS(426),
    [anon_sym_match] = ACTIONS(426),
    [anon_sym_pub] = ACTIONS(426),
    [anon_sym_return] = ACTIONS(426),
    [anon_sym_static] = ACTIONS(426),
    [anon_sym_while] = ACTIONS(426),
    [anon_sym_for] = ACTIONS(426),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(428),
    [sym_identifier] = ACTIONS(426),
    [sym_mutable_specifier] = ACTIONS(426),
    [sym_super] = ACTIONS(426),
    [sym_line_comment] = ACTIONS(3),
  },
  [46] = {
    [sym_delim_token_tree] = STATE(49),
    [sym__delim_tokens] = STATE(49),
    [sym__literal] = STATE(49),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(49),
    [aux_sym_delim_token_tree_repeat1] = STATE(49),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(430),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(430),
    [anon_sym_type] = ACTIONS(430),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(430),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(424),
    [anon_sym_mod] = ACTIONS(430),
    [anon_sym_struct] = ACTIONS(430),
    [anon_sym_enum] = ACTIONS(430),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(430),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(430),
    [anon_sym_use] = ACTIONS(430),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(430),
    [anon_sym_continue] = ACTIONS(430),
    [anon_sym_default] = ACTIONS(430),
    [anon_sym_if] = ACTIONS(430),
    [anon_sym_extern] = ACTIONS(430),
    [anon_sym_nopanic] = ACTIONS(430),
    [anon_sym_loop] = ACTIONS(430),
    [anon_sym_match] = ACTIONS(430),
    [anon_sym_pub] = ACTIONS(430),
    [anon_sym_return] = ACTIONS(430),
    [anon_sym_static] = ACTIONS(430),
    [anon_sym_while] = ACTIONS(430),
    [anon_sym_for] = ACTIONS(430),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(432),
    [sym_identifier] = ACTIONS(430),
    [sym_mutable_specifier] = ACTIONS(430),
    [sym_super] = ACTIONS(430),
    [sym_line_comment] = ACTIONS(3),
  },
  [47] = {
    [sym_delim_token_tree] = STATE(50),
    [sym__delim_tokens] = STATE(50),
    [sym__literal] = STATE(50),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(50),
    [aux_sym_delim_token_tree_repeat1] = STATE(50),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(434),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(434),
    [anon_sym_type] = ACTIONS(434),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(434),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(434),
    [anon_sym_struct] = ACTIONS(434),
    [anon_sym_enum] = ACTIONS(434),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(434),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(434),
    [anon_sym_use] = ACTIONS(434),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(424),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(434),
    [anon_sym_continue] = ACTIONS(434),
    [anon_sym_default] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(434),
    [anon_sym_extern] = ACTIONS(434),
    [anon_sym_nopanic] = ACTIONS(434),
    [anon_sym_loop] = ACTIONS(434),
    [anon_sym_match] = ACTIONS(434),
    [anon_sym_pub] = ACTIONS(434),
    [anon_sym_return] = ACTIONS(434),
    [anon_sym_static] = ACTIONS(434),
    [anon_sym_while] = ACTIONS(434),
    [anon_sym_for] = ACTIONS(434),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(436),
    [sym_identifier] = ACTIONS(434),
    [sym_mutable_specifier] = ACTIONS(434),
    [sym_super] = ACTIONS(434),
    [sym_line_comment] = ACTIONS(3),
  },
  [48] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(438),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [49] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(438),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [50] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(438),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [51] = {
    [sym_delim_token_tree] = STATE(43),
    [sym__delim_tokens] = STATE(43),
    [sym__literal] = STATE(43),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(43),
    [aux_sym_delim_token_tree_repeat1] = STATE(43),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(440),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(440),
    [anon_sym_type] = ACTIONS(440),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(440),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(442),
    [anon_sym_mod] = ACTIONS(440),
    [anon_sym_struct] = ACTIONS(440),
    [anon_sym_enum] = ACTIONS(440),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(440),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(440),
    [anon_sym_use] = ACTIONS(440),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(440),
    [anon_sym_continue] = ACTIONS(440),
    [anon_sym_default] = ACTIONS(440),
    [anon_sym_if] = ACTIONS(440),
    [anon_sym_extern] = ACTIONS(440),
    [anon_sym_nopanic] = ACTIONS(440),
    [anon_sym_loop] = ACTIONS(440),
    [anon_sym_match] = ACTIONS(440),
    [anon_sym_pub] = ACTIONS(440),
    [anon_sym_return] = ACTIONS(440),
    [anon_sym_static] = ACTIONS(440),
    [anon_sym_while] = ACTIONS(440),
    [anon_sym_for] = ACTIONS(440),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(444),
    [sym_identifier] = ACTIONS(440),
    [sym_mutable_specifier] = ACTIONS(440),
    [sym_super] = ACTIONS(440),
    [sym_line_comment] = ACTIONS(3),
  },
  [52] = {
    [sym_delim_token_tree] = STATE(44),
    [sym__delim_tokens] = STATE(44),
    [sym__literal] = STATE(44),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(44),
    [aux_sym_delim_token_tree_repeat1] = STATE(44),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(446),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(446),
    [anon_sym_type] = ACTIONS(446),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(446),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(446),
    [anon_sym_struct] = ACTIONS(446),
    [anon_sym_enum] = ACTIONS(446),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(446),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(446),
    [anon_sym_use] = ACTIONS(446),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(442),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(446),
    [anon_sym_continue] = ACTIONS(446),
    [anon_sym_default] = ACTIONS(446),
    [anon_sym_if] = ACTIONS(446),
    [anon_sym_extern] = ACTIONS(446),
    [anon_sym_nopanic] = ACTIONS(446),
    [anon_sym_loop] = ACTIONS(446),
    [anon_sym_match] = ACTIONS(446),
    [anon_sym_pub] = ACTIONS(446),
    [anon_sym_return] = ACTIONS(446),
    [anon_sym_static] = ACTIONS(446),
    [anon_sym_while] = ACTIONS(446),
    [anon_sym_for] = ACTIONS(446),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(448),
    [sym_identifier] = ACTIONS(446),
    [sym_mutable_specifier] = ACTIONS(446),
    [sym_super] = ACTIONS(446),
    [sym_line_comment] = ACTIONS(3),
  },
  [53] = {
    [sym_delim_token_tree] = STATE(56),
    [sym__delim_tokens] = STATE(56),
    [sym__literal] = STATE(56),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(56),
    [aux_sym_delim_token_tree_repeat1] = STATE(56),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(450),
    [anon_sym_impl] = ACTIONS(452),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(452),
    [anon_sym_type] = ACTIONS(452),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(452),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(452),
    [anon_sym_struct] = ACTIONS(452),
    [anon_sym_enum] = ACTIONS(452),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(452),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(452),
    [anon_sym_use] = ACTIONS(452),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(452),
    [anon_sym_continue] = ACTIONS(452),
    [anon_sym_default] = ACTIONS(452),
    [anon_sym_if] = ACTIONS(452),
    [anon_sym_extern] = ACTIONS(452),
    [anon_sym_nopanic] = ACTIONS(452),
    [anon_sym_loop] = ACTIONS(452),
    [anon_sym_match] = ACTIONS(452),
    [anon_sym_pub] = ACTIONS(452),
    [anon_sym_return] = ACTIONS(452),
    [anon_sym_static] = ACTIONS(452),
    [anon_sym_while] = ACTIONS(452),
    [anon_sym_for] = ACTIONS(452),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(454),
    [sym_identifier] = ACTIONS(452),
    [sym_mutable_specifier] = ACTIONS(452),
    [sym_super] = ACTIONS(452),
    [sym_line_comment] = ACTIONS(3),
  },
  [54] = {
    [sym_delim_token_tree] = STATE(57),
    [sym__delim_tokens] = STATE(57),
    [sym__literal] = STATE(57),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(57),
    [aux_sym_delim_token_tree_repeat1] = STATE(57),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(456),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(456),
    [anon_sym_type] = ACTIONS(456),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(456),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(450),
    [anon_sym_mod] = ACTIONS(456),
    [anon_sym_struct] = ACTIONS(456),
    [anon_sym_enum] = ACTIONS(456),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(456),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(456),
    [anon_sym_use] = ACTIONS(456),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(456),
    [anon_sym_continue] = ACTIONS(456),
    [anon_sym_default] = ACTIONS(456),
    [anon_sym_if] = ACTIONS(456),
    [anon_sym_extern] = ACTIONS(456),
    [anon_sym_nopanic] = ACTIONS(456),
    [anon_sym_loop] = ACTIONS(456),
    [anon_sym_match] = ACTIONS(456),
    [anon_sym_pub] = ACTIONS(456),
    [anon_sym_return] = ACTIONS(456),
    [anon_sym_static] = ACTIONS(456),
    [anon_sym_while] = ACTIONS(456),
    [anon_sym_for] = ACTIONS(456),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(458),
    [sym_identifier] = ACTIONS(456),
    [sym_mutable_specifier] = ACTIONS(456),
    [sym_super] = ACTIONS(456),
    [sym_line_comment] = ACTIONS(3),
  },
  [55] = {
    [sym_delim_token_tree] = STATE(58),
    [sym__delim_tokens] = STATE(58),
    [sym__literal] = STATE(58),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(58),
    [aux_sym_delim_token_tree_repeat1] = STATE(58),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(460),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(460),
    [anon_sym_type] = ACTIONS(460),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(460),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(460),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_enum] = ACTIONS(460),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(460),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(460),
    [anon_sym_use] = ACTIONS(460),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(450),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(460),
    [anon_sym_continue] = ACTIONS(460),
    [anon_sym_default] = ACTIONS(460),
    [anon_sym_if] = ACTIONS(460),
    [anon_sym_extern] = ACTIONS(460),
    [anon_sym_nopanic] = ACTIONS(460),
    [anon_sym_loop] = ACTIONS(460),
    [anon_sym_match] = ACTIONS(460),
    [anon_sym_pub] = ACTIONS(460),
    [anon_sym_return] = ACTIONS(460),
    [anon_sym_static] = ACTIONS(460),
    [anon_sym_while] = ACTIONS(460),
    [anon_sym_for] = ACTIONS(460),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(462),
    [sym_identifier] = ACTIONS(460),
    [sym_mutable_specifier] = ACTIONS(460),
    [sym_super] = ACTIONS(460),
    [sym_line_comment] = ACTIONS(3),
  },
  [56] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(464),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [57] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(464),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [58] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(464),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [59] = {
    [sym_delim_token_tree] = STATE(62),
    [sym__delim_tokens] = STATE(62),
    [sym__literal] = STATE(62),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(62),
    [aux_sym_delim_token_tree_repeat1] = STATE(62),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(466),
    [anon_sym_impl] = ACTIONS(468),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(468),
    [anon_sym_type] = ACTIONS(468),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(468),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(468),
    [anon_sym_struct] = ACTIONS(468),
    [anon_sym_enum] = ACTIONS(468),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(468),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(468),
    [anon_sym_use] = ACTIONS(468),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(468),
    [anon_sym_continue] = ACTIONS(468),
    [anon_sym_default] = ACTIONS(468),
    [anon_sym_if] = ACTIONS(468),
    [anon_sym_extern] = ACTIONS(468),
    [anon_sym_nopanic] = ACTIONS(468),
    [anon_sym_loop] = ACTIONS(468),
    [anon_sym_match] = ACTIONS(468),
    [anon_sym_pub] = ACTIONS(468),
    [anon_sym_return] = ACTIONS(468),
    [anon_sym_static] = ACTIONS(468),
    [anon_sym_while] = ACTIONS(468),
    [anon_sym_for] = ACTIONS(468),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(470),
    [sym_identifier] = ACTIONS(468),
    [sym_mutable_specifier] = ACTIONS(468),
    [sym_super] = ACTIONS(468),
    [sym_line_comment] = ACTIONS(3),
  },
  [60] = {
    [sym_delim_token_tree] = STATE(63),
    [sym__delim_tokens] = STATE(63),
    [sym__literal] = STATE(63),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(63),
    [aux_sym_delim_token_tree_repeat1] = STATE(63),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(472),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(472),
    [anon_sym_type] = ACTIONS(472),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(472),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(466),
    [anon_sym_mod] = ACTIONS(472),
    [anon_sym_struct] = ACTIONS(472),
    [anon_sym_enum] = ACTIONS(472),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(472),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(472),
    [anon_sym_use] = ACTIONS(472),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(472),
    [anon_sym_continue] = ACTIONS(472),
    [anon_sym_default] = ACTIONS(472),
    [anon_sym_if] = ACTIONS(472),
    [anon_sym_extern] = ACTIONS(472),
    [anon_sym_nopanic] = ACTIONS(472),
    [anon_sym_loop] = ACTIONS(472),
    [anon_sym_match] = ACTIONS(472),
    [anon_sym_pub] = ACTIONS(472),
    [anon_sym_return] = ACTIONS(472),
    [anon_sym_static] = ACTIONS(472),
    [anon_sym_while] = ACTIONS(472),
    [anon_sym_for] = ACTIONS(472),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(474),
    [sym_identifier] = ACTIONS(472),
    [sym_mutable_specifier] = ACTIONS(472),
    [sym_super] = ACTIONS(472),
    [sym_line_comment] = ACTIONS(3),
  },
  [61] = {
    [sym_delim_token_tree] = STATE(64),
    [sym__delim_tokens] = STATE(64),
    [sym__literal] = STATE(64),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(64),
    [aux_sym_delim_token_tree_repeat1] = STATE(64),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(476),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(476),
    [anon_sym_type] = ACTIONS(476),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(476),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(476),
    [anon_sym_struct] = ACTIONS(476),
    [anon_sym_enum] = ACTIONS(476),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(476),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(476),
    [anon_sym_use] = ACTIONS(476),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(466),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(476),
    [anon_sym_continue] = ACTIONS(476),
    [anon_sym_default] = ACTIONS(476),
    [anon_sym_if] = ACTIONS(476),
    [anon_sym_extern] = ACTIONS(476),
    [anon_sym_nopanic] = ACTIONS(476),
    [anon_sym_loop] = ACTIONS(476),
    [anon_sym_match] = ACTIONS(476),
    [anon_sym_pub] = ACTIONS(476),
    [anon_sym_return] = ACTIONS(476),
    [anon_sym_static] = ACTIONS(476),
    [anon_sym_while] = ACTIONS(476),
    [anon_sym_for] = ACTIONS(476),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(478),
    [sym_identifier] = ACTIONS(476),
    [sym_mutable_specifier] = ACTIONS(476),
    [sym_super] = ACTIONS(476),
    [sym_line_comment] = ACTIONS(3),
  },
  [62] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(480),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [63] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(480),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [64] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(480),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [65] = {
    [sym_delim_token_tree] = STATE(68),
    [sym__delim_tokens] = STATE(68),
    [sym__literal] = STATE(68),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(68),
    [aux_sym_delim_token_tree_repeat1] = STATE(68),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(482),
    [anon_sym_impl] = ACTIONS(484),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(484),
    [anon_sym_type] = ACTIONS(484),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(484),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(484),
    [anon_sym_struct] = ACTIONS(484),
    [anon_sym_enum] = ACTIONS(484),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(484),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(484),
    [anon_sym_use] = ACTIONS(484),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(484),
    [anon_sym_continue] = ACTIONS(484),
    [anon_sym_default] = ACTIONS(484),
    [anon_sym_if] = ACTIONS(484),
    [anon_sym_extern] = ACTIONS(484),
    [anon_sym_nopanic] = ACTIONS(484),
    [anon_sym_loop] = ACTIONS(484),
    [anon_sym_match] = ACTIONS(484),
    [anon_sym_pub] = ACTIONS(484),
    [anon_sym_return] = ACTIONS(484),
    [anon_sym_static] = ACTIONS(484),
    [anon_sym_while] = ACTIONS(484),
    [anon_sym_for] = ACTIONS(484),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(486),
    [sym_identifier] = ACTIONS(484),
    [sym_mutable_specifier] = ACTIONS(484),
    [sym_super] = ACTIONS(484),
    [sym_line_comment] = ACTIONS(3),
  },
  [66] = {
    [sym_delim_token_tree] = STATE(69),
    [sym__delim_tokens] = STATE(69),
    [sym__literal] = STATE(69),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(69),
    [aux_sym_delim_token_tree_repeat1] = STATE(69),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(488),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(488),
    [anon_sym_type] = ACTIONS(488),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(488),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(482),
    [anon_sym_mod] = ACTIONS(488),
    [anon_sym_struct] = ACTIONS(488),
    [anon_sym_enum] = ACTIONS(488),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(488),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(488),
    [anon_sym_use] = ACTIONS(488),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(488),
    [anon_sym_continue] = ACTIONS(488),
    [anon_sym_default] = ACTIONS(488),
    [anon_sym_if] = ACTIONS(488),
    [anon_sym_extern] = ACTIONS(488),
    [anon_sym_nopanic] = ACTIONS(488),
    [anon_sym_loop] = ACTIONS(488),
    [anon_sym_match] = ACTIONS(488),
    [anon_sym_pub] = ACTIONS(488),
    [anon_sym_return] = ACTIONS(488),
    [anon_sym_static] = ACTIONS(488),
    [anon_sym_while] = ACTIONS(488),
    [anon_sym_for] = ACTIONS(488),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(490),
    [sym_identifier] = ACTIONS(488),
    [sym_mutable_specifier] = ACTIONS(488),
    [sym_super] = ACTIONS(488),
    [sym_line_comment] = ACTIONS(3),
  },
  [67] = {
    [sym_delim_token_tree] = STATE(70),
    [sym__delim_tokens] = STATE(70),
    [sym__literal] = STATE(70),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(70),
    [aux_sym_delim_token_tree_repeat1] = STATE(70),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(492),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(492),
    [anon_sym_type] = ACTIONS(492),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(492),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(492),
    [anon_sym_struct] = ACTIONS(492),
    [anon_sym_enum] = ACTIONS(492),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(492),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(492),
    [anon_sym_use] = ACTIONS(492),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(482),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(492),
    [anon_sym_continue] = ACTIONS(492),
    [anon_sym_default] = ACTIONS(492),
    [anon_sym_if] = ACTIONS(492),
    [anon_sym_extern] = ACTIONS(492),
    [anon_sym_nopanic] = ACTIONS(492),
    [anon_sym_loop] = ACTIONS(492),
    [anon_sym_match] = ACTIONS(492),
    [anon_sym_pub] = ACTIONS(492),
    [anon_sym_return] = ACTIONS(492),
    [anon_sym_static] = ACTIONS(492),
    [anon_sym_while] = ACTIONS(492),
    [anon_sym_for] = ACTIONS(492),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(494),
    [sym_identifier] = ACTIONS(492),
    [sym_mutable_specifier] = ACTIONS(492),
    [sym_super] = ACTIONS(492),
    [sym_line_comment] = ACTIONS(3),
  },
  [68] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(496),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [69] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(496),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [70] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_RPAREN] = ACTIONS(496),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [71] = {
    [sym_delim_token_tree] = STATE(73),
    [sym__delim_tokens] = STATE(73),
    [sym__literal] = STATE(73),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(73),
    [aux_sym_delim_token_tree_repeat1] = STATE(73),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(400),
    [anon_sym_impl] = ACTIONS(498),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(498),
    [anon_sym_type] = ACTIONS(498),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(498),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(498),
    [anon_sym_struct] = ACTIONS(498),
    [anon_sym_enum] = ACTIONS(498),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(498),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(498),
    [anon_sym_use] = ACTIONS(498),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(498),
    [anon_sym_continue] = ACTIONS(498),
    [anon_sym_default] = ACTIONS(498),
    [anon_sym_if] = ACTIONS(498),
    [anon_sym_extern] = ACTIONS(498),
    [anon_sym_nopanic] = ACTIONS(498),
    [anon_sym_loop] = ACTIONS(498),
    [anon_sym_match] = ACTIONS(498),
    [anon_sym_pub] = ACTIONS(498),
    [anon_sym_return] = ACTIONS(498),
    [anon_sym_static] = ACTIONS(498),
    [anon_sym_while] = ACTIONS(498),
    [anon_sym_for] = ACTIONS(498),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(500),
    [sym_identifier] = ACTIONS(498),
    [sym_mutable_specifier] = ACTIONS(498),
    [sym_super] = ACTIONS(498),
    [sym_line_comment] = ACTIONS(3),
  },
  [72] = {
    [sym_delim_token_tree] = STATE(74),
    [sym__delim_tokens] = STATE(74),
    [sym__literal] = STATE(74),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(74),
    [aux_sym_delim_token_tree_repeat1] = STATE(74),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(502),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(502),
    [anon_sym_type] = ACTIONS(502),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(502),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(400),
    [anon_sym_mod] = ACTIONS(502),
    [anon_sym_struct] = ACTIONS(502),
    [anon_sym_enum] = ACTIONS(502),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(502),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(502),
    [anon_sym_use] = ACTIONS(502),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(502),
    [anon_sym_continue] = ACTIONS(502),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_if] = ACTIONS(502),
    [anon_sym_extern] = ACTIONS(502),
    [anon_sym_nopanic] = ACTIONS(502),
    [anon_sym_loop] = ACTIONS(502),
    [anon_sym_match] = ACTIONS(502),
    [anon_sym_pub] = ACTIONS(502),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_static] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(502),
    [anon_sym_for] = ACTIONS(502),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(504),
    [sym_identifier] = ACTIONS(502),
    [sym_mutable_specifier] = ACTIONS(502),
    [sym_super] = ACTIONS(502),
    [sym_line_comment] = ACTIONS(3),
  },
  [73] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(418),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [74] = {
    [sym_delim_token_tree] = STATE(39),
    [sym__delim_tokens] = STATE(39),
    [sym__literal] = STATE(39),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(39),
    [aux_sym_delim_token_tree_repeat1] = STATE(39),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_impl] = ACTIONS(416),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(416),
    [anon_sym_type] = ACTIONS(416),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(416),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_RBRACK] = ACTIONS(418),
    [anon_sym_mod] = ACTIONS(416),
    [anon_sym_struct] = ACTIONS(416),
    [anon_sym_enum] = ACTIONS(416),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(416),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(416),
    [anon_sym_use] = ACTIONS(416),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(416),
    [anon_sym_continue] = ACTIONS(416),
    [anon_sym_default] = ACTIONS(416),
    [anon_sym_if] = ACTIONS(416),
    [anon_sym_extern] = ACTIONS(416),
    [anon_sym_nopanic] = ACTIONS(416),
    [anon_sym_loop] = ACTIONS(416),
    [anon_sym_match] = ACTIONS(416),
    [anon_sym_pub] = ACTIONS(416),
    [anon_sym_return] = ACTIONS(416),
    [anon_sym_static] = ACTIONS(416),
    [anon_sym_while] = ACTIONS(416),
    [anon_sym_for] = ACTIONS(416),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(420),
    [sym_identifier] = ACTIONS(416),
    [sym_mutable_specifier] = ACTIONS(416),
    [sym_super] = ACTIONS(416),
    [sym_line_comment] = ACTIONS(3),
  },
  [75] = {
    [sym_delim_token_tree] = STATE(42),
    [sym__delim_tokens] = STATE(42),
    [sym__literal] = STATE(42),
    [sym_negative_literal] = STATE(78),
    [sym_string_literal] = STATE(78),
    [sym_boolean_literal] = STATE(78),
    [sym__non_delim_token] = STATE(42),
    [aux_sym_delim_token_tree_repeat1] = STATE(42),
    [aux_sym__non_special_token_repeat1] = STATE(76),
    [anon_sym_LBRACE] = ACTIONS(388),
    [anon_sym_RBRACE] = ACTIONS(442),
    [anon_sym_impl] = ACTIONS(506),
    [anon_sym_SEMI] = ACTIONS(392),
    [anon_sym_trait] = ACTIONS(506),
    [anon_sym_type] = ACTIONS(506),
    [anon_sym_COLON] = ACTIONS(394),
    [anon_sym_const] = ACTIONS(506),
    [anon_sym_EQ] = ACTIONS(394),
    [anon_sym_BANG] = ACTIONS(394),
    [anon_sym_POUND] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(396),
    [anon_sym_mod] = ACTIONS(506),
    [anon_sym_struct] = ACTIONS(506),
    [anon_sym_enum] = ACTIONS(506),
    [anon_sym_COMMA] = ACTIONS(392),
    [anon_sym_fn] = ACTIONS(506),
    [anon_sym_DASH_GT] = ACTIONS(392),
    [anon_sym_let] = ACTIONS(506),
    [anon_sym_use] = ACTIONS(506),
    [anon_sym_COLON_COLON] = ACTIONS(392),
    [anon_sym_STAR] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(398),
    [anon_sym__] = ACTIONS(394),
    [anon_sym_u8] = ACTIONS(402),
    [anon_sym_i8] = ACTIONS(402),
    [anon_sym_u16] = ACTIONS(402),
    [anon_sym_i16] = ACTIONS(402),
    [anon_sym_u32] = ACTIONS(402),
    [anon_sym_i32] = ACTIONS(402),
    [anon_sym_u64] = ACTIONS(402),
    [anon_sym_i64] = ACTIONS(402),
    [anon_sym_u128] = ACTIONS(402),
    [anon_sym_i128] = ACTIONS(402),
    [anon_sym_usize] = ACTIONS(402),
    [anon_sym_bool] = ACTIONS(402),
    [anon_sym_ByteArray] = ACTIONS(402),
    [anon_sym_felt252] = ACTIONS(402),
    [anon_sym_LT] = ACTIONS(394),
    [anon_sym_GT] = ACTIONS(394),
    [anon_sym_PLUS] = ACTIONS(394),
    [anon_sym_DASH] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(394),
    [anon_sym_PERCENT] = ACTIONS(394),
    [anon_sym_CARET] = ACTIONS(394),
    [anon_sym_TILDE] = ACTIONS(392),
    [anon_sym_AMP] = ACTIONS(394),
    [anon_sym_PIPE] = ACTIONS(394),
    [anon_sym_AMP_AMP] = ACTIONS(392),
    [anon_sym_PIPE_PIPE] = ACTIONS(392),
    [anon_sym_LT_LT] = ACTIONS(392),
    [anon_sym_GT_GT] = ACTIONS(392),
    [anon_sym_PLUS_EQ] = ACTIONS(392),
    [anon_sym_DASH_EQ] = ACTIONS(392),
    [anon_sym_STAR_EQ] = ACTIONS(392),
    [anon_sym_SLASH_EQ] = ACTIONS(392),
    [anon_sym_PERCENT_EQ] = ACTIONS(392),
    [anon_sym_CARET_EQ] = ACTIONS(392),
    [anon_sym_AMP_EQ] = ACTIONS(392),
    [anon_sym_PIPE_EQ] = ACTIONS(392),
    [anon_sym_EQ_EQ] = ACTIONS(392),
    [anon_sym_BANG_EQ] = ACTIONS(392),
    [anon_sym_GT_EQ] = ACTIONS(392),
    [anon_sym_LT_EQ] = ACTIONS(392),
    [anon_sym_AT] = ACTIONS(392),
    [anon_sym_DOT_DOT] = ACTIONS(392),
    [anon_sym_DOT] = ACTIONS(394),
    [anon_sym_EQ_GT] = ACTIONS(392),
    [anon_sym_QMARK] = ACTIONS(392),
    [anon_sym_break] = ACTIONS(506),
    [anon_sym_continue] = ACTIONS(506),
    [anon_sym_default] = ACTIONS(506),
    [anon_sym_if] = ACTIONS(506),
    [anon_sym_extern] = ACTIONS(506),
    [anon_sym_nopanic] = ACTIONS(506),
    [anon_sym_loop] = ACTIONS(506),
    [anon_sym_match] = ACTIONS(506),
    [anon_sym_pub] = ACTIONS(506),
    [anon_sym_return] = ACTIONS(506),
    [anon_sym_static] = ACTIONS(506),
    [anon_sym_while] = ACTIONS(506),
    [anon_sym_for] = ACTIONS(506),
    [sym_numeric_literal] = ACTIONS(406),
    [aux_sym_string_literal_token1] = ACTIONS(408),
    [sym_shortstring_literal] = ACTIONS(410),
    [anon_sym_true] = ACTIONS(412),
    [anon_sym_false] = ACTIONS(412),
    [anon_sym_DOLLAR] = ACTIONS(508),
    [sym_identifier] = ACTIONS(506),
    [sym_mutable_specifier] = ACTIONS(506),
    [sym_super] = ACTIONS(506),
    [sym_line_comment] = ACTIONS(3),
  },
  [76] = {
    [aux_sym__non_special_token_repeat1] = STATE(77),
    [anon_sym_LBRACE] = ACTIONS(510),
    [anon_sym_RBRACE] = ACTIONS(510),
    [anon_sym_impl] = ACTIONS(512),
    [anon_sym_SEMI] = ACTIONS(514),
    [anon_sym_trait] = ACTIONS(512),
    [anon_sym_type] = ACTIONS(512),
    [anon_sym_COLON] = ACTIONS(516),
    [anon_sym_const] = ACTIONS(512),
    [anon_sym_EQ] = ACTIONS(516),
    [anon_sym_BANG] = ACTIONS(516),
    [anon_sym_POUND] = ACTIONS(514),
    [anon_sym_LBRACK] = ACTIONS(510),
    [anon_sym_RBRACK] = ACTIONS(510),
    [anon_sym_mod] = ACTIONS(512),
    [anon_sym_struct] = ACTIONS(512),
    [anon_sym_enum] = ACTIONS(512),
    [anon_sym_COMMA] = ACTIONS(514),
    [anon_sym_fn] = ACTIONS(512),
    [anon_sym_DASH_GT] = ACTIONS(514),
    [anon_sym_let] = ACTIONS(512),
    [anon_sym_use] = ACTIONS(512),
    [anon_sym_COLON_COLON] = ACTIONS(514),
    [anon_sym_STAR] = ACTIONS(516),
    [anon_sym_LPAREN] = ACTIONS(510),
    [anon_sym__] = ACTIONS(516),
    [anon_sym_RPAREN] = ACTIONS(510),
    [anon_sym_u8] = ACTIONS(512),
    [anon_sym_i8] = ACTIONS(512),
    [anon_sym_u16] = ACTIONS(512),
    [anon_sym_i16] = ACTIONS(512),
    [anon_sym_u32] = ACTIONS(512),
    [anon_sym_i32] = ACTIONS(512),
    [anon_sym_u64] = ACTIONS(512),
    [anon_sym_i64] = ACTIONS(512),
    [anon_sym_u128] = ACTIONS(512),
    [anon_sym_i128] = ACTIONS(512),
    [anon_sym_usize] = ACTIONS(512),
    [anon_sym_bool] = ACTIONS(512),
    [anon_sym_ByteArray] = ACTIONS(512),
    [anon_sym_felt252] = ACTIONS(512),
    [anon_sym_LT] = ACTIONS(516),
    [anon_sym_GT] = ACTIONS(516),
    [anon_sym_PLUS] = ACTIONS(516),
    [anon_sym_DASH] = ACTIONS(516),
    [anon_sym_SLASH] = ACTIONS(516),
    [anon_sym_PERCENT] = ACTIONS(516),
    [anon_sym_CARET] = ACTIONS(516),
    [anon_sym_TILDE] = ACTIONS(514),
    [anon_sym_AMP] = ACTIONS(516),
    [anon_sym_PIPE] = ACTIONS(516),
    [anon_sym_AMP_AMP] = ACTIONS(514),
    [anon_sym_PIPE_PIPE] = ACTIONS(514),
    [anon_sym_LT_LT] = ACTIONS(514),
    [anon_sym_GT_GT] = ACTIONS(514),
    [anon_sym_PLUS_EQ] = ACTIONS(514),
    [anon_sym_DASH_EQ] = ACTIONS(514),
    [anon_sym_STAR_EQ] = ACTIONS(514),
    [anon_sym_SLASH_EQ] = ACTIONS(514),
    [anon_sym_PERCENT_EQ] = ACTIONS(514),
    [anon_sym_CARET_EQ] = ACTIONS(514),
    [anon_sym_AMP_EQ] = ACTIONS(514),
    [anon_sym_PIPE_EQ] = ACTIONS(514),
    [anon_sym_EQ_EQ] = ACTIONS(514),
    [anon_sym_BANG_EQ] = ACTIONS(514),
    [anon_sym_GT_EQ] = ACTIONS(514),
    [anon_sym_LT_EQ] = ACTIONS(514),
    [anon_sym_AT] = ACTIONS(514),
    [anon_sym_DOT_DOT] = ACTIONS(514),
    [anon_sym_DOT] = ACTIONS(516),
    [anon_sym_EQ_GT] = ACTIONS(514),
    [anon_sym_QMARK] = ACTIONS(514),
    [anon_sym_break] = ACTIONS(512),
    [anon_sym_continue] = ACTIONS(512),
    [anon_sym_default] = ACTIONS(512),
    [anon_sym_if] = ACTIONS(512),
    [anon_sym_extern] = ACTIONS(512),
    [anon_sym_nopanic] = ACTIONS(512),
    [anon_sym_loop] = ACTIONS(512),
    [anon_sym_match] = ACTIONS(512),
    [anon_sym_pub] = ACTIONS(512),
    [anon_sym_return] = ACTIONS(512),
    [anon_sym_static] = ACTIONS(512),
    [anon_sym_while] = ACTIONS(512),
    [anon_sym_for] = ACTIONS(512),
    [sym_numeric_literal] = ACTIONS(512),
    [aux_sym_string_literal_token1] = ACTIONS(510),
    [sym_shortstring_literal] = ACTIONS(510),
    [anon_sym_true] = ACTIONS(512),
    [anon_sym_false] = ACTIONS(512),
    [anon_sym_DOLLAR] = ACTIONS(510),
    [sym_identifier] = ACTIONS(512),
    [sym_mutable_specifier] = ACTIONS(512),
    [sym_super] = ACTIONS(512),
    [sym_line_comment] = ACTIONS(3),
  },
  [77] = {
    [aux_sym__non_special_token_repeat1] = STATE(77),
    [anon_sym_LBRACE] = ACTIONS(518),
    [anon_sym_RBRACE] = ACTIONS(518),
    [anon_sym_impl] = ACTIONS(520),
    [anon_sym_SEMI] = ACTIONS(522),
    [anon_sym_trait] = ACTIONS(520),
    [anon_sym_type] = ACTIONS(520),
    [anon_sym_COLON] = ACTIONS(525),
    [anon_sym_const] = ACTIONS(520),
    [anon_sym_EQ] = ACTIONS(525),
    [anon_sym_BANG] = ACTIONS(525),
    [anon_sym_POUND] = ACTIONS(522),
    [anon_sym_LBRACK] = ACTIONS(518),
    [anon_sym_RBRACK] = ACTIONS(518),
    [anon_sym_mod] = ACTIONS(520),
    [anon_sym_struct] = ACTIONS(520),
    [anon_sym_enum] = ACTIONS(520),
    [anon_sym_COMMA] = ACTIONS(522),
    [anon_sym_fn] = ACTIONS(520),
    [anon_sym_DASH_GT] = ACTIONS(522),
    [anon_sym_let] = ACTIONS(520),
    [anon_sym_use] = ACTIONS(520),
    [anon_sym_COLON_COLON] = ACTIONS(522),
    [anon_sym_STAR] = ACTIONS(525),
    [anon_sym_LPAREN] = ACTIONS(518),
    [anon_sym__] = ACTIONS(525),
    [anon_sym_RPAREN] = ACTIONS(518),
    [anon_sym_u8] = ACTIONS(520),
    [anon_sym_i8] = ACTIONS(520),
    [anon_sym_u16] = ACTIONS(520),
    [anon_sym_i16] = ACTIONS(520),
    [anon_sym_u32] = ACTIONS(520),
    [anon_sym_i32] = ACTIONS(520),
    [anon_sym_u64] = ACTIONS(520),
    [anon_sym_i64] = ACTIONS(520),
    [anon_sym_u128] = ACTIONS(520),
    [anon_sym_i128] = ACTIONS(520),
    [anon_sym_usize] = ACTIONS(520),
    [anon_sym_bool] = ACTIONS(520),
    [anon_sym_ByteArray] = ACTIONS(520),
    [anon_sym_felt252] = ACTIONS(520),
    [anon_sym_LT] = ACTIONS(525),
    [anon_sym_GT] = ACTIONS(525),
    [anon_sym_PLUS] = ACTIONS(525),
    [anon_sym_DASH] = ACTIONS(525),
    [anon_sym_SLASH] = ACTIONS(525),
    [anon_sym_PERCENT] = ACTIONS(525),
    [anon_sym_CARET] = ACTIONS(525),
    [anon_sym_TILDE] = ACTIONS(522),
    [anon_sym_AMP] = ACTIONS(525),
    [anon_sym_PIPE] = ACTIONS(525),
    [anon_sym_AMP_AMP] = ACTIONS(522),
    [anon_sym_PIPE_PIPE] = ACTIONS(522),
    [anon_sym_LT_LT] = ACTIONS(522),
    [anon_sym_GT_GT] = ACTIONS(522),
    [anon_sym_PLUS_EQ] = ACTIONS(522),
    [anon_sym_DASH_EQ] = ACTIONS(522),
    [anon_sym_STAR_EQ] = ACTIONS(522),
    [anon_sym_SLASH_EQ] = ACTIONS(522),
    [anon_sym_PERCENT_EQ] = ACTIONS(522),
    [anon_sym_CARET_EQ] = ACTIONS(522),
    [anon_sym_AMP_EQ] = ACTIONS(522),
    [anon_sym_PIPE_EQ] = ACTIONS(522),
    [anon_sym_EQ_EQ] = ACTIONS(522),
    [anon_sym_BANG_EQ] = ACTIONS(522),
    [anon_sym_GT_EQ] = ACTIONS(522),
    [anon_sym_LT_EQ] = ACTIONS(522),
    [anon_sym_AT] = ACTIONS(522),
    [anon_sym_DOT_DOT] = ACTIONS(522),
    [anon_sym_DOT] = ACTIONS(525),
    [anon_sym_EQ_GT] = ACTIONS(522),
    [anon_sym_QMARK] = ACTIONS(522),
    [anon_sym_break] = ACTIONS(520),
    [anon_sym_continue] = ACTIONS(520),
    [anon_sym_default] = ACTIONS(520),
    [anon_sym_if] = ACTIONS(520),
    [anon_sym_extern] = ACTIONS(520),
    [anon_sym_nopanic] = ACTIONS(520),
    [anon_sym_loop] = ACTIONS(520),
    [anon_sym_match] = ACTIONS(520),
    [anon_sym_pub] = ACTIONS(520),
    [anon_sym_return] = ACTIONS(520),
    [anon_sym_static] = ACTIONS(520),
    [anon_sym_while] = ACTIONS(520),
    [anon_sym_for] = ACTIONS(520),
    [sym_numeric_literal] = ACTIONS(520),
    [aux_sym_string_literal_token1] = ACTIONS(518),
    [sym_shortstring_literal] = ACTIONS(518),
    [anon_sym_true] = ACTIONS(520),
    [anon_sym_false] = ACTIONS(520),
    [anon_sym_DOLLAR] = ACTIONS(518),
    [sym_identifier] = ACTIONS(520),
    [sym_mutable_specifier] = ACTIONS(520),
    [sym_super] = ACTIONS(520),
    [sym_line_comment] = ACTIONS(3),
  },
  [78] = {
    [anon_sym_LBRACE] = ACTIONS(528),
    [anon_sym_RBRACE] = ACTIONS(528),
    [anon_sym_impl] = ACTIONS(530),
    [anon_sym_SEMI] = ACTIONS(528),
    [anon_sym_trait] = ACTIONS(530),
    [anon_sym_type] = ACTIONS(530),
    [anon_sym_COLON] = ACTIONS(530),
    [anon_sym_const] = ACTIONS(530),
    [anon_sym_EQ] = ACTIONS(530),
    [anon_sym_BANG] = ACTIONS(530),
    [anon_sym_POUND] = ACTIONS(528),
    [anon_sym_LBRACK] = ACTIONS(528),
    [anon_sym_RBRACK] = ACTIONS(528),
    [anon_sym_mod] = ACTIONS(530),
    [anon_sym_struct] = ACTIONS(530),
    [anon_sym_enum] = ACTIONS(530),
    [anon_sym_COMMA] = ACTIONS(528),
    [anon_sym_fn] = ACTIONS(530),
    [anon_sym_DASH_GT] = ACTIONS(528),
    [anon_sym_let] = ACTIONS(530),
    [anon_sym_use] = ACTIONS(530),
    [anon_sym_COLON_COLON] = ACTIONS(528),
    [anon_sym_STAR] = ACTIONS(530),
    [anon_sym_LPAREN] = ACTIONS(528),
    [anon_sym__] = ACTIONS(530),
    [anon_sym_RPAREN] = ACTIONS(528),
    [anon_sym_u8] = ACTIONS(530),
    [anon_sym_i8] = ACTIONS(530),
    [anon_sym_u16] = ACTIONS(530),
    [anon_sym_i16] = ACTIONS(530),
    [anon_sym_u32] = ACTIONS(530),
    [anon_sym_i32] = ACTIONS(530),
    [anon_sym_u64] = ACTIONS(530),
    [anon_sym_i64] = ACTIONS(530),
    [anon_sym_u128] = ACTIONS(530),
    [anon_sym_i128] = ACTIONS(530),
    [anon_sym_usize] = ACTIONS(530),
    [anon_sym_bool] = ACTIONS(530),
    [anon_sym_ByteArray] = ACTIONS(530),
    [anon_sym_felt252] = ACTIONS(530),
    [anon_sym_LT] = ACTIONS(530),
    [anon_sym_GT] = ACTIONS(530),
    [anon_sym_PLUS] = ACTIONS(530),
    [anon_sym_DASH] = ACTIONS(530),
    [anon_sym_SLASH] = ACTIONS(530),
    [anon_sym_PERCENT] = ACTIONS(530),
    [anon_sym_CARET] = ACTIONS(530),
    [anon_sym_TILDE] = ACTIONS(528),
    [anon_sym_AMP] = ACTIONS(530),
    [anon_sym_PIPE] = ACTIONS(530),
    [anon_sym_AMP_AMP] = ACTIONS(528),
    [anon_sym_PIPE_PIPE] = ACTIONS(528),
    [anon_sym_LT_LT] = ACTIONS(528),
    [anon_sym_GT_GT] = ACTIONS(528),
    [anon_sym_PLUS_EQ] = ACTIONS(528),
    [anon_sym_DASH_EQ] = ACTIONS(528),
    [anon_sym_STAR_EQ] = ACTIONS(528),
    [anon_sym_SLASH_EQ] = ACTIONS(528),
    [anon_sym_PERCENT_EQ] = ACTIONS(528),
    [anon_sym_CARET_EQ] = ACTIONS(528),
    [anon_sym_AMP_EQ] = ACTIONS(528),
    [anon_sym_PIPE_EQ] = ACTIONS(528),
    [anon_sym_EQ_EQ] = ACTIONS(528),
    [anon_sym_BANG_EQ] = ACTIONS(528),
    [anon_sym_GT_EQ] = ACTIONS(528),
    [anon_sym_LT_EQ] = ACTIONS(528),
    [anon_sym_AT] = ACTIONS(528),
    [anon_sym_DOT_DOT] = ACTIONS(528),
    [anon_sym_DOT] = ACTIONS(530),
    [anon_sym_EQ_GT] = ACTIONS(528),
    [anon_sym_QMARK] = ACTIONS(528),
    [anon_sym_break] = ACTIONS(530),
    [anon_sym_continue] = ACTIONS(530),
    [anon_sym_default] = ACTIONS(530),
    [anon_sym_if] = ACTIONS(530),
    [anon_sym_extern] = ACTIONS(530),
    [anon_sym_nopanic] = ACTIONS(530),
    [anon_sym_loop] = ACTIONS(530),
    [anon_sym_match] = ACTIONS(530),
    [anon_sym_pub] = ACTIONS(530),
    [anon_sym_return] = ACTIONS(530),
    [anon_sym_static] = ACTIONS(530),
    [anon_sym_while] = ACTIONS(530),
    [anon_sym_for] = ACTIONS(530),
    [sym_numeric_literal] = ACTIONS(530),
    [aux_sym_string_literal_token1] = ACTIONS(528),
    [sym_shortstring_literal] = ACTIONS(528),
    [anon_sym_true] = ACTIONS(530),
    [anon_sym_false] = ACTIONS(530),
    [anon_sym_DOLLAR] = ACTIONS(528),
    [sym_identifier] = ACTIONS(530),
    [sym_mutable_specifier] = ACTIONS(530),
    [sym_super] = ACTIONS(530),
    [sym_line_comment] = ACTIONS(3),
  },
  [79] = {
    [anon_sym_LBRACE] = ACTIONS(532),
    [anon_sym_RBRACE] = ACTIONS(532),
    [anon_sym_impl] = ACTIONS(534),
    [anon_sym_SEMI] = ACTIONS(532),
    [anon_sym_trait] = ACTIONS(534),
    [anon_sym_type] = ACTIONS(534),
    [anon_sym_COLON] = ACTIONS(534),
    [anon_sym_const] = ACTIONS(534),
    [anon_sym_EQ] = ACTIONS(534),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_POUND] = ACTIONS(532),
    [anon_sym_LBRACK] = ACTIONS(532),
    [anon_sym_RBRACK] = ACTIONS(532),
    [anon_sym_mod] = ACTIONS(534),
    [anon_sym_struct] = ACTIONS(534),
    [anon_sym_enum] = ACTIONS(534),
    [anon_sym_COMMA] = ACTIONS(532),
    [anon_sym_fn] = ACTIONS(534),
    [anon_sym_DASH_GT] = ACTIONS(532),
    [anon_sym_let] = ACTIONS(534),
    [anon_sym_use] = ACTIONS(534),
    [anon_sym_COLON_COLON] = ACTIONS(532),
    [anon_sym_STAR] = ACTIONS(534),
    [anon_sym_LPAREN] = ACTIONS(532),
    [anon_sym__] = ACTIONS(534),
    [anon_sym_RPAREN] = ACTIONS(532),
    [anon_sym_u8] = ACTIONS(534),
    [anon_sym_i8] = ACTIONS(534),
    [anon_sym_u16] = ACTIONS(534),
    [anon_sym_i16] = ACTIONS(534),
    [anon_sym_u32] = ACTIONS(534),
    [anon_sym_i32] = ACTIONS(534),
    [anon_sym_u64] = ACTIONS(534),
    [anon_sym_i64] = ACTIONS(534),
    [anon_sym_u128] = ACTIONS(534),
    [anon_sym_i128] = ACTIONS(534),
    [anon_sym_usize] = ACTIONS(534),
    [anon_sym_bool] = ACTIONS(534),
    [anon_sym_ByteArray] = ACTIONS(534),
    [anon_sym_felt252] = ACTIONS(534),
    [anon_sym_LT] = ACTIONS(534),
    [anon_sym_GT] = ACTIONS(534),
    [anon_sym_PLUS] = ACTIONS(534),
    [anon_sym_DASH] = ACTIONS(534),
    [anon_sym_SLASH] = ACTIONS(534),
    [anon_sym_PERCENT] = ACTIONS(534),
    [anon_sym_CARET] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(532),
    [anon_sym_AMP] = ACTIONS(534),
    [anon_sym_PIPE] = ACTIONS(534),
    [anon_sym_AMP_AMP] = ACTIONS(532),
    [anon_sym_PIPE_PIPE] = ACTIONS(532),
    [anon_sym_LT_LT] = ACTIONS(532),
    [anon_sym_GT_GT] = ACTIONS(532),
    [anon_sym_PLUS_EQ] = ACTIONS(532),
    [anon_sym_DASH_EQ] = ACTIONS(532),
    [anon_sym_STAR_EQ] = ACTIONS(532),
    [anon_sym_SLASH_EQ] = ACTIONS(532),
    [anon_sym_PERCENT_EQ] = ACTIONS(532),
    [anon_sym_CARET_EQ] = ACTIONS(532),
    [anon_sym_AMP_EQ] = ACTIONS(532),
    [anon_sym_PIPE_EQ] = ACTIONS(532),
    [anon_sym_EQ_EQ] = ACTIONS(532),
    [anon_sym_BANG_EQ] = ACTIONS(532),
    [anon_sym_GT_EQ] = ACTIONS(532),
    [anon_sym_LT_EQ] = ACTIONS(532),
    [anon_sym_AT] = ACTIONS(532),
    [anon_sym_DOT_DOT] = ACTIONS(532),
    [anon_sym_DOT] = ACTIONS(534),
    [anon_sym_EQ_GT] = ACTIONS(532),
    [anon_sym_QMARK] = ACTIONS(532),
    [anon_sym_break] = ACTIONS(534),
    [anon_sym_continue] = ACTIONS(534),
    [anon_sym_default] = ACTIONS(534),
    [anon_sym_if] = ACTIONS(534),
    [anon_sym_extern] = ACTIONS(534),
    [anon_sym_nopanic] = ACTIONS(534),
    [anon_sym_loop] = ACTIONS(534),
    [anon_sym_match] = ACTIONS(534),
    [anon_sym_pub] = ACTIONS(534),
    [anon_sym_return] = ACTIONS(534),
    [anon_sym_static] = ACTIONS(534),
    [anon_sym_while] = ACTIONS(534),
    [anon_sym_for] = ACTIONS(534),
    [sym_numeric_literal] = ACTIONS(534),
    [aux_sym_string_literal_token1] = ACTIONS(532),
    [sym_shortstring_literal] = ACTIONS(532),
    [anon_sym_true] = ACTIONS(534),
    [anon_sym_false] = ACTIONS(534),
    [anon_sym_DOLLAR] = ACTIONS(532),
    [sym_identifier] = ACTIONS(534),
    [sym_mutable_specifier] = ACTIONS(534),
    [sym_super] = ACTIONS(534),
    [sym_line_comment] = ACTIONS(3),
  },
  [80] = {
    [anon_sym_LBRACE] = ACTIONS(536),
    [anon_sym_RBRACE] = ACTIONS(536),
    [anon_sym_impl] = ACTIONS(538),
    [anon_sym_SEMI] = ACTIONS(536),
    [anon_sym_trait] = ACTIONS(538),
    [anon_sym_type] = ACTIONS(538),
    [anon_sym_COLON] = ACTIONS(538),
    [anon_sym_const] = ACTIONS(538),
    [anon_sym_EQ] = ACTIONS(538),
    [anon_sym_BANG] = ACTIONS(538),
    [anon_sym_POUND] = ACTIONS(536),
    [anon_sym_LBRACK] = ACTIONS(536),
    [anon_sym_RBRACK] = ACTIONS(536),
    [anon_sym_mod] = ACTIONS(538),
    [anon_sym_struct] = ACTIONS(538),
    [anon_sym_enum] = ACTIONS(538),
    [anon_sym_COMMA] = ACTIONS(536),
    [anon_sym_fn] = ACTIONS(538),
    [anon_sym_DASH_GT] = ACTIONS(536),
    [anon_sym_let] = ACTIONS(538),
    [anon_sym_use] = ACTIONS(538),
    [anon_sym_COLON_COLON] = ACTIONS(536),
    [anon_sym_STAR] = ACTIONS(538),
    [anon_sym_LPAREN] = ACTIONS(536),
    [anon_sym__] = ACTIONS(538),
    [anon_sym_RPAREN] = ACTIONS(536),
    [anon_sym_u8] = ACTIONS(538),
    [anon_sym_i8] = ACTIONS(538),
    [anon_sym_u16] = ACTIONS(538),
    [anon_sym_i16] = ACTIONS(538),
    [anon_sym_u32] = ACTIONS(538),
    [anon_sym_i32] = ACTIONS(538),
    [anon_sym_u64] = ACTIONS(538),
    [anon_sym_i64] = ACTIONS(538),
    [anon_sym_u128] = ACTIONS(538),
    [anon_sym_i128] = ACTIONS(538),
    [anon_sym_usize] = ACTIONS(538),
    [anon_sym_bool] = ACTIONS(538),
    [anon_sym_ByteArray] = ACTIONS(538),
    [anon_sym_felt252] = ACTIONS(538),
    [anon_sym_LT] = ACTIONS(538),
    [anon_sym_GT] = ACTIONS(538),
    [anon_sym_PLUS] = ACTIONS(538),
    [anon_sym_DASH] = ACTIONS(538),
    [anon_sym_SLASH] = ACTIONS(538),
    [anon_sym_PERCENT] = ACTIONS(538),
    [anon_sym_CARET] = ACTIONS(538),
    [anon_sym_TILDE] = ACTIONS(536),
    [anon_sym_AMP] = ACTIONS(538),
    [anon_sym_PIPE] = ACTIONS(538),
    [anon_sym_AMP_AMP] = ACTIONS(536),
    [anon_sym_PIPE_PIPE] = ACTIONS(536),
    [anon_sym_LT_LT] = ACTIONS(536),
    [anon_sym_GT_GT] = ACTIONS(536),
    [anon_sym_PLUS_EQ] = ACTIONS(536),
    [anon_sym_DASH_EQ] = ACTIONS(536),
    [anon_sym_STAR_EQ] = ACTIONS(536),
    [anon_sym_SLASH_EQ] = ACTIONS(536),
    [anon_sym_PERCENT_EQ] = ACTIONS(536),
    [anon_sym_CARET_EQ] = ACTIONS(536),
    [anon_sym_AMP_EQ] = ACTIONS(536),
    [anon_sym_PIPE_EQ] = ACTIONS(536),
    [anon_sym_EQ_EQ] = ACTIONS(536),
    [anon_sym_BANG_EQ] = ACTIONS(536),
    [anon_sym_GT_EQ] = ACTIONS(536),
    [anon_sym_LT_EQ] = ACTIONS(536),
    [anon_sym_AT] = ACTIONS(536),
    [anon_sym_DOT_DOT] = ACTIONS(536),
    [anon_sym_DOT] = ACTIONS(538),
    [anon_sym_EQ_GT] = ACTIONS(536),
    [anon_sym_QMARK] = ACTIONS(536),
    [anon_sym_break] = ACTIONS(538),
    [anon_sym_continue] = ACTIONS(538),
    [anon_sym_default] = ACTIONS(538),
    [anon_sym_if] = ACTIONS(538),
    [anon_sym_extern] = ACTIONS(538),
    [anon_sym_nopanic] = ACTIONS(538),
    [anon_sym_loop] = ACTIONS(538),
    [anon_sym_match] = ACTIONS(538),
    [anon_sym_pub] = ACTIONS(538),
    [anon_sym_return] = ACTIONS(538),
    [anon_sym_static] = ACTIONS(538),
    [anon_sym_while] = ACTIONS(538),
    [anon_sym_for] = ACTIONS(538),
    [sym_numeric_literal] = ACTIONS(538),
    [aux_sym_string_literal_token1] = ACTIONS(536),
    [sym_shortstring_literal] = ACTIONS(536),
    [anon_sym_true] = ACTIONS(538),
    [anon_sym_false] = ACTIONS(538),
    [anon_sym_DOLLAR] = ACTIONS(536),
    [sym_identifier] = ACTIONS(538),
    [sym_mutable_specifier] = ACTIONS(538),
    [sym_super] = ACTIONS(538),
    [sym_line_comment] = ACTIONS(3),
  },
  [81] = {
    [anon_sym_LBRACE] = ACTIONS(540),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_impl] = ACTIONS(542),
    [anon_sym_SEMI] = ACTIONS(540),
    [anon_sym_trait] = ACTIONS(542),
    [anon_sym_type] = ACTIONS(542),
    [anon_sym_COLON] = ACTIONS(542),
    [anon_sym_const] = ACTIONS(542),
    [anon_sym_EQ] = ACTIONS(542),
    [anon_sym_BANG] = ACTIONS(542),
    [anon_sym_POUND] = ACTIONS(540),
    [anon_sym_LBRACK] = ACTIONS(540),
    [anon_sym_RBRACK] = ACTIONS(540),
    [anon_sym_mod] = ACTIONS(542),
    [anon_sym_struct] = ACTIONS(542),
    [anon_sym_enum] = ACTIONS(542),
    [anon_sym_COMMA] = ACTIONS(540),
    [anon_sym_fn] = ACTIONS(542),
    [anon_sym_DASH_GT] = ACTIONS(540),
    [anon_sym_let] = ACTIONS(542),
    [anon_sym_use] = ACTIONS(542),
    [anon_sym_COLON_COLON] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(542),
    [anon_sym_LPAREN] = ACTIONS(540),
    [anon_sym__] = ACTIONS(542),
    [anon_sym_RPAREN] = ACTIONS(540),
    [anon_sym_u8] = ACTIONS(542),
    [anon_sym_i8] = ACTIONS(542),
    [anon_sym_u16] = ACTIONS(542),
    [anon_sym_i16] = ACTIONS(542),
    [anon_sym_u32] = ACTIONS(542),
    [anon_sym_i32] = ACTIONS(542),
    [anon_sym_u64] = ACTIONS(542),
    [anon_sym_i64] = ACTIONS(542),
    [anon_sym_u128] = ACTIONS(542),
    [anon_sym_i128] = ACTIONS(542),
    [anon_sym_usize] = ACTIONS(542),
    [anon_sym_bool] = ACTIONS(542),
    [anon_sym_ByteArray] = ACTIONS(542),
    [anon_sym_felt252] = ACTIONS(542),
    [anon_sym_LT] = ACTIONS(542),
    [anon_sym_GT] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_SLASH] = ACTIONS(542),
    [anon_sym_PERCENT] = ACTIONS(542),
    [anon_sym_CARET] = ACTIONS(542),
    [anon_sym_TILDE] = ACTIONS(540),
    [anon_sym_AMP] = ACTIONS(542),
    [anon_sym_PIPE] = ACTIONS(542),
    [anon_sym_AMP_AMP] = ACTIONS(540),
    [anon_sym_PIPE_PIPE] = ACTIONS(540),
    [anon_sym_LT_LT] = ACTIONS(540),
    [anon_sym_GT_GT] = ACTIONS(540),
    [anon_sym_PLUS_EQ] = ACTIONS(540),
    [anon_sym_DASH_EQ] = ACTIONS(540),
    [anon_sym_STAR_EQ] = ACTIONS(540),
    [anon_sym_SLASH_EQ] = ACTIONS(540),
    [anon_sym_PERCENT_EQ] = ACTIONS(540),
    [anon_sym_CARET_EQ] = ACTIONS(540),
    [anon_sym_AMP_EQ] = ACTIONS(540),
    [anon_sym_PIPE_EQ] = ACTIONS(540),
    [anon_sym_EQ_EQ] = ACTIONS(540),
    [anon_sym_BANG_EQ] = ACTIONS(540),
    [anon_sym_GT_EQ] = ACTIONS(540),
    [anon_sym_LT_EQ] = ACTIONS(540),
    [anon_sym_AT] = ACTIONS(540),
    [anon_sym_DOT_DOT] = ACTIONS(540),
    [anon_sym_DOT] = ACTIONS(542),
    [anon_sym_EQ_GT] = ACTIONS(540),
    [anon_sym_QMARK] = ACTIONS(540),
    [anon_sym_break] = ACTIONS(542),
    [anon_sym_continue] = ACTIONS(542),
    [anon_sym_default] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(542),
    [anon_sym_extern] = ACTIONS(542),
    [anon_sym_nopanic] = ACTIONS(542),
    [anon_sym_loop] = ACTIONS(542),
    [anon_sym_match] = ACTIONS(542),
    [anon_sym_pub] = ACTIONS(542),
    [anon_sym_return] = ACTIONS(542),
    [anon_sym_static] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_for] = ACTIONS(542),
    [sym_numeric_literal] = ACTIONS(542),
    [aux_sym_string_literal_token1] = ACTIONS(540),
    [sym_shortstring_literal] = ACTIONS(540),
    [anon_sym_true] = ACTIONS(542),
    [anon_sym_false] = ACTIONS(542),
    [anon_sym_DOLLAR] = ACTIONS(540),
    [sym_identifier] = ACTIONS(542),
    [sym_mutable_specifier] = ACTIONS(542),
    [sym_super] = ACTIONS(542),
    [sym_line_comment] = ACTIONS(3),
  },
  [82] = {
    [anon_sym_LBRACE] = ACTIONS(544),
    [anon_sym_RBRACE] = ACTIONS(544),
    [anon_sym_impl] = ACTIONS(546),
    [anon_sym_SEMI] = ACTIONS(544),
    [anon_sym_trait] = ACTIONS(546),
    [anon_sym_type] = ACTIONS(546),
    [anon_sym_COLON] = ACTIONS(546),
    [anon_sym_const] = ACTIONS(546),
    [anon_sym_EQ] = ACTIONS(546),
    [anon_sym_BANG] = ACTIONS(546),
    [anon_sym_POUND] = ACTIONS(544),
    [anon_sym_LBRACK] = ACTIONS(544),
    [anon_sym_RBRACK] = ACTIONS(544),
    [anon_sym_mod] = ACTIONS(546),
    [anon_sym_struct] = ACTIONS(546),
    [anon_sym_enum] = ACTIONS(546),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_fn] = ACTIONS(546),
    [anon_sym_DASH_GT] = ACTIONS(544),
    [anon_sym_let] = ACTIONS(546),
    [anon_sym_use] = ACTIONS(546),
    [anon_sym_COLON_COLON] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(546),
    [anon_sym_LPAREN] = ACTIONS(544),
    [anon_sym__] = ACTIONS(546),
    [anon_sym_RPAREN] = ACTIONS(544),
    [anon_sym_u8] = ACTIONS(546),
    [anon_sym_i8] = ACTIONS(546),
    [anon_sym_u16] = ACTIONS(546),
    [anon_sym_i16] = ACTIONS(546),
    [anon_sym_u32] = ACTIONS(546),
    [anon_sym_i32] = ACTIONS(546),
    [anon_sym_u64] = ACTIONS(546),
    [anon_sym_i64] = ACTIONS(546),
    [anon_sym_u128] = ACTIONS(546),
    [anon_sym_i128] = ACTIONS(546),
    [anon_sym_usize] = ACTIONS(546),
    [anon_sym_bool] = ACTIONS(546),
    [anon_sym_ByteArray] = ACTIONS(546),
    [anon_sym_felt252] = ACTIONS(546),
    [anon_sym_LT] = ACTIONS(546),
    [anon_sym_GT] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_SLASH] = ACTIONS(546),
    [anon_sym_PERCENT] = ACTIONS(546),
    [anon_sym_CARET] = ACTIONS(546),
    [anon_sym_TILDE] = ACTIONS(544),
    [anon_sym_AMP] = ACTIONS(546),
    [anon_sym_PIPE] = ACTIONS(546),
    [anon_sym_AMP_AMP] = ACTIONS(544),
    [anon_sym_PIPE_PIPE] = ACTIONS(544),
    [anon_sym_LT_LT] = ACTIONS(544),
    [anon_sym_GT_GT] = ACTIONS(544),
    [anon_sym_PLUS_EQ] = ACTIONS(544),
    [anon_sym_DASH_EQ] = ACTIONS(544),
    [anon_sym_STAR_EQ] = ACTIONS(544),
    [anon_sym_SLASH_EQ] = ACTIONS(544),
    [anon_sym_PERCENT_EQ] = ACTIONS(544),
    [anon_sym_CARET_EQ] = ACTIONS(544),
    [anon_sym_AMP_EQ] = ACTIONS(544),
    [anon_sym_PIPE_EQ] = ACTIONS(544),
    [anon_sym_EQ_EQ] = ACTIONS(544),
    [anon_sym_BANG_EQ] = ACTIONS(544),
    [anon_sym_GT_EQ] = ACTIONS(544),
    [anon_sym_LT_EQ] = ACTIONS(544),
    [anon_sym_AT] = ACTIONS(544),
    [anon_sym_DOT_DOT] = ACTIONS(544),
    [anon_sym_DOT] = ACTIONS(546),
    [anon_sym_EQ_GT] = ACTIONS(544),
    [anon_sym_QMARK] = ACTIONS(544),
    [anon_sym_break] = ACTIONS(546),
    [anon_sym_continue] = ACTIONS(546),
    [anon_sym_default] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(546),
    [anon_sym_extern] = ACTIONS(546),
    [anon_sym_nopanic] = ACTIONS(546),
    [anon_sym_loop] = ACTIONS(546),
    [anon_sym_match] = ACTIONS(546),
    [anon_sym_pub] = ACTIONS(546),
    [anon_sym_return] = ACTIONS(546),
    [anon_sym_static] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_for] = ACTIONS(546),
    [sym_numeric_literal] = ACTIONS(546),
    [aux_sym_string_literal_token1] = ACTIONS(544),
    [sym_shortstring_literal] = ACTIONS(544),
    [anon_sym_true] = ACTIONS(546),
    [anon_sym_false] = ACTIONS(546),
    [anon_sym_DOLLAR] = ACTIONS(544),
    [sym_identifier] = ACTIONS(546),
    [sym_mutable_specifier] = ACTIONS(546),
    [sym_super] = ACTIONS(546),
    [sym_line_comment] = ACTIONS(3),
  },
  [83] = {
    [anon_sym_LBRACE] = ACTIONS(548),
    [anon_sym_RBRACE] = ACTIONS(548),
    [anon_sym_impl] = ACTIONS(550),
    [anon_sym_SEMI] = ACTIONS(548),
    [anon_sym_trait] = ACTIONS(550),
    [anon_sym_type] = ACTIONS(550),
    [anon_sym_COLON] = ACTIONS(550),
    [anon_sym_const] = ACTIONS(550),
    [anon_sym_EQ] = ACTIONS(550),
    [anon_sym_BANG] = ACTIONS(550),
    [anon_sym_POUND] = ACTIONS(548),
    [anon_sym_LBRACK] = ACTIONS(548),
    [anon_sym_RBRACK] = ACTIONS(548),
    [anon_sym_mod] = ACTIONS(550),
    [anon_sym_struct] = ACTIONS(550),
    [anon_sym_enum] = ACTIONS(550),
    [anon_sym_COMMA] = ACTIONS(548),
    [anon_sym_fn] = ACTIONS(550),
    [anon_sym_DASH_GT] = ACTIONS(548),
    [anon_sym_let] = ACTIONS(550),
    [anon_sym_use] = ACTIONS(550),
    [anon_sym_COLON_COLON] = ACTIONS(548),
    [anon_sym_STAR] = ACTIONS(550),
    [anon_sym_LPAREN] = ACTIONS(548),
    [anon_sym__] = ACTIONS(550),
    [anon_sym_RPAREN] = ACTIONS(548),
    [anon_sym_u8] = ACTIONS(550),
    [anon_sym_i8] = ACTIONS(550),
    [anon_sym_u16] = ACTIONS(550),
    [anon_sym_i16] = ACTIONS(550),
    [anon_sym_u32] = ACTIONS(550),
    [anon_sym_i32] = ACTIONS(550),
    [anon_sym_u64] = ACTIONS(550),
    [anon_sym_i64] = ACTIONS(550),
    [anon_sym_u128] = ACTIONS(550),
    [anon_sym_i128] = ACTIONS(550),
    [anon_sym_usize] = ACTIONS(550),
    [anon_sym_bool] = ACTIONS(550),
    [anon_sym_ByteArray] = ACTIONS(550),
    [anon_sym_felt252] = ACTIONS(550),
    [anon_sym_LT] = ACTIONS(550),
    [anon_sym_GT] = ACTIONS(550),
    [anon_sym_PLUS] = ACTIONS(550),
    [anon_sym_DASH] = ACTIONS(550),
    [anon_sym_SLASH] = ACTIONS(550),
    [anon_sym_PERCENT] = ACTIONS(550),
    [anon_sym_CARET] = ACTIONS(550),
    [anon_sym_TILDE] = ACTIONS(548),
    [anon_sym_AMP] = ACTIONS(550),
    [anon_sym_PIPE] = ACTIONS(550),
    [anon_sym_AMP_AMP] = ACTIONS(548),
    [anon_sym_PIPE_PIPE] = ACTIONS(548),
    [anon_sym_LT_LT] = ACTIONS(548),
    [anon_sym_GT_GT] = ACTIONS(548),
    [anon_sym_PLUS_EQ] = ACTIONS(548),
    [anon_sym_DASH_EQ] = ACTIONS(548),
    [anon_sym_STAR_EQ] = ACTIONS(548),
    [anon_sym_SLASH_EQ] = ACTIONS(548),
    [anon_sym_PERCENT_EQ] = ACTIONS(548),
    [anon_sym_CARET_EQ] = ACTIONS(548),
    [anon_sym_AMP_EQ] = ACTIONS(548),
    [anon_sym_PIPE_EQ] = ACTIONS(548),
    [anon_sym_EQ_EQ] = ACTIONS(548),
    [anon_sym_BANG_EQ] = ACTIONS(548),
    [anon_sym_GT_EQ] = ACTIONS(548),
    [anon_sym_LT_EQ] = ACTIONS(548),
    [anon_sym_AT] = ACTIONS(548),
    [anon_sym_DOT_DOT] = ACTIONS(548),
    [anon_sym_DOT] = ACTIONS(550),
    [anon_sym_EQ_GT] = ACTIONS(548),
    [anon_sym_QMARK] = ACTIONS(548),
    [anon_sym_break] = ACTIONS(550),
    [anon_sym_continue] = ACTIONS(550),
    [anon_sym_default] = ACTIONS(550),
    [anon_sym_if] = ACTIONS(550),
    [anon_sym_extern] = ACTIONS(550),
    [anon_sym_nopanic] = ACTIONS(550),
    [anon_sym_loop] = ACTIONS(550),
    [anon_sym_match] = ACTIONS(550),
    [anon_sym_pub] = ACTIONS(550),
    [anon_sym_return] = ACTIONS(550),
    [anon_sym_static] = ACTIONS(550),
    [anon_sym_while] = ACTIONS(550),
    [anon_sym_for] = ACTIONS(550),
    [sym_numeric_literal] = ACTIONS(552),
    [aux_sym_string_literal_token1] = ACTIONS(548),
    [sym_shortstring_literal] = ACTIONS(548),
    [anon_sym_true] = ACTIONS(550),
    [anon_sym_false] = ACTIONS(550),
    [anon_sym_DOLLAR] = ACTIONS(548),
    [sym_identifier] = ACTIONS(550),
    [sym_mutable_specifier] = ACTIONS(550),
    [sym_super] = ACTIONS(550),
    [sym_line_comment] = ACTIONS(3),
  },
  [84] = {
    [anon_sym_LBRACE] = ACTIONS(555),
    [anon_sym_RBRACE] = ACTIONS(555),
    [anon_sym_impl] = ACTIONS(557),
    [anon_sym_SEMI] = ACTIONS(555),
    [anon_sym_trait] = ACTIONS(557),
    [anon_sym_type] = ACTIONS(557),
    [anon_sym_COLON] = ACTIONS(557),
    [anon_sym_const] = ACTIONS(557),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_BANG] = ACTIONS(557),
    [anon_sym_POUND] = ACTIONS(555),
    [anon_sym_LBRACK] = ACTIONS(555),
    [anon_sym_RBRACK] = ACTIONS(555),
    [anon_sym_mod] = ACTIONS(557),
    [anon_sym_struct] = ACTIONS(557),
    [anon_sym_enum] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(555),
    [anon_sym_fn] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(555),
    [anon_sym_let] = ACTIONS(557),
    [anon_sym_use] = ACTIONS(557),
    [anon_sym_COLON_COLON] = ACTIONS(555),
    [anon_sym_STAR] = ACTIONS(557),
    [anon_sym_LPAREN] = ACTIONS(555),
    [anon_sym__] = ACTIONS(557),
    [anon_sym_RPAREN] = ACTIONS(555),
    [anon_sym_u8] = ACTIONS(557),
    [anon_sym_i8] = ACTIONS(557),
    [anon_sym_u16] = ACTIONS(557),
    [anon_sym_i16] = ACTIONS(557),
    [anon_sym_u32] = ACTIONS(557),
    [anon_sym_i32] = ACTIONS(557),
    [anon_sym_u64] = ACTIONS(557),
    [anon_sym_i64] = ACTIONS(557),
    [anon_sym_u128] = ACTIONS(557),
    [anon_sym_i128] = ACTIONS(557),
    [anon_sym_usize] = ACTIONS(557),
    [anon_sym_bool] = ACTIONS(557),
    [anon_sym_ByteArray] = ACTIONS(557),
    [anon_sym_felt252] = ACTIONS(557),
    [anon_sym_LT] = ACTIONS(557),
    [anon_sym_GT] = ACTIONS(557),
    [anon_sym_PLUS] = ACTIONS(557),
    [anon_sym_DASH] = ACTIONS(557),
    [anon_sym_SLASH] = ACTIONS(557),
    [anon_sym_PERCENT] = ACTIONS(557),
    [anon_sym_CARET] = ACTIONS(557),
    [anon_sym_TILDE] = ACTIONS(555),
    [anon_sym_AMP] = ACTIONS(557),
    [anon_sym_PIPE] = ACTIONS(557),
    [anon_sym_AMP_AMP] = ACTIONS(555),
    [anon_sym_PIPE_PIPE] = ACTIONS(555),
    [anon_sym_LT_LT] = ACTIONS(555),
    [anon_sym_GT_GT] = ACTIONS(555),
    [anon_sym_PLUS_EQ] = ACTIONS(555),
    [anon_sym_DASH_EQ] = ACTIONS(555),
    [anon_sym_STAR_EQ] = ACTIONS(555),
    [anon_sym_SLASH_EQ] = ACTIONS(555),
    [anon_sym_PERCENT_EQ] = ACTIONS(555),
    [anon_sym_CARET_EQ] = ACTIONS(555),
    [anon_sym_AMP_EQ] = ACTIONS(555),
    [anon_sym_PIPE_EQ] = ACTIONS(555),
    [anon_sym_EQ_EQ] = ACTIONS(555),
    [anon_sym_BANG_EQ] = ACTIONS(555),
    [anon_sym_GT_EQ] = ACTIONS(555),
    [anon_sym_LT_EQ] = ACTIONS(555),
    [anon_sym_AT] = ACTIONS(555),
    [anon_sym_DOT_DOT] = ACTIONS(555),
    [anon_sym_DOT] = ACTIONS(557),
    [anon_sym_EQ_GT] = ACTIONS(555),
    [anon_sym_QMARK] = ACTIONS(555),
    [anon_sym_break] = ACTIONS(557),
    [anon_sym_continue] = ACTIONS(557),
    [anon_sym_default] = ACTIONS(557),
    [anon_sym_if] = ACTIONS(557),
    [anon_sym_extern] = ACTIONS(557),
    [anon_sym_nopanic] = ACTIONS(557),
    [anon_sym_loop] = ACTIONS(557),
    [anon_sym_match] = ACTIONS(557),
    [anon_sym_pub] = ACTIONS(557),
    [anon_sym_return] = ACTIONS(557),
    [anon_sym_static] = ACTIONS(557),
    [anon_sym_while] = ACTIONS(557),
    [anon_sym_for] = ACTIONS(557),
    [sym_numeric_literal] = ACTIONS(557),
    [aux_sym_string_literal_token1] = ACTIONS(555),
    [sym_shortstring_literal] = ACTIONS(555),
    [anon_sym_true] = ACTIONS(557),
    [anon_sym_false] = ACTIONS(557),
    [anon_sym_DOLLAR] = ACTIONS(555),
    [sym_identifier] = ACTIONS(557),
    [sym_mutable_specifier] = ACTIONS(557),
    [sym_super] = ACTIONS(557),
    [sym_line_comment] = ACTIONS(3),
  },
  [85] = {
    [anon_sym_LBRACE] = ACTIONS(559),
    [anon_sym_RBRACE] = ACTIONS(559),
    [anon_sym_impl] = ACTIONS(561),
    [anon_sym_SEMI] = ACTIONS(559),
    [anon_sym_trait] = ACTIONS(561),
    [anon_sym_type] = ACTIONS(561),
    [anon_sym_COLON] = ACTIONS(561),
    [anon_sym_const] = ACTIONS(561),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_BANG] = ACTIONS(561),
    [anon_sym_POUND] = ACTIONS(559),
    [anon_sym_LBRACK] = ACTIONS(559),
    [anon_sym_RBRACK] = ACTIONS(559),
    [anon_sym_mod] = ACTIONS(561),
    [anon_sym_struct] = ACTIONS(561),
    [anon_sym_enum] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(559),
    [anon_sym_fn] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(559),
    [anon_sym_let] = ACTIONS(561),
    [anon_sym_use] = ACTIONS(561),
    [anon_sym_COLON_COLON] = ACTIONS(559),
    [anon_sym_STAR] = ACTIONS(561),
    [anon_sym_LPAREN] = ACTIONS(559),
    [anon_sym__] = ACTIONS(561),
    [anon_sym_RPAREN] = ACTIONS(559),
    [anon_sym_u8] = ACTIONS(561),
    [anon_sym_i8] = ACTIONS(561),
    [anon_sym_u16] = ACTIONS(561),
    [anon_sym_i16] = ACTIONS(561),
    [anon_sym_u32] = ACTIONS(561),
    [anon_sym_i32] = ACTIONS(561),
    [anon_sym_u64] = ACTIONS(561),
    [anon_sym_i64] = ACTIONS(561),
    [anon_sym_u128] = ACTIONS(561),
    [anon_sym_i128] = ACTIONS(561),
    [anon_sym_usize] = ACTIONS(561),
    [anon_sym_bool] = ACTIONS(561),
    [anon_sym_ByteArray] = ACTIONS(561),
    [anon_sym_felt252] = ACTIONS(561),
    [anon_sym_LT] = ACTIONS(561),
    [anon_sym_GT] = ACTIONS(561),
    [anon_sym_PLUS] = ACTIONS(561),
    [anon_sym_DASH] = ACTIONS(561),
    [anon_sym_SLASH] = ACTIONS(561),
    [anon_sym_PERCENT] = ACTIONS(561),
    [anon_sym_CARET] = ACTIONS(561),
    [anon_sym_TILDE] = ACTIONS(559),
    [anon_sym_AMP] = ACTIONS(561),
    [anon_sym_PIPE] = ACTIONS(561),
    [anon_sym_AMP_AMP] = ACTIONS(559),
    [anon_sym_PIPE_PIPE] = ACTIONS(559),
    [anon_sym_LT_LT] = ACTIONS(559),
    [anon_sym_GT_GT] = ACTIONS(559),
    [anon_sym_PLUS_EQ] = ACTIONS(559),
    [anon_sym_DASH_EQ] = ACTIONS(559),
    [anon_sym_STAR_EQ] = ACTIONS(559),
    [anon_sym_SLASH_EQ] = ACTIONS(559),
    [anon_sym_PERCENT_EQ] = ACTIONS(559),
    [anon_sym_CARET_EQ] = ACTIONS(559),
    [anon_sym_AMP_EQ] = ACTIONS(559),
    [anon_sym_PIPE_EQ] = ACTIONS(559),
    [anon_sym_EQ_EQ] = ACTIONS(559),
    [anon_sym_BANG_EQ] = ACTIONS(559),
    [anon_sym_GT_EQ] = ACTIONS(559),
    [anon_sym_LT_EQ] = ACTIONS(559),
    [anon_sym_AT] = ACTIONS(559),
    [anon_sym_DOT_DOT] = ACTIONS(559),
    [anon_sym_DOT] = ACTIONS(561),
    [anon_sym_EQ_GT] = ACTIONS(559),
    [anon_sym_QMARK] = ACTIONS(559),
    [anon_sym_break] = ACTIONS(561),
    [anon_sym_continue] = ACTIONS(561),
    [anon_sym_default] = ACTIONS(561),
    [anon_sym_if] = ACTIONS(561),
    [anon_sym_extern] = ACTIONS(561),
    [anon_sym_nopanic] = ACTIONS(561),
    [anon_sym_loop] = ACTIONS(561),
    [anon_sym_match] = ACTIONS(561),
    [anon_sym_pub] = ACTIONS(561),
    [anon_sym_return] = ACTIONS(561),
    [anon_sym_static] = ACTIONS(561),
    [anon_sym_while] = ACTIONS(561),
    [anon_sym_for] = ACTIONS(561),
    [sym_numeric_literal] = ACTIONS(561),
    [aux_sym_string_literal_token1] = ACTIONS(559),
    [sym_shortstring_literal] = ACTIONS(559),
    [anon_sym_true] = ACTIONS(561),
    [anon_sym_false] = ACTIONS(561),
    [anon_sym_DOLLAR] = ACTIONS(559),
    [sym_identifier] = ACTIONS(561),
    [sym_mutable_specifier] = ACTIONS(561),
    [sym_super] = ACTIONS(561),
    [sym_line_comment] = ACTIONS(3),
  },
  [86] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(100),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(693),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1432),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(100),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COMMA] = ACTIONS(567),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(569),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [87] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(97),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(728),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1381),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(97),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COMMA] = ACTIONS(573),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(575),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [88] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(577),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [89] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(579),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [90] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(581),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [91] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(583),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [92] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(585),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [93] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(587),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [94] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(103),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(650),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(103),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(589),
    [anon_sym_COMMA] = ACTIONS(591),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [95] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(94),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(679),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(94),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(593),
    [anon_sym_COMMA] = ACTIONS(595),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [96] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(711),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(597),
    [anon_sym_BANG] = ACTIONS(600),
    [anon_sym_POUND] = ACTIONS(603),
    [anon_sym_LBRACK] = ACTIONS(606),
    [anon_sym_RBRACK] = ACTIONS(609),
    [anon_sym_COMMA] = ACTIONS(609),
    [anon_sym_COLON_COLON] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(614),
    [anon_sym_u8] = ACTIONS(617),
    [anon_sym_i8] = ACTIONS(617),
    [anon_sym_u16] = ACTIONS(617),
    [anon_sym_i16] = ACTIONS(617),
    [anon_sym_u32] = ACTIONS(617),
    [anon_sym_i32] = ACTIONS(617),
    [anon_sym_u64] = ACTIONS(617),
    [anon_sym_i64] = ACTIONS(617),
    [anon_sym_u128] = ACTIONS(617),
    [anon_sym_i128] = ACTIONS(617),
    [anon_sym_usize] = ACTIONS(617),
    [anon_sym_bool] = ACTIONS(617),
    [anon_sym_ByteArray] = ACTIONS(617),
    [anon_sym_felt252] = ACTIONS(617),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(600),
    [anon_sym_PIPE] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(626),
    [anon_sym_break] = ACTIONS(629),
    [anon_sym_continue] = ACTIONS(632),
    [anon_sym_default] = ACTIONS(635),
    [anon_sym_if] = ACTIONS(638),
    [anon_sym_loop] = ACTIONS(641),
    [anon_sym_match] = ACTIONS(644),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(650),
    [anon_sym_for] = ACTIONS(653),
    [sym_numeric_literal] = ACTIONS(656),
    [aux_sym_string_literal_token1] = ACTIONS(659),
    [sym_shortstring_literal] = ACTIONS(662),
    [anon_sym_true] = ACTIONS(665),
    [anon_sym_false] = ACTIONS(665),
    [anon_sym_move] = ACTIONS(668),
    [anon_sym_ref] = ACTIONS(671),
    [sym_identifier] = ACTIONS(674),
    [sym_super] = ACTIONS(677),
    [sym_line_comment] = ACTIONS(3),
  },
  [97] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(731),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1410),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [98] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(868),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1675),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [99] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(102),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(676),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(102),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(680),
    [anon_sym_COMMA] = ACTIONS(682),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [100] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(720),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1347),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [101] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(98),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(886),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_named_argument] = STATE(1704),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(98),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_COLON] = ACTIONS(563),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(571),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [102] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(96),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(653),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(96),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(684),
    [anon_sym_COMMA] = ACTIONS(686),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [103] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(730),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(597),
    [anon_sym_BANG] = ACTIONS(600),
    [anon_sym_POUND] = ACTIONS(603),
    [anon_sym_LBRACK] = ACTIONS(606),
    [anon_sym_RBRACK] = ACTIONS(609),
    [anon_sym_COMMA] = ACTIONS(609),
    [anon_sym_COLON_COLON] = ACTIONS(611),
    [anon_sym_STAR] = ACTIONS(600),
    [anon_sym_LPAREN] = ACTIONS(614),
    [anon_sym_u8] = ACTIONS(617),
    [anon_sym_i8] = ACTIONS(617),
    [anon_sym_u16] = ACTIONS(617),
    [anon_sym_i16] = ACTIONS(617),
    [anon_sym_u32] = ACTIONS(617),
    [anon_sym_i32] = ACTIONS(617),
    [anon_sym_u64] = ACTIONS(617),
    [anon_sym_i64] = ACTIONS(617),
    [anon_sym_u128] = ACTIONS(617),
    [anon_sym_i128] = ACTIONS(617),
    [anon_sym_usize] = ACTIONS(617),
    [anon_sym_bool] = ACTIONS(617),
    [anon_sym_ByteArray] = ACTIONS(617),
    [anon_sym_felt252] = ACTIONS(617),
    [anon_sym_DASH] = ACTIONS(620),
    [anon_sym_TILDE] = ACTIONS(600),
    [anon_sym_PIPE] = ACTIONS(623),
    [anon_sym_AT] = ACTIONS(600),
    [anon_sym_DOT_DOT] = ACTIONS(626),
    [anon_sym_break] = ACTIONS(629),
    [anon_sym_continue] = ACTIONS(632),
    [anon_sym_default] = ACTIONS(635),
    [anon_sym_if] = ACTIONS(638),
    [anon_sym_loop] = ACTIONS(641),
    [anon_sym_match] = ACTIONS(644),
    [anon_sym_return] = ACTIONS(647),
    [anon_sym_while] = ACTIONS(650),
    [anon_sym_for] = ACTIONS(653),
    [sym_numeric_literal] = ACTIONS(656),
    [aux_sym_string_literal_token1] = ACTIONS(659),
    [sym_shortstring_literal] = ACTIONS(662),
    [anon_sym_true] = ACTIONS(665),
    [anon_sym_false] = ACTIONS(665),
    [anon_sym_move] = ACTIONS(668),
    [anon_sym_ref] = ACTIONS(671),
    [sym_identifier] = ACTIONS(674),
    [sym_super] = ACTIONS(677),
    [sym_line_comment] = ACTIONS(3),
  },
  [104] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(688),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [105] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(690),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [106] = {
    [ts_builtin_sym_end] = ACTIONS(692),
    [anon_sym_LBRACE] = ACTIONS(692),
    [anon_sym_RBRACE] = ACTIONS(692),
    [anon_sym_impl] = ACTIONS(694),
    [anon_sym_SEMI] = ACTIONS(692),
    [anon_sym_trait] = ACTIONS(694),
    [anon_sym_type] = ACTIONS(694),
    [anon_sym_const] = ACTIONS(694),
    [anon_sym_EQ] = ACTIONS(694),
    [anon_sym_BANG] = ACTIONS(694),
    [anon_sym_POUND] = ACTIONS(692),
    [anon_sym_LBRACK] = ACTIONS(692),
    [anon_sym_RBRACK] = ACTIONS(692),
    [anon_sym_mod] = ACTIONS(694),
    [anon_sym_struct] = ACTIONS(694),
    [anon_sym_enum] = ACTIONS(694),
    [anon_sym_COMMA] = ACTIONS(692),
    [anon_sym_fn] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(694),
    [anon_sym_use] = ACTIONS(694),
    [anon_sym_COLON_COLON] = ACTIONS(692),
    [anon_sym_STAR] = ACTIONS(694),
    [anon_sym_LPAREN] = ACTIONS(692),
    [anon_sym_RPAREN] = ACTIONS(692),
    [anon_sym_u8] = ACTIONS(694),
    [anon_sym_i8] = ACTIONS(694),
    [anon_sym_u16] = ACTIONS(694),
    [anon_sym_i16] = ACTIONS(694),
    [anon_sym_u32] = ACTIONS(694),
    [anon_sym_i32] = ACTIONS(694),
    [anon_sym_u64] = ACTIONS(694),
    [anon_sym_i64] = ACTIONS(694),
    [anon_sym_u128] = ACTIONS(694),
    [anon_sym_i128] = ACTIONS(694),
    [anon_sym_usize] = ACTIONS(694),
    [anon_sym_bool] = ACTIONS(694),
    [anon_sym_ByteArray] = ACTIONS(694),
    [anon_sym_felt252] = ACTIONS(694),
    [anon_sym_LT] = ACTIONS(694),
    [anon_sym_GT] = ACTIONS(694),
    [anon_sym_PLUS] = ACTIONS(694),
    [anon_sym_DASH] = ACTIONS(694),
    [anon_sym_SLASH] = ACTIONS(694),
    [anon_sym_PERCENT] = ACTIONS(694),
    [anon_sym_CARET] = ACTIONS(692),
    [anon_sym_TILDE] = ACTIONS(692),
    [anon_sym_AMP] = ACTIONS(694),
    [anon_sym_PIPE] = ACTIONS(694),
    [anon_sym_AMP_AMP] = ACTIONS(692),
    [anon_sym_PIPE_PIPE] = ACTIONS(692),
    [anon_sym_LT_LT] = ACTIONS(692),
    [anon_sym_GT_GT] = ACTIONS(692),
    [anon_sym_PLUS_EQ] = ACTIONS(692),
    [anon_sym_DASH_EQ] = ACTIONS(692),
    [anon_sym_STAR_EQ] = ACTIONS(692),
    [anon_sym_SLASH_EQ] = ACTIONS(692),
    [anon_sym_PERCENT_EQ] = ACTIONS(692),
    [anon_sym_EQ_EQ] = ACTIONS(692),
    [anon_sym_BANG_EQ] = ACTIONS(692),
    [anon_sym_GT_EQ] = ACTIONS(692),
    [anon_sym_LT_EQ] = ACTIONS(692),
    [anon_sym_AT] = ACTIONS(692),
    [anon_sym_DOT_DOT] = ACTIONS(692),
    [anon_sym_DOT] = ACTIONS(694),
    [anon_sym_QMARK] = ACTIONS(692),
    [anon_sym_break] = ACTIONS(694),
    [anon_sym_continue] = ACTIONS(694),
    [anon_sym_default] = ACTIONS(694),
    [anon_sym_if] = ACTIONS(694),
    [anon_sym_extern] = ACTIONS(694),
    [anon_sym_loop] = ACTIONS(694),
    [anon_sym_match] = ACTIONS(694),
    [anon_sym_pub] = ACTIONS(694),
    [anon_sym_return] = ACTIONS(694),
    [anon_sym_while] = ACTIONS(694),
    [anon_sym_for] = ACTIONS(694),
    [sym_numeric_literal] = ACTIONS(694),
    [aux_sym_string_literal_token1] = ACTIONS(692),
    [sym_shortstring_literal] = ACTIONS(692),
    [anon_sym_true] = ACTIONS(694),
    [anon_sym_false] = ACTIONS(694),
    [anon_sym_move] = ACTIONS(694),
    [anon_sym_ref] = ACTIONS(694),
    [sym_identifier] = ACTIONS(694),
    [sym_super] = ACTIONS(694),
    [sym_line_comment] = ACTIONS(3),
  },
  [107] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(696),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [108] = {
    [ts_builtin_sym_end] = ACTIONS(698),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_impl] = ACTIONS(700),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_trait] = ACTIONS(700),
    [anon_sym_type] = ACTIONS(700),
    [anon_sym_const] = ACTIONS(700),
    [anon_sym_EQ] = ACTIONS(700),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_POUND] = ACTIONS(698),
    [anon_sym_LBRACK] = ACTIONS(698),
    [anon_sym_RBRACK] = ACTIONS(698),
    [anon_sym_mod] = ACTIONS(700),
    [anon_sym_struct] = ACTIONS(700),
    [anon_sym_enum] = ACTIONS(700),
    [anon_sym_COMMA] = ACTIONS(698),
    [anon_sym_fn] = ACTIONS(700),
    [anon_sym_let] = ACTIONS(700),
    [anon_sym_use] = ACTIONS(700),
    [anon_sym_COLON_COLON] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(700),
    [anon_sym_LPAREN] = ACTIONS(698),
    [anon_sym_RPAREN] = ACTIONS(698),
    [anon_sym_u8] = ACTIONS(700),
    [anon_sym_i8] = ACTIONS(700),
    [anon_sym_u16] = ACTIONS(700),
    [anon_sym_i16] = ACTIONS(700),
    [anon_sym_u32] = ACTIONS(700),
    [anon_sym_i32] = ACTIONS(700),
    [anon_sym_u64] = ACTIONS(700),
    [anon_sym_i64] = ACTIONS(700),
    [anon_sym_u128] = ACTIONS(700),
    [anon_sym_i128] = ACTIONS(700),
    [anon_sym_usize] = ACTIONS(700),
    [anon_sym_bool] = ACTIONS(700),
    [anon_sym_ByteArray] = ACTIONS(700),
    [anon_sym_felt252] = ACTIONS(700),
    [anon_sym_LT] = ACTIONS(700),
    [anon_sym_GT] = ACTIONS(700),
    [anon_sym_PLUS] = ACTIONS(700),
    [anon_sym_DASH] = ACTIONS(700),
    [anon_sym_SLASH] = ACTIONS(700),
    [anon_sym_PERCENT] = ACTIONS(700),
    [anon_sym_CARET] = ACTIONS(698),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_AMP] = ACTIONS(700),
    [anon_sym_PIPE] = ACTIONS(700),
    [anon_sym_AMP_AMP] = ACTIONS(698),
    [anon_sym_PIPE_PIPE] = ACTIONS(698),
    [anon_sym_LT_LT] = ACTIONS(698),
    [anon_sym_GT_GT] = ACTIONS(698),
    [anon_sym_PLUS_EQ] = ACTIONS(698),
    [anon_sym_DASH_EQ] = ACTIONS(698),
    [anon_sym_STAR_EQ] = ACTIONS(698),
    [anon_sym_SLASH_EQ] = ACTIONS(698),
    [anon_sym_PERCENT_EQ] = ACTIONS(698),
    [anon_sym_EQ_EQ] = ACTIONS(698),
    [anon_sym_BANG_EQ] = ACTIONS(698),
    [anon_sym_GT_EQ] = ACTIONS(698),
    [anon_sym_LT_EQ] = ACTIONS(698),
    [anon_sym_AT] = ACTIONS(698),
    [anon_sym_DOT_DOT] = ACTIONS(698),
    [anon_sym_DOT] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(698),
    [anon_sym_break] = ACTIONS(700),
    [anon_sym_continue] = ACTIONS(700),
    [anon_sym_default] = ACTIONS(700),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_extern] = ACTIONS(700),
    [anon_sym_loop] = ACTIONS(700),
    [anon_sym_match] = ACTIONS(700),
    [anon_sym_pub] = ACTIONS(700),
    [anon_sym_return] = ACTIONS(700),
    [anon_sym_while] = ACTIONS(700),
    [anon_sym_for] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(700),
    [aux_sym_string_literal_token1] = ACTIONS(698),
    [sym_shortstring_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_move] = ACTIONS(700),
    [anon_sym_ref] = ACTIONS(700),
    [sym_identifier] = ACTIONS(700),
    [sym_super] = ACTIONS(700),
    [sym_line_comment] = ACTIONS(3),
  },
  [109] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(130),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(887),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(130),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(702),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [110] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(704),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [111] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(706),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [112] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(708),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [113] = {
    [ts_builtin_sym_end] = ACTIONS(544),
    [anon_sym_LBRACE] = ACTIONS(544),
    [anon_sym_RBRACE] = ACTIONS(544),
    [anon_sym_impl] = ACTIONS(546),
    [anon_sym_SEMI] = ACTIONS(544),
    [anon_sym_trait] = ACTIONS(546),
    [anon_sym_type] = ACTIONS(546),
    [anon_sym_const] = ACTIONS(546),
    [anon_sym_EQ] = ACTIONS(546),
    [anon_sym_BANG] = ACTIONS(546),
    [anon_sym_POUND] = ACTIONS(544),
    [anon_sym_LBRACK] = ACTIONS(544),
    [anon_sym_RBRACK] = ACTIONS(544),
    [anon_sym_mod] = ACTIONS(546),
    [anon_sym_struct] = ACTIONS(546),
    [anon_sym_enum] = ACTIONS(546),
    [anon_sym_COMMA] = ACTIONS(544),
    [anon_sym_fn] = ACTIONS(546),
    [anon_sym_let] = ACTIONS(546),
    [anon_sym_use] = ACTIONS(546),
    [anon_sym_COLON_COLON] = ACTIONS(544),
    [anon_sym_STAR] = ACTIONS(546),
    [anon_sym_LPAREN] = ACTIONS(544),
    [anon_sym_RPAREN] = ACTIONS(544),
    [anon_sym_u8] = ACTIONS(546),
    [anon_sym_i8] = ACTIONS(546),
    [anon_sym_u16] = ACTIONS(546),
    [anon_sym_i16] = ACTIONS(546),
    [anon_sym_u32] = ACTIONS(546),
    [anon_sym_i32] = ACTIONS(546),
    [anon_sym_u64] = ACTIONS(546),
    [anon_sym_i64] = ACTIONS(546),
    [anon_sym_u128] = ACTIONS(546),
    [anon_sym_i128] = ACTIONS(546),
    [anon_sym_usize] = ACTIONS(546),
    [anon_sym_bool] = ACTIONS(546),
    [anon_sym_ByteArray] = ACTIONS(546),
    [anon_sym_felt252] = ACTIONS(546),
    [anon_sym_LT] = ACTIONS(546),
    [anon_sym_GT] = ACTIONS(546),
    [anon_sym_PLUS] = ACTIONS(546),
    [anon_sym_DASH] = ACTIONS(546),
    [anon_sym_SLASH] = ACTIONS(546),
    [anon_sym_PERCENT] = ACTIONS(546),
    [anon_sym_CARET] = ACTIONS(544),
    [anon_sym_TILDE] = ACTIONS(544),
    [anon_sym_AMP] = ACTIONS(546),
    [anon_sym_PIPE] = ACTIONS(546),
    [anon_sym_AMP_AMP] = ACTIONS(544),
    [anon_sym_PIPE_PIPE] = ACTIONS(544),
    [anon_sym_LT_LT] = ACTIONS(544),
    [anon_sym_GT_GT] = ACTIONS(544),
    [anon_sym_PLUS_EQ] = ACTIONS(544),
    [anon_sym_DASH_EQ] = ACTIONS(544),
    [anon_sym_STAR_EQ] = ACTIONS(544),
    [anon_sym_SLASH_EQ] = ACTIONS(544),
    [anon_sym_PERCENT_EQ] = ACTIONS(544),
    [anon_sym_EQ_EQ] = ACTIONS(544),
    [anon_sym_BANG_EQ] = ACTIONS(544),
    [anon_sym_GT_EQ] = ACTIONS(544),
    [anon_sym_LT_EQ] = ACTIONS(544),
    [anon_sym_AT] = ACTIONS(544),
    [anon_sym_DOT_DOT] = ACTIONS(544),
    [anon_sym_DOT] = ACTIONS(546),
    [anon_sym_QMARK] = ACTIONS(544),
    [anon_sym_break] = ACTIONS(546),
    [anon_sym_continue] = ACTIONS(546),
    [anon_sym_default] = ACTIONS(546),
    [anon_sym_if] = ACTIONS(546),
    [anon_sym_extern] = ACTIONS(546),
    [anon_sym_loop] = ACTIONS(546),
    [anon_sym_match] = ACTIONS(546),
    [anon_sym_pub] = ACTIONS(546),
    [anon_sym_return] = ACTIONS(546),
    [anon_sym_while] = ACTIONS(546),
    [anon_sym_for] = ACTIONS(546),
    [sym_numeric_literal] = ACTIONS(546),
    [aux_sym_string_literal_token1] = ACTIONS(544),
    [sym_shortstring_literal] = ACTIONS(544),
    [anon_sym_true] = ACTIONS(546),
    [anon_sym_false] = ACTIONS(546),
    [anon_sym_move] = ACTIONS(546),
    [anon_sym_ref] = ACTIONS(546),
    [sym_identifier] = ACTIONS(546),
    [sym_super] = ACTIONS(546),
    [sym_line_comment] = ACTIONS(3),
  },
  [114] = {
    [ts_builtin_sym_end] = ACTIONS(710),
    [anon_sym_LBRACE] = ACTIONS(710),
    [anon_sym_RBRACE] = ACTIONS(710),
    [anon_sym_impl] = ACTIONS(712),
    [anon_sym_SEMI] = ACTIONS(710),
    [anon_sym_trait] = ACTIONS(712),
    [anon_sym_type] = ACTIONS(712),
    [anon_sym_const] = ACTIONS(712),
    [anon_sym_EQ] = ACTIONS(712),
    [anon_sym_BANG] = ACTIONS(712),
    [anon_sym_POUND] = ACTIONS(710),
    [anon_sym_LBRACK] = ACTIONS(710),
    [anon_sym_RBRACK] = ACTIONS(710),
    [anon_sym_mod] = ACTIONS(712),
    [anon_sym_struct] = ACTIONS(712),
    [anon_sym_enum] = ACTIONS(712),
    [anon_sym_COMMA] = ACTIONS(710),
    [anon_sym_fn] = ACTIONS(712),
    [anon_sym_let] = ACTIONS(712),
    [anon_sym_use] = ACTIONS(712),
    [anon_sym_COLON_COLON] = ACTIONS(710),
    [anon_sym_STAR] = ACTIONS(712),
    [anon_sym_LPAREN] = ACTIONS(710),
    [anon_sym_RPAREN] = ACTIONS(710),
    [anon_sym_u8] = ACTIONS(712),
    [anon_sym_i8] = ACTIONS(712),
    [anon_sym_u16] = ACTIONS(712),
    [anon_sym_i16] = ACTIONS(712),
    [anon_sym_u32] = ACTIONS(712),
    [anon_sym_i32] = ACTIONS(712),
    [anon_sym_u64] = ACTIONS(712),
    [anon_sym_i64] = ACTIONS(712),
    [anon_sym_u128] = ACTIONS(712),
    [anon_sym_i128] = ACTIONS(712),
    [anon_sym_usize] = ACTIONS(712),
    [anon_sym_bool] = ACTIONS(712),
    [anon_sym_ByteArray] = ACTIONS(712),
    [anon_sym_felt252] = ACTIONS(712),
    [anon_sym_LT] = ACTIONS(712),
    [anon_sym_GT] = ACTIONS(712),
    [anon_sym_PLUS] = ACTIONS(712),
    [anon_sym_DASH] = ACTIONS(712),
    [anon_sym_SLASH] = ACTIONS(712),
    [anon_sym_PERCENT] = ACTIONS(712),
    [anon_sym_CARET] = ACTIONS(710),
    [anon_sym_TILDE] = ACTIONS(710),
    [anon_sym_AMP] = ACTIONS(712),
    [anon_sym_PIPE] = ACTIONS(712),
    [anon_sym_AMP_AMP] = ACTIONS(710),
    [anon_sym_PIPE_PIPE] = ACTIONS(710),
    [anon_sym_LT_LT] = ACTIONS(710),
    [anon_sym_GT_GT] = ACTIONS(710),
    [anon_sym_PLUS_EQ] = ACTIONS(710),
    [anon_sym_DASH_EQ] = ACTIONS(710),
    [anon_sym_STAR_EQ] = ACTIONS(710),
    [anon_sym_SLASH_EQ] = ACTIONS(710),
    [anon_sym_PERCENT_EQ] = ACTIONS(710),
    [anon_sym_EQ_EQ] = ACTIONS(710),
    [anon_sym_BANG_EQ] = ACTIONS(710),
    [anon_sym_GT_EQ] = ACTIONS(710),
    [anon_sym_LT_EQ] = ACTIONS(710),
    [anon_sym_AT] = ACTIONS(710),
    [anon_sym_DOT_DOT] = ACTIONS(710),
    [anon_sym_DOT] = ACTIONS(712),
    [anon_sym_QMARK] = ACTIONS(710),
    [anon_sym_break] = ACTIONS(712),
    [anon_sym_continue] = ACTIONS(712),
    [anon_sym_default] = ACTIONS(712),
    [anon_sym_if] = ACTIONS(712),
    [anon_sym_extern] = ACTIONS(712),
    [anon_sym_loop] = ACTIONS(712),
    [anon_sym_match] = ACTIONS(712),
    [anon_sym_pub] = ACTIONS(712),
    [anon_sym_return] = ACTIONS(712),
    [anon_sym_while] = ACTIONS(712),
    [anon_sym_for] = ACTIONS(712),
    [sym_numeric_literal] = ACTIONS(712),
    [aux_sym_string_literal_token1] = ACTIONS(710),
    [sym_shortstring_literal] = ACTIONS(710),
    [anon_sym_true] = ACTIONS(712),
    [anon_sym_false] = ACTIONS(712),
    [anon_sym_move] = ACTIONS(712),
    [anon_sym_ref] = ACTIONS(712),
    [sym_identifier] = ACTIONS(712),
    [sym_super] = ACTIONS(712),
    [sym_line_comment] = ACTIONS(3),
  },
  [115] = {
    [ts_builtin_sym_end] = ACTIONS(714),
    [anon_sym_LBRACE] = ACTIONS(714),
    [anon_sym_RBRACE] = ACTIONS(714),
    [anon_sym_impl] = ACTIONS(716),
    [anon_sym_SEMI] = ACTIONS(714),
    [anon_sym_trait] = ACTIONS(716),
    [anon_sym_type] = ACTIONS(716),
    [anon_sym_const] = ACTIONS(716),
    [anon_sym_EQ] = ACTIONS(716),
    [anon_sym_BANG] = ACTIONS(716),
    [anon_sym_POUND] = ACTIONS(714),
    [anon_sym_LBRACK] = ACTIONS(714),
    [anon_sym_RBRACK] = ACTIONS(714),
    [anon_sym_mod] = ACTIONS(716),
    [anon_sym_struct] = ACTIONS(716),
    [anon_sym_enum] = ACTIONS(716),
    [anon_sym_COMMA] = ACTIONS(714),
    [anon_sym_fn] = ACTIONS(716),
    [anon_sym_let] = ACTIONS(716),
    [anon_sym_use] = ACTIONS(716),
    [anon_sym_COLON_COLON] = ACTIONS(714),
    [anon_sym_STAR] = ACTIONS(716),
    [anon_sym_LPAREN] = ACTIONS(714),
    [anon_sym_RPAREN] = ACTIONS(714),
    [anon_sym_u8] = ACTIONS(716),
    [anon_sym_i8] = ACTIONS(716),
    [anon_sym_u16] = ACTIONS(716),
    [anon_sym_i16] = ACTIONS(716),
    [anon_sym_u32] = ACTIONS(716),
    [anon_sym_i32] = ACTIONS(716),
    [anon_sym_u64] = ACTIONS(716),
    [anon_sym_i64] = ACTIONS(716),
    [anon_sym_u128] = ACTIONS(716),
    [anon_sym_i128] = ACTIONS(716),
    [anon_sym_usize] = ACTIONS(716),
    [anon_sym_bool] = ACTIONS(716),
    [anon_sym_ByteArray] = ACTIONS(716),
    [anon_sym_felt252] = ACTIONS(716),
    [anon_sym_LT] = ACTIONS(716),
    [anon_sym_GT] = ACTIONS(716),
    [anon_sym_PLUS] = ACTIONS(716),
    [anon_sym_DASH] = ACTIONS(716),
    [anon_sym_SLASH] = ACTIONS(716),
    [anon_sym_PERCENT] = ACTIONS(716),
    [anon_sym_CARET] = ACTIONS(714),
    [anon_sym_TILDE] = ACTIONS(714),
    [anon_sym_AMP] = ACTIONS(716),
    [anon_sym_PIPE] = ACTIONS(716),
    [anon_sym_AMP_AMP] = ACTIONS(714),
    [anon_sym_PIPE_PIPE] = ACTIONS(714),
    [anon_sym_LT_LT] = ACTIONS(714),
    [anon_sym_GT_GT] = ACTIONS(714),
    [anon_sym_PLUS_EQ] = ACTIONS(714),
    [anon_sym_DASH_EQ] = ACTIONS(714),
    [anon_sym_STAR_EQ] = ACTIONS(714),
    [anon_sym_SLASH_EQ] = ACTIONS(714),
    [anon_sym_PERCENT_EQ] = ACTIONS(714),
    [anon_sym_EQ_EQ] = ACTIONS(714),
    [anon_sym_BANG_EQ] = ACTIONS(714),
    [anon_sym_GT_EQ] = ACTIONS(714),
    [anon_sym_LT_EQ] = ACTIONS(714),
    [anon_sym_AT] = ACTIONS(714),
    [anon_sym_DOT_DOT] = ACTIONS(714),
    [anon_sym_DOT] = ACTIONS(716),
    [anon_sym_QMARK] = ACTIONS(714),
    [anon_sym_break] = ACTIONS(716),
    [anon_sym_continue] = ACTIONS(716),
    [anon_sym_default] = ACTIONS(716),
    [anon_sym_if] = ACTIONS(716),
    [anon_sym_extern] = ACTIONS(716),
    [anon_sym_loop] = ACTIONS(716),
    [anon_sym_match] = ACTIONS(716),
    [anon_sym_pub] = ACTIONS(716),
    [anon_sym_return] = ACTIONS(716),
    [anon_sym_while] = ACTIONS(716),
    [anon_sym_for] = ACTIONS(716),
    [sym_numeric_literal] = ACTIONS(716),
    [aux_sym_string_literal_token1] = ACTIONS(714),
    [sym_shortstring_literal] = ACTIONS(714),
    [anon_sym_true] = ACTIONS(716),
    [anon_sym_false] = ACTIONS(716),
    [anon_sym_move] = ACTIONS(716),
    [anon_sym_ref] = ACTIONS(716),
    [sym_identifier] = ACTIONS(716),
    [sym_super] = ACTIONS(716),
    [sym_line_comment] = ACTIONS(3),
  },
  [116] = {
    [ts_builtin_sym_end] = ACTIONS(718),
    [anon_sym_LBRACE] = ACTIONS(718),
    [anon_sym_RBRACE] = ACTIONS(718),
    [anon_sym_impl] = ACTIONS(720),
    [anon_sym_SEMI] = ACTIONS(718),
    [anon_sym_trait] = ACTIONS(720),
    [anon_sym_type] = ACTIONS(720),
    [anon_sym_const] = ACTIONS(720),
    [anon_sym_EQ] = ACTIONS(720),
    [anon_sym_BANG] = ACTIONS(720),
    [anon_sym_POUND] = ACTIONS(718),
    [anon_sym_LBRACK] = ACTIONS(718),
    [anon_sym_RBRACK] = ACTIONS(718),
    [anon_sym_mod] = ACTIONS(720),
    [anon_sym_struct] = ACTIONS(720),
    [anon_sym_enum] = ACTIONS(720),
    [anon_sym_COMMA] = ACTIONS(718),
    [anon_sym_fn] = ACTIONS(720),
    [anon_sym_let] = ACTIONS(720),
    [anon_sym_use] = ACTIONS(720),
    [anon_sym_COLON_COLON] = ACTIONS(718),
    [anon_sym_STAR] = ACTIONS(720),
    [anon_sym_LPAREN] = ACTIONS(718),
    [anon_sym_RPAREN] = ACTIONS(718),
    [anon_sym_u8] = ACTIONS(720),
    [anon_sym_i8] = ACTIONS(720),
    [anon_sym_u16] = ACTIONS(720),
    [anon_sym_i16] = ACTIONS(720),
    [anon_sym_u32] = ACTIONS(720),
    [anon_sym_i32] = ACTIONS(720),
    [anon_sym_u64] = ACTIONS(720),
    [anon_sym_i64] = ACTIONS(720),
    [anon_sym_u128] = ACTIONS(720),
    [anon_sym_i128] = ACTIONS(720),
    [anon_sym_usize] = ACTIONS(720),
    [anon_sym_bool] = ACTIONS(720),
    [anon_sym_ByteArray] = ACTIONS(720),
    [anon_sym_felt252] = ACTIONS(720),
    [anon_sym_LT] = ACTIONS(720),
    [anon_sym_GT] = ACTIONS(720),
    [anon_sym_PLUS] = ACTIONS(720),
    [anon_sym_DASH] = ACTIONS(720),
    [anon_sym_SLASH] = ACTIONS(720),
    [anon_sym_PERCENT] = ACTIONS(720),
    [anon_sym_CARET] = ACTIONS(718),
    [anon_sym_TILDE] = ACTIONS(718),
    [anon_sym_AMP] = ACTIONS(720),
    [anon_sym_PIPE] = ACTIONS(720),
    [anon_sym_AMP_AMP] = ACTIONS(718),
    [anon_sym_PIPE_PIPE] = ACTIONS(718),
    [anon_sym_LT_LT] = ACTIONS(718),
    [anon_sym_GT_GT] = ACTIONS(718),
    [anon_sym_PLUS_EQ] = ACTIONS(718),
    [anon_sym_DASH_EQ] = ACTIONS(718),
    [anon_sym_STAR_EQ] = ACTIONS(718),
    [anon_sym_SLASH_EQ] = ACTIONS(718),
    [anon_sym_PERCENT_EQ] = ACTIONS(718),
    [anon_sym_EQ_EQ] = ACTIONS(718),
    [anon_sym_BANG_EQ] = ACTIONS(718),
    [anon_sym_GT_EQ] = ACTIONS(718),
    [anon_sym_LT_EQ] = ACTIONS(718),
    [anon_sym_AT] = ACTIONS(718),
    [anon_sym_DOT_DOT] = ACTIONS(718),
    [anon_sym_DOT] = ACTIONS(720),
    [anon_sym_QMARK] = ACTIONS(718),
    [anon_sym_break] = ACTIONS(720),
    [anon_sym_continue] = ACTIONS(720),
    [anon_sym_default] = ACTIONS(720),
    [anon_sym_if] = ACTIONS(720),
    [anon_sym_extern] = ACTIONS(720),
    [anon_sym_loop] = ACTIONS(720),
    [anon_sym_match] = ACTIONS(720),
    [anon_sym_pub] = ACTIONS(720),
    [anon_sym_return] = ACTIONS(720),
    [anon_sym_while] = ACTIONS(720),
    [anon_sym_for] = ACTIONS(720),
    [sym_numeric_literal] = ACTIONS(720),
    [aux_sym_string_literal_token1] = ACTIONS(718),
    [sym_shortstring_literal] = ACTIONS(718),
    [anon_sym_true] = ACTIONS(720),
    [anon_sym_false] = ACTIONS(720),
    [anon_sym_move] = ACTIONS(720),
    [anon_sym_ref] = ACTIONS(720),
    [sym_identifier] = ACTIONS(720),
    [sym_super] = ACTIONS(720),
    [sym_line_comment] = ACTIONS(3),
  },
  [117] = {
    [ts_builtin_sym_end] = ACTIONS(722),
    [anon_sym_LBRACE] = ACTIONS(722),
    [anon_sym_RBRACE] = ACTIONS(722),
    [anon_sym_impl] = ACTIONS(724),
    [anon_sym_SEMI] = ACTIONS(722),
    [anon_sym_trait] = ACTIONS(724),
    [anon_sym_type] = ACTIONS(724),
    [anon_sym_const] = ACTIONS(724),
    [anon_sym_EQ] = ACTIONS(724),
    [anon_sym_BANG] = ACTIONS(724),
    [anon_sym_POUND] = ACTIONS(722),
    [anon_sym_LBRACK] = ACTIONS(722),
    [anon_sym_RBRACK] = ACTIONS(722),
    [anon_sym_mod] = ACTIONS(724),
    [anon_sym_struct] = ACTIONS(724),
    [anon_sym_enum] = ACTIONS(724),
    [anon_sym_COMMA] = ACTIONS(722),
    [anon_sym_fn] = ACTIONS(724),
    [anon_sym_let] = ACTIONS(724),
    [anon_sym_use] = ACTIONS(724),
    [anon_sym_COLON_COLON] = ACTIONS(722),
    [anon_sym_STAR] = ACTIONS(724),
    [anon_sym_LPAREN] = ACTIONS(722),
    [anon_sym_RPAREN] = ACTIONS(722),
    [anon_sym_u8] = ACTIONS(724),
    [anon_sym_i8] = ACTIONS(724),
    [anon_sym_u16] = ACTIONS(724),
    [anon_sym_i16] = ACTIONS(724),
    [anon_sym_u32] = ACTIONS(724),
    [anon_sym_i32] = ACTIONS(724),
    [anon_sym_u64] = ACTIONS(724),
    [anon_sym_i64] = ACTIONS(724),
    [anon_sym_u128] = ACTIONS(724),
    [anon_sym_i128] = ACTIONS(724),
    [anon_sym_usize] = ACTIONS(724),
    [anon_sym_bool] = ACTIONS(724),
    [anon_sym_ByteArray] = ACTIONS(724),
    [anon_sym_felt252] = ACTIONS(724),
    [anon_sym_LT] = ACTIONS(724),
    [anon_sym_GT] = ACTIONS(724),
    [anon_sym_PLUS] = ACTIONS(724),
    [anon_sym_DASH] = ACTIONS(724),
    [anon_sym_SLASH] = ACTIONS(724),
    [anon_sym_PERCENT] = ACTIONS(724),
    [anon_sym_CARET] = ACTIONS(722),
    [anon_sym_TILDE] = ACTIONS(722),
    [anon_sym_AMP] = ACTIONS(724),
    [anon_sym_PIPE] = ACTIONS(724),
    [anon_sym_AMP_AMP] = ACTIONS(722),
    [anon_sym_PIPE_PIPE] = ACTIONS(722),
    [anon_sym_LT_LT] = ACTIONS(722),
    [anon_sym_GT_GT] = ACTIONS(722),
    [anon_sym_PLUS_EQ] = ACTIONS(722),
    [anon_sym_DASH_EQ] = ACTIONS(722),
    [anon_sym_STAR_EQ] = ACTIONS(722),
    [anon_sym_SLASH_EQ] = ACTIONS(722),
    [anon_sym_PERCENT_EQ] = ACTIONS(722),
    [anon_sym_EQ_EQ] = ACTIONS(722),
    [anon_sym_BANG_EQ] = ACTIONS(722),
    [anon_sym_GT_EQ] = ACTIONS(722),
    [anon_sym_LT_EQ] = ACTIONS(722),
    [anon_sym_AT] = ACTIONS(722),
    [anon_sym_DOT_DOT] = ACTIONS(722),
    [anon_sym_DOT] = ACTIONS(724),
    [anon_sym_QMARK] = ACTIONS(722),
    [anon_sym_break] = ACTIONS(724),
    [anon_sym_continue] = ACTIONS(724),
    [anon_sym_default] = ACTIONS(724),
    [anon_sym_if] = ACTIONS(724),
    [anon_sym_extern] = ACTIONS(724),
    [anon_sym_loop] = ACTIONS(724),
    [anon_sym_match] = ACTIONS(724),
    [anon_sym_pub] = ACTIONS(724),
    [anon_sym_return] = ACTIONS(724),
    [anon_sym_while] = ACTIONS(724),
    [anon_sym_for] = ACTIONS(724),
    [sym_numeric_literal] = ACTIONS(724),
    [aux_sym_string_literal_token1] = ACTIONS(722),
    [sym_shortstring_literal] = ACTIONS(722),
    [anon_sym_true] = ACTIONS(724),
    [anon_sym_false] = ACTIONS(724),
    [anon_sym_move] = ACTIONS(724),
    [anon_sym_ref] = ACTIONS(724),
    [sym_identifier] = ACTIONS(724),
    [sym_super] = ACTIONS(724),
    [sym_line_comment] = ACTIONS(3),
  },
  [118] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(726),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [119] = {
    [ts_builtin_sym_end] = ACTIONS(728),
    [anon_sym_LBRACE] = ACTIONS(728),
    [anon_sym_RBRACE] = ACTIONS(728),
    [anon_sym_impl] = ACTIONS(730),
    [anon_sym_SEMI] = ACTIONS(728),
    [anon_sym_trait] = ACTIONS(730),
    [anon_sym_type] = ACTIONS(730),
    [anon_sym_const] = ACTIONS(730),
    [anon_sym_EQ] = ACTIONS(730),
    [anon_sym_BANG] = ACTIONS(730),
    [anon_sym_POUND] = ACTIONS(728),
    [anon_sym_LBRACK] = ACTIONS(728),
    [anon_sym_RBRACK] = ACTIONS(728),
    [anon_sym_mod] = ACTIONS(730),
    [anon_sym_struct] = ACTIONS(730),
    [anon_sym_enum] = ACTIONS(730),
    [anon_sym_COMMA] = ACTIONS(728),
    [anon_sym_fn] = ACTIONS(730),
    [anon_sym_let] = ACTIONS(730),
    [anon_sym_use] = ACTIONS(730),
    [anon_sym_COLON_COLON] = ACTIONS(728),
    [anon_sym_STAR] = ACTIONS(730),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RPAREN] = ACTIONS(728),
    [anon_sym_u8] = ACTIONS(730),
    [anon_sym_i8] = ACTIONS(730),
    [anon_sym_u16] = ACTIONS(730),
    [anon_sym_i16] = ACTIONS(730),
    [anon_sym_u32] = ACTIONS(730),
    [anon_sym_i32] = ACTIONS(730),
    [anon_sym_u64] = ACTIONS(730),
    [anon_sym_i64] = ACTIONS(730),
    [anon_sym_u128] = ACTIONS(730),
    [anon_sym_i128] = ACTIONS(730),
    [anon_sym_usize] = ACTIONS(730),
    [anon_sym_bool] = ACTIONS(730),
    [anon_sym_ByteArray] = ACTIONS(730),
    [anon_sym_felt252] = ACTIONS(730),
    [anon_sym_LT] = ACTIONS(730),
    [anon_sym_GT] = ACTIONS(730),
    [anon_sym_PLUS] = ACTIONS(730),
    [anon_sym_DASH] = ACTIONS(730),
    [anon_sym_SLASH] = ACTIONS(730),
    [anon_sym_PERCENT] = ACTIONS(730),
    [anon_sym_CARET] = ACTIONS(728),
    [anon_sym_TILDE] = ACTIONS(728),
    [anon_sym_AMP] = ACTIONS(730),
    [anon_sym_PIPE] = ACTIONS(730),
    [anon_sym_AMP_AMP] = ACTIONS(728),
    [anon_sym_PIPE_PIPE] = ACTIONS(728),
    [anon_sym_LT_LT] = ACTIONS(728),
    [anon_sym_GT_GT] = ACTIONS(728),
    [anon_sym_PLUS_EQ] = ACTIONS(728),
    [anon_sym_DASH_EQ] = ACTIONS(728),
    [anon_sym_STAR_EQ] = ACTIONS(728),
    [anon_sym_SLASH_EQ] = ACTIONS(728),
    [anon_sym_PERCENT_EQ] = ACTIONS(728),
    [anon_sym_EQ_EQ] = ACTIONS(728),
    [anon_sym_BANG_EQ] = ACTIONS(728),
    [anon_sym_GT_EQ] = ACTIONS(728),
    [anon_sym_LT_EQ] = ACTIONS(728),
    [anon_sym_AT] = ACTIONS(728),
    [anon_sym_DOT_DOT] = ACTIONS(728),
    [anon_sym_DOT] = ACTIONS(730),
    [anon_sym_QMARK] = ACTIONS(728),
    [anon_sym_break] = ACTIONS(730),
    [anon_sym_continue] = ACTIONS(730),
    [anon_sym_default] = ACTIONS(730),
    [anon_sym_if] = ACTIONS(730),
    [anon_sym_extern] = ACTIONS(730),
    [anon_sym_loop] = ACTIONS(730),
    [anon_sym_match] = ACTIONS(730),
    [anon_sym_pub] = ACTIONS(730),
    [anon_sym_return] = ACTIONS(730),
    [anon_sym_while] = ACTIONS(730),
    [anon_sym_for] = ACTIONS(730),
    [sym_numeric_literal] = ACTIONS(730),
    [aux_sym_string_literal_token1] = ACTIONS(728),
    [sym_shortstring_literal] = ACTIONS(728),
    [anon_sym_true] = ACTIONS(730),
    [anon_sym_false] = ACTIONS(730),
    [anon_sym_move] = ACTIONS(730),
    [anon_sym_ref] = ACTIONS(730),
    [sym_identifier] = ACTIONS(730),
    [sym_super] = ACTIONS(730),
    [sym_line_comment] = ACTIONS(3),
  },
  [120] = {
    [ts_builtin_sym_end] = ACTIONS(732),
    [anon_sym_LBRACE] = ACTIONS(732),
    [anon_sym_RBRACE] = ACTIONS(732),
    [anon_sym_impl] = ACTIONS(734),
    [anon_sym_SEMI] = ACTIONS(732),
    [anon_sym_trait] = ACTIONS(734),
    [anon_sym_type] = ACTIONS(734),
    [anon_sym_const] = ACTIONS(734),
    [anon_sym_EQ] = ACTIONS(734),
    [anon_sym_BANG] = ACTIONS(734),
    [anon_sym_POUND] = ACTIONS(732),
    [anon_sym_LBRACK] = ACTIONS(732),
    [anon_sym_RBRACK] = ACTIONS(732),
    [anon_sym_mod] = ACTIONS(734),
    [anon_sym_struct] = ACTIONS(734),
    [anon_sym_enum] = ACTIONS(734),
    [anon_sym_COMMA] = ACTIONS(732),
    [anon_sym_fn] = ACTIONS(734),
    [anon_sym_let] = ACTIONS(734),
    [anon_sym_use] = ACTIONS(734),
    [anon_sym_COLON_COLON] = ACTIONS(732),
    [anon_sym_STAR] = ACTIONS(734),
    [anon_sym_LPAREN] = ACTIONS(732),
    [anon_sym_RPAREN] = ACTIONS(732),
    [anon_sym_u8] = ACTIONS(734),
    [anon_sym_i8] = ACTIONS(734),
    [anon_sym_u16] = ACTIONS(734),
    [anon_sym_i16] = ACTIONS(734),
    [anon_sym_u32] = ACTIONS(734),
    [anon_sym_i32] = ACTIONS(734),
    [anon_sym_u64] = ACTIONS(734),
    [anon_sym_i64] = ACTIONS(734),
    [anon_sym_u128] = ACTIONS(734),
    [anon_sym_i128] = ACTIONS(734),
    [anon_sym_usize] = ACTIONS(734),
    [anon_sym_bool] = ACTIONS(734),
    [anon_sym_ByteArray] = ACTIONS(734),
    [anon_sym_felt252] = ACTIONS(734),
    [anon_sym_LT] = ACTIONS(734),
    [anon_sym_GT] = ACTIONS(734),
    [anon_sym_PLUS] = ACTIONS(734),
    [anon_sym_DASH] = ACTIONS(734),
    [anon_sym_SLASH] = ACTIONS(734),
    [anon_sym_PERCENT] = ACTIONS(734),
    [anon_sym_CARET] = ACTIONS(732),
    [anon_sym_TILDE] = ACTIONS(732),
    [anon_sym_AMP] = ACTIONS(734),
    [anon_sym_PIPE] = ACTIONS(734),
    [anon_sym_AMP_AMP] = ACTIONS(732),
    [anon_sym_PIPE_PIPE] = ACTIONS(732),
    [anon_sym_LT_LT] = ACTIONS(732),
    [anon_sym_GT_GT] = ACTIONS(732),
    [anon_sym_PLUS_EQ] = ACTIONS(732),
    [anon_sym_DASH_EQ] = ACTIONS(732),
    [anon_sym_STAR_EQ] = ACTIONS(732),
    [anon_sym_SLASH_EQ] = ACTIONS(732),
    [anon_sym_PERCENT_EQ] = ACTIONS(732),
    [anon_sym_EQ_EQ] = ACTIONS(732),
    [anon_sym_BANG_EQ] = ACTIONS(732),
    [anon_sym_GT_EQ] = ACTIONS(732),
    [anon_sym_LT_EQ] = ACTIONS(732),
    [anon_sym_AT] = ACTIONS(732),
    [anon_sym_DOT_DOT] = ACTIONS(732),
    [anon_sym_DOT] = ACTIONS(734),
    [anon_sym_QMARK] = ACTIONS(732),
    [anon_sym_break] = ACTIONS(734),
    [anon_sym_continue] = ACTIONS(734),
    [anon_sym_default] = ACTIONS(734),
    [anon_sym_if] = ACTIONS(734),
    [anon_sym_extern] = ACTIONS(734),
    [anon_sym_loop] = ACTIONS(734),
    [anon_sym_match] = ACTIONS(734),
    [anon_sym_pub] = ACTIONS(734),
    [anon_sym_return] = ACTIONS(734),
    [anon_sym_while] = ACTIONS(734),
    [anon_sym_for] = ACTIONS(734),
    [sym_numeric_literal] = ACTIONS(734),
    [aux_sym_string_literal_token1] = ACTIONS(732),
    [sym_shortstring_literal] = ACTIONS(732),
    [anon_sym_true] = ACTIONS(734),
    [anon_sym_false] = ACTIONS(734),
    [anon_sym_move] = ACTIONS(734),
    [anon_sym_ref] = ACTIONS(734),
    [sym_identifier] = ACTIONS(734),
    [sym_super] = ACTIONS(734),
    [sym_line_comment] = ACTIONS(3),
  },
  [121] = {
    [ts_builtin_sym_end] = ACTIONS(736),
    [anon_sym_LBRACE] = ACTIONS(736),
    [anon_sym_RBRACE] = ACTIONS(736),
    [anon_sym_impl] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(736),
    [anon_sym_trait] = ACTIONS(738),
    [anon_sym_type] = ACTIONS(738),
    [anon_sym_const] = ACTIONS(738),
    [anon_sym_EQ] = ACTIONS(738),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_POUND] = ACTIONS(736),
    [anon_sym_LBRACK] = ACTIONS(736),
    [anon_sym_RBRACK] = ACTIONS(736),
    [anon_sym_mod] = ACTIONS(738),
    [anon_sym_struct] = ACTIONS(738),
    [anon_sym_enum] = ACTIONS(738),
    [anon_sym_COMMA] = ACTIONS(736),
    [anon_sym_fn] = ACTIONS(738),
    [anon_sym_let] = ACTIONS(738),
    [anon_sym_use] = ACTIONS(738),
    [anon_sym_COLON_COLON] = ACTIONS(736),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_LPAREN] = ACTIONS(736),
    [anon_sym_RPAREN] = ACTIONS(736),
    [anon_sym_u8] = ACTIONS(738),
    [anon_sym_i8] = ACTIONS(738),
    [anon_sym_u16] = ACTIONS(738),
    [anon_sym_i16] = ACTIONS(738),
    [anon_sym_u32] = ACTIONS(738),
    [anon_sym_i32] = ACTIONS(738),
    [anon_sym_u64] = ACTIONS(738),
    [anon_sym_i64] = ACTIONS(738),
    [anon_sym_u128] = ACTIONS(738),
    [anon_sym_i128] = ACTIONS(738),
    [anon_sym_usize] = ACTIONS(738),
    [anon_sym_bool] = ACTIONS(738),
    [anon_sym_ByteArray] = ACTIONS(738),
    [anon_sym_felt252] = ACTIONS(738),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(738),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(738),
    [anon_sym_CARET] = ACTIONS(736),
    [anon_sym_TILDE] = ACTIONS(736),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_PIPE] = ACTIONS(738),
    [anon_sym_AMP_AMP] = ACTIONS(736),
    [anon_sym_PIPE_PIPE] = ACTIONS(736),
    [anon_sym_LT_LT] = ACTIONS(736),
    [anon_sym_GT_GT] = ACTIONS(736),
    [anon_sym_PLUS_EQ] = ACTIONS(736),
    [anon_sym_DASH_EQ] = ACTIONS(736),
    [anon_sym_STAR_EQ] = ACTIONS(736),
    [anon_sym_SLASH_EQ] = ACTIONS(736),
    [anon_sym_PERCENT_EQ] = ACTIONS(736),
    [anon_sym_EQ_EQ] = ACTIONS(736),
    [anon_sym_BANG_EQ] = ACTIONS(736),
    [anon_sym_GT_EQ] = ACTIONS(736),
    [anon_sym_LT_EQ] = ACTIONS(736),
    [anon_sym_AT] = ACTIONS(736),
    [anon_sym_DOT_DOT] = ACTIONS(736),
    [anon_sym_DOT] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(736),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_default] = ACTIONS(738),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_extern] = ACTIONS(738),
    [anon_sym_loop] = ACTIONS(738),
    [anon_sym_match] = ACTIONS(738),
    [anon_sym_pub] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(738),
    [aux_sym_string_literal_token1] = ACTIONS(736),
    [sym_shortstring_literal] = ACTIONS(736),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_move] = ACTIONS(738),
    [anon_sym_ref] = ACTIONS(738),
    [sym_identifier] = ACTIONS(738),
    [sym_super] = ACTIONS(738),
    [sym_line_comment] = ACTIONS(3),
  },
  [122] = {
    [ts_builtin_sym_end] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_impl] = ACTIONS(742),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_trait] = ACTIONS(742),
    [anon_sym_type] = ACTIONS(742),
    [anon_sym_const] = ACTIONS(742),
    [anon_sym_EQ] = ACTIONS(742),
    [anon_sym_BANG] = ACTIONS(742),
    [anon_sym_POUND] = ACTIONS(740),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_RBRACK] = ACTIONS(740),
    [anon_sym_mod] = ACTIONS(742),
    [anon_sym_struct] = ACTIONS(742),
    [anon_sym_enum] = ACTIONS(742),
    [anon_sym_COMMA] = ACTIONS(740),
    [anon_sym_fn] = ACTIONS(742),
    [anon_sym_let] = ACTIONS(742),
    [anon_sym_use] = ACTIONS(742),
    [anon_sym_COLON_COLON] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(742),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_RPAREN] = ACTIONS(740),
    [anon_sym_u8] = ACTIONS(742),
    [anon_sym_i8] = ACTIONS(742),
    [anon_sym_u16] = ACTIONS(742),
    [anon_sym_i16] = ACTIONS(742),
    [anon_sym_u32] = ACTIONS(742),
    [anon_sym_i32] = ACTIONS(742),
    [anon_sym_u64] = ACTIONS(742),
    [anon_sym_i64] = ACTIONS(742),
    [anon_sym_u128] = ACTIONS(742),
    [anon_sym_i128] = ACTIONS(742),
    [anon_sym_usize] = ACTIONS(742),
    [anon_sym_bool] = ACTIONS(742),
    [anon_sym_ByteArray] = ACTIONS(742),
    [anon_sym_felt252] = ACTIONS(742),
    [anon_sym_LT] = ACTIONS(742),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(742),
    [anon_sym_DASH] = ACTIONS(742),
    [anon_sym_SLASH] = ACTIONS(742),
    [anon_sym_PERCENT] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(742),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS_EQ] = ACTIONS(740),
    [anon_sym_DASH_EQ] = ACTIONS(740),
    [anon_sym_STAR_EQ] = ACTIONS(740),
    [anon_sym_SLASH_EQ] = ACTIONS(740),
    [anon_sym_PERCENT_EQ] = ACTIONS(740),
    [anon_sym_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_AT] = ACTIONS(740),
    [anon_sym_DOT_DOT] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(742),
    [anon_sym_QMARK] = ACTIONS(740),
    [anon_sym_break] = ACTIONS(742),
    [anon_sym_continue] = ACTIONS(742),
    [anon_sym_default] = ACTIONS(742),
    [anon_sym_if] = ACTIONS(742),
    [anon_sym_extern] = ACTIONS(742),
    [anon_sym_loop] = ACTIONS(742),
    [anon_sym_match] = ACTIONS(742),
    [anon_sym_pub] = ACTIONS(742),
    [anon_sym_return] = ACTIONS(742),
    [anon_sym_while] = ACTIONS(742),
    [anon_sym_for] = ACTIONS(742),
    [sym_numeric_literal] = ACTIONS(742),
    [aux_sym_string_literal_token1] = ACTIONS(740),
    [sym_shortstring_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(742),
    [anon_sym_false] = ACTIONS(742),
    [anon_sym_move] = ACTIONS(742),
    [anon_sym_ref] = ACTIONS(742),
    [sym_identifier] = ACTIONS(742),
    [sym_super] = ACTIONS(742),
    [sym_line_comment] = ACTIONS(3),
  },
  [123] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_RBRACK] = ACTIONS(744),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [124] = {
    [ts_builtin_sym_end] = ACTIONS(746),
    [anon_sym_LBRACE] = ACTIONS(746),
    [anon_sym_RBRACE] = ACTIONS(746),
    [anon_sym_impl] = ACTIONS(748),
    [anon_sym_SEMI] = ACTIONS(746),
    [anon_sym_trait] = ACTIONS(748),
    [anon_sym_type] = ACTIONS(748),
    [anon_sym_const] = ACTIONS(748),
    [anon_sym_EQ] = ACTIONS(748),
    [anon_sym_BANG] = ACTIONS(748),
    [anon_sym_POUND] = ACTIONS(746),
    [anon_sym_LBRACK] = ACTIONS(746),
    [anon_sym_RBRACK] = ACTIONS(746),
    [anon_sym_mod] = ACTIONS(748),
    [anon_sym_struct] = ACTIONS(748),
    [anon_sym_enum] = ACTIONS(748),
    [anon_sym_COMMA] = ACTIONS(746),
    [anon_sym_fn] = ACTIONS(748),
    [anon_sym_let] = ACTIONS(748),
    [anon_sym_use] = ACTIONS(748),
    [anon_sym_COLON_COLON] = ACTIONS(746),
    [anon_sym_STAR] = ACTIONS(748),
    [anon_sym_LPAREN] = ACTIONS(746),
    [anon_sym_RPAREN] = ACTIONS(746),
    [anon_sym_u8] = ACTIONS(748),
    [anon_sym_i8] = ACTIONS(748),
    [anon_sym_u16] = ACTIONS(748),
    [anon_sym_i16] = ACTIONS(748),
    [anon_sym_u32] = ACTIONS(748),
    [anon_sym_i32] = ACTIONS(748),
    [anon_sym_u64] = ACTIONS(748),
    [anon_sym_i64] = ACTIONS(748),
    [anon_sym_u128] = ACTIONS(748),
    [anon_sym_i128] = ACTIONS(748),
    [anon_sym_usize] = ACTIONS(748),
    [anon_sym_bool] = ACTIONS(748),
    [anon_sym_ByteArray] = ACTIONS(748),
    [anon_sym_felt252] = ACTIONS(748),
    [anon_sym_LT] = ACTIONS(748),
    [anon_sym_GT] = ACTIONS(748),
    [anon_sym_PLUS] = ACTIONS(748),
    [anon_sym_DASH] = ACTIONS(748),
    [anon_sym_SLASH] = ACTIONS(748),
    [anon_sym_PERCENT] = ACTIONS(748),
    [anon_sym_CARET] = ACTIONS(746),
    [anon_sym_TILDE] = ACTIONS(746),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(748),
    [anon_sym_AMP_AMP] = ACTIONS(746),
    [anon_sym_PIPE_PIPE] = ACTIONS(746),
    [anon_sym_LT_LT] = ACTIONS(746),
    [anon_sym_GT_GT] = ACTIONS(746),
    [anon_sym_PLUS_EQ] = ACTIONS(746),
    [anon_sym_DASH_EQ] = ACTIONS(746),
    [anon_sym_STAR_EQ] = ACTIONS(746),
    [anon_sym_SLASH_EQ] = ACTIONS(746),
    [anon_sym_PERCENT_EQ] = ACTIONS(746),
    [anon_sym_EQ_EQ] = ACTIONS(746),
    [anon_sym_BANG_EQ] = ACTIONS(746),
    [anon_sym_GT_EQ] = ACTIONS(746),
    [anon_sym_LT_EQ] = ACTIONS(746),
    [anon_sym_AT] = ACTIONS(746),
    [anon_sym_DOT_DOT] = ACTIONS(746),
    [anon_sym_DOT] = ACTIONS(748),
    [anon_sym_QMARK] = ACTIONS(746),
    [anon_sym_break] = ACTIONS(748),
    [anon_sym_continue] = ACTIONS(748),
    [anon_sym_default] = ACTIONS(748),
    [anon_sym_if] = ACTIONS(748),
    [anon_sym_extern] = ACTIONS(748),
    [anon_sym_loop] = ACTIONS(748),
    [anon_sym_match] = ACTIONS(748),
    [anon_sym_pub] = ACTIONS(748),
    [anon_sym_return] = ACTIONS(748),
    [anon_sym_while] = ACTIONS(748),
    [anon_sym_for] = ACTIONS(748),
    [sym_numeric_literal] = ACTIONS(748),
    [aux_sym_string_literal_token1] = ACTIONS(746),
    [sym_shortstring_literal] = ACTIONS(746),
    [anon_sym_true] = ACTIONS(748),
    [anon_sym_false] = ACTIONS(748),
    [anon_sym_move] = ACTIONS(748),
    [anon_sym_ref] = ACTIONS(748),
    [sym_identifier] = ACTIONS(748),
    [sym_super] = ACTIONS(748),
    [sym_line_comment] = ACTIONS(3),
  },
  [125] = {
    [ts_builtin_sym_end] = ACTIONS(750),
    [anon_sym_LBRACE] = ACTIONS(750),
    [anon_sym_RBRACE] = ACTIONS(750),
    [anon_sym_impl] = ACTIONS(752),
    [anon_sym_SEMI] = ACTIONS(750),
    [anon_sym_trait] = ACTIONS(752),
    [anon_sym_type] = ACTIONS(752),
    [anon_sym_const] = ACTIONS(752),
    [anon_sym_EQ] = ACTIONS(752),
    [anon_sym_BANG] = ACTIONS(752),
    [anon_sym_POUND] = ACTIONS(750),
    [anon_sym_LBRACK] = ACTIONS(750),
    [anon_sym_RBRACK] = ACTIONS(750),
    [anon_sym_mod] = ACTIONS(752),
    [anon_sym_struct] = ACTIONS(752),
    [anon_sym_enum] = ACTIONS(752),
    [anon_sym_COMMA] = ACTIONS(750),
    [anon_sym_fn] = ACTIONS(752),
    [anon_sym_let] = ACTIONS(752),
    [anon_sym_use] = ACTIONS(752),
    [anon_sym_COLON_COLON] = ACTIONS(750),
    [anon_sym_STAR] = ACTIONS(752),
    [anon_sym_LPAREN] = ACTIONS(750),
    [anon_sym_RPAREN] = ACTIONS(750),
    [anon_sym_u8] = ACTIONS(752),
    [anon_sym_i8] = ACTIONS(752),
    [anon_sym_u16] = ACTIONS(752),
    [anon_sym_i16] = ACTIONS(752),
    [anon_sym_u32] = ACTIONS(752),
    [anon_sym_i32] = ACTIONS(752),
    [anon_sym_u64] = ACTIONS(752),
    [anon_sym_i64] = ACTIONS(752),
    [anon_sym_u128] = ACTIONS(752),
    [anon_sym_i128] = ACTIONS(752),
    [anon_sym_usize] = ACTIONS(752),
    [anon_sym_bool] = ACTIONS(752),
    [anon_sym_ByteArray] = ACTIONS(752),
    [anon_sym_felt252] = ACTIONS(752),
    [anon_sym_LT] = ACTIONS(752),
    [anon_sym_GT] = ACTIONS(752),
    [anon_sym_PLUS] = ACTIONS(752),
    [anon_sym_DASH] = ACTIONS(752),
    [anon_sym_SLASH] = ACTIONS(752),
    [anon_sym_PERCENT] = ACTIONS(752),
    [anon_sym_CARET] = ACTIONS(750),
    [anon_sym_TILDE] = ACTIONS(750),
    [anon_sym_AMP] = ACTIONS(752),
    [anon_sym_PIPE] = ACTIONS(752),
    [anon_sym_AMP_AMP] = ACTIONS(750),
    [anon_sym_PIPE_PIPE] = ACTIONS(750),
    [anon_sym_LT_LT] = ACTIONS(750),
    [anon_sym_GT_GT] = ACTIONS(750),
    [anon_sym_PLUS_EQ] = ACTIONS(750),
    [anon_sym_DASH_EQ] = ACTIONS(750),
    [anon_sym_STAR_EQ] = ACTIONS(750),
    [anon_sym_SLASH_EQ] = ACTIONS(750),
    [anon_sym_PERCENT_EQ] = ACTIONS(750),
    [anon_sym_EQ_EQ] = ACTIONS(750),
    [anon_sym_BANG_EQ] = ACTIONS(750),
    [anon_sym_GT_EQ] = ACTIONS(750),
    [anon_sym_LT_EQ] = ACTIONS(750),
    [anon_sym_AT] = ACTIONS(750),
    [anon_sym_DOT_DOT] = ACTIONS(750),
    [anon_sym_DOT] = ACTIONS(752),
    [anon_sym_QMARK] = ACTIONS(750),
    [anon_sym_break] = ACTIONS(752),
    [anon_sym_continue] = ACTIONS(752),
    [anon_sym_default] = ACTIONS(752),
    [anon_sym_if] = ACTIONS(752),
    [anon_sym_extern] = ACTIONS(752),
    [anon_sym_loop] = ACTIONS(752),
    [anon_sym_match] = ACTIONS(752),
    [anon_sym_pub] = ACTIONS(752),
    [anon_sym_return] = ACTIONS(752),
    [anon_sym_while] = ACTIONS(752),
    [anon_sym_for] = ACTIONS(752),
    [sym_numeric_literal] = ACTIONS(752),
    [aux_sym_string_literal_token1] = ACTIONS(750),
    [sym_shortstring_literal] = ACTIONS(750),
    [anon_sym_true] = ACTIONS(752),
    [anon_sym_false] = ACTIONS(752),
    [anon_sym_move] = ACTIONS(752),
    [anon_sym_ref] = ACTIONS(752),
    [sym_identifier] = ACTIONS(752),
    [sym_super] = ACTIONS(752),
    [sym_line_comment] = ACTIONS(3),
  },
  [126] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(141),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(858),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(141),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(754),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [127] = {
    [ts_builtin_sym_end] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(756),
    [anon_sym_RBRACE] = ACTIONS(756),
    [anon_sym_impl] = ACTIONS(758),
    [anon_sym_SEMI] = ACTIONS(756),
    [anon_sym_trait] = ACTIONS(758),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_const] = ACTIONS(758),
    [anon_sym_EQ] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(758),
    [anon_sym_POUND] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(756),
    [anon_sym_RBRACK] = ACTIONS(756),
    [anon_sym_mod] = ACTIONS(758),
    [anon_sym_struct] = ACTIONS(758),
    [anon_sym_enum] = ACTIONS(758),
    [anon_sym_COMMA] = ACTIONS(756),
    [anon_sym_fn] = ACTIONS(758),
    [anon_sym_let] = ACTIONS(758),
    [anon_sym_use] = ACTIONS(758),
    [anon_sym_COLON_COLON] = ACTIONS(756),
    [anon_sym_STAR] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(756),
    [anon_sym_RPAREN] = ACTIONS(756),
    [anon_sym_u8] = ACTIONS(758),
    [anon_sym_i8] = ACTIONS(758),
    [anon_sym_u16] = ACTIONS(758),
    [anon_sym_i16] = ACTIONS(758),
    [anon_sym_u32] = ACTIONS(758),
    [anon_sym_i32] = ACTIONS(758),
    [anon_sym_u64] = ACTIONS(758),
    [anon_sym_i64] = ACTIONS(758),
    [anon_sym_u128] = ACTIONS(758),
    [anon_sym_i128] = ACTIONS(758),
    [anon_sym_usize] = ACTIONS(758),
    [anon_sym_bool] = ACTIONS(758),
    [anon_sym_ByteArray] = ACTIONS(758),
    [anon_sym_felt252] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(758),
    [anon_sym_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(758),
    [anon_sym_DASH] = ACTIONS(758),
    [anon_sym_SLASH] = ACTIONS(758),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_CARET] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(756),
    [anon_sym_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_PLUS_EQ] = ACTIONS(756),
    [anon_sym_DASH_EQ] = ACTIONS(756),
    [anon_sym_STAR_EQ] = ACTIONS(756),
    [anon_sym_SLASH_EQ] = ACTIONS(756),
    [anon_sym_PERCENT_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_GT_EQ] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(756),
    [anon_sym_AT] = ACTIONS(756),
    [anon_sym_DOT_DOT] = ACTIONS(756),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(758),
    [anon_sym_continue] = ACTIONS(758),
    [anon_sym_default] = ACTIONS(758),
    [anon_sym_if] = ACTIONS(758),
    [anon_sym_extern] = ACTIONS(758),
    [anon_sym_loop] = ACTIONS(758),
    [anon_sym_match] = ACTIONS(758),
    [anon_sym_pub] = ACTIONS(758),
    [anon_sym_return] = ACTIONS(758),
    [anon_sym_while] = ACTIONS(758),
    [anon_sym_for] = ACTIONS(758),
    [sym_numeric_literal] = ACTIONS(758),
    [aux_sym_string_literal_token1] = ACTIONS(756),
    [sym_shortstring_literal] = ACTIONS(756),
    [anon_sym_true] = ACTIONS(758),
    [anon_sym_false] = ACTIONS(758),
    [anon_sym_move] = ACTIONS(758),
    [anon_sym_ref] = ACTIONS(758),
    [sym_identifier] = ACTIONS(758),
    [sym_super] = ACTIONS(758),
    [sym_line_comment] = ACTIONS(3),
  },
  [128] = {
    [ts_builtin_sym_end] = ACTIONS(760),
    [anon_sym_LBRACE] = ACTIONS(760),
    [anon_sym_RBRACE] = ACTIONS(760),
    [anon_sym_impl] = ACTIONS(762),
    [anon_sym_SEMI] = ACTIONS(760),
    [anon_sym_trait] = ACTIONS(762),
    [anon_sym_type] = ACTIONS(762),
    [anon_sym_const] = ACTIONS(762),
    [anon_sym_EQ] = ACTIONS(762),
    [anon_sym_BANG] = ACTIONS(762),
    [anon_sym_POUND] = ACTIONS(760),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_RBRACK] = ACTIONS(760),
    [anon_sym_mod] = ACTIONS(762),
    [anon_sym_struct] = ACTIONS(762),
    [anon_sym_enum] = ACTIONS(762),
    [anon_sym_COMMA] = ACTIONS(760),
    [anon_sym_fn] = ACTIONS(762),
    [anon_sym_let] = ACTIONS(762),
    [anon_sym_use] = ACTIONS(762),
    [anon_sym_COLON_COLON] = ACTIONS(760),
    [anon_sym_STAR] = ACTIONS(762),
    [anon_sym_LPAREN] = ACTIONS(760),
    [anon_sym_RPAREN] = ACTIONS(760),
    [anon_sym_u8] = ACTIONS(762),
    [anon_sym_i8] = ACTIONS(762),
    [anon_sym_u16] = ACTIONS(762),
    [anon_sym_i16] = ACTIONS(762),
    [anon_sym_u32] = ACTIONS(762),
    [anon_sym_i32] = ACTIONS(762),
    [anon_sym_u64] = ACTIONS(762),
    [anon_sym_i64] = ACTIONS(762),
    [anon_sym_u128] = ACTIONS(762),
    [anon_sym_i128] = ACTIONS(762),
    [anon_sym_usize] = ACTIONS(762),
    [anon_sym_bool] = ACTIONS(762),
    [anon_sym_ByteArray] = ACTIONS(762),
    [anon_sym_felt252] = ACTIONS(762),
    [anon_sym_LT] = ACTIONS(762),
    [anon_sym_GT] = ACTIONS(762),
    [anon_sym_PLUS] = ACTIONS(762),
    [anon_sym_DASH] = ACTIONS(762),
    [anon_sym_SLASH] = ACTIONS(762),
    [anon_sym_PERCENT] = ACTIONS(762),
    [anon_sym_CARET] = ACTIONS(760),
    [anon_sym_TILDE] = ACTIONS(760),
    [anon_sym_AMP] = ACTIONS(762),
    [anon_sym_PIPE] = ACTIONS(762),
    [anon_sym_AMP_AMP] = ACTIONS(760),
    [anon_sym_PIPE_PIPE] = ACTIONS(760),
    [anon_sym_LT_LT] = ACTIONS(760),
    [anon_sym_GT_GT] = ACTIONS(760),
    [anon_sym_PLUS_EQ] = ACTIONS(760),
    [anon_sym_DASH_EQ] = ACTIONS(760),
    [anon_sym_STAR_EQ] = ACTIONS(760),
    [anon_sym_SLASH_EQ] = ACTIONS(760),
    [anon_sym_PERCENT_EQ] = ACTIONS(760),
    [anon_sym_EQ_EQ] = ACTIONS(760),
    [anon_sym_BANG_EQ] = ACTIONS(760),
    [anon_sym_GT_EQ] = ACTIONS(760),
    [anon_sym_LT_EQ] = ACTIONS(760),
    [anon_sym_AT] = ACTIONS(760),
    [anon_sym_DOT_DOT] = ACTIONS(760),
    [anon_sym_DOT] = ACTIONS(762),
    [anon_sym_QMARK] = ACTIONS(760),
    [anon_sym_break] = ACTIONS(762),
    [anon_sym_continue] = ACTIONS(762),
    [anon_sym_default] = ACTIONS(762),
    [anon_sym_if] = ACTIONS(762),
    [anon_sym_extern] = ACTIONS(762),
    [anon_sym_loop] = ACTIONS(762),
    [anon_sym_match] = ACTIONS(762),
    [anon_sym_pub] = ACTIONS(762),
    [anon_sym_return] = ACTIONS(762),
    [anon_sym_while] = ACTIONS(762),
    [anon_sym_for] = ACTIONS(762),
    [sym_numeric_literal] = ACTIONS(762),
    [aux_sym_string_literal_token1] = ACTIONS(760),
    [sym_shortstring_literal] = ACTIONS(760),
    [anon_sym_true] = ACTIONS(762),
    [anon_sym_false] = ACTIONS(762),
    [anon_sym_move] = ACTIONS(762),
    [anon_sym_ref] = ACTIONS(762),
    [sym_identifier] = ACTIONS(762),
    [sym_super] = ACTIONS(762),
    [sym_line_comment] = ACTIONS(3),
  },
  [129] = {
    [ts_builtin_sym_end] = ACTIONS(540),
    [anon_sym_LBRACE] = ACTIONS(540),
    [anon_sym_RBRACE] = ACTIONS(540),
    [anon_sym_impl] = ACTIONS(542),
    [anon_sym_SEMI] = ACTIONS(540),
    [anon_sym_trait] = ACTIONS(542),
    [anon_sym_type] = ACTIONS(542),
    [anon_sym_const] = ACTIONS(542),
    [anon_sym_EQ] = ACTIONS(542),
    [anon_sym_BANG] = ACTIONS(542),
    [anon_sym_POUND] = ACTIONS(540),
    [anon_sym_LBRACK] = ACTIONS(540),
    [anon_sym_RBRACK] = ACTIONS(540),
    [anon_sym_mod] = ACTIONS(542),
    [anon_sym_struct] = ACTIONS(542),
    [anon_sym_enum] = ACTIONS(542),
    [anon_sym_COMMA] = ACTIONS(540),
    [anon_sym_fn] = ACTIONS(542),
    [anon_sym_let] = ACTIONS(542),
    [anon_sym_use] = ACTIONS(542),
    [anon_sym_COLON_COLON] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(542),
    [anon_sym_LPAREN] = ACTIONS(540),
    [anon_sym_RPAREN] = ACTIONS(540),
    [anon_sym_u8] = ACTIONS(542),
    [anon_sym_i8] = ACTIONS(542),
    [anon_sym_u16] = ACTIONS(542),
    [anon_sym_i16] = ACTIONS(542),
    [anon_sym_u32] = ACTIONS(542),
    [anon_sym_i32] = ACTIONS(542),
    [anon_sym_u64] = ACTIONS(542),
    [anon_sym_i64] = ACTIONS(542),
    [anon_sym_u128] = ACTIONS(542),
    [anon_sym_i128] = ACTIONS(542),
    [anon_sym_usize] = ACTIONS(542),
    [anon_sym_bool] = ACTIONS(542),
    [anon_sym_ByteArray] = ACTIONS(542),
    [anon_sym_felt252] = ACTIONS(542),
    [anon_sym_LT] = ACTIONS(542),
    [anon_sym_GT] = ACTIONS(542),
    [anon_sym_PLUS] = ACTIONS(542),
    [anon_sym_DASH] = ACTIONS(542),
    [anon_sym_SLASH] = ACTIONS(542),
    [anon_sym_PERCENT] = ACTIONS(542),
    [anon_sym_CARET] = ACTIONS(540),
    [anon_sym_TILDE] = ACTIONS(540),
    [anon_sym_AMP] = ACTIONS(542),
    [anon_sym_PIPE] = ACTIONS(542),
    [anon_sym_AMP_AMP] = ACTIONS(540),
    [anon_sym_PIPE_PIPE] = ACTIONS(540),
    [anon_sym_LT_LT] = ACTIONS(540),
    [anon_sym_GT_GT] = ACTIONS(540),
    [anon_sym_PLUS_EQ] = ACTIONS(540),
    [anon_sym_DASH_EQ] = ACTIONS(540),
    [anon_sym_STAR_EQ] = ACTIONS(540),
    [anon_sym_SLASH_EQ] = ACTIONS(540),
    [anon_sym_PERCENT_EQ] = ACTIONS(540),
    [anon_sym_EQ_EQ] = ACTIONS(540),
    [anon_sym_BANG_EQ] = ACTIONS(540),
    [anon_sym_GT_EQ] = ACTIONS(540),
    [anon_sym_LT_EQ] = ACTIONS(540),
    [anon_sym_AT] = ACTIONS(540),
    [anon_sym_DOT_DOT] = ACTIONS(540),
    [anon_sym_DOT] = ACTIONS(542),
    [anon_sym_QMARK] = ACTIONS(540),
    [anon_sym_break] = ACTIONS(542),
    [anon_sym_continue] = ACTIONS(542),
    [anon_sym_default] = ACTIONS(542),
    [anon_sym_if] = ACTIONS(542),
    [anon_sym_extern] = ACTIONS(542),
    [anon_sym_loop] = ACTIONS(542),
    [anon_sym_match] = ACTIONS(542),
    [anon_sym_pub] = ACTIONS(542),
    [anon_sym_return] = ACTIONS(542),
    [anon_sym_while] = ACTIONS(542),
    [anon_sym_for] = ACTIONS(542),
    [sym_numeric_literal] = ACTIONS(542),
    [aux_sym_string_literal_token1] = ACTIONS(540),
    [sym_shortstring_literal] = ACTIONS(540),
    [anon_sym_true] = ACTIONS(542),
    [anon_sym_false] = ACTIONS(542),
    [anon_sym_move] = ACTIONS(542),
    [anon_sym_ref] = ACTIONS(542),
    [sym_identifier] = ACTIONS(542),
    [sym_super] = ACTIONS(542),
    [sym_line_comment] = ACTIONS(3),
  },
  [130] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(922),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [131] = {
    [sym_else_clause] = STATE(106),
    [ts_builtin_sym_end] = ACTIONS(764),
    [anon_sym_LBRACE] = ACTIONS(764),
    [anon_sym_RBRACE] = ACTIONS(764),
    [anon_sym_impl] = ACTIONS(766),
    [anon_sym_SEMI] = ACTIONS(764),
    [anon_sym_trait] = ACTIONS(766),
    [anon_sym_type] = ACTIONS(766),
    [anon_sym_const] = ACTIONS(766),
    [anon_sym_EQ] = ACTIONS(766),
    [anon_sym_BANG] = ACTIONS(766),
    [anon_sym_POUND] = ACTIONS(764),
    [anon_sym_LBRACK] = ACTIONS(764),
    [anon_sym_mod] = ACTIONS(766),
    [anon_sym_struct] = ACTIONS(766),
    [anon_sym_enum] = ACTIONS(766),
    [anon_sym_fn] = ACTIONS(766),
    [anon_sym_let] = ACTIONS(766),
    [anon_sym_use] = ACTIONS(766),
    [anon_sym_COLON_COLON] = ACTIONS(764),
    [anon_sym_STAR] = ACTIONS(766),
    [anon_sym_LPAREN] = ACTIONS(764),
    [anon_sym_u8] = ACTIONS(766),
    [anon_sym_i8] = ACTIONS(766),
    [anon_sym_u16] = ACTIONS(766),
    [anon_sym_i16] = ACTIONS(766),
    [anon_sym_u32] = ACTIONS(766),
    [anon_sym_i32] = ACTIONS(766),
    [anon_sym_u64] = ACTIONS(766),
    [anon_sym_i64] = ACTIONS(766),
    [anon_sym_u128] = ACTIONS(766),
    [anon_sym_i128] = ACTIONS(766),
    [anon_sym_usize] = ACTIONS(766),
    [anon_sym_bool] = ACTIONS(766),
    [anon_sym_ByteArray] = ACTIONS(766),
    [anon_sym_felt252] = ACTIONS(766),
    [anon_sym_LT] = ACTIONS(766),
    [anon_sym_GT] = ACTIONS(766),
    [anon_sym_PLUS] = ACTIONS(766),
    [anon_sym_DASH] = ACTIONS(766),
    [anon_sym_SLASH] = ACTIONS(766),
    [anon_sym_PERCENT] = ACTIONS(766),
    [anon_sym_CARET] = ACTIONS(764),
    [anon_sym_TILDE] = ACTIONS(764),
    [anon_sym_AMP] = ACTIONS(766),
    [anon_sym_PIPE] = ACTIONS(766),
    [anon_sym_AMP_AMP] = ACTIONS(764),
    [anon_sym_PIPE_PIPE] = ACTIONS(764),
    [anon_sym_LT_LT] = ACTIONS(764),
    [anon_sym_GT_GT] = ACTIONS(764),
    [anon_sym_PLUS_EQ] = ACTIONS(764),
    [anon_sym_DASH_EQ] = ACTIONS(764),
    [anon_sym_STAR_EQ] = ACTIONS(764),
    [anon_sym_SLASH_EQ] = ACTIONS(764),
    [anon_sym_PERCENT_EQ] = ACTIONS(764),
    [anon_sym_EQ_EQ] = ACTIONS(764),
    [anon_sym_BANG_EQ] = ACTIONS(764),
    [anon_sym_GT_EQ] = ACTIONS(764),
    [anon_sym_LT_EQ] = ACTIONS(764),
    [anon_sym_AT] = ACTIONS(764),
    [anon_sym_DOT_DOT] = ACTIONS(764),
    [anon_sym_DOT] = ACTIONS(766),
    [anon_sym_QMARK] = ACTIONS(764),
    [anon_sym_break] = ACTIONS(766),
    [anon_sym_continue] = ACTIONS(766),
    [anon_sym_default] = ACTIONS(766),
    [anon_sym_if] = ACTIONS(766),
    [anon_sym_extern] = ACTIONS(766),
    [anon_sym_loop] = ACTIONS(766),
    [anon_sym_match] = ACTIONS(766),
    [anon_sym_pub] = ACTIONS(766),
    [anon_sym_return] = ACTIONS(766),
    [anon_sym_while] = ACTIONS(766),
    [anon_sym_for] = ACTIONS(766),
    [sym_numeric_literal] = ACTIONS(766),
    [aux_sym_string_literal_token1] = ACTIONS(764),
    [sym_shortstring_literal] = ACTIONS(764),
    [anon_sym_true] = ACTIONS(766),
    [anon_sym_false] = ACTIONS(766),
    [anon_sym_else] = ACTIONS(768),
    [anon_sym_move] = ACTIONS(766),
    [anon_sym_ref] = ACTIONS(766),
    [sym_identifier] = ACTIONS(766),
    [sym_super] = ACTIONS(766),
    [sym_line_comment] = ACTIONS(3),
  },
  [132] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1653),
    [sym_let_condition] = STATE(1653),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [133] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1545),
    [sym_let_condition] = STATE(1545),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [134] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(874),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [135] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1578),
    [sym_let_condition] = STATE(1578),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [136] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1584),
    [sym_let_condition] = STATE(1584),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [137] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(902),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym__condition] = STATE(1812),
    [sym_let_condition] = STATE(1812),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_let] = ACTIONS(776),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(780),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [138] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1606),
    [sym_let_condition] = STATE(1606),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [139] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1608),
    [sym_let_condition] = STATE(1608),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [140] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(892),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym__condition] = STATE(1630),
    [sym_let_condition] = STATE(1630),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_let] = ACTIONS(770),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [141] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(401),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(919),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(401),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [142] = {
    [sym_macro_invocation] = STATE(515),
    [sym_attribute_item] = STATE(134),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(787),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_enum_variant_list_repeat1] = STATE(134),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_POUND] = ACTIONS(565),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [143] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(556),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(782),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(784),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [144] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(866),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(161),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(786),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [145] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(855),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(152),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(788),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [146] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(778),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(782),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(784),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [147] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(554),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(790),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [148] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(833),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(790),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [149] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(784),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(790),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(792),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [150] = {
    [ts_builtin_sym_end] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(756),
    [anon_sym_RBRACE] = ACTIONS(756),
    [anon_sym_impl] = ACTIONS(758),
    [anon_sym_SEMI] = ACTIONS(756),
    [anon_sym_trait] = ACTIONS(758),
    [anon_sym_type] = ACTIONS(758),
    [anon_sym_const] = ACTIONS(758),
    [anon_sym_EQ] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(758),
    [anon_sym_POUND] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(756),
    [anon_sym_mod] = ACTIONS(758),
    [anon_sym_struct] = ACTIONS(758),
    [anon_sym_enum] = ACTIONS(758),
    [anon_sym_fn] = ACTIONS(758),
    [anon_sym_let] = ACTIONS(758),
    [anon_sym_use] = ACTIONS(758),
    [anon_sym_COLON_COLON] = ACTIONS(756),
    [anon_sym_STAR] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(756),
    [anon_sym_u8] = ACTIONS(758),
    [anon_sym_i8] = ACTIONS(758),
    [anon_sym_u16] = ACTIONS(758),
    [anon_sym_i16] = ACTIONS(758),
    [anon_sym_u32] = ACTIONS(758),
    [anon_sym_i32] = ACTIONS(758),
    [anon_sym_u64] = ACTIONS(758),
    [anon_sym_i64] = ACTIONS(758),
    [anon_sym_u128] = ACTIONS(758),
    [anon_sym_i128] = ACTIONS(758),
    [anon_sym_usize] = ACTIONS(758),
    [anon_sym_bool] = ACTIONS(758),
    [anon_sym_ByteArray] = ACTIONS(758),
    [anon_sym_felt252] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(758),
    [anon_sym_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(758),
    [anon_sym_DASH] = ACTIONS(758),
    [anon_sym_SLASH] = ACTIONS(758),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_CARET] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(756),
    [anon_sym_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(756),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_PLUS_EQ] = ACTIONS(756),
    [anon_sym_DASH_EQ] = ACTIONS(756),
    [anon_sym_STAR_EQ] = ACTIONS(756),
    [anon_sym_SLASH_EQ] = ACTIONS(756),
    [anon_sym_PERCENT_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_GT_EQ] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(756),
    [anon_sym_AT] = ACTIONS(756),
    [anon_sym_DOT_DOT] = ACTIONS(756),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(758),
    [anon_sym_continue] = ACTIONS(758),
    [anon_sym_default] = ACTIONS(758),
    [anon_sym_if] = ACTIONS(758),
    [anon_sym_extern] = ACTIONS(758),
    [anon_sym_loop] = ACTIONS(758),
    [anon_sym_match] = ACTIONS(758),
    [anon_sym_pub] = ACTIONS(758),
    [anon_sym_return] = ACTIONS(758),
    [anon_sym_while] = ACTIONS(758),
    [anon_sym_for] = ACTIONS(758),
    [sym_numeric_literal] = ACTIONS(758),
    [aux_sym_string_literal_token1] = ACTIONS(756),
    [sym_shortstring_literal] = ACTIONS(756),
    [anon_sym_true] = ACTIONS(758),
    [anon_sym_false] = ACTIONS(758),
    [anon_sym_else] = ACTIONS(758),
    [anon_sym_move] = ACTIONS(758),
    [anon_sym_ref] = ACTIONS(758),
    [sym_identifier] = ACTIONS(758),
    [sym_super] = ACTIONS(758),
    [sym_line_comment] = ACTIONS(3),
  },
  [151] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(832),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(155),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(794),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [152] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(897),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(152),
    [anon_sym_LBRACE] = ACTIONS(796),
    [anon_sym_BANG] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(802),
    [anon_sym_COLON_COLON] = ACTIONS(805),
    [anon_sym_STAR] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(808),
    [anon_sym_RPAREN] = ACTIONS(811),
    [anon_sym_u8] = ACTIONS(813),
    [anon_sym_i8] = ACTIONS(813),
    [anon_sym_u16] = ACTIONS(813),
    [anon_sym_i16] = ACTIONS(813),
    [anon_sym_u32] = ACTIONS(813),
    [anon_sym_i32] = ACTIONS(813),
    [anon_sym_u64] = ACTIONS(813),
    [anon_sym_i64] = ACTIONS(813),
    [anon_sym_u128] = ACTIONS(813),
    [anon_sym_i128] = ACTIONS(813),
    [anon_sym_usize] = ACTIONS(813),
    [anon_sym_bool] = ACTIONS(813),
    [anon_sym_ByteArray] = ACTIONS(813),
    [anon_sym_felt252] = ACTIONS(813),
    [anon_sym_DASH] = ACTIONS(816),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(819),
    [anon_sym_AT] = ACTIONS(799),
    [anon_sym_DOT_DOT] = ACTIONS(822),
    [anon_sym_break] = ACTIONS(825),
    [anon_sym_continue] = ACTIONS(828),
    [anon_sym_default] = ACTIONS(831),
    [anon_sym_if] = ACTIONS(834),
    [anon_sym_loop] = ACTIONS(837),
    [anon_sym_match] = ACTIONS(840),
    [anon_sym_return] = ACTIONS(843),
    [anon_sym_while] = ACTIONS(846),
    [anon_sym_for] = ACTIONS(849),
    [sym_numeric_literal] = ACTIONS(852),
    [aux_sym_string_literal_token1] = ACTIONS(855),
    [sym_shortstring_literal] = ACTIONS(858),
    [anon_sym_true] = ACTIONS(861),
    [anon_sym_false] = ACTIONS(861),
    [anon_sym_move] = ACTIONS(864),
    [anon_sym_ref] = ACTIONS(867),
    [sym_identifier] = ACTIONS(870),
    [sym_super] = ACTIONS(873),
    [sym_line_comment] = ACTIONS(3),
  },
  [153] = {
    [ts_builtin_sym_end] = ACTIONS(746),
    [anon_sym_LBRACE] = ACTIONS(746),
    [anon_sym_RBRACE] = ACTIONS(746),
    [anon_sym_impl] = ACTIONS(748),
    [anon_sym_SEMI] = ACTIONS(746),
    [anon_sym_trait] = ACTIONS(748),
    [anon_sym_type] = ACTIONS(748),
    [anon_sym_const] = ACTIONS(748),
    [anon_sym_EQ] = ACTIONS(748),
    [anon_sym_BANG] = ACTIONS(748),
    [anon_sym_POUND] = ACTIONS(746),
    [anon_sym_LBRACK] = ACTIONS(746),
    [anon_sym_mod] = ACTIONS(748),
    [anon_sym_struct] = ACTIONS(748),
    [anon_sym_enum] = ACTIONS(748),
    [anon_sym_fn] = ACTIONS(748),
    [anon_sym_let] = ACTIONS(748),
    [anon_sym_use] = ACTIONS(748),
    [anon_sym_COLON_COLON] = ACTIONS(746),
    [anon_sym_STAR] = ACTIONS(748),
    [anon_sym_LPAREN] = ACTIONS(746),
    [anon_sym_u8] = ACTIONS(748),
    [anon_sym_i8] = ACTIONS(748),
    [anon_sym_u16] = ACTIONS(748),
    [anon_sym_i16] = ACTIONS(748),
    [anon_sym_u32] = ACTIONS(748),
    [anon_sym_i32] = ACTIONS(748),
    [anon_sym_u64] = ACTIONS(748),
    [anon_sym_i64] = ACTIONS(748),
    [anon_sym_u128] = ACTIONS(748),
    [anon_sym_i128] = ACTIONS(748),
    [anon_sym_usize] = ACTIONS(748),
    [anon_sym_bool] = ACTIONS(748),
    [anon_sym_ByteArray] = ACTIONS(748),
    [anon_sym_felt252] = ACTIONS(748),
    [anon_sym_LT] = ACTIONS(748),
    [anon_sym_GT] = ACTIONS(748),
    [anon_sym_PLUS] = ACTIONS(748),
    [anon_sym_DASH] = ACTIONS(748),
    [anon_sym_SLASH] = ACTIONS(748),
    [anon_sym_PERCENT] = ACTIONS(748),
    [anon_sym_CARET] = ACTIONS(746),
    [anon_sym_TILDE] = ACTIONS(746),
    [anon_sym_AMP] = ACTIONS(748),
    [anon_sym_PIPE] = ACTIONS(748),
    [anon_sym_AMP_AMP] = ACTIONS(746),
    [anon_sym_PIPE_PIPE] = ACTIONS(746),
    [anon_sym_LT_LT] = ACTIONS(746),
    [anon_sym_GT_GT] = ACTIONS(746),
    [anon_sym_PLUS_EQ] = ACTIONS(746),
    [anon_sym_DASH_EQ] = ACTIONS(746),
    [anon_sym_STAR_EQ] = ACTIONS(746),
    [anon_sym_SLASH_EQ] = ACTIONS(746),
    [anon_sym_PERCENT_EQ] = ACTIONS(746),
    [anon_sym_EQ_EQ] = ACTIONS(746),
    [anon_sym_BANG_EQ] = ACTIONS(746),
    [anon_sym_GT_EQ] = ACTIONS(746),
    [anon_sym_LT_EQ] = ACTIONS(746),
    [anon_sym_AT] = ACTIONS(746),
    [anon_sym_DOT_DOT] = ACTIONS(746),
    [anon_sym_DOT] = ACTIONS(748),
    [anon_sym_QMARK] = ACTIONS(746),
    [anon_sym_break] = ACTIONS(748),
    [anon_sym_continue] = ACTIONS(748),
    [anon_sym_default] = ACTIONS(748),
    [anon_sym_if] = ACTIONS(748),
    [anon_sym_extern] = ACTIONS(748),
    [anon_sym_loop] = ACTIONS(748),
    [anon_sym_match] = ACTIONS(748),
    [anon_sym_pub] = ACTIONS(748),
    [anon_sym_return] = ACTIONS(748),
    [anon_sym_while] = ACTIONS(748),
    [anon_sym_for] = ACTIONS(748),
    [sym_numeric_literal] = ACTIONS(748),
    [aux_sym_string_literal_token1] = ACTIONS(746),
    [sym_shortstring_literal] = ACTIONS(746),
    [anon_sym_true] = ACTIONS(748),
    [anon_sym_false] = ACTIONS(748),
    [anon_sym_else] = ACTIONS(748),
    [anon_sym_move] = ACTIONS(748),
    [anon_sym_ref] = ACTIONS(748),
    [sym_identifier] = ACTIONS(748),
    [sym_super] = ACTIONS(748),
    [sym_line_comment] = ACTIONS(3),
  },
  [154] = {
    [ts_builtin_sym_end] = ACTIONS(740),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_impl] = ACTIONS(742),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_trait] = ACTIONS(742),
    [anon_sym_type] = ACTIONS(742),
    [anon_sym_const] = ACTIONS(742),
    [anon_sym_EQ] = ACTIONS(742),
    [anon_sym_BANG] = ACTIONS(742),
    [anon_sym_POUND] = ACTIONS(740),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_mod] = ACTIONS(742),
    [anon_sym_struct] = ACTIONS(742),
    [anon_sym_enum] = ACTIONS(742),
    [anon_sym_fn] = ACTIONS(742),
    [anon_sym_let] = ACTIONS(742),
    [anon_sym_use] = ACTIONS(742),
    [anon_sym_COLON_COLON] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(742),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_u8] = ACTIONS(742),
    [anon_sym_i8] = ACTIONS(742),
    [anon_sym_u16] = ACTIONS(742),
    [anon_sym_i16] = ACTIONS(742),
    [anon_sym_u32] = ACTIONS(742),
    [anon_sym_i32] = ACTIONS(742),
    [anon_sym_u64] = ACTIONS(742),
    [anon_sym_i64] = ACTIONS(742),
    [anon_sym_u128] = ACTIONS(742),
    [anon_sym_i128] = ACTIONS(742),
    [anon_sym_usize] = ACTIONS(742),
    [anon_sym_bool] = ACTIONS(742),
    [anon_sym_ByteArray] = ACTIONS(742),
    [anon_sym_felt252] = ACTIONS(742),
    [anon_sym_LT] = ACTIONS(742),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_PLUS] = ACTIONS(742),
    [anon_sym_DASH] = ACTIONS(742),
    [anon_sym_SLASH] = ACTIONS(742),
    [anon_sym_PERCENT] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(742),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS_EQ] = ACTIONS(740),
    [anon_sym_DASH_EQ] = ACTIONS(740),
    [anon_sym_STAR_EQ] = ACTIONS(740),
    [anon_sym_SLASH_EQ] = ACTIONS(740),
    [anon_sym_PERCENT_EQ] = ACTIONS(740),
    [anon_sym_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_AT] = ACTIONS(740),
    [anon_sym_DOT_DOT] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(742),
    [anon_sym_QMARK] = ACTIONS(740),
    [anon_sym_break] = ACTIONS(742),
    [anon_sym_continue] = ACTIONS(742),
    [anon_sym_default] = ACTIONS(742),
    [anon_sym_if] = ACTIONS(742),
    [anon_sym_extern] = ACTIONS(742),
    [anon_sym_loop] = ACTIONS(742),
    [anon_sym_match] = ACTIONS(742),
    [anon_sym_pub] = ACTIONS(742),
    [anon_sym_return] = ACTIONS(742),
    [anon_sym_while] = ACTIONS(742),
    [anon_sym_for] = ACTIONS(742),
    [sym_numeric_literal] = ACTIONS(742),
    [aux_sym_string_literal_token1] = ACTIONS(740),
    [sym_shortstring_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(742),
    [anon_sym_false] = ACTIONS(742),
    [anon_sym_else] = ACTIONS(742),
    [anon_sym_move] = ACTIONS(742),
    [anon_sym_ref] = ACTIONS(742),
    [sym_identifier] = ACTIONS(742),
    [sym_super] = ACTIONS(742),
    [sym_line_comment] = ACTIONS(3),
  },
  [155] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(889),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(152),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(876),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [156] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(869),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(157),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(878),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [157] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(870),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(152),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(880),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [158] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(889),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(145),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(876),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [159] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(757),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_DASH_GT] = ACTIONS(782),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym__] = ACTIONS(784),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(255),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [160] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(847),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_DASH_GT] = ACTIONS(882),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym__] = ACTIONS(884),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(317),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [161] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(869),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [aux_sym_tuple_expression_repeat1] = STATE(152),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_RPAREN] = ACTIONS(878),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [162] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(849),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_DASH_GT] = ACTIONS(886),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym__] = ACTIONS(888),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(317),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [163] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(521),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_mutable_specifier] = ACTIONS(890),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [164] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(770),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_mutable_specifier] = ACTIONS(892),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [165] = {
    [ts_builtin_sym_end] = ACTIONS(894),
    [anon_sym_LBRACE] = ACTIONS(894),
    [anon_sym_RBRACE] = ACTIONS(894),
    [anon_sym_impl] = ACTIONS(896),
    [anon_sym_SEMI] = ACTIONS(894),
    [anon_sym_trait] = ACTIONS(896),
    [anon_sym_type] = ACTIONS(896),
    [anon_sym_const] = ACTIONS(896),
    [anon_sym_EQ] = ACTIONS(898),
    [anon_sym_BANG] = ACTIONS(896),
    [anon_sym_POUND] = ACTIONS(894),
    [anon_sym_LBRACK] = ACTIONS(894),
    [anon_sym_mod] = ACTIONS(896),
    [anon_sym_struct] = ACTIONS(896),
    [anon_sym_enum] = ACTIONS(896),
    [anon_sym_fn] = ACTIONS(896),
    [anon_sym_let] = ACTIONS(896),
    [anon_sym_use] = ACTIONS(896),
    [anon_sym_COLON_COLON] = ACTIONS(894),
    [anon_sym_STAR] = ACTIONS(896),
    [anon_sym_LPAREN] = ACTIONS(894),
    [anon_sym_u8] = ACTIONS(896),
    [anon_sym_i8] = ACTIONS(896),
    [anon_sym_u16] = ACTIONS(896),
    [anon_sym_i16] = ACTIONS(896),
    [anon_sym_u32] = ACTIONS(896),
    [anon_sym_i32] = ACTIONS(896),
    [anon_sym_u64] = ACTIONS(896),
    [anon_sym_i64] = ACTIONS(896),
    [anon_sym_u128] = ACTIONS(896),
    [anon_sym_i128] = ACTIONS(896),
    [anon_sym_usize] = ACTIONS(896),
    [anon_sym_bool] = ACTIONS(896),
    [anon_sym_ByteArray] = ACTIONS(896),
    [anon_sym_felt252] = ACTIONS(896),
    [anon_sym_LT] = ACTIONS(898),
    [anon_sym_GT] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(898),
    [anon_sym_DASH] = ACTIONS(896),
    [anon_sym_SLASH] = ACTIONS(898),
    [anon_sym_PERCENT] = ACTIONS(898),
    [anon_sym_CARET] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(894),
    [anon_sym_AMP] = ACTIONS(898),
    [anon_sym_PIPE] = ACTIONS(896),
    [anon_sym_AMP_AMP] = ACTIONS(900),
    [anon_sym_PIPE_PIPE] = ACTIONS(900),
    [anon_sym_LT_LT] = ACTIONS(900),
    [anon_sym_GT_GT] = ACTIONS(900),
    [anon_sym_PLUS_EQ] = ACTIONS(900),
    [anon_sym_DASH_EQ] = ACTIONS(900),
    [anon_sym_STAR_EQ] = ACTIONS(900),
    [anon_sym_SLASH_EQ] = ACTIONS(900),
    [anon_sym_PERCENT_EQ] = ACTIONS(900),
    [anon_sym_EQ_EQ] = ACTIONS(900),
    [anon_sym_BANG_EQ] = ACTIONS(900),
    [anon_sym_GT_EQ] = ACTIONS(900),
    [anon_sym_LT_EQ] = ACTIONS(900),
    [anon_sym_AT] = ACTIONS(894),
    [anon_sym_DOT_DOT] = ACTIONS(894),
    [anon_sym_DOT] = ACTIONS(898),
    [anon_sym_QMARK] = ACTIONS(900),
    [anon_sym_break] = ACTIONS(896),
    [anon_sym_continue] = ACTIONS(896),
    [anon_sym_default] = ACTIONS(896),
    [anon_sym_if] = ACTIONS(896),
    [anon_sym_extern] = ACTIONS(896),
    [anon_sym_loop] = ACTIONS(896),
    [anon_sym_match] = ACTIONS(896),
    [anon_sym_pub] = ACTIONS(896),
    [anon_sym_return] = ACTIONS(896),
    [anon_sym_while] = ACTIONS(896),
    [anon_sym_for] = ACTIONS(896),
    [sym_numeric_literal] = ACTIONS(896),
    [aux_sym_string_literal_token1] = ACTIONS(894),
    [sym_shortstring_literal] = ACTIONS(894),
    [anon_sym_true] = ACTIONS(896),
    [anon_sym_false] = ACTIONS(896),
    [anon_sym_move] = ACTIONS(896),
    [anon_sym_ref] = ACTIONS(896),
    [sym_identifier] = ACTIONS(896),
    [sym_super] = ACTIONS(896),
    [sym_line_comment] = ACTIONS(3),
  },
  [166] = {
    [ts_builtin_sym_end] = ACTIONS(902),
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_RBRACE] = ACTIONS(900),
    [anon_sym_impl] = ACTIONS(904),
    [anon_sym_SEMI] = ACTIONS(900),
    [anon_sym_trait] = ACTIONS(904),
    [anon_sym_type] = ACTIONS(904),
    [anon_sym_const] = ACTIONS(904),
    [anon_sym_EQ] = ACTIONS(898),
    [anon_sym_BANG] = ACTIONS(904),
    [anon_sym_POUND] = ACTIONS(902),
    [anon_sym_LBRACK] = ACTIONS(900),
    [anon_sym_mod] = ACTIONS(904),
    [anon_sym_struct] = ACTIONS(904),
    [anon_sym_enum] = ACTIONS(904),
    [anon_sym_fn] = ACTIONS(904),
    [anon_sym_let] = ACTIONS(904),
    [anon_sym_use] = ACTIONS(904),
    [anon_sym_COLON_COLON] = ACTIONS(902),
    [anon_sym_STAR] = ACTIONS(898),
    [anon_sym_LPAREN] = ACTIONS(900),
    [anon_sym_u8] = ACTIONS(904),
    [anon_sym_i8] = ACTIONS(904),
    [anon_sym_u16] = ACTIONS(904),
    [anon_sym_i16] = ACTIONS(904),
    [anon_sym_u32] = ACTIONS(904),
    [anon_sym_i32] = ACTIONS(904),
    [anon_sym_u64] = ACTIONS(904),
    [anon_sym_i64] = ACTIONS(904),
    [anon_sym_u128] = ACTIONS(904),
    [anon_sym_i128] = ACTIONS(904),
    [anon_sym_usize] = ACTIONS(904),
    [anon_sym_bool] = ACTIONS(904),
    [anon_sym_ByteArray] = ACTIONS(904),
    [anon_sym_felt252] = ACTIONS(904),
    [anon_sym_LT] = ACTIONS(898),
    [anon_sym_GT] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(898),
    [anon_sym_DASH] = ACTIONS(898),
    [anon_sym_SLASH] = ACTIONS(898),
    [anon_sym_PERCENT] = ACTIONS(898),
    [anon_sym_CARET] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(902),
    [anon_sym_AMP] = ACTIONS(898),
    [anon_sym_PIPE] = ACTIONS(898),
    [anon_sym_AMP_AMP] = ACTIONS(900),
    [anon_sym_PIPE_PIPE] = ACTIONS(900),
    [anon_sym_LT_LT] = ACTIONS(900),
    [anon_sym_GT_GT] = ACTIONS(900),
    [anon_sym_PLUS_EQ] = ACTIONS(900),
    [anon_sym_DASH_EQ] = ACTIONS(900),
    [anon_sym_STAR_EQ] = ACTIONS(900),
    [anon_sym_SLASH_EQ] = ACTIONS(900),
    [anon_sym_PERCENT_EQ] = ACTIONS(900),
    [anon_sym_EQ_EQ] = ACTIONS(900),
    [anon_sym_BANG_EQ] = ACTIONS(900),
    [anon_sym_GT_EQ] = ACTIONS(900),
    [anon_sym_LT_EQ] = ACTIONS(900),
    [anon_sym_AT] = ACTIONS(902),
    [anon_sym_DOT_DOT] = ACTIONS(900),
    [anon_sym_DOT] = ACTIONS(898),
    [anon_sym_QMARK] = ACTIONS(900),
    [anon_sym_break] = ACTIONS(904),
    [anon_sym_continue] = ACTIONS(904),
    [anon_sym_default] = ACTIONS(904),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_extern] = ACTIONS(904),
    [anon_sym_loop] = ACTIONS(904),
    [anon_sym_match] = ACTIONS(904),
    [anon_sym_pub] = ACTIONS(904),
    [anon_sym_return] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(904),
    [anon_sym_for] = ACTIONS(904),
    [sym_numeric_literal] = ACTIONS(904),
    [aux_sym_string_literal_token1] = ACTIONS(902),
    [sym_shortstring_literal] = ACTIONS(902),
    [anon_sym_true] = ACTIONS(904),
    [anon_sym_false] = ACTIONS(904),
    [anon_sym_move] = ACTIONS(904),
    [anon_sym_ref] = ACTIONS(904),
    [sym_identifier] = ACTIONS(904),
    [sym_super] = ACTIONS(904),
    [sym_line_comment] = ACTIONS(3),
  },
  [167] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(521),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_mutable_specifier] = ACTIONS(906),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [168] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(548),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [169] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(903),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [170] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(906),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [171] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(918),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [172] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(486),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(908),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [173] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(917),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [174] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(773),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [175] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(774),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [176] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(814),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [177] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(911),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [178] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(893),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [179] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(513),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [180] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(856),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(359),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(359),
    [sym_if_expression] = STATE(359),
    [sym_match_expression] = STATE(359),
    [sym_while_expression] = STATE(359),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(359),
    [sym_loop_expression] = STATE(359),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(912),
    [anon_sym_loop] = ACTIONS(914),
    [anon_sym_match] = ACTIONS(916),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(918),
    [anon_sym_for] = ACTIONS(920),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [181] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(864),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [182] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(865),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [183] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(895),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [184] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(920),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [185] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(541),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [186] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(888),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(363),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(363),
    [sym_if_expression] = STATE(363),
    [sym_match_expression] = STATE(363),
    [sym_while_expression] = STATE(363),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(363),
    [sym_loop_expression] = STATE(363),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(912),
    [anon_sym_loop] = ACTIONS(914),
    [anon_sym_match] = ACTIONS(916),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(918),
    [anon_sym_for] = ACTIONS(920),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [187] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(908),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [188] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(519),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [189] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(923),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [190] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(924),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(359),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(359),
    [sym_if_expression] = STATE(359),
    [sym_match_expression] = STATE(359),
    [sym_while_expression] = STATE(359),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(359),
    [sym_loop_expression] = STATE(359),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(912),
    [anon_sym_loop] = ACTIONS(914),
    [anon_sym_match] = ACTIONS(916),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(918),
    [anon_sym_for] = ACTIONS(920),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [191] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(912),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(363),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(363),
    [sym_if_expression] = STATE(363),
    [sym_match_expression] = STATE(363),
    [sym_while_expression] = STATE(363),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(363),
    [sym_loop_expression] = STATE(363),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(912),
    [anon_sym_loop] = ACTIONS(914),
    [anon_sym_match] = ACTIONS(916),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(918),
    [anon_sym_for] = ACTIONS(920),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [192] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(763),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(922),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [193] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(543),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [194] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(544),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [195] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(545),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [196] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(546),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [197] = {
    [anon_sym_LBRACE] = ACTIONS(902),
    [anon_sym_RBRACE] = ACTIONS(902),
    [anon_sym_impl] = ACTIONS(904),
    [anon_sym_SEMI] = ACTIONS(900),
    [anon_sym_trait] = ACTIONS(904),
    [anon_sym_type] = ACTIONS(904),
    [anon_sym_const] = ACTIONS(904),
    [anon_sym_EQ] = ACTIONS(898),
    [anon_sym_BANG] = ACTIONS(904),
    [anon_sym_POUND] = ACTIONS(902),
    [anon_sym_LBRACK] = ACTIONS(900),
    [anon_sym_mod] = ACTIONS(904),
    [anon_sym_struct] = ACTIONS(904),
    [anon_sym_enum] = ACTIONS(904),
    [anon_sym_fn] = ACTIONS(904),
    [anon_sym_let] = ACTIONS(904),
    [anon_sym_use] = ACTIONS(904),
    [anon_sym_COLON_COLON] = ACTIONS(902),
    [anon_sym_STAR] = ACTIONS(898),
    [anon_sym_LPAREN] = ACTIONS(900),
    [anon_sym_u8] = ACTIONS(904),
    [anon_sym_i8] = ACTIONS(904),
    [anon_sym_u16] = ACTIONS(904),
    [anon_sym_i16] = ACTIONS(904),
    [anon_sym_u32] = ACTIONS(904),
    [anon_sym_i32] = ACTIONS(904),
    [anon_sym_u64] = ACTIONS(904),
    [anon_sym_i64] = ACTIONS(904),
    [anon_sym_u128] = ACTIONS(904),
    [anon_sym_i128] = ACTIONS(904),
    [anon_sym_usize] = ACTIONS(904),
    [anon_sym_bool] = ACTIONS(904),
    [anon_sym_ByteArray] = ACTIONS(904),
    [anon_sym_felt252] = ACTIONS(904),
    [anon_sym_LT] = ACTIONS(898),
    [anon_sym_GT] = ACTIONS(898),
    [anon_sym_PLUS] = ACTIONS(898),
    [anon_sym_DASH] = ACTIONS(898),
    [anon_sym_SLASH] = ACTIONS(898),
    [anon_sym_PERCENT] = ACTIONS(898),
    [anon_sym_CARET] = ACTIONS(900),
    [anon_sym_TILDE] = ACTIONS(902),
    [anon_sym_AMP] = ACTIONS(898),
    [anon_sym_PIPE] = ACTIONS(898),
    [anon_sym_AMP_AMP] = ACTIONS(900),
    [anon_sym_PIPE_PIPE] = ACTIONS(900),
    [anon_sym_LT_LT] = ACTIONS(900),
    [anon_sym_GT_GT] = ACTIONS(900),
    [anon_sym_PLUS_EQ] = ACTIONS(900),
    [anon_sym_DASH_EQ] = ACTIONS(900),
    [anon_sym_STAR_EQ] = ACTIONS(900),
    [anon_sym_SLASH_EQ] = ACTIONS(900),
    [anon_sym_PERCENT_EQ] = ACTIONS(900),
    [anon_sym_EQ_EQ] = ACTIONS(900),
    [anon_sym_BANG_EQ] = ACTIONS(900),
    [anon_sym_GT_EQ] = ACTIONS(900),
    [anon_sym_LT_EQ] = ACTIONS(900),
    [anon_sym_AT] = ACTIONS(902),
    [anon_sym_DOT_DOT] = ACTIONS(900),
    [anon_sym_DOT] = ACTIONS(898),
    [anon_sym_QMARK] = ACTIONS(900),
    [anon_sym_break] = ACTIONS(904),
    [anon_sym_continue] = ACTIONS(904),
    [anon_sym_default] = ACTIONS(904),
    [anon_sym_if] = ACTIONS(904),
    [anon_sym_extern] = ACTIONS(904),
    [anon_sym_loop] = ACTIONS(904),
    [anon_sym_match] = ACTIONS(904),
    [anon_sym_pub] = ACTIONS(904),
    [anon_sym_return] = ACTIONS(904),
    [anon_sym_while] = ACTIONS(904),
    [anon_sym_for] = ACTIONS(904),
    [sym_numeric_literal] = ACTIONS(904),
    [aux_sym_string_literal_token1] = ACTIONS(902),
    [sym_shortstring_literal] = ACTIONS(902),
    [anon_sym_true] = ACTIONS(904),
    [anon_sym_false] = ACTIONS(904),
    [anon_sym_move] = ACTIONS(904),
    [anon_sym_ref] = ACTIONS(904),
    [sym_identifier] = ACTIONS(904),
    [sym_super] = ACTIONS(904),
    [sym_line_comment] = ACTIONS(3),
  },
  [198] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(547),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [199] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(513),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [200] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(789),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [201] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(519),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [202] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(791),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [203] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(792),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [204] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(793),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [205] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(794),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [206] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(795),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [207] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(796),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [208] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(797),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [209] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(798),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [210] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(799),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [211] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(549),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [212] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(550),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [213] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(910),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(780),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [214] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(551),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [215] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(785),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [216] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(834),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [217] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(790),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [218] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(835),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [219] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(836),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [220] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(837),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [221] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(838),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [222] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(839),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [223] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(840),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [224] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(841),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [225] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(842),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [226] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(843),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [227] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(915),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [228] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(486),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [229] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(486),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(345),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(908),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [230] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(905),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [231] = {
    [sym_macro_invocation] = STATE(762),
    [sym_generic_type_with_turbofish] = STATE(1352),
    [sym__literal] = STATE(760),
    [sym_negative_literal] = STATE(846),
    [sym_string_literal] = STATE(846),
    [sym_boolean_literal] = STATE(846),
    [sym_scoped_identifier] = STATE(680),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1549),
    [sym_expression] = STATE(763),
    [sym_expression_except_range] = STATE(700),
    [sym_generic_function] = STATE(760),
    [sym_tuple_expression] = STATE(760),
    [sym_return_expression] = STATE(760),
    [sym_struct_expression] = STATE(760),
    [sym_assignment_expression] = STATE(760),
    [sym_break_expression] = STATE(760),
    [sym_continue_expression] = STATE(760),
    [sym_index_expression] = STATE(760),
    [sym_array_expression] = STATE(760),
    [sym_parenthesized_expression] = STATE(760),
    [sym_unit_expression] = STATE(760),
    [sym_compound_assignment_expr] = STATE(760),
    [sym__expression_ending_with_block] = STATE(760),
    [sym_unary_expression] = STATE(760),
    [sym_range_expression] = STATE(761),
    [sym_try_expression] = STATE(760),
    [sym_field_expression] = STATE(701),
    [sym_block] = STATE(760),
    [sym_if_expression] = STATE(760),
    [sym_match_expression] = STATE(760),
    [sym_while_expression] = STATE(760),
    [sym_closure_expression] = STATE(760),
    [sym_closure_parameters] = STATE(160),
    [sym_for_expression] = STATE(760),
    [sym_loop_expression] = STATE(760),
    [sym_binary_expression] = STATE(760),
    [sym_call_expression] = STATE(760),
    [sym_reference_expression] = STATE(760),
    [anon_sym_LBRACE] = ACTIONS(269),
    [anon_sym_BANG] = ACTIONS(277),
    [anon_sym_LBRACK] = ACTIONS(313),
    [anon_sym_COLON_COLON] = ACTIONS(273),
    [anon_sym_STAR] = ACTIONS(277),
    [anon_sym_LPAREN] = ACTIONS(315),
    [anon_sym_u8] = ACTIONS(275),
    [anon_sym_i8] = ACTIONS(275),
    [anon_sym_u16] = ACTIONS(275),
    [anon_sym_i16] = ACTIONS(275),
    [anon_sym_u32] = ACTIONS(275),
    [anon_sym_i32] = ACTIONS(275),
    [anon_sym_u64] = ACTIONS(275),
    [anon_sym_i64] = ACTIONS(275),
    [anon_sym_u128] = ACTIONS(275),
    [anon_sym_i128] = ACTIONS(275),
    [anon_sym_usize] = ACTIONS(275),
    [anon_sym_bool] = ACTIONS(275),
    [anon_sym_ByteArray] = ACTIONS(275),
    [anon_sym_felt252] = ACTIONS(275),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(277),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(277),
    [anon_sym_DOT_DOT] = ACTIONS(319),
    [anon_sym_break] = ACTIONS(279),
    [anon_sym_continue] = ACTIONS(281),
    [anon_sym_default] = ACTIONS(283),
    [anon_sym_if] = ACTIONS(285),
    [anon_sym_loop] = ACTIONS(287),
    [anon_sym_match] = ACTIONS(289),
    [anon_sym_return] = ACTIONS(291),
    [anon_sym_while] = ACTIONS(293),
    [anon_sym_for] = ACTIONS(295),
    [sym_numeric_literal] = ACTIONS(297),
    [aux_sym_string_literal_token1] = ACTIONS(299),
    [sym_shortstring_literal] = ACTIONS(301),
    [anon_sym_true] = ACTIONS(303),
    [anon_sym_false] = ACTIONS(303),
    [anon_sym_move] = ACTIONS(305),
    [anon_sym_ref] = ACTIONS(307),
    [sym_identifier] = ACTIONS(309),
    [sym_super] = ACTIONS(311),
    [sym_line_comment] = ACTIONS(3),
  },
  [232] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(486),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(259),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [233] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(788),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [234] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(848),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [235] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(850),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [236] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(853),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [237] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(861),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [238] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(913),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [239] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(914),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [240] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(921),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [241] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(867),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [242] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(909),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [243] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(925),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [244] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(894),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [245] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(896),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [246] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(898),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [247] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(899),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [248] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(900),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
  [249] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(872),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [250] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1496),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(649),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(875),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(146),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(327),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(323),
    [anon_sym_STAR] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(325),
    [anon_sym_i8] = ACTIONS(325),
    [anon_sym_u16] = ACTIONS(325),
    [anon_sym_i16] = ACTIONS(325),
    [anon_sym_u32] = ACTIONS(325),
    [anon_sym_i32] = ACTIONS(325),
    [anon_sym_u64] = ACTIONS(325),
    [anon_sym_i64] = ACTIONS(325),
    [anon_sym_u128] = ACTIONS(325),
    [anon_sym_i128] = ACTIONS(325),
    [anon_sym_usize] = ACTIONS(325),
    [anon_sym_bool] = ACTIONS(325),
    [anon_sym_ByteArray] = ACTIONS(325),
    [anon_sym_felt252] = ACTIONS(325),
    [anon_sym_DASH] = ACTIONS(772),
    [anon_sym_TILDE] = ACTIONS(327),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(327),
    [anon_sym_DOT_DOT] = ACTIONS(774),
    [anon_sym_break] = ACTIONS(329),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(331),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(333),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(335),
    [anon_sym_ref] = ACTIONS(337),
    [sym_identifier] = ACTIONS(339),
    [sym_super] = ACTIONS(341),
    [sym_line_comment] = ACTIONS(3),
  },
  [251] = {
    [sym_macro_invocation] = STATE(515),
    [sym_generic_type_with_turbofish] = STATE(1494),
    [sym__literal] = STATE(498),
    [sym_negative_literal] = STATE(516),
    [sym_string_literal] = STATE(516),
    [sym_boolean_literal] = STATE(516),
    [sym_scoped_identifier] = STATE(484),
    [sym_scoped_type_identifier_in_expression_position] = STATE(1622),
    [sym_expression] = STATE(901),
    [sym_expression_except_range] = STATE(478),
    [sym_generic_function] = STATE(498),
    [sym_tuple_expression] = STATE(498),
    [sym_return_expression] = STATE(498),
    [sym_struct_expression] = STATE(498),
    [sym_assignment_expression] = STATE(498),
    [sym_break_expression] = STATE(498),
    [sym_continue_expression] = STATE(498),
    [sym_index_expression] = STATE(498),
    [sym_array_expression] = STATE(498),
    [sym_parenthesized_expression] = STATE(498),
    [sym_unit_expression] = STATE(498),
    [sym_compound_assignment_expr] = STATE(498),
    [sym__expression_ending_with_block] = STATE(498),
    [sym_unary_expression] = STATE(498),
    [sym_range_expression] = STATE(504),
    [sym_try_expression] = STATE(498),
    [sym_field_expression] = STATE(477),
    [sym_block] = STATE(498),
    [sym_if_expression] = STATE(498),
    [sym_match_expression] = STATE(498),
    [sym_while_expression] = STATE(498),
    [sym_closure_expression] = STATE(498),
    [sym_closure_parameters] = STATE(143),
    [sym_for_expression] = STATE(498),
    [sym_loop_expression] = STATE(498),
    [sym_binary_expression] = STATE(498),
    [sym_call_expression] = STATE(498),
    [sym_reference_expression] = STATE(498),
    [anon_sym_LBRACE] = ACTIONS(7),
    [anon_sym_BANG] = ACTIONS(19),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_COLON_COLON] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(19),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_u8] = ACTIONS(41),
    [anon_sym_i8] = ACTIONS(41),
    [anon_sym_u16] = ACTIONS(41),
    [anon_sym_i16] = ACTIONS(41),
    [anon_sym_u32] = ACTIONS(41),
    [anon_sym_i32] = ACTIONS(41),
    [anon_sym_u64] = ACTIONS(41),
    [anon_sym_i64] = ACTIONS(41),
    [anon_sym_u128] = ACTIONS(41),
    [anon_sym_i128] = ACTIONS(41),
    [anon_sym_usize] = ACTIONS(41),
    [anon_sym_bool] = ACTIONS(41),
    [anon_sym_ByteArray] = ACTIONS(41),
    [anon_sym_felt252] = ACTIONS(41),
    [anon_sym_DASH] = ACTIONS(43),
    [anon_sym_TILDE] = ACTIONS(19),
    [anon_sym_PIPE] = ACTIONS(45),
    [anon_sym_AT] = ACTIONS(19),
    [anon_sym_DOT_DOT] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(49),
    [anon_sym_continue] = ACTIONS(51),
    [anon_sym_default] = ACTIONS(53),
    [anon_sym_if] = ACTIONS(249),
    [anon_sym_loop] = ACTIONS(59),
    [anon_sym_match] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(65),
    [anon_sym_while] = ACTIONS(67),
    [anon_sym_for] = ACTIONS(69),
    [sym_numeric_literal] = ACTIONS(71),
    [aux_sym_string_literal_token1] = ACTIONS(73),
    [sym_shortstring_literal] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_move] = ACTIONS(79),
    [anon_sym_ref] = ACTIONS(81),
    [sym_identifier] = ACTIONS(83),
    [sym_super] = ACTIONS(85),
    [sym_line_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1071), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(924), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(926), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [91] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1075), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(930), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(932), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [182] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1075), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(934), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(936), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [273] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(714), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(716), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [344] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1075), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(938), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(940), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [435] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(746), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(748), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [506] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(740), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(742), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [577] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(542), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [648] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(750), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(752), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [719] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(544), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(546), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [790] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(756), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
    ACTIONS(758), 40,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_EQ,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_STAR,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [861] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(746), 19,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(748), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [930] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(740), 19,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(742), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [999] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(756), 19,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_GT,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(758), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1068] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(942), 1,
      anon_sym_else,
    STATE(369), 1,
      sym_else_clause,
    ACTIONS(764), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(766), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [1139] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(944), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(946), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1206] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(948), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(950), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1273] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(952), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(954), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1340] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(956), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(958), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1407] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(960), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(962), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1474] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(964), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(966), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1541] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(968), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(970), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1608] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(972), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(974), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1675] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(976), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(978), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1742] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(980), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(982), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1809] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(984), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(986), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1876] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(988), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(990), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [1943] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(992), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(994), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2010] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(996), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(998), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2077] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1000), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1002), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2144] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1004), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1006), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2211] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1008), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1010), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2278] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1012), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1014), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2345] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1016), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1018), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2412] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1020), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1022), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2479] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1024), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1026), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2546] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1028), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1030), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2613] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1032), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1034), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2680] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1036), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1038), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2747] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1040), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1042), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2814] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1044), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1046), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2881] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1048), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1050), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [2948] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1052), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1054), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3015] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1056), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1058), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3082] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1060), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1062), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3149] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1064), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1066), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3216] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1068), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1070), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3283] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1072), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1074), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3350] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1076), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1078), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3417] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1080), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1082), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3484] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1084), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1086), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3551] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1088), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1090), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3618] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1092), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1094), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3685] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1096), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1098), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3752] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1100), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1102), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3819] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1104), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1106), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3886] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1108), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1110), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [3953] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1112), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1114), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4020] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1116), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1118), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4087] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1120), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1122), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4154] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1124), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1126), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4221] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1128), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1130), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4288] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1132), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1134), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4355] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1136), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1138), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4422] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1140), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1142), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4489] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1144), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1146), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4556] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1148), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1150), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4623] = 35,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1152), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1156), 1,
      anon_sym_COMMA,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1162), 1,
      anon_sym__,
    ACTIONS(1164), 1,
      anon_sym_RPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    STATE(379), 1,
      sym_attribute_item,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1353), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [4754] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1192), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1194), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4821] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1196), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1198), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4888] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1200), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1202), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [4955] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1204), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1206), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5022] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1208), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1210), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5089] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1212), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1214), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5156] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1218), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5223] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1220), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1222), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5290] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1224), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1226), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5357] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1228), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1230), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5424] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1232), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1234), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5491] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1236), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1238), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5558] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1240), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1242), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5625] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1244), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1246), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5692] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1248), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1250), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5759] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1252), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1254), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5826] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1256), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1258), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5893] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1260), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1262), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [5960] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1264), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1266), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6027] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1268), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1270), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6094] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1272), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1274), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6161] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1276), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1278), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6228] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1280), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1282), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6295] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1284), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1286), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6362] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1288), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1290), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6429] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1292), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1294), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6496] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1296), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1298), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6563] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1300), 17,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1302), 42,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_extern,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_pub,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [6630] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1152), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1304), 1,
      anon_sym__,
    ACTIONS(1306), 1,
      anon_sym_RPAREN,
    STATE(380), 1,
      sym_attribute_item,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1594), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [6758] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1152), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1304), 1,
      anon_sym__,
    ACTIONS(1308), 1,
      anon_sym_RPAREN,
    STATE(380), 1,
      sym_attribute_item,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1594), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [6886] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(746), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(748), 34,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_else,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [6952] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(740), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(742), 34,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_else,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [7018] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(756), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(758), 34,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_else,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [7084] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(31), 1,
      anon_sym_fn,
    ACTIONS(57), 1,
      anon_sym_extern,
    ACTIONS(63), 1,
      anon_sym_pub,
    ACTIONS(1310), 1,
      anon_sym_RBRACE,
    ACTIONS(1312), 1,
      anon_sym_impl,
    ACTIONS(1314), 1,
      anon_sym_SEMI,
    ACTIONS(1316), 1,
      anon_sym_trait,
    ACTIONS(1318), 1,
      anon_sym_type,
    ACTIONS(1320), 1,
      anon_sym_const,
    ACTIONS(1322), 1,
      anon_sym_POUND,
    ACTIONS(1324), 1,
      anon_sym_mod,
    ACTIONS(1326), 1,
      anon_sym_struct,
    ACTIONS(1328), 1,
      anon_sym_enum,
    ACTIONS(1330), 1,
      anon_sym_let,
    ACTIONS(1332), 1,
      anon_sym_use,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1338), 1,
      anon_sym_default,
    ACTIONS(1340), 1,
      sym_identifier,
    STATE(641), 1,
      sym_extern_type,
    STATE(987), 1,
      sym_visibility_modifier,
    STATE(1290), 1,
      sym_extern,
    STATE(1351), 1,
      sym_function,
    STATE(1658), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1336), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
    STATE(355), 19,
      sym_impl_item,
      sym_trait_item,
      sym_associated_type,
      sym_associated_impl,
      sym_const_item,
      sym_macro_invocation,
      sym_empty_statement,
      sym_attribute_item,
      sym_inner_attribute_item,
      sym_mod_item,
      sym_struct_item,
      sym_enum_item,
      sym_type_item,
      sym_external_function_item,
      sym_function_item,
      sym_function_signature_item,
      sym_let_declaration,
      sym_use_declaration,
      aux_sym_declaration_list_repeat1,
  [7198] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1342), 1,
      anon_sym_RBRACE,
    ACTIONS(1344), 1,
      anon_sym_impl,
    ACTIONS(1347), 1,
      anon_sym_SEMI,
    ACTIONS(1350), 1,
      anon_sym_trait,
    ACTIONS(1353), 1,
      anon_sym_type,
    ACTIONS(1356), 1,
      anon_sym_const,
    ACTIONS(1359), 1,
      anon_sym_POUND,
    ACTIONS(1362), 1,
      anon_sym_mod,
    ACTIONS(1365), 1,
      anon_sym_struct,
    ACTIONS(1368), 1,
      anon_sym_enum,
    ACTIONS(1371), 1,
      anon_sym_fn,
    ACTIONS(1374), 1,
      anon_sym_let,
    ACTIONS(1377), 1,
      anon_sym_use,
    ACTIONS(1380), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1386), 1,
      anon_sym_default,
    ACTIONS(1389), 1,
      anon_sym_extern,
    ACTIONS(1392), 1,
      anon_sym_pub,
    ACTIONS(1395), 1,
      sym_identifier,
    STATE(641), 1,
      sym_extern_type,
    STATE(987), 1,
      sym_visibility_modifier,
    STATE(1290), 1,
      sym_extern,
    STATE(1351), 1,
      sym_function,
    STATE(1658), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1383), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
    STATE(354), 19,
      sym_impl_item,
      sym_trait_item,
      sym_associated_type,
      sym_associated_impl,
      sym_const_item,
      sym_macro_invocation,
      sym_empty_statement,
      sym_attribute_item,
      sym_inner_attribute_item,
      sym_mod_item,
      sym_struct_item,
      sym_enum_item,
      sym_type_item,
      sym_external_function_item,
      sym_function_item,
      sym_function_signature_item,
      sym_let_declaration,
      sym_use_declaration,
      aux_sym_declaration_list_repeat1,
  [7312] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(31), 1,
      anon_sym_fn,
    ACTIONS(57), 1,
      anon_sym_extern,
    ACTIONS(63), 1,
      anon_sym_pub,
    ACTIONS(1312), 1,
      anon_sym_impl,
    ACTIONS(1314), 1,
      anon_sym_SEMI,
    ACTIONS(1316), 1,
      anon_sym_trait,
    ACTIONS(1318), 1,
      anon_sym_type,
    ACTIONS(1320), 1,
      anon_sym_const,
    ACTIONS(1322), 1,
      anon_sym_POUND,
    ACTIONS(1324), 1,
      anon_sym_mod,
    ACTIONS(1326), 1,
      anon_sym_struct,
    ACTIONS(1328), 1,
      anon_sym_enum,
    ACTIONS(1330), 1,
      anon_sym_let,
    ACTIONS(1332), 1,
      anon_sym_use,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1338), 1,
      anon_sym_default,
    ACTIONS(1340), 1,
      sym_identifier,
    ACTIONS(1398), 1,
      anon_sym_RBRACE,
    STATE(641), 1,
      sym_extern_type,
    STATE(987), 1,
      sym_visibility_modifier,
    STATE(1290), 1,
      sym_extern,
    STATE(1351), 1,
      sym_function,
    STATE(1658), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1336), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
    STATE(354), 19,
      sym_impl_item,
      sym_trait_item,
      sym_associated_type,
      sym_associated_impl,
      sym_const_item,
      sym_macro_invocation,
      sym_empty_statement,
      sym_attribute_item,
      sym_inner_attribute_item,
      sym_mod_item,
      sym_struct_item,
      sym_enum_item,
      sym_type_item,
      sym_external_function_item,
      sym_function_item,
      sym_function_signature_item,
      sym_let_declaration,
      sym_use_declaration,
      aux_sym_declaration_list_repeat1,
  [7426] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(31), 1,
      anon_sym_fn,
    ACTIONS(57), 1,
      anon_sym_extern,
    ACTIONS(63), 1,
      anon_sym_pub,
    ACTIONS(1312), 1,
      anon_sym_impl,
    ACTIONS(1314), 1,
      anon_sym_SEMI,
    ACTIONS(1316), 1,
      anon_sym_trait,
    ACTIONS(1318), 1,
      anon_sym_type,
    ACTIONS(1320), 1,
      anon_sym_const,
    ACTIONS(1322), 1,
      anon_sym_POUND,
    ACTIONS(1324), 1,
      anon_sym_mod,
    ACTIONS(1326), 1,
      anon_sym_struct,
    ACTIONS(1328), 1,
      anon_sym_enum,
    ACTIONS(1330), 1,
      anon_sym_let,
    ACTIONS(1332), 1,
      anon_sym_use,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1338), 1,
      anon_sym_default,
    ACTIONS(1340), 1,
      sym_identifier,
    ACTIONS(1400), 1,
      anon_sym_RBRACE,
    STATE(641), 1,
      sym_extern_type,
    STATE(987), 1,
      sym_visibility_modifier,
    STATE(1290), 1,
      sym_extern,
    STATE(1351), 1,
      sym_function,
    STATE(1658), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1336), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
    STATE(358), 19,
      sym_impl_item,
      sym_trait_item,
      sym_associated_type,
      sym_associated_impl,
      sym_const_item,
      sym_macro_invocation,
      sym_empty_statement,
      sym_attribute_item,
      sym_inner_attribute_item,
      sym_mod_item,
      sym_struct_item,
      sym_enum_item,
      sym_type_item,
      sym_external_function_item,
      sym_function_item,
      sym_function_signature_item,
      sym_let_declaration,
      sym_use_declaration,
      aux_sym_declaration_list_repeat1,
  [7540] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1152), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1304), 1,
      anon_sym__,
    ACTIONS(1402), 1,
      anon_sym_RPAREN,
    STATE(380), 1,
      sym_attribute_item,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1594), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [7668] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(31), 1,
      anon_sym_fn,
    ACTIONS(57), 1,
      anon_sym_extern,
    ACTIONS(63), 1,
      anon_sym_pub,
    ACTIONS(1312), 1,
      anon_sym_impl,
    ACTIONS(1314), 1,
      anon_sym_SEMI,
    ACTIONS(1316), 1,
      anon_sym_trait,
    ACTIONS(1318), 1,
      anon_sym_type,
    ACTIONS(1320), 1,
      anon_sym_const,
    ACTIONS(1322), 1,
      anon_sym_POUND,
    ACTIONS(1324), 1,
      anon_sym_mod,
    ACTIONS(1326), 1,
      anon_sym_struct,
    ACTIONS(1328), 1,
      anon_sym_enum,
    ACTIONS(1330), 1,
      anon_sym_let,
    ACTIONS(1332), 1,
      anon_sym_use,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1338), 1,
      anon_sym_default,
    ACTIONS(1340), 1,
      sym_identifier,
    ACTIONS(1404), 1,
      anon_sym_RBRACE,
    STATE(641), 1,
      sym_extern_type,
    STATE(987), 1,
      sym_visibility_modifier,
    STATE(1290), 1,
      sym_extern,
    STATE(1351), 1,
      sym_function,
    STATE(1658), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1336), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
    STATE(354), 19,
      sym_impl_item,
      sym_trait_item,
      sym_associated_type,
      sym_associated_impl,
      sym_const_item,
      sym_macro_invocation,
      sym_empty_statement,
      sym_attribute_item,
      sym_inner_attribute_item,
      sym_mod_item,
      sym_struct_item,
      sym_enum_item,
      sym_type_item,
      sym_external_function_item,
      sym_function_item,
      sym_function_signature_item,
      sym_let_declaration,
      sym_use_declaration,
      aux_sym_declaration_list_repeat1,
  [7782] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1406), 6,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(898), 9,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(900), 18,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
    ACTIONS(1408), 24,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [7851] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(756), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(758), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [7916] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1410), 1,
      anon_sym_COMMA,
    ACTIONS(1412), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1414), 1,
      anon_sym_LPAREN,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1418), 1,
      anon_sym_RPAREN,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1424), 1,
      anon_sym_default,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1428), 1,
      sym_identifier,
    ACTIONS(1430), 1,
      sym_super,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1095), 1,
      sym_scoped_identifier,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1217), 1,
      sym__pattern,
    STATE(1316), 1,
      sym_generic_type_with_turbofish,
    STATE(1350), 1,
      sym__type,
    STATE(1434), 1,
      sym_closure_expression,
    STATE(1537), 1,
      sym_macro_invocation,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1420), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [8043] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1410), 1,
      anon_sym_COMMA,
    ACTIONS(1412), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1414), 1,
      anon_sym_LPAREN,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1424), 1,
      anon_sym_default,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1428), 1,
      sym_identifier,
    ACTIONS(1430), 1,
      sym_super,
    ACTIONS(1432), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1095), 1,
      sym_scoped_identifier,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1217), 1,
      sym__pattern,
    STATE(1316), 1,
      sym_generic_type_with_turbofish,
    STATE(1350), 1,
      sym__type,
    STATE(1434), 1,
      sym_closure_expression,
    STATE(1537), 1,
      sym_macro_invocation,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1420), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [8170] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1434), 6,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(898), 9,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(900), 18,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
    ACTIONS(1436), 24,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8239] = 33,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1152), 1,
      anon_sym_POUND,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1304), 1,
      anon_sym__,
    STATE(380), 1,
      sym_attribute_item,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1594), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [8364] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1410), 1,
      anon_sym_COMMA,
    ACTIONS(1412), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1414), 1,
      anon_sym_LPAREN,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1424), 1,
      anon_sym_default,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1428), 1,
      sym_identifier,
    ACTIONS(1430), 1,
      sym_super,
    ACTIONS(1438), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1095), 1,
      sym_scoped_identifier,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1217), 1,
      sym__pattern,
    STATE(1316), 1,
      sym_generic_type_with_turbofish,
    STATE(1350), 1,
      sym__type,
    STATE(1434), 1,
      sym_closure_expression,
    STATE(1537), 1,
      sym_macro_invocation,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1420), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [8491] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(746), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(748), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8556] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(732), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(734), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8621] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(736), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(738), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8686] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(692), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(694), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8751] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(698), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(700), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8816] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(722), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(724), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8881] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(710), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(712), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [8946] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(718), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(720), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [9011] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(728), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(730), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [9076] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(740), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(742), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [9141] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(760), 24,
      anon_sym_RBRACE,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(762), 33,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [9206] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1440), 1,
      anon_sym_RBRACE,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1769), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(383), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9325] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    ACTIONS(1474), 1,
      anon_sym_RBRACE,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1808), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(382), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9444] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1476), 1,
      anon_sym__,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1477), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9563] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1174), 1,
      anon_sym_default,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1186), 1,
      sym_identifier,
    ACTIONS(1188), 1,
      sym_mutable_specifier,
    ACTIONS(1190), 1,
      sym_super,
    ACTIONS(1478), 1,
      anon_sym__,
    STATE(445), 1,
      sym_ref_specifier,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1137), 1,
      sym_scoped_identifier,
    STATE(1297), 1,
      sym_macro_invocation,
    STATE(1318), 1,
      sym_generic_type_with_turbofish,
    STATE(1565), 1,
      sym__pattern,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1591), 2,
      sym_parameter,
      sym__type,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1166), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9682] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    ACTIONS(1480), 1,
      anon_sym_RBRACE,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1818), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(384), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9801] = 30,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1823), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(386), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [9917] = 30,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1784), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(386), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10033] = 30,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1839), 1,
      sym_last_match_arm,
    STATE(1843), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(386), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(387), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10149] = 31,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1154), 1,
      anon_sym_LBRACK,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1482), 1,
      anon_sym_RBRACK,
    ACTIONS(1484), 1,
      anon_sym_COMMA,
    ACTIONS(1486), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1488), 1,
      anon_sym_LPAREN,
    ACTIONS(1492), 1,
      anon_sym_default,
    ACTIONS(1494), 1,
      sym_identifier,
    ACTIONS(1496), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1100), 1,
      sym_scoped_type_identifier,
    STATE(1111), 1,
      sym_scoped_identifier,
    STATE(1192), 1,
      sym_generic_type_with_turbofish,
    STATE(1199), 1,
      sym__pattern,
    STATE(1204), 1,
      sym_macro_invocation,
    STATE(1713), 1,
      sym__type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 4,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    STATE(1069), 7,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1490), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10267] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1498), 1,
      anon_sym_POUND,
    ACTIONS(1501), 1,
      anon_sym_LBRACK,
    ACTIONS(1504), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1507), 1,
      anon_sym_LPAREN,
    ACTIONS(1510), 1,
      anon_sym__,
    ACTIONS(1516), 1,
      anon_sym_DASH,
    ACTIONS(1519), 1,
      anon_sym_PIPE,
    ACTIONS(1522), 1,
      anon_sym_default,
    ACTIONS(1525), 1,
      sym_numeric_literal,
    ACTIONS(1528), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1531), 1,
      sym_shortstring_literal,
    ACTIONS(1537), 1,
      sym_identifier,
    ACTIONS(1540), 1,
      sym_mutable_specifier,
    ACTIONS(1543), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1754), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1534), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(386), 2,
      sym_match_arm,
      aux_sym_match_block_repeat1,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(388), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1513), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10380] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1834), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(582), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10489] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1442), 1,
      anon_sym_POUND,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1330), 1,
      sym__pattern,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1787), 1,
      sym_match_pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(582), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10598] = 30,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1548), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1554), 1,
      anon_sym_RPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1324), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1374), 1,
      sym_closure_expression,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10711] = 30,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1410), 1,
      anon_sym_COMMA,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1564), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1217), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1434), 1,
      sym_closure_expression,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10824] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1566), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1487), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1673), 1,
      sym_closure_expression,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [10934] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1568), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1487), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1673), 1,
      sym_closure_expression,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11044] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1570), 1,
      anon_sym_COMMA,
    ACTIONS(1572), 1,
      anon_sym_PIPE,
    ACTIONS(1574), 1,
      sym_mutable_specifier,
    STATE(428), 1,
      sym_ref_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1145), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1443), 1,
      sym_parameter,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11154] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1576), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1487), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1673), 1,
      sym_closure_expression,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11264] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1570), 1,
      anon_sym_COMMA,
    ACTIONS(1572), 1,
      anon_sym_PIPE,
    ACTIONS(1574), 1,
      sym_mutable_specifier,
    STATE(428), 1,
      sym_ref_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1313), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1443), 1,
      sym_parameter,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11374] = 29,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1578), 1,
      anon_sym_RPAREN,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1487), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1673), 1,
      sym_closure_expression,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11484] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1574), 1,
      sym_mutable_specifier,
    STATE(428), 1,
      sym_ref_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1512), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1695), 1,
      sym_parameter,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11591] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1574), 1,
      sym_mutable_specifier,
    ACTIONS(1580), 1,
      anon_sym_PIPE,
    STATE(428), 1,
      sym_ref_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1512), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1695), 1,
      sym_parameter,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11698] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1422), 1,
      anon_sym_PIPE,
    ACTIONS(1426), 1,
      anon_sym_move,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(159), 1,
      sym_closure_parameters,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1487), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1673), 1,
      sym_closure_expression,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11805] = 28,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1184), 1,
      anon_sym_ref,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1574), 1,
      sym_mutable_specifier,
    ACTIONS(1582), 1,
      anon_sym_PIPE,
    STATE(428), 1,
      sym_ref_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1512), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1695), 1,
      sym_parameter,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [11912] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(603), 1,
      anon_sym_POUND,
    STATE(401), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    ACTIONS(609), 15,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1584), 31,
      anon_sym_COLON,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [11973] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1586), 1,
      anon_sym_COMMA,
    ACTIONS(1588), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1265), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12077] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1590), 1,
      anon_sym_RBRACK,
    ACTIONS(1592), 1,
      anon_sym_COMMA,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1322), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12181] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1594), 1,
      anon_sym_COMMA,
    ACTIONS(1596), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1273), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12285] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1482), 1,
      anon_sym_RBRACK,
    ACTIONS(1484), 1,
      anon_sym_COMMA,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1199), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12389] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1598), 1,
      anon_sym_COMMA,
    ACTIONS(1600), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1212), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12493] = 27,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1602), 1,
      anon_sym_COMMA,
    ACTIONS(1604), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1213), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12597] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1606), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12698] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1608), 1,
      anon_sym_RBRACK,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12799] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 16,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1218), 31,
      anon_sym_COLON,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [12854] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1610), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [12955] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1612), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13056] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1614), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13157] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1616), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13258] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1618), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13359] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1620), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13460] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1622), 1,
      anon_sym_RBRACK,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13561] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1624), 1,
      anon_sym_RBRACK,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13662] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1626), 1,
      anon_sym_RPAREN,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13763] = 26,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1628), 1,
      anon_sym_RBRACK,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13864] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1738), 1,
      sym__pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [13962] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1733), 1,
      sym__pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14060] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1610), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14158] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1595), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14256] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1075), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14354] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1046), 1,
      sym__pattern,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14452] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1279), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14550] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1577), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14648] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1075), 1,
      sym__pattern,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14746] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1046), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14844] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1509), 1,
      sym__pattern,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [14942] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1527), 1,
      sym__pattern,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15040] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1071), 1,
      sym__pattern,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15138] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1071), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15236] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1522), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15334] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1642), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1232), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15432] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1281), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15530] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1219), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15628] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1472), 1,
      sym__pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15726] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    ACTIONS(1644), 1,
      sym_mutable_specifier,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1298), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15824] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1196), 1,
      sym__pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [15922] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1671), 1,
      sym__pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16020] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1444), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1448), 1,
      anon_sym_LPAREN,
    ACTIONS(1450), 1,
      anon_sym__,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1456), 1,
      anon_sym_PIPE,
    ACTIONS(1458), 1,
      anon_sym_default,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1468), 1,
      sym_identifier,
    ACTIONS(1470), 1,
      sym_mutable_specifier,
    ACTIONS(1472), 1,
      sym_super,
    STATE(1102), 1,
      sym_scoped_identifier,
    STATE(1229), 1,
      sym__literal_pattern,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1500), 1,
      sym_scoped_type_identifier,
    STATE(1501), 1,
      sym__pattern,
    STATE(1683), 1,
      sym_generic_type_with_turbofish,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1409), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1452), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16118] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_PIPE,
    ACTIONS(1634), 1,
      anon_sym_default,
    ACTIONS(1636), 1,
      sym_identifier,
    ACTIONS(1638), 1,
      sym_mutable_specifier,
    ACTIONS(1640), 1,
      sym_super,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1113), 1,
      sym_scoped_identifier,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1359), 1,
      sym__literal_pattern,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1731), 1,
      sym__pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1630), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16216] = 25,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(928), 1,
      sym_mutable_specifier,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1170), 1,
      anon_sym_PIPE,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1416), 1,
      anon_sym__,
    ACTIONS(1546), 1,
      anon_sym_LBRACK,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1552), 1,
      anon_sym_LPAREN,
    ACTIONS(1558), 1,
      anon_sym_default,
    ACTIONS(1560), 1,
      sym_identifier,
    ACTIONS(1562), 1,
      sym_super,
    STATE(990), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1030), 1,
      sym__literal_pattern,
    STATE(1344), 1,
      sym_scoped_type_identifier,
    STATE(1623), 1,
      sym_generic_type_with_turbofish,
    STATE(1734), 1,
      sym__pattern,
    STATE(1858), 1,
      sym_generic_type,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1069), 8,
      sym_macro_invocation,
      sym_tuple_pattern,
      sym_range_pattern,
      sym_slice_pattern,
      sym_struct_pattern,
      sym_mut_pattern,
      sym_or_pattern,
      sym_tuple_enum_pattern,
    ACTIONS(1556), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16314] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(930), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(932), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [16367] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(924), 13,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_DASH_GT,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(926), 32,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_DASH,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [16420] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1656), 1,
      anon_sym_GT,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16512] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1670), 1,
      anon_sym_GT,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16604] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1672), 1,
      anon_sym_GT,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16696] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1674), 1,
      anon_sym_GT,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16788] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1676), 1,
      anon_sym_GT,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16880] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1678), 1,
      anon_sym_GT,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [16972] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(811), 14,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_STAR,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_AT,
      anon_sym_DOT_DOT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1680), 30,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_default,
      anon_sym_if,
      anon_sym_loop,
      anon_sym_match,
      anon_sym_return,
      anon_sym_while,
      anon_sym_for,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_move,
      anon_sym_ref,
      sym_identifier,
      sym_super,
  [17024] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1453), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [17113] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(1691), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [17202] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1398), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [17291] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1662), 1,
      sym_numeric_literal,
    ACTIONS(1664), 1,
      sym_shortstring_literal,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1458), 3,
      sym__type,
      sym__literal,
      sym_block,
    STATE(1637), 3,
      sym_negative_literal,
      sym_string_literal,
      sym_boolean_literal,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [17380] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1682), 1,
      anon_sym_LBRACE,
    ACTIONS(1684), 1,
      anon_sym_BANG,
    ACTIONS(1686), 1,
      anon_sym_COLON_COLON,
    STATE(524), 1,
      sym_field_initializer_list,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17434] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1688), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17480] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1694), 1,
      anon_sym_COLON,
    ACTIONS(1698), 1,
      anon_sym_default,
    ACTIONS(1700), 1,
      sym_identifier,
    STATE(1017), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1055), 1,
      sym__literal_pattern,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(1692), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
    ACTIONS(1696), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [17554] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1702), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17600] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1706), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17646] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1710), 26,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17692] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1716), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1714), 27,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_nopanic,
  [17738] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1720), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1718), 27,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_nopanic,
  [17784] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1724), 1,
      anon_sym_COLON,
    ACTIONS(1728), 1,
      anon_sym_default,
    ACTIONS(1730), 1,
      sym_identifier,
    STATE(1006), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1053), 1,
      sym__literal_pattern,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(1722), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
    ACTIONS(1726), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [17858] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1734), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1732), 27,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_nopanic,
  [17904] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1736), 1,
      anon_sym_LBRACE,
    ACTIONS(1708), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1706), 24,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17951] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1738), 1,
      anon_sym_LBRACE,
    ACTIONS(1690), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1688), 24,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [17998] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1740), 1,
      anon_sym_LBRACE,
    ACTIONS(1704), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1702), 24,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18045] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1742), 1,
      anon_sym_else,
    STATE(106), 1,
      sym_else_clause,
    ACTIONS(766), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(764), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18094] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1744), 1,
      anon_sym_LBRACE,
    ACTIONS(1712), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1710), 24,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18141] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1750), 1,
      anon_sym_BANG,
    ACTIONS(1752), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1748), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1746), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18189] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(742), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(740), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_else,
  [18233] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1754), 2,
      anon_sym_LBRACE,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18279] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1760), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18325] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1766), 1,
      anon_sym_LPAREN,
    STATE(499), 1,
      sym_arguments,
    ACTIONS(1764), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1762), 23,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18373] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1768), 2,
      anon_sym_LBRACE,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18419] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1772), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1770), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18463] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(748), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(746), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_else,
  [18507] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1682), 1,
      anon_sym_LBRACE,
    ACTIONS(1684), 1,
      anon_sym_BANG,
    ACTIONS(1686), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1774), 1,
      anon_sym_COLON,
    STATE(524), 1,
      sym_field_initializer_list,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 20,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18561] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1778), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1776), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18605] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1684), 1,
      anon_sym_BANG,
    ACTIONS(1780), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18653] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(756), 25,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
      anon_sym_else,
  [18697] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1784), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1782), 22,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [18746] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1794), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1792), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18789] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1798), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1796), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18832] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1802), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1800), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18875] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1806), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1804), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [18918] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1120), 1,
      sym__type,
    STATE(1569), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1808), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [18991] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1820), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1818), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19034] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1824), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1822), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19077] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1115), 1,
      sym__type,
    STATE(1712), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1826), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [19150] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1830), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1828), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19193] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1834), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1832), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19236] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1138), 1,
      sym__type,
    STATE(1617), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1836), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [19309] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19352] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1840), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1838), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19395] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1844), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1842), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19438] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1848), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1846), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19481] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1852), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1850), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19524] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1856), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1854), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19567] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1764), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1762), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19610] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1860), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1858), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19653] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1864), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1862), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19696] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1868), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1866), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19739] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1122), 1,
      sym__type,
    STATE(1688), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1870), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [19812] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1874), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1872), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19855] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(538), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(536), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19898] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1878), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1876), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19941] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1882), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1880), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [19984] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1886), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1884), 22,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [20033] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1890), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1888), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20076] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20119] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(530), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(528), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20162] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1894), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1892), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20205] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1896), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20248] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 22,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [20297] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1906), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1904), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20340] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1910), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1908), 22,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [20389] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1912), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 23,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20434] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1916), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1914), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20477] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1920), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1918), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20520] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1135), 1,
      sym__type,
    STATE(1667), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1922), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [20593] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20636] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1116), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(1735), 1,
      sym_nopanic,
    ACTIONS(1924), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [20709] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1928), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1926), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20752] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1933), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1930), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20795] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1938), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1936), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20838] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1942), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1940), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20881] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(534), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(532), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20924] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1946), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1944), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [20967] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1134), 1,
      sym__type,
    STATE(1654), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1948), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [21040] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1952), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1950), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [21083] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1814), 1,
      anon_sym_nopanic,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1130), 1,
      sym__type,
    STATE(1564), 1,
      sym_nopanic,
    STATE(1714), 1,
      sym_scoped_identifier,
    ACTIONS(1954), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [21156] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1958), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1956), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [21199] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1962), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1960), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [21242] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1966), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1964), 24,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [21285] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1968), 1,
      anon_sym_LBRACE,
    ACTIONS(1970), 1,
      anon_sym_BANG,
    ACTIONS(1972), 1,
      anon_sym_COLON_COLON,
    STATE(771), 1,
      sym_field_initializer_list,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [21335] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1976), 1,
      anon_sym_EQ,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1974), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [21405] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(263), 1,
      anon_sym_EQ,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(261), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [21473] = 12,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1902), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1900), 18,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21533] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 7,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 21,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21583] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 19,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21639] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 19,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21693] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 18,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21751] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 14,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [21815] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 13,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [21881] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 21,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [21933] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2002), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2000), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [22003] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2006), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2004), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [22071] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2010), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2008), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [22141] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(1876), 6,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [22213] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2018), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2016), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [22283] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1998), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
    ACTIONS(1842), 6,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
  [22355] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1072), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1074), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22396] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1032), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1034), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22437] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1036), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1038), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22478] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1040), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1042), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22519] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1044), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1046), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22560] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1048), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1050), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22601] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1744), 1,
      anon_sym_LBRACE,
    ACTIONS(1712), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1710), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [22644] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1052), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1054), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22685] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1056), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1058), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22726] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1060), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1062), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22767] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1064), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1066), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22808] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1196), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1198), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22849] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1068), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1070), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22890] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1212), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1214), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22931] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1008), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1010), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [22972] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1084), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1086), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23013] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1088), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1090), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23054] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1092), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1094), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23095] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1096), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1098), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23136] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1220), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1222), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23177] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1724), 1,
      anon_sym_if,
    ACTIONS(2020), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2024), 1,
      anon_sym_default,
    ACTIONS(2026), 1,
      sym_identifier,
    STATE(1216), 1,
      sym_scoped_identifier,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1540), 1,
      sym__literal_pattern,
    STATE(1859), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1722), 2,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(2022), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [23246] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    ACTIONS(1460), 1,
      sym_numeric_literal,
    ACTIONS(1462), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1464), 1,
      sym_shortstring_literal,
    ACTIONS(1694), 1,
      anon_sym_if,
    ACTIONS(2020), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2030), 1,
      anon_sym_default,
    ACTIONS(2032), 1,
      sym_identifier,
    STATE(1230), 1,
      sym_negative_literal,
    STATE(1233), 1,
      sym_scoped_identifier,
    STATE(1464), 1,
      sym__literal_pattern,
    STATE(1859), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1466), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1692), 2,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
    STATE(1228), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(2028), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [23315] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1736), 1,
      anon_sym_LBRACE,
    ACTIONS(1708), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1706), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [23358] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1224), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1226), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23399] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1740), 1,
      anon_sym_LBRACE,
    ACTIONS(1704), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1702), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [23442] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2034), 1,
      anon_sym_POUND,
    STATE(582), 3,
      sym_attribute_item,
      sym_inner_attribute_item,
      aux_sym_match_arm_repeat1,
    ACTIONS(2037), 7,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2039), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [23487] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1228), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1230), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23528] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1236), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1238), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23569] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1244), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1246), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23610] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1738), 1,
      anon_sym_LBRACE,
    ACTIONS(1690), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1688), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [23653] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1100), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1102), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23694] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1252), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1254), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23735] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1104), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1106), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23776] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1256), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1258), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23817] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1108), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1110), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23858] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1300), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1302), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23899] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1124), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1126), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23940] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1132), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1134), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [23981] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1144), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1146), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24022] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1148), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1150), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24063] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1260), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1262), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24104] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1264), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1266), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24145] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1268), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1270), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24186] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1276), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1278), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24227] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1012), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1014), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24268] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1112), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1114), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24309] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(964), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(966), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24350] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1120), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1122), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24391] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1128), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1130), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24432] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1136), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1138), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24473] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1140), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1142), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24514] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(944), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(946), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24555] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(948), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(950), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24596] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(952), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(954), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24637] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(956), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(958), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24678] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(960), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(962), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24719] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(968), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(970), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24760] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(972), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(974), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24801] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(976), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(978), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24842] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(980), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(982), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24883] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1218), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24924] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(984), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(986), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [24965] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(988), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(990), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25006] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1192), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1194), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25047] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1076), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1078), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25088] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(992), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(994), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25129] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1016), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1018), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25170] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1200), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1202), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25211] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1232), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1234), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25252] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1240), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1242), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25293] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1248), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1250), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25334] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1284), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1286), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25375] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1288), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1290), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25416] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1292), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1294), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25457] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1296), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1298), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25498] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1684), 1,
      anon_sym_BANG,
    ACTIONS(2041), 1,
      anon_sym_COLON_COLON,
    STATE(524), 1,
      sym_field_initializer_list,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [25545] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1116), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1118), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25586] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1204), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1206), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25627] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1020), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1022), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25668] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(996), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(998), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25709] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1000), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1002), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25750] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1004), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1006), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25791] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1208), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1210), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25832] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1024), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1026), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25873] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1080), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1082), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25914] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1028), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1030), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25955] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1280), 4,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
    ACTIONS(1282), 29,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_let,
      anon_sym_use,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      anon_sym_extern,
      anon_sym_pub,
      sym_identifier,
      sym_super,
  [25996] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2053), 1,
      anon_sym_GT,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [26062] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1750), 1,
      anon_sym_BANG,
    ACTIONS(2061), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1748), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1746), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26106] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2063), 1,
      anon_sym_RPAREN,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1350), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [26172] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1692), 1,
      anon_sym_PIPE,
    ACTIONS(1694), 1,
      anon_sym_in,
    ACTIONS(1698), 1,
      anon_sym_default,
    ACTIONS(1700), 1,
      sym_identifier,
    STATE(1017), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1055), 1,
      sym__literal_pattern,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(1696), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [26240] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1716), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1714), 21,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [26280] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1684), 1,
      anon_sym_BANG,
    ACTIONS(2069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26324] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(690), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2071), 1,
      anon_sym_SEMI,
    ACTIONS(2073), 1,
      anon_sym_COMMA,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    STATE(1391), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [26400] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1720), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1718), 21,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [26440] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1710), 20,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26480] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(744), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2077), 1,
      anon_sym_SEMI,
    ACTIONS(2079), 1,
      anon_sym_COMMA,
    STATE(1470), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [26556] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1706), 20,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26596] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1702), 20,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26636] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2081), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [26702] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2083), 1,
      anon_sym_BANG,
    ACTIONS(2085), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1748), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1746), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [26746] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1688), 20,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [26786] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    ACTIONS(2087), 1,
      anon_sym_RPAREN,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [26852] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1168), 1,
      anon_sym_DASH,
    ACTIONS(1176), 1,
      sym_numeric_literal,
    ACTIONS(1178), 1,
      aux_sym_string_literal_token1,
    ACTIONS(1180), 1,
      sym_shortstring_literal,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1722), 1,
      anon_sym_PIPE,
    ACTIONS(1724), 1,
      anon_sym_in,
    ACTIONS(1728), 1,
      anon_sym_default,
    ACTIONS(1730), 1,
      sym_identifier,
    STATE(1006), 1,
      sym_scoped_identifier,
    STATE(1026), 1,
      sym_negative_literal,
    STATE(1053), 1,
      sym__literal_pattern,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(1182), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(1007), 2,
      sym_string_literal,
      sym_boolean_literal,
    ACTIONS(1726), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [26920] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1710), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [26960] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1411), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [27026] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2091), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [27092] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2093), 1,
      anon_sym_else,
    STATE(805), 1,
      sym_else_clause,
    ACTIONS(766), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(764), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27136] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2095), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [27202] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1706), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27242] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1702), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27282] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2097), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [27348] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 12,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1688), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27388] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2099), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [27454] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    ACTIONS(2101), 1,
      anon_sym_RPAREN,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [27520] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    ACTIONS(2103), 1,
      anon_sym_GT,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [27586] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    ACTIONS(2105), 1,
      anon_sym_RPAREN,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [27652] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1754), 2,
      anon_sym_LBRACE,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27694] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1734), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1732), 21,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27734] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(684), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2107), 1,
      anon_sym_SEMI,
    ACTIONS(2109), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [27810] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    ACTIONS(2111), 1,
      anon_sym_RPAREN,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [27876] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1768), 2,
      anon_sym_LBRACE,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [27918] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(589), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2113), 1,
      anon_sym_SEMI,
    ACTIONS(2115), 1,
      anon_sym_COMMA,
    STATE(1371), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [27994] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1970), 1,
      anon_sym_BANG,
    ACTIONS(2117), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [28038] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(2121), 1,
      anon_sym_AT,
    ACTIONS(2123), 1,
      anon_sym_default,
    ACTIONS(2125), 1,
      sym_identifier,
    ACTIONS(2127), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1686), 1,
      sym__type,
    STATE(1710), 1,
      sym_generic_type_with_turbofish,
    STATE(1711), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2119), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28101] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1518), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28164] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1328), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28227] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1783), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28290] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1356), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28353] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1561), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28416] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2129), 1,
      sym_identifier,
    STATE(1375), 1,
      sym_generic_type,
    STATE(1376), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(933), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1641), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [28479] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1154), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28542] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(2121), 1,
      anon_sym_AT,
    ACTIONS(2123), 1,
      anon_sym_default,
    ACTIONS(2125), 1,
      sym_identifier,
    ACTIONS(2127), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1548), 1,
      sym__type,
    STATE(1710), 1,
      sym_generic_type_with_turbofish,
    STATE(1711), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2119), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28605] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1583), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28668] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28731] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2059), 1,
      sym_identifier,
    STATE(1379), 1,
      sym_generic_type,
    STATE(1428), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(687), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1729), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [28794] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2131), 1,
      anon_sym_COMMA,
    ACTIONS(2133), 1,
      anon_sym_RPAREN,
    STATE(1345), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [28867] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1713), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28930] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(2121), 1,
      anon_sym_AT,
    ACTIONS(2123), 1,
      anon_sym_default,
    ACTIONS(2125), 1,
      sym_identifier,
    ACTIONS(2127), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(994), 1,
      sym__type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1710), 1,
      sym_generic_type_with_turbofish,
    STATE(1711), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2119), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [28993] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2135), 1,
      anon_sym_RBRACE,
    ACTIONS(2137), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2139), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [29034] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2141), 1,
      anon_sym_LBRACK,
    ACTIONS(2143), 1,
      anon_sym_LPAREN,
    ACTIONS(2147), 1,
      anon_sym_AT,
    ACTIONS(2149), 1,
      anon_sym_default,
    ACTIONS(2151), 1,
      sym_identifier,
    ACTIONS(2153), 1,
      sym_super,
    STATE(1256), 1,
      sym_scoped_type_identifier,
    STATE(1438), 1,
      sym_generic_type,
    STATE(1441), 1,
      sym_generic_type_with_turbofish,
    STATE(1640), 1,
      sym_scoped_identifier,
    STATE(1646), 1,
      sym__type,
    STATE(1576), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2145), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29097] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2155), 1,
      anon_sym_RBRACE,
    ACTIONS(2157), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2159), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [29138] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2161), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [29179] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2163), 1,
      anon_sym_LPAREN,
    STATE(776), 1,
      sym_arguments,
    ACTIONS(1764), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1762), 18,
      anon_sym_LBRACK,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [29222] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2165), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [29263] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2167), 1,
      sym_identifier,
    STATE(1223), 1,
      sym_generic_type,
    STATE(1225), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(933), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1423), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [29326] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1430), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29389] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1838), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29452] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(2121), 1,
      anon_sym_AT,
    ACTIONS(2123), 1,
      anon_sym_default,
    ACTIONS(2125), 1,
      sym_identifier,
    ACTIONS(2127), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1705), 1,
      sym__type,
    STATE(1710), 1,
      sym_generic_type_with_turbofish,
    STATE(1711), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2119), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29515] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1754), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [29556] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1768), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [29597] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1772), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1770), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [29636] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1778), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1776), 20,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [29675] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1158), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2141), 1,
      anon_sym_LBRACK,
    ACTIONS(2143), 1,
      anon_sym_LPAREN,
    ACTIONS(2147), 1,
      anon_sym_AT,
    ACTIONS(2149), 1,
      anon_sym_default,
    ACTIONS(2151), 1,
      sym_identifier,
    ACTIONS(2153), 1,
      sym_super,
    STATE(1256), 1,
      sym_scoped_type_identifier,
    STATE(1438), 1,
      sym_generic_type,
    STATE(1441), 1,
      sym_generic_type_with_turbofish,
    STATE(1596), 1,
      sym__type,
    STATE(1640), 1,
      sym_scoped_identifier,
    STATE(1576), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2145), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29738] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(688), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2169), 1,
      anon_sym_COMMA,
    STATE(1459), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [29811] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1171), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29874] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1382), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [29937] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1842), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30000] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1758), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30063] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2043), 1,
      anon_sym_impl,
    ACTIONS(2045), 1,
      anon_sym_const,
    ACTIONS(2047), 1,
      anon_sym_POUND,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2171), 1,
      sym_identifier,
    STATE(1251), 1,
      sym_generic_type,
    STATE(1255), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2055), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(702), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1456), 2,
      sym_const_parameter,
      sym_constrained_type_parameter,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [30126] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(1694), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30189] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1442), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30252] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(1687), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30315] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(577), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(1348), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [30388] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(994), 1,
      sym__type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30451] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(742), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(740), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
      anon_sym_else,
  [30490] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(756), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
      anon_sym_else,
  [30529] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 8,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AT,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1218), 23,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      anon_sym_ref,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [30568] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1490), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30631] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1759), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30694] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(1726), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30757] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2175), 1,
      anon_sym_COMMA,
    ACTIONS(2177), 1,
      anon_sym_RPAREN,
    STATE(1408), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [30830] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(994), 1,
      sym__type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [30893] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(696), 1,
      anon_sym_RBRACK,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2179), 1,
      anon_sym_COMMA,
    STATE(1418), 1,
      aux_sym_array_expression_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [30966] = 20,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2181), 1,
      anon_sym_COMMA,
    STATE(1435), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [31039] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1156), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31102] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1573), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31165] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(1810), 1,
      anon_sym_AT,
    ACTIONS(1812), 1,
      anon_sym_default,
    ACTIONS(1816), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1169), 1,
      sym__type,
    STATE(1714), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31228] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2183), 1,
      anon_sym_COLON_COLON,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_QMARK,
  [31269] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(1644), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31332] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1387), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31395] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1821), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31458] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1822), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31521] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(1701), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31584] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1544), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31647] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1518), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31710] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1550), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(2121), 1,
      anon_sym_AT,
    ACTIONS(2123), 1,
      anon_sym_default,
    ACTIONS(2125), 1,
      sym_identifier,
    ACTIONS(2127), 1,
      sym_super,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1555), 1,
      sym__type,
    STATE(1710), 1,
      sym_generic_type_with_turbofish,
    STATE(1711), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(2119), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31773] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1558), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31836] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1415), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31899] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1820), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [31962] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1570), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32025] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1442), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32088] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1437), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32151] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1868), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32214] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1581), 1,
      sym__type,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32277] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1446), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32340] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(1799), 1,
      sym__type,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32403] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1172), 1,
      anon_sym_AT,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1668), 1,
      sym_super,
    ACTIONS(2065), 1,
      anon_sym_default,
    ACTIONS(2067), 1,
      sym_identifier,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(1028), 1,
      sym_scoped_type_identifier,
    STATE(1191), 1,
      sym__type,
    STATE(1690), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32466] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1648), 1,
      anon_sym_LBRACK,
    ACTIONS(1650), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1652), 1,
      anon_sym_LPAREN,
    ACTIONS(1658), 1,
      anon_sym_AT,
    ACTIONS(1660), 1,
      anon_sym_default,
    ACTIONS(1666), 1,
      sym_identifier,
    ACTIONS(1668), 1,
      sym_super,
    STATE(973), 1,
      sym_generic_type_with_turbofish,
    STATE(974), 1,
      sym_generic_type,
    STATE(994), 1,
      sym__type,
    STATE(1089), 1,
      sym_scoped_type_identifier,
    STATE(1621), 1,
      sym_scoped_identifier,
    STATE(983), 5,
      sym_macro_invocation,
      sym_array_type,
      sym_tuple_type,
      sym_unit_type,
      sym_snapshot_type,
    ACTIONS(1654), 14,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
  [32529] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(748), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(746), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
      anon_sym_else,
  [32568] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1842), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [32636] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2157), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2159), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [32674] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1860), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1858), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32712] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32750] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1764), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1762), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32788] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(900), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32826] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(1784), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1782), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [32870] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1946), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1944), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32908] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1933), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1930), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [32946] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(263), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(261), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [33010] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2010), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2008), 7,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_GT,
  [33076] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(762), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(760), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33114] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2018), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2016), 7,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_GT,
  [33180] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(1910), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1908), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [33224] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1920), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1918), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33262] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1864), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1862), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33300] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2213), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [33368] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2215), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [33436] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1820), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1818), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33474] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1840), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1838), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33512] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1844), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1842), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33550] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1842), 2,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [33618] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1962), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1960), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33656] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1802), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1800), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33694] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(734), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(732), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33732] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(738), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(736), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33770] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1878), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1876), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33808] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1876), 2,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [33876] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(1886), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1884), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [33920] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1890), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1888), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [33958] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2243), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [34026] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2245), 1,
      anon_sym_LBRACE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    STATE(120), 1,
      sym_match_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [34096] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1976), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1974), 7,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [34162] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 10,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [34206] = 12,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1902), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1900), 14,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34262] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 7,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 17,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34308] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 15,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34360] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 15,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34410] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 14,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34464] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 10,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [34524] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 9,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [34586] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 17,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
  [34634] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2002), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2000), 7,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [34700] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2006), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2004), 8,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [34764] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1916), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1914), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34802] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1758), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1756), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34840] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1806), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1804), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34878] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1898), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1896), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34916] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(694), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(692), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34954] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(700), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(698), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [34992] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1952), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1950), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35030] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1906), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1904), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35068] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1938), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1936), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35106] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1868), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1866), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35144] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2249), 1,
      anon_sym_RBRACE,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [35214] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1874), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1872), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35252] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1882), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1880), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35290] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2253), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [35358] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1894), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1892), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35396] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(712), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(710), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35434] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(720), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(718), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35472] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(724), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(722), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35510] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1942), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1940), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35548] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1958), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1956), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35586] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1834), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1832), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35624] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1794), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1792), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35662] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1798), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1796), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35700] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1824), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1822), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35738] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(730), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(728), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35776] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1848), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1846), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35814] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1852), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1850), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35852] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1928), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1926), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35890] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1830), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1828), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35928] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1856), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1854), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [35966] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(93), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [36036] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(876), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [36106] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1876), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [36174] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1976), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1974), 7,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_GT,
  [36240] = 12,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1902), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1900), 14,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36296] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 7,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36342] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 15,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36394] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 15,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36444] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 4,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PIPE,
    ACTIONS(1900), 14,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36498] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 10,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36558] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1902), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1900), 9,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36620] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1902), 5,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_PIPE,
    ACTIONS(1900), 17,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36668] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2002), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2000), 7,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_GT,
  [36734] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2006), 1,
      anon_sym_EQ,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2004), 8,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
  [36798] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1072), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1074), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [36836] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(530), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(528), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [36874] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2257), 1,
      anon_sym_EQ,
    ACTIONS(1842), 2,
      anon_sym_LPAREN,
      anon_sym_EQ_GT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2259), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [36942] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    STATE(117), 1,
      sym_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37012] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2211), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2257), 1,
      anon_sym_EQ,
    ACTIONS(1876), 2,
      anon_sym_LPAREN,
      anon_sym_EQ_GT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2259), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37080] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2261), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37148] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(534), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(532), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [37186] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(538), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(536), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [37224] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2263), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37292] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(1218), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [37330] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(2265), 1,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37400] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2267), 1,
      anon_sym_RBRACE,
    ACTIONS(2269), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37470] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(219), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37540] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2271), 1,
      anon_sym_COMMA,
    ACTIONS(2273), 1,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37610] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(263), 1,
      anon_sym_EQ,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(261), 8,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_DOT_DOT,
  [37674] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2010), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2008), 7,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37740] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2275), 1,
      anon_sym_LBRACE,
    STATE(781), 1,
      sym_match_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37810] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2018), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2241), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2016), 7,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37876] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2277), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [37946] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2279), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38014] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2281), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38082] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(878), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38152] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    STATE(818), 1,
      sym_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38222] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2283), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38290] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(880), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38360] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(2285), 1,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38430] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(223), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38500] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2287), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym_match_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38570] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2289), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38640] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2291), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38708] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(910), 1,
      anon_sym_LBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    STATE(371), 1,
      sym_block,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38778] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(227), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38848] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2293), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38918] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(231), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [38988] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2295), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39058] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(235), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39128] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2297), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39198] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(239), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39268] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2299), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39338] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(89), 1,
      anon_sym_RBRACE,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39408] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(2301), 1,
      anon_sym_RBRACE,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39478] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2303), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39546] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2305), 1,
      anon_sym_COMMA,
    ACTIONS(2307), 1,
      anon_sym_RPAREN,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39616] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2309), 1,
      anon_sym_RBRACE,
    ACTIONS(2311), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39686] = 19,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(788), 1,
      anon_sym_RPAREN,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39756] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2137), 8,
      anon_sym_POUND,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2139), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [39794] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1966), 11,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_DOT,
    ACTIONS(1964), 19,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_QMARK,
  [39832] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2313), 1,
      anon_sym_LBRACE,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39899] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2315), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [39966] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2317), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40033] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2319), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40100] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2321), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40167] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40234] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2323), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40301] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2325), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40368] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2327), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40435] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2329), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40502] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2257), 1,
      anon_sym_EQ,
    ACTIONS(2313), 1,
      anon_sym_EQ_GT,
    ACTIONS(2331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2259), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40569] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2333), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40636] = 12,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2337), 1,
      anon_sym_RBRACE,
    ACTIONS(2339), 1,
      anon_sym_COMMA,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1536), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [40691] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2351), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40758] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2353), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40825] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2355), 7,
      anon_sym_LBRACK,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_DASH,
      anon_sym_PIPE,
      aux_sym_string_literal_token1,
      sym_shortstring_literal,
    ACTIONS(2357), 22,
      anon_sym__,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_numeric_literal,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      sym_mutable_specifier,
      sym_super,
  [40862] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2359), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40929] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2361), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [40996] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2185), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_DOT,
    ACTIONS(2189), 1,
      anon_sym_QMARK,
    ACTIONS(2197), 1,
      anon_sym_CARET,
    ACTIONS(2199), 1,
      anon_sym_AMP,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2203), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2205), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2257), 1,
      anon_sym_EQ,
    ACTIONS(2331), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2363), 1,
      anon_sym_EQ_GT,
    ACTIONS(2193), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2195), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2207), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2191), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2209), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2259), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41063] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2365), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41130] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2367), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41197] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2369), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41264] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2371), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41331] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2373), 1,
      anon_sym_RBRACK,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41398] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2251), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41465] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(2217), 1,
      anon_sym_EQ,
    ACTIONS(2225), 1,
      anon_sym_CARET,
    ACTIONS(2227), 1,
      anon_sym_AMP,
    ACTIONS(2229), 1,
      anon_sym_PIPE,
    ACTIONS(2231), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2233), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2247), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2363), 1,
      anon_sym_LBRACE,
    ACTIONS(2221), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(2223), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2235), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2219), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2239), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2237), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41532] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2375), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41599] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2377), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41666] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2379), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41733] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2381), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41800] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2383), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41867] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2385), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [41934] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2387), 1,
      anon_sym_COMMA,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [42001] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1786), 1,
      anon_sym_LBRACK,
    ACTIONS(1788), 1,
      anon_sym_DOT,
    ACTIONS(1790), 1,
      anon_sym_QMARK,
    ACTIONS(1984), 1,
      anon_sym_CARET,
    ACTIONS(1986), 1,
      anon_sym_AMP,
    ACTIONS(1988), 1,
      anon_sym_PIPE,
    ACTIONS(1990), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1992), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2012), 1,
      anon_sym_EQ,
    ACTIONS(2075), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2389), 1,
      anon_sym_SEMI,
    ACTIONS(1980), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1994), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1978), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2014), 5,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
  [42068] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    ACTIONS(2391), 1,
      anon_sym_RBRACE,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1715), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42120] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    ACTIONS(2393), 1,
      anon_sym_RBRACE,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1715), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42172] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1715), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42221] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1892), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42270] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1813), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42319] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1850), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42368] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2341), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2343), 1,
      anon_sym_STAR,
    ACTIONS(2347), 1,
      anon_sym_default,
    ACTIONS(2349), 1,
      sym_identifier,
    STATE(1166), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    STATE(1793), 5,
      sym__use_clause,
      sym_scoped_use_list,
      sym_use_list,
      sym_use_as_clause,
      sym_use_wildcard,
    ACTIONS(2345), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42417] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2395), 1,
      anon_sym_POUND,
    STATE(933), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    ACTIONS(609), 3,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1584), 19,
      anon_sym_impl,
      anon_sym_const,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_identifier,
      sym_super,
  [42454] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 4,
      anon_sym_POUND,
      anon_sym_COLON_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1218), 19,
      anon_sym_impl,
      anon_sym_const,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      anon_sym_default,
      sym_identifier,
      sym_super,
  [42485] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2049), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2057), 1,
      anon_sym_default,
    ACTIONS(2398), 1,
      sym_identifier,
    STATE(1211), 1,
      sym_generic_type,
    STATE(1214), 1,
      sym_generic_type_with_turbofish,
    STATE(1627), 1,
      sym_scoped_type_identifier,
    STATE(1782), 1,
      sym_scoped_identifier,
    ACTIONS(2051), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42527] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1745), 1,
      sym_attribute,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42566] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1760), 1,
      sym_attribute,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42605] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1806), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42644] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1750), 1,
      sym_attribute,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42683] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1851), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42722] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1807), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42761] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1826), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42800] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1798), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42839] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1885), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42878] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    STATE(1878), 1,
      sym_attribute,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42917] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1334), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2402), 1,
      anon_sym_default,
    ACTIONS(2404), 1,
      sym_identifier,
    STATE(1094), 1,
      sym_scoped_identifier,
    STATE(1751), 1,
      sym_attribute,
    STATE(1789), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2400), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42956] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2406), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2410), 1,
      anon_sym_default,
    ACTIONS(2412), 1,
      sym_identifier,
    STATE(1685), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2408), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [42992] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2406), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2416), 1,
      anon_sym_default,
    ACTIONS(2418), 1,
      sym_identifier,
    STATE(1553), 1,
      sym_scoped_identifier,
    STATE(1900), 1,
      sym_generic_type_with_turbofish,
    ACTIONS(2414), 15,
      anon_sym_u8,
      anon_sym_i8,
      anon_sym_u16,
      anon_sym_i16,
      anon_sym_u32,
      anon_sym_i32,
      anon_sym_u64,
      anon_sym_i64,
      anon_sym_u128,
      anon_sym_i128,
      anon_sym_usize,
      anon_sym_bool,
      anon_sym_ByteArray,
      anon_sym_felt252,
      sym_super,
  [43028] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1702), 2,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
    ACTIONS(2420), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_LT2,
  [43051] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1688), 2,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
    ACTIONS(2422), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_LT2,
  [43074] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 1,
      anon_sym_COLON,
    ACTIONS(1710), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43097] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 1,
      anon_sym_COLON,
    ACTIONS(2424), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(1706), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43122] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 1,
      anon_sym_COLON,
    ACTIONS(1702), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43145] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 1,
      anon_sym_COLON,
    ACTIONS(2420), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(1702), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43170] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 1,
      anon_sym_COLON,
    ACTIONS(2426), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(1710), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43195] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 1,
      anon_sym_COLON,
    ACTIONS(2422), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(1688), 12,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43220] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2428), 1,
      anon_sym_LBRACE,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2436), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2430), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [43257] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 1,
      anon_sym_COLON,
    ACTIONS(1706), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43280] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 1,
      anon_sym_COLON,
    ACTIONS(1688), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_BANG,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [43303] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1706), 2,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
    ACTIONS(2424), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_LT2,
  [43326] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1710), 2,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
    ACTIONS(2426), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_LT2,
  [43349] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2444), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43369] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(544), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_in,
  [43389] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(714), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_in,
  [43409] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(750), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_in,
  [43429] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1754), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43449] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_in,
  [43469] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1768), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43489] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2446), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43508] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2448), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43527] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2452), 1,
      anon_sym_COLON,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2456), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2458), 1,
      anon_sym_DOT_DOT,
    STATE(970), 1,
      sym_type_arguments,
    ACTIONS(2450), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [43558] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2462), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2460), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43579] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2466), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43600] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43621] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2470), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_COLON_COLON,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43640] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2424), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
      anon_sym_LT2,
  [43659] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2472), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43677] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2474), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43695] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2476), 1,
      anon_sym_impl,
    ACTIONS(2478), 1,
      anon_sym_trait,
    ACTIONS(2480), 1,
      anon_sym_type,
    ACTIONS(2482), 1,
      anon_sym_const,
    ACTIONS(2484), 1,
      anon_sym_mod,
    ACTIONS(2486), 1,
      anon_sym_struct,
    ACTIONS(2488), 1,
      anon_sym_enum,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(2492), 1,
      anon_sym_use,
    ACTIONS(2494), 1,
      anon_sym_extern,
    STATE(1319), 1,
      sym_extern,
    STATE(1520), 1,
      sym_function,
  [43735] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1690), 1,
      anon_sym_COLON,
    ACTIONS(1688), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
    ACTIONS(2422), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT2,
      sym_identifier,
  [43757] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2496), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43775] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1712), 1,
      anon_sym_COLON,
    ACTIONS(1710), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
    ACTIONS(2426), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT2,
      sym_identifier,
  [43797] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2464), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43815] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2498), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43833] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2500), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [43851] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2502), 1,
      anon_sym_RBRACK,
    ACTIONS(2424), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_LT2,
    ACTIONS(1706), 8,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [43873] = 13,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(2494), 1,
      anon_sym_extern,
    ACTIONS(2505), 1,
      anon_sym_impl,
    ACTIONS(2507), 1,
      anon_sym_trait,
    ACTIONS(2509), 1,
      anon_sym_type,
    ACTIONS(2511), 1,
      anon_sym_const,
    ACTIONS(2513), 1,
      anon_sym_mod,
    ACTIONS(2515), 1,
      anon_sym_struct,
    ACTIONS(2517), 1,
      anon_sym_enum,
    ACTIONS(2519), 1,
      anon_sym_use,
    STATE(1294), 1,
      sym_extern,
    STATE(1368), 1,
      sym_function,
  [43913] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1704), 1,
      anon_sym_COLON,
    ACTIONS(1702), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
    ACTIONS(2420), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT2,
      sym_identifier,
  [43935] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2521), 1,
      anon_sym_RBRACK,
    ACTIONS(2420), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_LT2,
    ACTIONS(1702), 8,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [43957] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2524), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [43985] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2526), 1,
      anon_sym_RBRACK,
    ACTIONS(2422), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_LT2,
    ACTIONS(1688), 8,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [44007] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1708), 1,
      anon_sym_COLON,
    ACTIONS(1706), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
    ACTIONS(2424), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT2,
      sym_identifier,
  [44029] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2529), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [44047] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2531), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_nopanic,
  [44065] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2533), 1,
      anon_sym_RBRACK,
    ACTIONS(2426), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_LT2,
    ACTIONS(1710), 8,
      anon_sym_BANG,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [44087] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(532), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [44104] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2428), 1,
      anon_sym_LBRACE,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2536), 1,
      anon_sym_SEMI,
    ACTIONS(2538), 1,
      anon_sym_RBRACK,
    ACTIONS(2541), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2430), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [44139] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2543), 1,
      anon_sym_RBRACE,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2547), 1,
      anon_sym_COMMA,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1523), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44170] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2428), 1,
      anon_sym_LBRACE,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2555), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2536), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44205] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(559), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [44222] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(536), 11,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [44239] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2559), 1,
      anon_sym_LPAREN,
    ACTIONS(2557), 10,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_use,
      anon_sym_extern,
  [44258] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    ACTIONS(2561), 1,
      anon_sym_RBRACE,
    ACTIONS(2563), 1,
      anon_sym_COMMA,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1380), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44289] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2565), 10,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_use,
      anon_sym_extern,
  [44305] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2569), 1,
      anon_sym_COLON,
    ACTIONS(2571), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44325] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2569), 1,
      anon_sym_COLON,
    ACTIONS(2573), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44345] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2575), 10,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [44361] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2571), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2579), 1,
      anon_sym_COLON,
    ACTIONS(2577), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44381] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2583), 1,
      anon_sym_COLON,
    ACTIONS(2585), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2581), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44401] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2587), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2536), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_PIPE,
  [44425] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 7,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [44447] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2579), 1,
      anon_sym_COLON,
    ACTIONS(2593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2577), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44467] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2595), 1,
      anon_sym_RBRACE,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2599), 1,
      anon_sym_COMMA,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    STATE(1332), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1080), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [44499] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2605), 1,
      anon_sym_RBRACE,
    ACTIONS(2607), 1,
      anon_sym_COMMA,
    STATE(1393), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1090), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [44531] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    ACTIONS(2609), 1,
      anon_sym_RBRACE,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1716), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44559] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2611), 1,
      anon_sym_LBRACE,
    ACTIONS(2613), 1,
      anon_sym_BANG,
    ACTIONS(2615), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2617), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_DOT_DOT,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2430), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [44589] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2573), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2579), 1,
      anon_sym_COLON,
    ACTIONS(2577), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44609] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2428), 1,
      anon_sym_LBRACE,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2621), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2538), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44641] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2623), 1,
      anon_sym_BANG,
    ACTIONS(2625), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2536), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [44665] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2585), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON,
    ACTIONS(2627), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44685] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2569), 1,
      anon_sym_COLON,
    ACTIONS(2593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44705] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    ACTIONS(2631), 1,
      anon_sym_RBRACE,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1716), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44733] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2633), 10,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_use,
      anon_sym_extern,
  [44749] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2635), 10,
      anon_sym_impl,
      anon_sym_trait,
      anon_sym_type,
      anon_sym_const,
      anon_sym_mod,
      anon_sym_struct,
      anon_sym_enum,
      anon_sym_fn,
      anon_sym_use,
      anon_sym_extern,
  [44765] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    ACTIONS(2637), 1,
      anon_sym_RBRACE,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1716), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44793] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2575), 10,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_in,
  [44809] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    ACTIONS(2639), 1,
      anon_sym_RBRACE,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1716), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44837] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(975), 1,
      sym_type_arguments,
    ACTIONS(2464), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_RPAREN,
      anon_sym_nopanic,
  [44857] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2641), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44872] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2430), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [44889] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2643), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44904] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1732), 9,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      sym_identifier,
  [44919] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2645), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [44948] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2647), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [44963] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2549), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2551), 1,
      sym_numeric_literal,
    ACTIONS(2553), 1,
      sym_identifier,
    STATE(1184), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
    STATE(1716), 3,
      sym_shorthand_field_initializer,
      sym_field_initializer,
      sym_base_field_initializer,
  [44988] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1714), 9,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      sym_identifier,
  [45003] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1718), 9,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_COLON_COLON,
      anon_sym_GT,
      anon_sym_PIPE,
      sym_identifier,
  [45018] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2649), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45033] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2651), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45062] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2653), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45091] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2655), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45106] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2657), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45121] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2659), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45136] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2428), 1,
      anon_sym_LBRACE,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2436), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2661), 1,
      anon_sym_DOT_DOT,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2430), 2,
      anon_sym_PIPE,
      anon_sym_in,
  [45165] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2663), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45180] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2665), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45195] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2420), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(2521), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1702), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
  [45214] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2426), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(2533), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1710), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
  [45233] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2667), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45248] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2669), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45263] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2671), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45278] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2673), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45293] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2567), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45308] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2675), 1,
      anon_sym_RBRACE,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(2679), 1,
      sym_identifier,
    STATE(1358), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1099), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45337] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2577), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45352] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2681), 1,
      anon_sym_RBRACE,
    ACTIONS(2683), 1,
      anon_sym_COMMA,
    STATE(1392), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1107), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45381] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2685), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45396] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2687), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45425] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2689), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45440] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2691), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45455] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2693), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45470] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2695), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45485] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2697), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45500] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2699), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45515] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2701), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45530] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2703), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45545] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2625), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2536), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_implicits,
      anon_sym_nopanic,
  [45568] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2705), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45583] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45598] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2707), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45627] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2709), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45642] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2422), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(2526), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1688), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
  [45661] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2424), 2,
      anon_sym_LBRACE,
      anon_sym_LT2,
    ACTIONS(2502), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1706), 5,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
  [45680] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2711), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45695] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2713), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45710] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    ACTIONS(2715), 1,
      anon_sym_RBRACE,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45739] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2717), 9,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
      anon_sym_in,
  [45754] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    STATE(1586), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45780] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2458), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2719), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
    ACTIONS(2450), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [45804] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    STATE(1469), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45830] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2721), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45856] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    STATE(1554), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1078), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45882] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2723), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45908] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2725), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45934] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2727), 1,
      anon_sym_BANG,
    ACTIONS(2729), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2731), 1,
      anon_sym_DOT_DOT,
    STATE(970), 1,
      sym_type_arguments,
    ACTIONS(2450), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [45958] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2733), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [45984] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2735), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46010] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    ACTIONS(2737), 1,
      anon_sym_RBRACE,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46036] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    STATE(975), 1,
      sym_type_arguments,
    ACTIONS(2464), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_PIPE,
  [46054] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2603), 1,
      sym_identifier,
    STATE(1422), 1,
      sym_enum_variant,
    STATE(1709), 1,
      sym_field_declaration,
    STATE(1852), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46080] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2458), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2739), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
    ACTIONS(2450), 3,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [46104] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2456), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2741), 1,
      anon_sym_DOT_DOT,
    STATE(970), 1,
      sym_type_arguments,
    ACTIONS(2450), 2,
      anon_sym_PIPE,
      anon_sym_in,
  [46127] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2743), 1,
      anon_sym_STAR,
    STATE(968), 1,
      sym_type_arguments,
    STATE(1481), 1,
      sym_use_list,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [46150] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2573), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2749), 1,
      anon_sym_EQ,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_RBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    STATE(1809), 1,
      sym_delim_token_tree,
  [46175] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2757), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [46196] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2743), 1,
      anon_sym_STAR,
    STATE(966), 1,
      sym_type_arguments,
    STATE(1481), 1,
      sym_use_list,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [46219] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    STATE(1571), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46242] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    STATE(1666), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1097), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46265] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    STATE(1465), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46288] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2759), 1,
      anon_sym_LBRACE,
    STATE(975), 1,
      sym_type_arguments,
    ACTIONS(2464), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [46307] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1710), 7,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [46320] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2613), 1,
      anon_sym_BANG,
    ACTIONS(2617), 1,
      anon_sym_LPAREN,
    ACTIONS(2619), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2761), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [46341] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1706), 7,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [46354] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1702), 7,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [46367] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2450), 1,
      anon_sym_PIPE,
    ACTIONS(2452), 1,
      anon_sym_COLON,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2458), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2763), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
  [46392] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1688), 7,
      anon_sym_BANG,
      anon_sym_COLON_COLON,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [46405] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2597), 1,
      anon_sym_POUND,
    ACTIONS(2601), 1,
      anon_sym_pub,
    ACTIONS(2679), 1,
      sym_identifier,
    STATE(1420), 1,
      sym_field_declaration,
    STATE(1743), 1,
      sym_visibility_modifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [46428] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2571), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2749), 1,
      anon_sym_EQ,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_RBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    STATE(1809), 1,
      sym_delim_token_tree,
  [46453] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2765), 1,
      anon_sym_STAR,
    STATE(962), 1,
      sym_type_arguments,
    STATE(1484), 1,
      sym_use_list,
    ACTIONS(2767), 2,
      sym_identifier,
      sym_super,
  [46476] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2585), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    ACTIONS(2769), 1,
      anon_sym_EQ,
    ACTIONS(2771), 1,
      anon_sym_RBRACK,
    STATE(1815), 1,
      sym_delim_token_tree,
  [46501] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2773), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 3,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [46522] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2749), 1,
      anon_sym_EQ,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2753), 1,
      anon_sym_RBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    STATE(1809), 1,
      sym_delim_token_tree,
  [46547] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2524), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2661), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2430), 2,
      anon_sym_PIPE,
      anon_sym_in,
  [46567] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2775), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2460), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [46587] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1127), 1,
      aux_sym_function_repeat1,
    STATE(1543), 1,
      sym_nopanic,
    ACTIONS(2777), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46607] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1121), 1,
      aux_sym_function_repeat1,
    STATE(1651), 1,
      sym_nopanic,
    ACTIONS(2783), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46627] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2460), 1,
      anon_sym_SEMI,
    ACTIONS(2785), 1,
      anon_sym_RBRACK,
    ACTIONS(2788), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [46647] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1697), 1,
      sym_nopanic,
    ACTIONS(2790), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46667] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1703), 1,
      sym_nopanic,
    ACTIONS(2792), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46687] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1123), 1,
      aux_sym_function_repeat1,
    STATE(1706), 1,
      sym_nopanic,
    ACTIONS(2794), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46707] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1720), 1,
      sym_nopanic,
    ACTIONS(2796), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46727] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1124), 1,
      aux_sym_function_repeat1,
    STATE(1730), 1,
      sym_nopanic,
    ACTIONS(2798), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46747] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1556), 1,
      sym_nopanic,
    ACTIONS(2800), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46767] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1566), 1,
      sym_nopanic,
    ACTIONS(2802), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46787] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2806), 1,
      anon_sym_DASH_GT,
    ACTIONS(2808), 1,
      anon_sym_implicits,
    STATE(1664), 1,
      sym_nopanic,
    ACTIONS(2804), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46807] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2812), 1,
      anon_sym_DASH_GT,
    ACTIONS(2814), 1,
      anon_sym_implicits,
    STATE(1684), 1,
      sym_nopanic,
    ACTIONS(2810), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46827] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1742), 1,
      sym_nopanic,
    ACTIONS(2816), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46847] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2818), 1,
      anon_sym_LBRACK,
    ACTIONS(2822), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2820), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [46867] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2822), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2824), 1,
      anon_sym_COMMA,
    ACTIONS(2826), 1,
      anon_sym_GT,
    STATE(969), 1,
      sym_type_arguments,
    STATE(1489), 1,
      aux_sym_type_parameters_repeat1,
  [46889] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1118), 1,
      aux_sym_function_repeat1,
    STATE(1692), 1,
      sym_nopanic,
    ACTIONS(2828), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46909] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2832), 1,
      anon_sym_DASH_GT,
    ACTIONS(2834), 1,
      anon_sym_implicits,
    STATE(1585), 1,
      sym_nopanic,
    ACTIONS(2830), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46929] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2822), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2836), 1,
      anon_sym_COMMA,
    ACTIONS(2838), 1,
      anon_sym_GT,
    STATE(969), 1,
      sym_type_arguments,
    STATE(1403), 1,
      aux_sym_type_parameters_repeat1,
  [46951] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1625), 1,
      sym_nopanic,
    ACTIONS(2840), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46971] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1133), 1,
      aux_sym_function_repeat1,
    STATE(1632), 1,
      sym_nopanic,
    ACTIONS(2842), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [46991] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1139), 1,
      aux_sym_function_repeat1,
    STATE(1634), 1,
      sym_nopanic,
    ACTIONS(2844), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47011] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2848), 1,
      anon_sym_DASH_GT,
    ACTIONS(2850), 1,
      anon_sym_implicits,
    STATE(1588), 1,
      sym_nopanic,
    ACTIONS(2846), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47031] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(2432), 1,
      anon_sym_COLON,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2852), 1,
      anon_sym_COLON_COLON,
  [47053] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1119), 1,
      aux_sym_function_repeat1,
    STATE(1562), 1,
      sym_nopanic,
    ACTIONS(2854), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47073] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2779), 1,
      anon_sym_COMMA,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    STATE(1575), 1,
      sym_nopanic,
    ACTIONS(2856), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47093] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2858), 1,
      anon_sym_BANG,
    ACTIONS(2860), 1,
      anon_sym_COLON_COLON,
    STATE(1511), 1,
      sym_type_arguments,
    ACTIONS(2536), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [47113] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2864), 1,
      anon_sym_COMMA,
    STATE(1141), 1,
      aux_sym_function_repeat1,
    ACTIONS(2862), 3,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_nopanic,
  [47128] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2867), 1,
      anon_sym_RBRACE,
    ACTIONS(2869), 1,
      anon_sym_COMMA,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    STATE(1399), 1,
      sym_field_pattern,
  [47147] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(2875), 1,
      anon_sym_RBRACE,
    ACTIONS(2877), 1,
      anon_sym_COMMA,
    STATE(1400), 1,
      sym_field_pattern,
  [47166] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2879), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47177] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2713), 1,
      anon_sym_RPAREN,
    ACTIONS(2881), 1,
      anon_sym_COLON,
    ACTIONS(2883), 1,
      anon_sym_COMMA,
    ACTIONS(2885), 1,
      anon_sym_PIPE,
    STATE(1531), 1,
      aux_sym_closure_parameters_repeat1,
  [47196] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(2889), 1,
      anon_sym_SEMI,
    ACTIONS(2891), 1,
      anon_sym_LT,
    STATE(284), 1,
      sym_declaration_list,
    STATE(1357), 1,
      sym_type_parameters,
  [47215] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(2895), 1,
      anon_sym_SEMI,
    STATE(601), 1,
      sym_declaration_list,
    STATE(1412), 1,
      sym_type_parameters,
  [47234] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2897), 1,
      anon_sym_LBRACE,
    ACTIONS(2899), 1,
      anon_sym_SEMI,
    STATE(642), 1,
      sym_field_declaration_list,
    STATE(1413), 1,
      sym_type_parameters,
  [47253] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2901), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
      anon_sym_implicits,
      anon_sym_nopanic,
  [47264] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2905), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2907), 1,
      anon_sym_as,
    ACTIONS(2903), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [47279] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2909), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47290] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2911), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47301] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2619), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2913), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2430), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [47316] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2917), 1,
      anon_sym_implicits,
    STATE(1676), 1,
      sym_nopanic,
    ACTIONS(2915), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47333] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2919), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47344] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2923), 1,
      anon_sym_implicits,
    STATE(1740), 1,
      sym_nopanic,
    ACTIONS(2921), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47361] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2925), 1,
      anon_sym_LBRACE,
    ACTIONS(2927), 1,
      anon_sym_SEMI,
    STATE(317), 1,
      sym_field_declaration_list,
    STATE(1354), 1,
      sym_type_parameters,
  [47380] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2929), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47391] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2933), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2935), 1,
      anon_sym_as,
    ACTIONS(2931), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [47406] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2937), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2785), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [47423] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2939), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
      anon_sym_implicits,
      anon_sym_nopanic,
  [47434] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2822), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2941), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47451] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2822), 1,
      anon_sym_COLON_COLON,
    STATE(969), 1,
      sym_type_arguments,
    ACTIONS(2943), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [47468] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(2945), 1,
      anon_sym_RBRACE,
    ACTIONS(2947), 1,
      anon_sym_COMMA,
    STATE(1460), 1,
      sym_field_pattern,
  [47487] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2949), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47498] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2935), 1,
      anon_sym_as,
    ACTIONS(2951), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2931), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [47513] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2953), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47524] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2955), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
      anon_sym_implicits,
      anon_sym_nopanic,
  [47535] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2959), 1,
      anon_sym_implicits,
    STATE(1631), 1,
      sym_nopanic,
    ACTIONS(2957), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47552] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1308), 1,
      anon_sym_RPAREN,
    ACTIONS(2961), 1,
      anon_sym_COMMA,
    STATE(1449), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(2430), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [47569] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2781), 1,
      anon_sym_nopanic,
    ACTIONS(2965), 1,
      anon_sym_implicits,
    STATE(1619), 1,
      sym_nopanic,
    ACTIONS(2963), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [47586] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2967), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47597] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(2969), 1,
      anon_sym_SEMI,
    STATE(589), 1,
      sym_declaration_list,
    STATE(1369), 1,
      sym_type_parameters,
  [47616] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2897), 1,
      anon_sym_LBRACE,
    ACTIONS(2971), 1,
      anon_sym_SEMI,
    STATE(595), 1,
      sym_field_declaration_list,
    STATE(1373), 1,
      sym_type_parameters,
  [47635] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2973), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
      anon_sym_implicits,
      anon_sym_nopanic,
  [47646] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2975), 1,
      anon_sym_POUND,
    ACTIONS(1584), 2,
      anon_sym_pub,
      sym_identifier,
    STATE(1176), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [47661] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    ACTIONS(2743), 1,
      anon_sym_STAR,
    STATE(1481), 1,
      sym_use_list,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [47678] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2925), 1,
      anon_sym_LBRACE,
    ACTIONS(2978), 1,
      anon_sym_SEMI,
    STATE(288), 1,
      sym_field_declaration_list,
    STATE(1370), 1,
      sym_type_parameters,
  [47697] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2935), 1,
      anon_sym_as,
    ACTIONS(2980), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2931), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [47712] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2982), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47723] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2984), 1,
      anon_sym_POUND,
    ACTIONS(1584), 2,
      sym_numeric_literal,
      sym_identifier,
    STATE(1181), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [47738] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(2987), 1,
      anon_sym_RBRACE,
    ACTIONS(2989), 1,
      anon_sym_COMMA,
    STATE(1476), 1,
      sym_field_pattern,
  [47757] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2991), 1,
      anon_sym_SEMI,
    STATE(307), 1,
      sym_declaration_list,
    STATE(1504), 1,
      sym_type_parameters,
  [47776] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2545), 1,
      anon_sym_POUND,
    ACTIONS(2993), 1,
      sym_numeric_literal,
    ACTIONS(2995), 1,
      sym_identifier,
    STATE(1181), 2,
      sym_attribute_item,
      aux_sym_enum_variant_list_repeat1,
  [47793] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2997), 5,
      anon_sym_LBRACE,
      anon_sym_of,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LPAREN,
  [47804] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2436), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2536), 1,
      anon_sym_LBRACE,
    ACTIONS(2623), 1,
      anon_sym_BANG,
    STATE(969), 1,
      sym_type_arguments,
  [47823] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(2999), 1,
      anon_sym_of,
    ACTIONS(3001), 1,
      anon_sym_COLON,
    ACTIONS(3003), 1,
      anon_sym_EQ,
    STATE(1635), 1,
      sym_type_parameters,
  [47842] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3005), 1,
      anon_sym_COMMA,
    ACTIONS(3007), 1,
      anon_sym_RPAREN,
    STATE(1475), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(2430), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [47859] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3009), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_DASH_GT,
      anon_sym_implicits,
      anon_sym_nopanic,
  [47870] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3011), 1,
      anon_sym_of,
    ACTIONS(3013), 1,
      anon_sym_COLON,
    ACTIONS(3015), 1,
      anon_sym_EQ,
    STATE(1732), 1,
      sym_type_parameters,
  [47889] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2862), 5,
      anon_sym_LBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_nopanic,
  [47900] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3017), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3019), 1,
      anon_sym_LPAREN,
    ACTIONS(2464), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [47914] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3021), 1,
      sym_identifier,
    ACTIONS(3023), 1,
      sym_super,
    STATE(962), 1,
      sym_type_arguments,
  [47930] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2474), 1,
      anon_sym_SEMI,
    ACTIONS(3025), 1,
      anon_sym_RBRACK,
    ACTIONS(2657), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [47944] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3028), 1,
      sym_identifier,
    ACTIONS(3030), 1,
      sym_super,
    STATE(966), 1,
      sym_type_arguments,
  [47960] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2665), 1,
      anon_sym_PIPE,
    ACTIONS(3032), 1,
      anon_sym_SEMI,
    ACTIONS(3034), 1,
      anon_sym_COLON,
    ACTIONS(3036), 1,
      anon_sym_EQ,
  [47976] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3028), 1,
      sym_identifier,
    ACTIONS(3030), 1,
      sym_super,
    STATE(968), 1,
      sym_type_arguments,
  [47992] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(3038), 1,
      anon_sym_type,
    ACTIONS(3040), 1,
      anon_sym_const,
    STATE(1788), 1,
      sym_function,
  [48008] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3042), 1,
      anon_sym_RBRACK,
    ACTIONS(3044), 1,
      anon_sym_COMMA,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    STATE(1388), 1,
      aux_sym_slice_pattern_repeat1,
  [48024] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3003), 1,
      anon_sym_EQ,
    ACTIONS(3048), 1,
      anon_sym_SEMI,
    STATE(1700), 1,
      sym_type_parameters,
  [48040] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3050), 1,
      anon_sym_LPAREN,
    STATE(1136), 1,
      sym_parameters,
    STATE(1679), 1,
      sym_type_parameters,
  [48056] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3052), 1,
      sym_identifier,
    STATE(479), 1,
      sym_type_arguments,
  [48072] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3054), 1,
      anon_sym_BANG,
    ACTIONS(3056), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
  [48088] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2464), 1,
      anon_sym_SEMI,
    ACTIONS(3058), 1,
      anon_sym_RBRACK,
    ACTIONS(2430), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [48102] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3061), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48114] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3063), 1,
      anon_sym_LBRACE,
    STATE(558), 1,
      sym_enum_variant_list,
    STATE(1560), 1,
      sym_type_parameters,
  [48130] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(962), 1,
      sym_type_arguments,
    ACTIONS(3065), 2,
      sym_identifier,
      sym_super,
  [48144] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(966), 1,
      sym_type_arguments,
    ACTIONS(3067), 2,
      sym_identifier,
      sym_super,
  [48158] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(968), 1,
      sym_type_arguments,
    ACTIONS(3067), 2,
      sym_identifier,
      sym_super,
  [48172] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2627), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48184] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3071), 1,
      anon_sym_LBRACK,
    ACTIONS(3073), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [48198] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3075), 1,
      anon_sym_COMMA,
    ACTIONS(3077), 1,
      anon_sym_RPAREN,
    STATE(1429), 1,
      aux_sym_slice_pattern_repeat1,
  [48214] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3079), 1,
      anon_sym_COMMA,
    ACTIONS(3081), 1,
      anon_sym_RPAREN,
    STATE(1431), 1,
      aux_sym_slice_pattern_repeat1,
  [48230] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3071), 1,
      anon_sym_LBRACK,
    ACTIONS(3083), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3073), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [48244] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3085), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48256] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3087), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2567), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48268] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3089), 1,
      anon_sym_COMMA,
    ACTIONS(3091), 1,
      anon_sym_RPAREN,
    STATE(1396), 1,
      aux_sym_tuple_pattern_repeat1,
  [48284] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(3093), 1,
      anon_sym_if,
    STATE(816), 2,
      sym_block,
      sym_if_expression,
  [48298] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3095), 1,
      anon_sym_COLON,
    ACTIONS(2665), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [48310] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3061), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2577), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48322] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3069), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2581), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48334] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(3097), 1,
      anon_sym_if,
    STATE(114), 2,
      sym_block,
      sym_if_expression,
  [48348] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2097), 1,
      anon_sym_GT,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3099), 1,
      anon_sym_COMMA,
    STATE(1492), 1,
      aux_sym_type_parameters_repeat1,
  [48364] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3101), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [48380] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2097), 1,
      anon_sym_GT,
    ACTIONS(3083), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3099), 1,
      anon_sym_COMMA,
    STATE(1492), 1,
      aux_sym_type_parameters_repeat1,
  [48396] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3085), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2577), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48408] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3103), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [48424] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2575), 4,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48434] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2619), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2430), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48446] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2575), 4,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48456] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(532), 4,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48466] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3105), 1,
      anon_sym_SEMI,
    ACTIONS(3107), 1,
      anon_sym_COLON,
    ACTIONS(3109), 1,
      anon_sym_EQ,
  [48482] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3087), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2577), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48494] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3111), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [48510] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3113), 1,
      anon_sym_LBRACE,
    STATE(318), 1,
      sym_enum_variant_list,
    STATE(1604), 1,
      sym_type_parameters,
  [48526] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3115), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [48542] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(3117), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [48554] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3119), 1,
      anon_sym_of,
    ACTIONS(3121), 1,
      anon_sym_EQ,
    STATE(1557), 1,
      sym_type_parameters,
  [48570] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(536), 4,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [48580] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3023), 1,
      sym_super,
    ACTIONS(3123), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [48596] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3127), 1,
      anon_sym_LBRACK,
    ACTIONS(3129), 1,
      anon_sym_LPAREN,
    STATE(255), 1,
      sym_delim_token_tree,
  [48612] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3131), 1,
      sym_identifier,
    ACTIONS(3133), 1,
      sym_super,
    STATE(962), 1,
      sym_type_arguments,
  [48628] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3052), 1,
      sym_identifier,
    STATE(476), 1,
      sym_type_arguments,
  [48644] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3125), 1,
      anon_sym_LBRACE,
    ACTIONS(3127), 1,
      anon_sym_LBRACK,
    ACTIONS(3129), 1,
      anon_sym_LPAREN,
    STATE(260), 1,
      sym_delim_token_tree,
  [48660] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3135), 1,
      anon_sym_LT2,
    ACTIONS(3137), 1,
      sym_identifier,
    ACTIONS(3139), 1,
      sym_super,
    STATE(674), 1,
      sym_type_arguments,
  [48676] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3135), 1,
      anon_sym_LT2,
    ACTIONS(3137), 1,
      sym_identifier,
    ACTIONS(3139), 1,
      sym_super,
    STATE(678), 1,
      sym_type_arguments,
  [48692] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2767), 1,
      sym_super,
    ACTIONS(3123), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [48708] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [48724] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [48740] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3143), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
  [48756] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3145), 1,
      anon_sym_COMMA,
    ACTIONS(3147), 1,
      anon_sym_GT,
    STATE(1417), 1,
      aux_sym_type_parameters_repeat1,
  [48772] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(3149), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [48784] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [48800] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(910), 1,
      anon_sym_LBRACE,
    ACTIONS(3151), 1,
      anon_sym_if,
    STATE(372), 2,
      sym_block,
      sym_if_expression,
  [48814] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3083), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3145), 1,
      anon_sym_COMMA,
    ACTIONS(3147), 1,
      anon_sym_GT,
    STATE(1417), 1,
      aux_sym_type_parameters_repeat1,
  [48830] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    STATE(1513), 1,
      sym_type_arguments,
    ACTIONS(2464), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [48844] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3153), 1,
      anon_sym_LBRACE,
    ACTIONS(3155), 1,
      anon_sym_LBRACK,
    ACTIONS(3157), 1,
      anon_sym_LPAREN,
    STATE(1333), 1,
      sym_delim_token_tree,
  [48860] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3153), 1,
      anon_sym_LBRACE,
    ACTIONS(3155), 1,
      anon_sym_LBRACK,
    ACTIONS(3157), 1,
      anon_sym_LPAREN,
    STATE(1334), 1,
      sym_delim_token_tree,
  [48876] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3023), 1,
      sym_super,
    ACTIONS(3159), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [48892] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3161), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [48908] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3161), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [48924] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3050), 1,
      anon_sym_LPAREN,
    STATE(1126), 1,
      sym_parameters,
    STATE(1660), 1,
      sym_type_parameters,
  [48940] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(962), 1,
      sym_type_arguments,
    ACTIONS(2767), 2,
      sym_identifier,
      sym_super,
  [48954] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    STATE(115), 1,
      sym_delim_token_tree,
  [48970] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3163), 1,
      anon_sym_COMMA,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
    STATE(1508), 1,
      aux_sym_slice_pattern_repeat1,
  [48986] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(966), 1,
      sym_type_arguments,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [49000] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2474), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(2657), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
  [49012] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3167), 1,
      anon_sym_LBRACE,
    ACTIONS(3169), 1,
      anon_sym_LBRACK,
    ACTIONS(3171), 1,
      anon_sym_LPAREN,
    STATE(1609), 1,
      sym_delim_token_tree,
  [49028] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3167), 1,
      anon_sym_LBRACE,
    ACTIONS(3169), 1,
      anon_sym_LBRACK,
    ACTIONS(3171), 1,
      anon_sym_LPAREN,
    STATE(1624), 1,
      sym_delim_token_tree,
  [49044] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3065), 1,
      sym_super,
    ACTIONS(3173), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [49060] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3067), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [49076] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3067), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [49092] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3177), 1,
      anon_sym_COMMA,
    ACTIONS(3179), 1,
      anon_sym_RPAREN,
    STATE(1515), 1,
      aux_sym_slice_pattern_repeat1,
  [49108] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(968), 1,
      sym_type_arguments,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [49122] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3015), 1,
      anon_sym_EQ,
    ACTIONS(3181), 1,
      anon_sym_SEMI,
    STATE(1612), 1,
      sym_type_parameters,
  [49138] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3023), 1,
      sym_super,
    ACTIONS(3173), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [49154] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [49170] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [49186] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2665), 1,
      anon_sym_PIPE,
    ACTIONS(3183), 1,
      anon_sym_SEMI,
    ACTIONS(3185), 1,
      anon_sym_COLON,
    ACTIONS(3187), 1,
      anon_sym_EQ,
  [49202] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2335), 1,
      anon_sym_LBRACE,
    STATE(1538), 1,
      sym_use_list,
    ACTIONS(3189), 2,
      sym_identifier,
      sym_super,
  [49216] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3191), 3,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [49228] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3193), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
    ACTIONS(3191), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [49242] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3023), 1,
      sym_super,
    ACTIONS(3196), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [49258] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3198), 1,
      sym_identifier,
    STATE(966), 1,
      sym_type_arguments,
  [49274] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3198), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [49290] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3023), 1,
      sym_super,
    ACTIONS(3159), 1,
      sym_identifier,
    STATE(1524), 1,
      sym_type_arguments,
  [49306] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3161), 1,
      sym_identifier,
    STATE(1473), 1,
      sym_type_arguments,
  [49322] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3161), 1,
      sym_identifier,
    STATE(1516), 1,
      sym_type_arguments,
  [49338] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2767), 1,
      sym_super,
    ACTIONS(3200), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [49354] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(3040), 1,
      anon_sym_const,
    ACTIONS(3202), 1,
      anon_sym_type,
    STATE(1829), 1,
      sym_function,
  [49370] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3063), 1,
      anon_sym_LBRACE,
    STATE(596), 1,
      sym_enum_variant_list,
    STATE(1638), 1,
      sym_type_parameters,
  [49386] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2661), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2430), 2,
      anon_sym_PIPE,
      anon_sym_in,
  [49400] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3204), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [49416] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(3040), 1,
      anon_sym_const,
    ACTIONS(3206), 1,
      anon_sym_type,
    STATE(1814), 1,
      sym_function,
  [49432] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(962), 1,
      sym_type_arguments,
    ACTIONS(3023), 2,
      sym_identifier,
      sym_super,
  [49446] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(966), 1,
      sym_type_arguments,
    ACTIONS(3030), 2,
      sym_identifier,
      sym_super,
  [49460] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 2,
      anon_sym_COLON,
      anon_sym_PIPE,
    ACTIONS(2464), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [49472] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3208), 1,
      anon_sym_SEMI,
    ACTIONS(3210), 1,
      anon_sym_COLON,
    ACTIONS(3212), 1,
      anon_sym_EQ,
  [49488] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2456), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3054), 1,
      anon_sym_BANG,
    STATE(970), 1,
      sym_type_arguments,
  [49504] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(559), 4,
      anon_sym_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_EQ_GT,
      anon_sym_if,
  [49514] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3113), 1,
      anon_sym_LBRACE,
    STATE(289), 1,
      sym_enum_variant_list,
    STATE(1650), 1,
      sym_type_parameters,
  [49530] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
    STATE(968), 1,
      sym_type_arguments,
  [49546] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(968), 1,
      sym_type_arguments,
    ACTIONS(3030), 2,
      sym_identifier,
      sym_super,
  [49560] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    ACTIONS(3214), 1,
      anon_sym_if,
    STATE(114), 2,
      sym_block,
      sym_if_expression,
  [49574] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3216), 1,
      anon_sym_LBRACE,
    ACTIONS(3218), 1,
      anon_sym_LBRACK,
    ACTIONS(3220), 1,
      anon_sym_LPAREN,
    STATE(964), 1,
      sym_delim_token_tree,
  [49590] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3222), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [49606] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3224), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [49622] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2767), 1,
      sym_super,
    ACTIONS(3226), 1,
      sym_identifier,
    STATE(962), 1,
      sym_type_arguments,
  [49638] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3021), 1,
      sym_identifier,
    ACTIONS(3023), 1,
      sym_super,
    STATE(962), 1,
      sym_type_arguments,
  [49654] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3028), 1,
      sym_identifier,
    ACTIONS(3030), 1,
      sym_super,
    STATE(966), 1,
      sym_type_arguments,
  [49670] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3028), 1,
      sym_identifier,
    ACTIONS(3030), 1,
      sym_super,
    STATE(968), 1,
      sym_type_arguments,
  [49686] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2454), 1,
      anon_sym_BANG,
    ACTIONS(3056), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
  [49702] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2881), 1,
      anon_sym_COLON,
    ACTIONS(2883), 1,
      anon_sym_COMMA,
    ACTIONS(2885), 1,
      anon_sym_PIPE,
    STATE(1531), 1,
      aux_sym_closure_parameters_repeat1,
  [49718] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3216), 1,
      anon_sym_LBRACE,
    ACTIONS(3218), 1,
      anon_sym_LBRACK,
    ACTIONS(3220), 1,
      anon_sym_LPAREN,
    STATE(965), 1,
      sym_delim_token_tree,
  [49734] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3228), 1,
      sym_identifier,
    STATE(706), 1,
      sym_type_arguments,
  [49750] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3019), 1,
      anon_sym_LPAREN,
    ACTIONS(3230), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [49764] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3228), 1,
      sym_identifier,
    STATE(707), 1,
      sym_type_arguments,
  [49780] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3019), 1,
      anon_sym_LPAREN,
    ACTIONS(3232), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [49794] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2490), 1,
      anon_sym_fn,
    ACTIONS(3040), 1,
      anon_sym_const,
    ACTIONS(3234), 1,
      anon_sym_type,
    STATE(1755), 1,
      sym_function,
  [49810] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2747), 1,
      anon_sym_LBRACE,
    ACTIONS(2751), 1,
      anon_sym_LBRACK,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
    STATE(125), 1,
      sym_delim_token_tree,
  [49826] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    ACTIONS(3236), 1,
      anon_sym_RBRACE,
    STATE(1707), 1,
      sym_field_pattern,
  [49842] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3238), 1,
      anon_sym_RBRACK,
    ACTIONS(3240), 1,
      anon_sym_COMMA,
    STATE(1395), 1,
      aux_sym_slice_pattern_repeat1,
  [49858] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3242), 1,
      anon_sym_of,
    ACTIONS(3244), 1,
      anon_sym_EQ,
    STATE(1736), 1,
      sym_type_parameters,
  [49874] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3246), 1,
      anon_sym_COMMA,
    ACTIONS(3248), 1,
      anon_sym_RPAREN,
    STATE(1397), 1,
      aux_sym_tuple_pattern_repeat1,
  [49890] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3250), 1,
      anon_sym_BANG,
    ACTIONS(3252), 1,
      anon_sym_COLON_COLON,
    STATE(1510), 1,
      sym_type_arguments,
  [49906] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3254), 1,
      anon_sym_SEMI,
    STATE(1746), 1,
      sym_type_parameters,
  [49919] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2657), 1,
      anon_sym_PIPE,
    ACTIONS(3025), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [49930] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3256), 1,
      anon_sym_SEMI,
    STATE(274), 1,
      sym_declaration_list,
  [49943] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3258), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [49952] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3260), 1,
      anon_sym_PIPE,
    ACTIONS(3262), 1,
      anon_sym_EQ_GT,
    ACTIONS(3264), 1,
      anon_sym_if,
  [49965] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3268), 1,
      anon_sym_COLON,
    ACTIONS(3266), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [49976] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3270), 1,
      anon_sym_RBRACE,
    ACTIONS(3272), 1,
      anon_sym_COMMA,
    STATE(1467), 1,
      aux_sym_enum_variant_list_repeat2,
  [49989] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(714), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [49998] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(750), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50007] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(744), 1,
      anon_sym_RBRACK,
    ACTIONS(2079), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [50020] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3121), 1,
      anon_sym_EQ,
    STATE(1845), 1,
      sym_type_parameters,
  [50033] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2637), 1,
      anon_sym_RBRACE,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    STATE(1378), 1,
      aux_sym_field_initializer_list_repeat1,
  [50046] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3278), 1,
      anon_sym_COLON,
    ACTIONS(3276), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [50057] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2303), 1,
      anon_sym_RPAREN,
    ACTIONS(3280), 1,
      anon_sym_COMMA,
    STATE(1339), 1,
      aux_sym_arguments_repeat1,
  [50070] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3283), 1,
      anon_sym_SEMI,
    STATE(286), 1,
      sym_declaration_list,
  [50083] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3285), 1,
      anon_sym_RBRACK,
    ACTIONS(3287), 1,
      sym_identifier,
    STATE(1532), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [50096] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50105] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(544), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50114] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(2759), 1,
      anon_sym_LBRACE,
    STATE(975), 1,
      sym_type_arguments,
  [50127] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(577), 1,
      anon_sym_RPAREN,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(1339), 1,
      aux_sym_arguments_repeat1,
  [50140] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 1,
      anon_sym_POUND,
    ACTIONS(1218), 2,
      anon_sym_pub,
      sym_identifier,
  [50151] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(577), 1,
      anon_sym_RPAREN,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(1348), 1,
      aux_sym_arguments_repeat1,
  [50164] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(583), 1,
      anon_sym_RPAREN,
    ACTIONS(3289), 1,
      anon_sym_COMMA,
    STATE(1339), 1,
      aux_sym_arguments_repeat1,
  [50177] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3291), 1,
      anon_sym_in,
    ACTIONS(3293), 2,
      sym_super,
      sym_crate,
  [50188] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3295), 1,
      anon_sym_COMMA,
    ACTIONS(3297), 1,
      anon_sym_RPAREN,
    STATE(1486), 1,
      aux_sym_function_repeat1,
  [50201] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(3299), 1,
      anon_sym_SEMI,
    STATE(570), 1,
      sym_block,
  [50214] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1968), 1,
      anon_sym_LBRACE,
    ACTIONS(3301), 1,
      anon_sym_COLON_COLON,
    STATE(772), 1,
      sym_field_initializer_list,
  [50227] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3005), 1,
      anon_sym_COMMA,
    ACTIONS(3007), 1,
      anon_sym_RPAREN,
    STATE(1475), 1,
      aux_sym_parameters_repeat1,
  [50240] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2925), 1,
      anon_sym_LBRACE,
    ACTIONS(3303), 1,
      anon_sym_SEMI,
    STATE(280), 1,
      sym_field_declaration_list,
  [50253] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3305), 1,
      anon_sym_SEMI,
    STATE(593), 1,
      sym_declaration_list,
  [50266] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3307), 1,
      anon_sym_LBRACK,
    ACTIONS(3309), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [50277] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3311), 1,
      anon_sym_SEMI,
    STATE(328), 1,
      sym_declaration_list,
  [50290] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3313), 1,
      anon_sym_RBRACE,
    ACTIONS(3315), 1,
      anon_sym_COMMA,
    STATE(1462), 1,
      aux_sym_field_declaration_list_repeat1,
  [50303] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2661), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2430), 2,
      anon_sym_PIPE,
      anon_sym_in,
  [50314] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2693), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50323] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2697), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50332] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2647), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50341] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2649), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50350] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2669), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50359] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3287), 1,
      sym_identifier,
    ACTIONS(3317), 1,
      anon_sym_RBRACK,
    STATE(1532), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [50372] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2695), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50381] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3319), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [50390] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    ACTIONS(3321), 1,
      anon_sym_SEMI,
    STATE(626), 1,
      sym_block,
  [50403] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3323), 1,
      anon_sym_SEMI,
    STATE(630), 1,
      sym_declaration_list,
  [50416] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2925), 1,
      anon_sym_LBRACE,
    ACTIONS(3325), 1,
      anon_sym_SEMI,
    STATE(331), 1,
      sym_field_declaration_list,
  [50429] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(690), 1,
      anon_sym_RBRACK,
    ACTIONS(2073), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [50442] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3287), 1,
      sym_identifier,
    ACTIONS(3327), 1,
      anon_sym_RBRACK,
    STATE(1532), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [50455] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2897), 1,
      anon_sym_LBRACE,
    ACTIONS(3329), 1,
      anon_sym_SEMI,
    STATE(636), 1,
      sym_field_declaration_list,
  [50468] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3246), 1,
      anon_sym_COMMA,
    ACTIONS(3248), 1,
      anon_sym_RPAREN,
    STATE(1397), 1,
      aux_sym_tuple_pattern_repeat1,
  [50481] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3331), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [50492] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3083), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3331), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [50503] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3333), 1,
      anon_sym_SEMI,
    STATE(1899), 1,
      sym_type_parameters,
  [50516] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3335), 1,
      anon_sym_RBRACE,
    ACTIONS(3337), 1,
      anon_sym_COMMA,
    STATE(1378), 1,
      aux_sym_field_initializer_list_repeat1,
  [50529] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3340), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [50540] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3342), 1,
      anon_sym_RBRACE,
    ACTIONS(3344), 1,
      anon_sym_COMMA,
    STATE(1406), 1,
      aux_sym_field_initializer_list_repeat1,
  [50553] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2175), 1,
      anon_sym_COMMA,
    ACTIONS(2177), 1,
      anon_sym_RPAREN,
    STATE(1408), 1,
      aux_sym_arguments_repeat1,
  [50566] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3346), 1,
      anon_sym_SEMI,
    STATE(294), 1,
      sym_declaration_list,
  [50579] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3348), 1,
      anon_sym_RBRACE,
    ACTIONS(3350), 1,
      anon_sym_COMMA,
    STATE(1383), 1,
      aux_sym_field_declaration_list_repeat1,
  [50592] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3353), 1,
      anon_sym_SEMI,
    STATE(635), 1,
      sym_declaration_list,
  [50605] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2775), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2460), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [50616] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3355), 1,
      anon_sym_SEMI,
    STATE(1817), 1,
      sym_type_parameters,
  [50629] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3357), 1,
      anon_sym_SEMI,
    STATE(564), 1,
      sym_declaration_list,
  [50642] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1622), 1,
      anon_sym_RBRACK,
    ACTIONS(3359), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [50655] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3287), 1,
      sym_identifier,
    ACTIONS(3361), 1,
      anon_sym_RBRACK,
    STATE(1365), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [50668] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2723), 1,
      anon_sym_RBRACE,
    ACTIONS(3363), 1,
      anon_sym_COMMA,
    STATE(1383), 1,
      aux_sym_field_declaration_list_repeat1,
  [50681] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(696), 1,
      anon_sym_RBRACK,
    ACTIONS(2179), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [50694] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3365), 1,
      anon_sym_RBRACE,
    ACTIONS(3367), 1,
      anon_sym_COMMA,
    STATE(1419), 1,
      aux_sym_field_declaration_list_repeat1,
  [50707] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3369), 1,
      anon_sym_RBRACE,
    ACTIONS(3371), 1,
      anon_sym_COMMA,
    STATE(1421), 1,
      aux_sym_enum_variant_list_repeat2,
  [50720] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3373), 1,
      anon_sym_SEMI,
    STATE(312), 1,
      sym_declaration_list,
  [50733] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1608), 1,
      anon_sym_RBRACK,
    ACTIONS(3375), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [50746] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1576), 1,
      anon_sym_RPAREN,
    ACTIONS(3377), 1,
      anon_sym_COMMA,
    STATE(1493), 1,
      aux_sym_tuple_pattern_repeat1,
  [50759] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1566), 1,
      anon_sym_RPAREN,
    ACTIONS(3379), 1,
      anon_sym_COMMA,
    STATE(1493), 1,
      aux_sym_tuple_pattern_repeat1,
  [50772] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3381), 1,
      anon_sym_COMMA,
    ACTIONS(3383), 1,
      anon_sym_GT,
    STATE(1425), 1,
      aux_sym_type_arguments_repeat1,
  [50785] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3385), 1,
      anon_sym_RBRACE,
    ACTIONS(3387), 1,
      anon_sym_COMMA,
    STATE(1427), 1,
      aux_sym_struct_pattern_repeat1,
  [50798] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3389), 1,
      anon_sym_RBRACE,
    ACTIONS(3391), 1,
      anon_sym_COMMA,
    STATE(1433), 1,
      aux_sym_struct_pattern_repeat1,
  [50811] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2673), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50820] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2691), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50829] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2095), 1,
      anon_sym_GT,
    ACTIONS(3393), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_type_parameters_repeat1,
  [50842] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2705), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50851] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2701), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50860] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2631), 1,
      anon_sym_RBRACE,
    ACTIONS(3395), 1,
      anon_sym_COMMA,
    STATE(1378), 1,
      aux_sym_field_initializer_list_repeat1,
  [50873] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2685), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50882] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2181), 1,
      anon_sym_COMMA,
    STATE(1339), 1,
      aux_sym_arguments_repeat1,
  [50895] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50904] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(585), 1,
      anon_sym_RPAREN,
    ACTIONS(2181), 1,
      anon_sym_COMMA,
    STATE(1435), 1,
      aux_sym_arguments_repeat1,
  [50917] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3397), 1,
      anon_sym_COMMA,
    ACTIONS(3399), 1,
      anon_sym_RPAREN,
    STATE(1436), 1,
      aux_sym_function_repeat1,
  [50930] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3401), 1,
      anon_sym_SEMI,
    STATE(580), 1,
      sym_declaration_list,
  [50943] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2897), 1,
      anon_sym_LBRACE,
    ACTIONS(3403), 1,
      anon_sym_SEMI,
    STATE(584), 1,
      sym_field_declaration_list,
  [50956] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3405), 1,
      anon_sym_SEMI,
    STATE(1874), 1,
      sym_type_parameters,
  [50969] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3407), 1,
      anon_sym_SEMI,
    STATE(598), 1,
      sym_declaration_list,
  [50982] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2689), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [50991] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2097), 1,
      anon_sym_GT,
    ACTIONS(3099), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_type_parameters_repeat1,
  [51004] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(704), 1,
      anon_sym_RBRACK,
    ACTIONS(3409), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [51017] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2725), 1,
      anon_sym_RBRACE,
    ACTIONS(3411), 1,
      anon_sym_COMMA,
    STATE(1383), 1,
      aux_sym_field_declaration_list_repeat1,
  [51030] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2725), 1,
      anon_sym_RBRACE,
    ACTIONS(3411), 1,
      anon_sym_COMMA,
    STATE(1439), 1,
      aux_sym_field_declaration_list_repeat1,
  [51043] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2687), 1,
      anon_sym_RBRACE,
    ACTIONS(3413), 1,
      anon_sym_COMMA,
    STATE(1444), 1,
      aux_sym_enum_variant_list_repeat2,
  [51056] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2687), 1,
      anon_sym_RBRACE,
    ACTIONS(3413), 1,
      anon_sym_COMMA,
    STATE(1440), 1,
      aux_sym_enum_variant_list_repeat2,
  [51069] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2097), 1,
      anon_sym_GT,
    ACTIONS(3099), 1,
      anon_sym_COMMA,
    STATE(1492), 1,
      aux_sym_type_parameters_repeat1,
  [51082] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2643), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51091] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1670), 1,
      anon_sym_GT,
    ACTIONS(3415), 1,
      anon_sym_COMMA,
    STATE(1521), 1,
      aux_sym_type_arguments_repeat1,
  [51104] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2655), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51113] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3101), 1,
      anon_sym_RBRACE,
    ACTIONS(3417), 1,
      anon_sym_COMMA,
    STATE(1529), 1,
      aux_sym_struct_pattern_repeat1,
  [51126] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3083), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3340), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [51137] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1616), 1,
      anon_sym_RPAREN,
    ACTIONS(3419), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [51150] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3421), 1,
      anon_sym_SEMI,
    STATE(338), 1,
      sym_declaration_list,
  [51163] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1626), 1,
      anon_sym_RPAREN,
    ACTIONS(3423), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [51176] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2131), 1,
      anon_sym_COMMA,
    ACTIONS(2133), 1,
      anon_sym_RPAREN,
    STATE(1345), 1,
      aux_sym_arguments_repeat1,
  [51189] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3103), 1,
      anon_sym_RBRACE,
    ACTIONS(3425), 1,
      anon_sym_COMMA,
    STATE(1529), 1,
      aux_sym_struct_pattern_repeat1,
  [51202] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3089), 1,
      anon_sym_COMMA,
    ACTIONS(3091), 1,
      anon_sym_RPAREN,
    STATE(1396), 1,
      aux_sym_tuple_pattern_repeat1,
  [51215] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(587), 1,
      anon_sym_RPAREN,
    ACTIONS(3427), 1,
      anon_sym_COMMA,
    STATE(1339), 1,
      aux_sym_arguments_repeat1,
  [51228] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2101), 1,
      anon_sym_RPAREN,
    ACTIONS(3429), 1,
      anon_sym_COMMA,
    STATE(1535), 1,
      aux_sym_function_repeat1,
  [51241] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3431), 1,
      anon_sym_SEMI,
    STATE(605), 1,
      sym_declaration_list,
  [51254] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3433), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [51265] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2733), 1,
      anon_sym_RBRACE,
    ACTIONS(3435), 1,
      anon_sym_COMMA,
    STATE(1383), 1,
      aux_sym_field_declaration_list_repeat1,
  [51278] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2707), 1,
      anon_sym_RBRACE,
    ACTIONS(3437), 1,
      anon_sym_COMMA,
    STATE(1444), 1,
      aux_sym_enum_variant_list_repeat2,
  [51291] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3232), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2464), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [51302] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3439), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [51311] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2883), 1,
      anon_sym_COMMA,
    ACTIONS(3441), 1,
      anon_sym_PIPE,
    STATE(1531), 1,
      aux_sym_closure_parameters_repeat1,
  [51324] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3443), 1,
      anon_sym_RBRACE,
    ACTIONS(3445), 1,
      anon_sym_COMMA,
    STATE(1444), 1,
      aux_sym_enum_variant_list_repeat2,
  [51337] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2645), 1,
      anon_sym_RBRACE,
    ACTIONS(3448), 1,
      anon_sym_COMMA,
    STATE(1444), 1,
      aux_sym_enum_variant_list_repeat2,
  [51350] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2893), 1,
      anon_sym_LBRACE,
    ACTIONS(3450), 1,
      anon_sym_SEMI,
    STATE(614), 1,
      sym_declaration_list,
  [51363] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2659), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51372] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3117), 1,
      anon_sym_RPAREN,
    ACTIONS(3452), 1,
      anon_sym_COMMA,
    STATE(1448), 1,
      aux_sym_parameters_repeat1,
  [51385] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1402), 1,
      anon_sym_RPAREN,
    ACTIONS(3455), 1,
      anon_sym_COMMA,
    STATE(1448), 1,
      aux_sym_parameters_repeat1,
  [51398] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    ACTIONS(3457), 1,
      anon_sym_COLON_COLON,
    STATE(970), 1,
      sym_type_arguments,
  [51411] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2663), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51420] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2671), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51429] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3459), 1,
      anon_sym_COMMA,
    ACTIONS(3461), 1,
      anon_sym_GT,
    STATE(1495), 1,
      aux_sym_type_arguments_repeat1,
  [51442] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2717), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51451] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2243), 1,
      anon_sym_RBRACK,
    ACTIONS(3463), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [51464] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3145), 1,
      anon_sym_COMMA,
    ACTIONS(3147), 1,
      anon_sym_GT,
    STATE(1417), 1,
      aux_sym_type_parameters_repeat1,
  [51477] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3468), 1,
      anon_sym_COLON,
    ACTIONS(3466), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [51488] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3470), 1,
      anon_sym_COMMA,
    ACTIONS(3472), 1,
      anon_sym_GT,
    STATE(1461), 1,
      aux_sym_type_arguments_repeat1,
  [51501] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(708), 1,
      anon_sym_RBRACK,
    ACTIONS(3474), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [51514] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3476), 1,
      anon_sym_RBRACE,
    ACTIONS(3478), 1,
      anon_sym_COMMA,
    STATE(1503), 1,
      aux_sym_struct_pattern_repeat1,
  [51527] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1676), 1,
      anon_sym_GT,
    ACTIONS(3480), 1,
      anon_sym_COMMA,
    STATE(1521), 1,
      aux_sym_type_arguments_repeat1,
  [51540] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2737), 1,
      anon_sym_RBRACE,
    ACTIONS(3482), 1,
      anon_sym_COMMA,
    STATE(1383), 1,
      aux_sym_field_declaration_list_repeat1,
  [51553] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3287), 1,
      sym_identifier,
    ACTIONS(3484), 1,
      anon_sym_RBRACK,
    STATE(1372), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [51566] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2577), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51575] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2737), 1,
      anon_sym_RBRACE,
    ACTIONS(3482), 1,
      anon_sym_COMMA,
    STATE(1390), 1,
      aux_sym_field_declaration_list_repeat1,
  [51588] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3340), 1,
      anon_sym_GT,
    ACTIONS(3486), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_type_parameters_repeat1,
  [51601] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2651), 1,
      anon_sym_RBRACE,
    ACTIONS(3489), 1,
      anon_sym_COMMA,
    STATE(1444), 1,
      aux_sym_enum_variant_list_repeat2,
  [51614] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3493), 1,
      anon_sym_COLON,
    ACTIONS(3491), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [51625] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2651), 1,
      anon_sym_RBRACE,
    ACTIONS(3489), 1,
      anon_sym_COMMA,
    STATE(1445), 1,
      aux_sym_enum_variant_list_repeat2,
  [51638] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(688), 1,
      anon_sym_RBRACK,
    ACTIONS(2169), 1,
      anon_sym_COMMA,
    STATE(1455), 1,
      aux_sym_array_expression_repeat1,
  [51651] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2641), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51660] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3495), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [51671] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1754), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [51680] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2871), 1,
      sym_identifier,
    ACTIONS(2873), 1,
      sym_mutable_specifier,
    STATE(1707), 1,
      sym_field_pattern,
  [51693] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1308), 1,
      anon_sym_RPAREN,
    ACTIONS(2961), 1,
      anon_sym_COMMA,
    STATE(1448), 1,
      aux_sym_parameters_repeat1,
  [51706] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3497), 1,
      anon_sym_RBRACE,
    ACTIONS(3499), 1,
      anon_sym_COMMA,
    STATE(1525), 1,
      aux_sym_struct_pattern_repeat1,
  [51719] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1308), 1,
      anon_sym_RPAREN,
    ACTIONS(2961), 1,
      anon_sym_COMMA,
    STATE(1449), 1,
      aux_sym_parameters_repeat1,
  [51732] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3501), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51741] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2393), 1,
      anon_sym_RBRACE,
    ACTIONS(3503), 1,
      anon_sym_COMMA,
    STATE(1530), 1,
      aux_sym_use_list_repeat1,
  [51754] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3505), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51763] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3507), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51772] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3509), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51781] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3511), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51790] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3513), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51799] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2667), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51808] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2105), 1,
      anon_sym_RPAREN,
    ACTIONS(3515), 1,
      anon_sym_COMMA,
    STATE(1535), 1,
      aux_sym_function_repeat1,
  [51821] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3517), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [51832] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3519), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [51841] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2091), 1,
      anon_sym_GT,
    ACTIONS(3521), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_type_parameters_repeat1,
  [51854] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3523), 1,
      anon_sym_SEMI,
    STATE(313), 1,
      sym_declaration_list,
  [51867] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2424), 3,
      anon_sym_RBRACK,
      anon_sym_LT2,
      sym_identifier,
  [51876] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2053), 1,
      anon_sym_GT,
    ACTIONS(3525), 1,
      anon_sym_COMMA,
    STATE(1466), 1,
      aux_sym_type_parameters_repeat1,
  [51889] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3517), 1,
      anon_sym_RPAREN,
    ACTIONS(3527), 1,
      anon_sym_COMMA,
    STATE(1493), 1,
      aux_sym_tuple_pattern_repeat1,
  [51902] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1682), 1,
      anon_sym_LBRACE,
    ACTIONS(3530), 1,
      anon_sym_COLON_COLON,
    STATE(506), 1,
      sym_field_initializer_list,
  [51915] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1656), 1,
      anon_sym_GT,
    ACTIONS(3532), 1,
      anon_sym_COMMA,
    STATE(1521), 1,
      aux_sym_type_arguments_repeat1,
  [51928] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1682), 1,
      anon_sym_LBRACE,
    ACTIONS(3534), 1,
      anon_sym_COLON_COLON,
    STATE(506), 1,
      sym_field_initializer_list,
  [51941] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2703), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51950] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(3536), 1,
      anon_sym_SEMI,
    STATE(325), 1,
      sym_block,
  [51963] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3540), 1,
      anon_sym_COLON,
    ACTIONS(3538), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [51974] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    ACTIONS(3542), 1,
      anon_sym_LBRACE,
    STATE(975), 1,
      sym_type_arguments,
  [51987] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2709), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [51996] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3544), 1,
      anon_sym_in,
    ACTIONS(3546), 2,
      sym_super,
      sym_crate,
  [52007] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3204), 1,
      anon_sym_RBRACE,
    ACTIONS(3548), 1,
      anon_sym_COMMA,
    STATE(1529), 1,
      aux_sym_struct_pattern_repeat1,
  [52020] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2887), 1,
      anon_sym_LBRACE,
    ACTIONS(3550), 1,
      anon_sym_SEMI,
    STATE(345), 1,
      sym_declaration_list,
  [52033] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2699), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52042] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2657), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52051] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3552), 3,
      anon_sym_type,
      anon_sym_const,
      anon_sym_fn,
  [52060] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1620), 1,
      anon_sym_RPAREN,
    ACTIONS(3554), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [52073] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2713), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52082] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2448), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [52091] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2446), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [52100] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2881), 1,
      anon_sym_COLON,
    ACTIONS(3556), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [52111] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2470), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [52120] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3560), 1,
      anon_sym_COLON,
    ACTIONS(3558), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52131] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1612), 1,
      anon_sym_RPAREN,
    ACTIONS(3562), 1,
      anon_sym_COMMA,
    STATE(1282), 1,
      aux_sym_slice_pattern_repeat1,
  [52144] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1768), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [52153] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3556), 1,
      anon_sym_PIPE,
    ACTIONS(3564), 1,
      anon_sym_COMMA,
    STATE(1517), 1,
      aux_sym_closure_parameters_repeat1,
  [52166] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3567), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [52175] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2711), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52184] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1646), 1,
      anon_sym_LBRACE,
    ACTIONS(3569), 1,
      anon_sym_SEMI,
    STATE(332), 1,
      sym_block,
  [52197] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3571), 1,
      anon_sym_COMMA,
    ACTIONS(3574), 1,
      anon_sym_GT,
    STATE(1521), 1,
      aux_sym_type_arguments_repeat1,
  [52210] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3576), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52221] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3578), 1,
      anon_sym_RBRACE,
    ACTIONS(3580), 1,
      anon_sym_COMMA,
    STATE(1337), 1,
      aux_sym_field_initializer_list_repeat1,
  [52234] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2444), 3,
      anon_sym_RBRACK,
      anon_sym_COLON_COLON,
      sym_identifier,
  [52243] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3222), 1,
      anon_sym_RBRACE,
    ACTIONS(3582), 1,
      anon_sym_COMMA,
    STATE(1529), 1,
      aux_sym_struct_pattern_repeat1,
  [52256] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3584), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [52265] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2665), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52274] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3287), 1,
      sym_identifier,
    ACTIONS(3586), 1,
      anon_sym_RBRACK,
    STATE(1341), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [52287] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3588), 1,
      anon_sym_RBRACE,
    ACTIONS(3590), 1,
      anon_sym_COMMA,
    STATE(1529), 1,
      aux_sym_struct_pattern_repeat1,
  [52300] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3593), 1,
      anon_sym_RBRACE,
    ACTIONS(3595), 1,
      anon_sym_COMMA,
    STATE(1530), 1,
      aux_sym_use_list_repeat1,
  [52313] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3598), 1,
      anon_sym_COMMA,
    ACTIONS(3600), 1,
      anon_sym_PIPE,
    STATE(1517), 1,
      aux_sym_closure_parameters_repeat1,
  [52326] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3602), 1,
      anon_sym_RBRACK,
    ACTIONS(3604), 1,
      sym_identifier,
    STATE(1532), 1,
      aux_sym_constrained_type_parameter_repeat1,
  [52339] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3607), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [52348] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1216), 1,
      anon_sym_POUND,
    ACTIONS(1218), 2,
      sym_numeric_literal,
      sym_identifier,
  [52359] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2862), 1,
      anon_sym_RPAREN,
    ACTIONS(3609), 1,
      anon_sym_COMMA,
    STATE(1535), 1,
      aux_sym_function_repeat1,
  [52372] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3612), 1,
      anon_sym_RBRACE,
    ACTIONS(3614), 1,
      anon_sym_COMMA,
    STATE(1479), 1,
      aux_sym_use_list_repeat1,
  [52385] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2430), 1,
      anon_sym_PIPE,
    ACTIONS(3058), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [52396] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3616), 3,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [52405] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2891), 1,
      anon_sym_LT,
    ACTIONS(3244), 1,
      anon_sym_EQ,
    STATE(1891), 1,
      sym_type_parameters,
  [52418] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2567), 3,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_if,
  [52427] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2474), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [52435] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3618), 1,
      anon_sym_fn,
    ACTIONS(3620), 1,
      sym_identifier,
  [52445] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3622), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52453] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3624), 1,
      anon_sym_SEMI,
    ACTIONS(3626), 1,
      anon_sym_EQ,
  [52463] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(121), 1,
      sym_block,
  [52473] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    STATE(768), 1,
      sym_block,
  [52483] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 1,
      anon_sym_PIPE,
    STATE(149), 1,
      sym_closure_parameters,
  [52493] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(531), 1,
      sym_block,
  [52503] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1968), 1,
      anon_sym_LBRACE,
    STATE(772), 1,
      sym_field_initializer_list,
  [52513] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3628), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3630), 1,
      anon_sym_RPAREN,
  [52523] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3634), 1,
      anon_sym_RPAREN,
  [52533] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3630), 1,
      anon_sym_RPAREN,
    ACTIONS(3636), 1,
      anon_sym_COLON_COLON,
  [52543] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3630), 1,
      anon_sym_RPAREN,
    ACTIONS(3638), 1,
      anon_sym_COLON_COLON,
  [52553] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3443), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52561] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    STATE(819), 1,
      sym_block,
  [52571] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3640), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52579] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3642), 1,
      anon_sym_of,
    ACTIONS(3644), 1,
      anon_sym_EQ,
  [52589] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3646), 1,
      anon_sym_SEMI,
    ACTIONS(3648), 1,
      anon_sym_RBRACK,
  [52599] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3650), 1,
      sym_identifier,
    ACTIONS(3652), 1,
      sym_super,
  [52609] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3063), 1,
      anon_sym_LBRACE,
    STATE(585), 1,
      sym_enum_variant_list,
  [52619] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3654), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [52627] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3656), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52635] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3658), 1,
      sym_identifier,
    ACTIONS(3660), 1,
      sym_super,
  [52645] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3662), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52653] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3664), 1,
      anon_sym_COLON,
  [52663] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3666), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52671] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2661), 1,
      anon_sym_DOT_DOT,
  [52681] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2745), 2,
      sym_identifier,
      sym_super,
  [52689] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3668), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52697] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3670), 1,
      anon_sym_SEMI,
    ACTIONS(3672), 1,
      anon_sym_EQ,
  [52707] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3674), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52715] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3228), 1,
      sym_identifier,
  [52725] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3676), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52733] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3678), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [52741] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3680), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52749] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2464), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [52757] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3095), 1,
      anon_sym_COLON,
  [52767] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3682), 1,
      anon_sym_LBRACE,
    STATE(472), 1,
      sym_block,
  [52777] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
  [52787] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3684), 1,
      sym_numeric_literal,
    ACTIONS(3686), 1,
      sym_identifier,
  [52797] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3688), 1,
      anon_sym_SEMI,
    ACTIONS(3690), 1,
      anon_sym_EQ,
  [52807] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2496), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [52815] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3692), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52823] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    STATE(782), 1,
      sym_block,
  [52833] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3694), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52841] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3696), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [52849] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3660), 1,
      sym_super,
    ACTIONS(3698), 1,
      sym_identifier,
  [52859] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3700), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [52867] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(128), 1,
      sym_block,
  [52877] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3652), 1,
      sym_super,
    ACTIONS(3702), 1,
      sym_identifier,
  [52887] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3149), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [52895] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3704), 1,
      sym_numeric_literal,
    ACTIONS(3706), 1,
      sym_identifier,
  [52905] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3708), 1,
      anon_sym_BANG,
    ACTIONS(3710), 1,
      anon_sym_LBRACK,
  [52915] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3117), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [52923] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3712), 1,
      anon_sym_PIPE,
    ACTIONS(3714), 1,
      anon_sym_in,
  [52933] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2531), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [52941] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3135), 1,
      anon_sym_LT2,
    STATE(802), 1,
      sym_type_arguments,
  [52951] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3716), 1,
      sym_identifier,
    ACTIONS(3718), 1,
      sym_super,
  [52961] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(910), 1,
      anon_sym_LBRACE,
    STATE(376), 1,
      sym_block,
  [52971] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 1,
      anon_sym_PIPE,
    STATE(148), 1,
      sym_closure_parameters,
  [52981] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3189), 1,
      sym_super,
    ACTIONS(3698), 1,
      sym_identifier,
  [52991] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2619), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2913), 1,
      anon_sym_COLON_COLON,
  [53001] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3137), 1,
      sym_identifier,
    ACTIONS(3139), 1,
      sym_super,
  [53011] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3113), 1,
      anon_sym_LBRACE,
    STATE(282), 1,
      sym_enum_variant_list,
  [53021] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2557), 1,
      sym_identifier,
    ACTIONS(3720), 1,
      anon_sym_LPAREN,
  [53031] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3722), 1,
      anon_sym_LBRACE,
    STATE(664), 1,
      sym_block,
  [53041] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3724), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [53049] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(910), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym_block,
  [53059] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(714), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53067] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3726), 1,
      anon_sym_EQ,
  [53077] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3728), 1,
      sym_identifier,
    ACTIONS(3730), 1,
      sym_super,
  [53087] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3732), 1,
      anon_sym_SEMI,
    ACTIONS(3734), 1,
      anon_sym_EQ,
  [53097] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3141), 1,
      sym_identifier,
  [53107] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2498), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53115] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2500), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53123] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3652), 1,
      sym_super,
    ACTIONS(3736), 1,
      sym_identifier,
  [53133] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3738), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53141] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3740), 2,
      sym_identifier,
      sym_super,
  [53149] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3742), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53157] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3744), 2,
      sym_identifier,
      sym_super,
  [53165] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(3746), 1,
      anon_sym_COLON_COLON,
  [53175] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1682), 1,
      anon_sym_LBRACE,
    STATE(506), 1,
      sym_field_initializer_list,
  [53185] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3019), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_COLON_COLON,
  [53195] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(750), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53203] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3750), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53211] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 1,
      anon_sym_PIPE,
    STATE(162), 1,
      sym_closure_parameters,
  [53221] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2589), 1,
      anon_sym_LT2,
    STATE(975), 1,
      sym_type_arguments,
  [53231] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3660), 1,
      sym_super,
    ACTIONS(3752), 1,
      sym_identifier,
  [53241] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3754), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [53249] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3756), 1,
      anon_sym_LBRACE,
    STATE(266), 1,
      sym_block,
  [53259] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3758), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53267] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3760), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53275] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3161), 1,
      sym_identifier,
  [53285] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3762), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53293] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3764), 1,
      anon_sym_of,
    ACTIONS(3766), 1,
      anon_sym_EQ,
  [53303] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3768), 1,
      sym_identifier,
    ACTIONS(3770), 1,
      sym_super,
  [53313] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(528), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [53321] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3063), 1,
      anon_sym_LBRACE,
    STATE(638), 1,
      sym_enum_variant_list,
  [53331] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2460), 1,
      anon_sym_LBRACE,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
  [53341] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2858), 1,
      anon_sym_BANG,
    ACTIONS(3772), 1,
      anon_sym_COLON_COLON,
  [53351] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3331), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [53359] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3628), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3774), 1,
      anon_sym_RPAREN,
  [53369] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3028), 1,
      sym_identifier,
    ACTIONS(3030), 1,
      sym_super,
  [53379] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3776), 1,
      anon_sym_SEMI,
    ACTIONS(3778), 1,
      anon_sym_EQ,
  [53389] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3744), 1,
      sym_super,
    ACTIONS(3780), 1,
      sym_identifier,
  [53399] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3782), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53407] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2442), 1,
      anon_sym_LT2,
    STATE(526), 1,
      sym_type_arguments,
  [53417] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3067), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
  [53427] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3740), 1,
      sym_super,
    ACTIONS(3784), 1,
      sym_identifier,
  [53437] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3113), 1,
      anon_sym_LBRACE,
    STATE(333), 1,
      sym_enum_variant_list,
  [53447] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3786), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53455] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3770), 1,
      sym_super,
    ACTIONS(3788), 1,
      sym_identifier,
  [53465] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3790), 1,
      anon_sym_LBRACE,
    STATE(131), 1,
      sym_block,
  [53475] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3792), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53483] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2585), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3794), 1,
      anon_sym_BANG,
  [53493] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2593), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3796), 1,
      anon_sym_BANG,
  [53503] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3660), 1,
      sym_super,
    ACTIONS(3780), 1,
      sym_identifier,
  [53513] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2573), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3796), 1,
      anon_sym_BANG,
  [53523] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3175), 1,
      sym_identifier,
  [53533] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3050), 1,
      anon_sym_LPAREN,
    STATE(1125), 1,
      sym_parameters,
  [53543] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3632), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3798), 1,
      anon_sym_RPAREN,
  [53553] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3770), 1,
      sym_super,
    ACTIONS(3784), 1,
      sym_identifier,
  [53563] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3636), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3774), 1,
      anon_sym_RPAREN,
  [53573] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3800), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53581] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3770), 2,
      sym_identifier,
      sym_super,
  [53589] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3348), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [53597] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3802), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53605] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2745), 1,
      sym_super,
    ACTIONS(3052), 1,
      sym_identifier,
  [53615] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3660), 1,
      sym_super,
    ACTIONS(3804), 1,
      sym_identifier,
  [53625] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3030), 1,
      sym_super,
    ACTIONS(3198), 1,
      sym_identifier,
  [53635] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3806), 1,
      anon_sym_EQ,
  [53645] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3770), 1,
      sym_super,
    ACTIONS(3808), 1,
      sym_identifier,
  [53655] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3517), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53663] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3736), 1,
      sym_identifier,
    ACTIONS(3770), 1,
      sym_super,
  [53673] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2283), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53681] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3810), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53689] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2529), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53697] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3189), 2,
      sym_identifier,
      sym_super,
  [53705] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3050), 1,
      anon_sym_LPAREN,
    STATE(1131), 1,
      sym_parameters,
  [53715] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2472), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53723] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3812), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53731] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2775), 1,
      anon_sym_COLON_COLON,
  [53741] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3814), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3816), 1,
      anon_sym_LPAREN,
  [53751] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3818), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53759] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3638), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3774), 1,
      anon_sym_RPAREN,
  [53769] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(269), 1,
      anon_sym_LBRACE,
    STATE(810), 1,
      sym_block,
  [53779] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3820), 1,
      anon_sym_SEMI,
    ACTIONS(3822), 1,
      anon_sym_EQ,
  [53789] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3824), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53797] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3030), 2,
      sym_identifier,
      sym_super,
  [53805] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2623), 1,
      anon_sym_BANG,
    ACTIONS(3826), 1,
      anon_sym_COLON_COLON,
  [53815] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3574), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [53823] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3828), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53831] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53839] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3830), 1,
      anon_sym_SEMI,
    ACTIONS(3832), 1,
      anon_sym_EQ,
  [53849] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3556), 2,
      anon_sym_COMMA,
      anon_sym_PIPE,
  [53857] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(544), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [53865] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3834), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53873] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
  [53883] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3618), 1,
      anon_sym_fn,
    ACTIONS(3836), 1,
      sym_identifier,
  [53893] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3766), 1,
      anon_sym_EQ,
    ACTIONS(3838), 1,
      anon_sym_SEMI,
  [53903] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3840), 1,
      anon_sym_SEMI,
    ACTIONS(3842), 1,
      anon_sym_EQ,
  [53913] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3067), 2,
      sym_identifier,
      sym_super,
  [53921] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3844), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53929] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2303), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [53937] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACE,
    STATE(507), 1,
      sym_block,
  [53947] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3846), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [53955] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3588), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [53963] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 1,
      anon_sym_PIPE,
    STATE(147), 1,
      sym_closure_parameters,
  [53973] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3266), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [53981] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2464), 1,
      anon_sym_LBRACE,
    ACTIONS(3748), 1,
      anon_sym_COLON_COLON,
  [53991] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2524), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2623), 1,
      anon_sym_BANG,
  [54001] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3848), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54009] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3850), 1,
      anon_sym_SEMI,
    ACTIONS(3852), 1,
      anon_sym_RBRACK,
  [54019] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2434), 1,
      anon_sym_BANG,
    ACTIONS(3826), 1,
      anon_sym_COLON_COLON,
  [54029] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3593), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [54037] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3335), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
  [54045] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3854), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [54053] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2788), 1,
      anon_sym_COLON_COLON,
  [54063] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3856), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [54071] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3858), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54079] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3652), 2,
      sym_identifier,
      sym_super,
  [54087] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3189), 1,
      sym_super,
    ACTIONS(3860), 1,
      sym_identifier,
  [54097] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3189), 1,
      sym_super,
    ACTIONS(3862), 1,
      sym_identifier,
  [54107] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3864), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [54115] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2440), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2937), 1,
      anon_sym_COLON_COLON,
  [54125] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3866), 1,
      anon_sym_SEMI,
    ACTIONS(3868), 1,
      anon_sym_EQ,
  [54135] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3618), 1,
      anon_sym_fn,
    ACTIONS(3870), 1,
      sym_identifier,
  [54145] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3872), 1,
      anon_sym_BANG,
    ACTIONS(3874), 1,
      anon_sym_LBRACK,
  [54155] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3340), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [54163] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3876), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54171] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3712), 1,
      anon_sym_PIPE,
    ACTIONS(3878), 1,
      anon_sym_in,
  [54181] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3734), 1,
      anon_sym_EQ,
    ACTIONS(3880), 1,
      anon_sym_of,
  [54191] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2665), 1,
      anon_sym_PIPE,
    ACTIONS(3882), 1,
      anon_sym_COLON,
  [54201] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3046), 1,
      anon_sym_PIPE,
    ACTIONS(3882), 1,
      anon_sym_COLON,
  [54211] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3884), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54219] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3886), 1,
      anon_sym_of,
    ACTIONS(3888), 1,
      anon_sym_EQ,
  [54229] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3890), 1,
      anon_sym_BANG,
    ACTIONS(3892), 1,
      anon_sym_LBRACK,
  [54239] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3712), 1,
      anon_sym_PIPE,
    ACTIONS(3894), 1,
      anon_sym_in,
  [54249] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3618), 1,
      anon_sym_fn,
    ACTIONS(3896), 1,
      sym_identifier,
  [54259] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3898), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54267] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3660), 2,
      sym_identifier,
      sym_super,
  [54275] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3900), 2,
      anon_sym_LBRACE,
      anon_sym_SEMI,
  [54283] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3902), 1,
      sym_identifier,
  [54290] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3042), 1,
      anon_sym_RBRACK,
  [54297] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3904), 1,
      anon_sym_RBRACK,
  [54304] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3906), 1,
      anon_sym_SEMI,
  [54311] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3908), 1,
      anon_sym_COLON_COLON,
  [54318] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3910), 1,
      sym_identifier,
  [54325] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3578), 1,
      anon_sym_RBRACE,
  [54332] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3912), 1,
      anon_sym_RBRACK,
  [54339] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3914), 1,
      anon_sym_RBRACK,
  [54346] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3916), 1,
      sym_identifier,
  [54353] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3918), 1,
      anon_sym_fn,
  [54360] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3920), 1,
      anon_sym_EQ_GT,
  [54367] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3922), 1,
      anon_sym_SEMI,
  [54374] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3924), 1,
      sym_identifier,
  [54381] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3926), 1,
      anon_sym_RPAREN,
  [54388] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
  [54395] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3930), 1,
      anon_sym_SEMI,
  [54402] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3932), 1,
      anon_sym_RBRACK,
  [54409] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3342), 1,
      anon_sym_RBRACE,
  [54416] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(690), 1,
      anon_sym_RBRACK,
  [54423] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3934), 1,
      anon_sym_COLON,
  [54430] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3936), 1,
      sym_identifier,
  [54437] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3938), 1,
      sym_identifier,
  [54444] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3940), 1,
      sym_identifier,
  [54451] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3942), 1,
      sym_identifier,
  [54458] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3944), 1,
      sym_identifier,
  [54465] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3946), 1,
      anon_sym_RBRACE,
  [54472] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3948), 1,
      sym_numeric_literal,
  [54479] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3950), 1,
      sym_identifier,
  [54486] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2177), 1,
      anon_sym_RPAREN,
  [54493] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3952), 1,
      sym_identifier,
  [54500] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3954), 1,
      sym_identifier,
  [54507] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2591), 1,
      anon_sym_COLON_COLON,
  [54514] = 2,
    ACTIONS(3956), 1,
      aux_sym_string_literal_token2,
    ACTIONS(3958), 1,
      sym_line_comment,
  [54521] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2183), 1,
      anon_sym_COLON_COLON,
  [54528] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3960), 1,
      sym_identifier,
  [54535] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3165), 1,
      anon_sym_RPAREN,
  [54542] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3962), 1,
      anon_sym_COLON,
  [54549] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3091), 1,
      anon_sym_RPAREN,
  [54556] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3964), 1,
      anon_sym_COLON_COLON,
  [54563] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3966), 1,
      anon_sym_SEMI,
  [54570] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3968), 1,
      anon_sym_RBRACE,
  [54577] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3970), 1,
      ts_builtin_sym_end,
  [54584] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3972), 1,
      sym_identifier,
  [54591] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3974), 1,
      anon_sym_EQ_GT,
  [54598] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3976), 1,
      anon_sym_SEMI,
  [54605] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3978), 1,
      anon_sym_COLON_COLON,
  [54612] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3980), 1,
      sym_identifier,
  [54619] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2462), 1,
      anon_sym_COLON_COLON,
  [54626] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3493), 1,
      anon_sym_COLON,
  [54633] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3982), 1,
      anon_sym_SEMI,
  [54640] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3984), 1,
      sym_identifier,
  [54647] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3986), 1,
      sym_identifier,
  [54654] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3988), 1,
      sym_identifier,
  [54661] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3990), 1,
      sym_identifier,
  [54668] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3992), 1,
      anon_sym_RBRACK,
  [54675] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3994), 1,
      anon_sym_SEMI,
  [54682] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3996), 1,
      sym_identifier,
  [54689] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3998), 1,
      sym_identifier,
  [54696] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4000), 1,
      sym_identifier,
  [54703] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4002), 1,
      anon_sym_DQUOTE,
  [54710] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(744), 1,
      anon_sym_RBRACK,
  [54717] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4004), 1,
      sym_identifier,
  [54724] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4006), 1,
      anon_sym_RBRACK,
  [54731] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4008), 1,
      anon_sym_RBRACK,
  [54738] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4010), 1,
      anon_sym_RBRACE,
  [54745] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4012), 1,
      anon_sym_RBRACK,
  [54752] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4014), 1,
      sym_identifier,
  [54759] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1912), 1,
      anon_sym_COLON_COLON,
  [54766] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4016), 1,
      anon_sym_EQ_GT,
  [54773] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4018), 1,
      anon_sym_SEMI,
  [54780] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4020), 1,
      anon_sym_SEMI,
  [54787] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4022), 1,
      anon_sym_RBRACK,
  [54794] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3007), 1,
      anon_sym_RPAREN,
  [54801] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4024), 1,
      anon_sym_SEMI,
  [54808] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4026), 1,
      anon_sym_RBRACE,
  [54815] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4028), 1,
      sym_identifier,
  [54822] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4030), 1,
      anon_sym_SEMI,
  [54829] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4032), 1,
      anon_sym_SEMI,
  [54836] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4034), 1,
      anon_sym_SEMI,
  [54843] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4036), 1,
      anon_sym_RBRACE,
  [54850] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4038), 1,
      anon_sym_COLON,
  [54857] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3179), 1,
      anon_sym_RPAREN,
  [54864] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4040), 1,
      anon_sym_RBRACK,
  [54871] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3238), 1,
      anon_sym_RBRACK,
  [54878] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2775), 1,
      anon_sym_COLON_COLON,
  [54885] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4042), 1,
      anon_sym_SEMI,
  [54892] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3081), 1,
      anon_sym_RPAREN,
  [54899] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4044), 1,
      sym_identifier,
  [54906] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3248), 1,
      anon_sym_RPAREN,
  [54913] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(684), 1,
      anon_sym_RBRACK,
  [54920] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4046), 1,
      anon_sym_EQ_GT,
  [54927] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4048), 1,
      anon_sym_COLON,
  [54934] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4050), 1,
      anon_sym_RPAREN,
  [54941] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4052), 1,
      sym_identifier,
  [54948] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4054), 1,
      anon_sym_SEMI,
  [54955] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4056), 1,
      anon_sym_RBRACE,
  [54962] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4058), 1,
      sym_identifier,
  [54969] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3270), 1,
      anon_sym_RBRACE,
  [54976] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4060), 1,
      anon_sym_SEMI,
  [54983] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4062), 1,
      anon_sym_EQ_GT,
  [54990] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3389), 1,
      anon_sym_RBRACE,
  [54997] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3644), 1,
      anon_sym_EQ,
  [55004] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3365), 1,
      anon_sym_RBRACE,
  [55011] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4064), 1,
      anon_sym_DQUOTE,
  [55018] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3369), 1,
      anon_sym_RBRACE,
  [55025] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2565), 1,
      sym_identifier,
  [55032] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4066), 1,
      anon_sym_SEMI,
  [55039] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4068), 1,
      anon_sym_RBRACK,
  [55046] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4070), 1,
      sym_identifier,
  [55053] = 2,
    ACTIONS(3958), 1,
      sym_line_comment,
    ACTIONS(4072), 1,
      aux_sym_string_literal_token2,
  [55060] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2161), 1,
      anon_sym_COLON_COLON,
  [55067] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4074), 1,
      anon_sym_COLON,
  [55074] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3268), 1,
      anon_sym_COLON,
  [55081] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2635), 1,
      sym_identifier,
  [55088] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2468), 1,
      anon_sym_COLON_COLON,
  [55095] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4076), 1,
      anon_sym_COLON_COLON,
  [55102] = 2,
    ACTIONS(3958), 1,
      sym_line_comment,
    ACTIONS(4078), 1,
      aux_sym_string_literal_token2,
  [55109] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3313), 1,
      anon_sym_RBRACE,
  [55116] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3612), 1,
      anon_sym_RBRACE,
  [55123] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3441), 1,
      anon_sym_PIPE,
  [55130] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4080), 1,
      anon_sym_DQUOTE,
  [55137] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3497), 1,
      anon_sym_RBRACE,
  [55144] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2571), 1,
      anon_sym_COLON_COLON,
  [55151] = 2,
    ACTIONS(3958), 1,
      sym_line_comment,
    ACTIONS(4082), 1,
      aux_sym_string_literal_token2,
  [55158] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4084), 1,
      anon_sym_SEMI,
  [55165] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4086), 1,
      sym_identifier,
  [55172] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4088), 1,
      sym_identifier,
  [55179] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3385), 1,
      anon_sym_RBRACE,
  [55186] = 2,
    ACTIONS(3958), 1,
      sym_line_comment,
    ACTIONS(4090), 1,
      aux_sym_string_literal_token2,
  [55193] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4092), 1,
      anon_sym_LBRACK,
  [55200] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4094), 1,
      anon_sym_SEMI,
  [55207] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4096), 1,
      sym_numeric_literal,
  [55214] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2633), 1,
      sym_identifier,
  [55221] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4098), 1,
      anon_sym_DQUOTE,
  [55228] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4100), 1,
      anon_sym_RBRACK,
  [55235] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4102), 1,
      anon_sym_COLON,
  [55242] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4104), 1,
      anon_sym_LBRACK,
  [55249] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4106), 1,
      anon_sym_LBRACK,
  [55256] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4108), 1,
      sym_identifier,
  [55263] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4110), 1,
      sym_identifier,
  [55270] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4112), 1,
      anon_sym_COLON,
  [55277] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4114), 1,
      anon_sym_RBRACK,
  [55284] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4116), 1,
      sym_identifier,
  [55291] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4118), 1,
      anon_sym_DQUOTE,
  [55298] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3077), 1,
      anon_sym_RPAREN,
  [55305] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4120), 1,
      anon_sym_COLON,
  [55312] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4122), 1,
      sym_identifier,
  [55319] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3888), 1,
      anon_sym_EQ,
  [55326] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4124), 1,
      anon_sym_SEMI,
  [55333] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4126), 1,
      anon_sym_LBRACK,
  [55340] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4128), 1,
      anon_sym_LBRACK,
  [55347] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4130), 1,
      anon_sym_COLON,
  [55354] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4132), 1,
      anon_sym_LBRACK,
  [55361] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4134), 1,
      anon_sym_LBRACK,
  [55368] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4136), 1,
      sym_identifier,
  [55375] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4138), 1,
      anon_sym_SEMI,
  [55382] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4140), 1,
      anon_sym_COLON_COLON,
  [55389] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(589), 1,
      anon_sym_RBRACK,
  [55396] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4142), 1,
      sym_identifier,
  [55403] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4144), 1,
      sym_identifier,
  [55410] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4146), 1,
      sym_identifier,
  [55417] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(3476), 1,
      anon_sym_RBRACE,
  [55424] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(4148), 1,
      anon_sym_LBRACK,
  [55431] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(2133), 1,
      anon_sym_RPAREN,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(252)] = 0,
  [SMALL_STATE(253)] = 91,
  [SMALL_STATE(254)] = 182,
  [SMALL_STATE(255)] = 273,
  [SMALL_STATE(256)] = 344,
  [SMALL_STATE(257)] = 435,
  [SMALL_STATE(258)] = 506,
  [SMALL_STATE(259)] = 577,
  [SMALL_STATE(260)] = 648,
  [SMALL_STATE(261)] = 719,
  [SMALL_STATE(262)] = 790,
  [SMALL_STATE(263)] = 861,
  [SMALL_STATE(264)] = 930,
  [SMALL_STATE(265)] = 999,
  [SMALL_STATE(266)] = 1068,
  [SMALL_STATE(267)] = 1139,
  [SMALL_STATE(268)] = 1206,
  [SMALL_STATE(269)] = 1273,
  [SMALL_STATE(270)] = 1340,
  [SMALL_STATE(271)] = 1407,
  [SMALL_STATE(272)] = 1474,
  [SMALL_STATE(273)] = 1541,
  [SMALL_STATE(274)] = 1608,
  [SMALL_STATE(275)] = 1675,
  [SMALL_STATE(276)] = 1742,
  [SMALL_STATE(277)] = 1809,
  [SMALL_STATE(278)] = 1876,
  [SMALL_STATE(279)] = 1943,
  [SMALL_STATE(280)] = 2010,
  [SMALL_STATE(281)] = 2077,
  [SMALL_STATE(282)] = 2144,
  [SMALL_STATE(283)] = 2211,
  [SMALL_STATE(284)] = 2278,
  [SMALL_STATE(285)] = 2345,
  [SMALL_STATE(286)] = 2412,
  [SMALL_STATE(287)] = 2479,
  [SMALL_STATE(288)] = 2546,
  [SMALL_STATE(289)] = 2613,
  [SMALL_STATE(290)] = 2680,
  [SMALL_STATE(291)] = 2747,
  [SMALL_STATE(292)] = 2814,
  [SMALL_STATE(293)] = 2881,
  [SMALL_STATE(294)] = 2948,
  [SMALL_STATE(295)] = 3015,
  [SMALL_STATE(296)] = 3082,
  [SMALL_STATE(297)] = 3149,
  [SMALL_STATE(298)] = 3216,
  [SMALL_STATE(299)] = 3283,
  [SMALL_STATE(300)] = 3350,
  [SMALL_STATE(301)] = 3417,
  [SMALL_STATE(302)] = 3484,
  [SMALL_STATE(303)] = 3551,
  [SMALL_STATE(304)] = 3618,
  [SMALL_STATE(305)] = 3685,
  [SMALL_STATE(306)] = 3752,
  [SMALL_STATE(307)] = 3819,
  [SMALL_STATE(308)] = 3886,
  [SMALL_STATE(309)] = 3953,
  [SMALL_STATE(310)] = 4020,
  [SMALL_STATE(311)] = 4087,
  [SMALL_STATE(312)] = 4154,
  [SMALL_STATE(313)] = 4221,
  [SMALL_STATE(314)] = 4288,
  [SMALL_STATE(315)] = 4355,
  [SMALL_STATE(316)] = 4422,
  [SMALL_STATE(317)] = 4489,
  [SMALL_STATE(318)] = 4556,
  [SMALL_STATE(319)] = 4623,
  [SMALL_STATE(320)] = 4754,
  [SMALL_STATE(321)] = 4821,
  [SMALL_STATE(322)] = 4888,
  [SMALL_STATE(323)] = 4955,
  [SMALL_STATE(324)] = 5022,
  [SMALL_STATE(325)] = 5089,
  [SMALL_STATE(326)] = 5156,
  [SMALL_STATE(327)] = 5223,
  [SMALL_STATE(328)] = 5290,
  [SMALL_STATE(329)] = 5357,
  [SMALL_STATE(330)] = 5424,
  [SMALL_STATE(331)] = 5491,
  [SMALL_STATE(332)] = 5558,
  [SMALL_STATE(333)] = 5625,
  [SMALL_STATE(334)] = 5692,
  [SMALL_STATE(335)] = 5759,
  [SMALL_STATE(336)] = 5826,
  [SMALL_STATE(337)] = 5893,
  [SMALL_STATE(338)] = 5960,
  [SMALL_STATE(339)] = 6027,
  [SMALL_STATE(340)] = 6094,
  [SMALL_STATE(341)] = 6161,
  [SMALL_STATE(342)] = 6228,
  [SMALL_STATE(343)] = 6295,
  [SMALL_STATE(344)] = 6362,
  [SMALL_STATE(345)] = 6429,
  [SMALL_STATE(346)] = 6496,
  [SMALL_STATE(347)] = 6563,
  [SMALL_STATE(348)] = 6630,
  [SMALL_STATE(349)] = 6758,
  [SMALL_STATE(350)] = 6886,
  [SMALL_STATE(351)] = 6952,
  [SMALL_STATE(352)] = 7018,
  [SMALL_STATE(353)] = 7084,
  [SMALL_STATE(354)] = 7198,
  [SMALL_STATE(355)] = 7312,
  [SMALL_STATE(356)] = 7426,
  [SMALL_STATE(357)] = 7540,
  [SMALL_STATE(358)] = 7668,
  [SMALL_STATE(359)] = 7782,
  [SMALL_STATE(360)] = 7851,
  [SMALL_STATE(361)] = 7916,
  [SMALL_STATE(362)] = 8043,
  [SMALL_STATE(363)] = 8170,
  [SMALL_STATE(364)] = 8239,
  [SMALL_STATE(365)] = 8364,
  [SMALL_STATE(366)] = 8491,
  [SMALL_STATE(367)] = 8556,
  [SMALL_STATE(368)] = 8621,
  [SMALL_STATE(369)] = 8686,
  [SMALL_STATE(370)] = 8751,
  [SMALL_STATE(371)] = 8816,
  [SMALL_STATE(372)] = 8881,
  [SMALL_STATE(373)] = 8946,
  [SMALL_STATE(374)] = 9011,
  [SMALL_STATE(375)] = 9076,
  [SMALL_STATE(376)] = 9141,
  [SMALL_STATE(377)] = 9206,
  [SMALL_STATE(378)] = 9325,
  [SMALL_STATE(379)] = 9444,
  [SMALL_STATE(380)] = 9563,
  [SMALL_STATE(381)] = 9682,
  [SMALL_STATE(382)] = 9801,
  [SMALL_STATE(383)] = 9917,
  [SMALL_STATE(384)] = 10033,
  [SMALL_STATE(385)] = 10149,
  [SMALL_STATE(386)] = 10267,
  [SMALL_STATE(387)] = 10380,
  [SMALL_STATE(388)] = 10489,
  [SMALL_STATE(389)] = 10598,
  [SMALL_STATE(390)] = 10711,
  [SMALL_STATE(391)] = 10824,
  [SMALL_STATE(392)] = 10934,
  [SMALL_STATE(393)] = 11044,
  [SMALL_STATE(394)] = 11154,
  [SMALL_STATE(395)] = 11264,
  [SMALL_STATE(396)] = 11374,
  [SMALL_STATE(397)] = 11484,
  [SMALL_STATE(398)] = 11591,
  [SMALL_STATE(399)] = 11698,
  [SMALL_STATE(400)] = 11805,
  [SMALL_STATE(401)] = 11912,
  [SMALL_STATE(402)] = 11973,
  [SMALL_STATE(403)] = 12077,
  [SMALL_STATE(404)] = 12181,
  [SMALL_STATE(405)] = 12285,
  [SMALL_STATE(406)] = 12389,
  [SMALL_STATE(407)] = 12493,
  [SMALL_STATE(408)] = 12597,
  [SMALL_STATE(409)] = 12698,
  [SMALL_STATE(410)] = 12799,
  [SMALL_STATE(411)] = 12854,
  [SMALL_STATE(412)] = 12955,
  [SMALL_STATE(413)] = 13056,
  [SMALL_STATE(414)] = 13157,
  [SMALL_STATE(415)] = 13258,
  [SMALL_STATE(416)] = 13359,
  [SMALL_STATE(417)] = 13460,
  [SMALL_STATE(418)] = 13561,
  [SMALL_STATE(419)] = 13662,
  [SMALL_STATE(420)] = 13763,
  [SMALL_STATE(421)] = 13864,
  [SMALL_STATE(422)] = 13962,
  [SMALL_STATE(423)] = 14060,
  [SMALL_STATE(424)] = 14158,
  [SMALL_STATE(425)] = 14256,
  [SMALL_STATE(426)] = 14354,
  [SMALL_STATE(427)] = 14452,
  [SMALL_STATE(428)] = 14550,
  [SMALL_STATE(429)] = 14648,
  [SMALL_STATE(430)] = 14746,
  [SMALL_STATE(431)] = 14844,
  [SMALL_STATE(432)] = 14942,
  [SMALL_STATE(433)] = 15040,
  [SMALL_STATE(434)] = 15138,
  [SMALL_STATE(435)] = 15236,
  [SMALL_STATE(436)] = 15334,
  [SMALL_STATE(437)] = 15432,
  [SMALL_STATE(438)] = 15530,
  [SMALL_STATE(439)] = 15628,
  [SMALL_STATE(440)] = 15726,
  [SMALL_STATE(441)] = 15824,
  [SMALL_STATE(442)] = 15922,
  [SMALL_STATE(443)] = 16020,
  [SMALL_STATE(444)] = 16118,
  [SMALL_STATE(445)] = 16216,
  [SMALL_STATE(446)] = 16314,
  [SMALL_STATE(447)] = 16367,
  [SMALL_STATE(448)] = 16420,
  [SMALL_STATE(449)] = 16512,
  [SMALL_STATE(450)] = 16604,
  [SMALL_STATE(451)] = 16696,
  [SMALL_STATE(452)] = 16788,
  [SMALL_STATE(453)] = 16880,
  [SMALL_STATE(454)] = 16972,
  [SMALL_STATE(455)] = 17024,
  [SMALL_STATE(456)] = 17113,
  [SMALL_STATE(457)] = 17202,
  [SMALL_STATE(458)] = 17291,
  [SMALL_STATE(459)] = 17380,
  [SMALL_STATE(460)] = 17434,
  [SMALL_STATE(461)] = 17480,
  [SMALL_STATE(462)] = 17554,
  [SMALL_STATE(463)] = 17600,
  [SMALL_STATE(464)] = 17646,
  [SMALL_STATE(465)] = 17692,
  [SMALL_STATE(466)] = 17738,
  [SMALL_STATE(467)] = 17784,
  [SMALL_STATE(468)] = 17858,
  [SMALL_STATE(469)] = 17904,
  [SMALL_STATE(470)] = 17951,
  [SMALL_STATE(471)] = 17998,
  [SMALL_STATE(472)] = 18045,
  [SMALL_STATE(473)] = 18094,
  [SMALL_STATE(474)] = 18141,
  [SMALL_STATE(475)] = 18189,
  [SMALL_STATE(476)] = 18233,
  [SMALL_STATE(477)] = 18279,
  [SMALL_STATE(478)] = 18325,
  [SMALL_STATE(479)] = 18373,
  [SMALL_STATE(480)] = 18419,
  [SMALL_STATE(481)] = 18463,
  [SMALL_STATE(482)] = 18507,
  [SMALL_STATE(483)] = 18561,
  [SMALL_STATE(484)] = 18605,
  [SMALL_STATE(485)] = 18653,
  [SMALL_STATE(486)] = 18697,
  [SMALL_STATE(487)] = 18746,
  [SMALL_STATE(488)] = 18789,
  [SMALL_STATE(489)] = 18832,
  [SMALL_STATE(490)] = 18875,
  [SMALL_STATE(491)] = 18918,
  [SMALL_STATE(492)] = 18991,
  [SMALL_STATE(493)] = 19034,
  [SMALL_STATE(494)] = 19077,
  [SMALL_STATE(495)] = 19150,
  [SMALL_STATE(496)] = 19193,
  [SMALL_STATE(497)] = 19236,
  [SMALL_STATE(498)] = 19309,
  [SMALL_STATE(499)] = 19352,
  [SMALL_STATE(500)] = 19395,
  [SMALL_STATE(501)] = 19438,
  [SMALL_STATE(502)] = 19481,
  [SMALL_STATE(503)] = 19524,
  [SMALL_STATE(504)] = 19567,
  [SMALL_STATE(505)] = 19610,
  [SMALL_STATE(506)] = 19653,
  [SMALL_STATE(507)] = 19696,
  [SMALL_STATE(508)] = 19739,
  [SMALL_STATE(509)] = 19812,
  [SMALL_STATE(510)] = 19855,
  [SMALL_STATE(511)] = 19898,
  [SMALL_STATE(512)] = 19941,
  [SMALL_STATE(513)] = 19984,
  [SMALL_STATE(514)] = 20033,
  [SMALL_STATE(515)] = 20076,
  [SMALL_STATE(516)] = 20119,
  [SMALL_STATE(517)] = 20162,
  [SMALL_STATE(518)] = 20205,
  [SMALL_STATE(519)] = 20248,
  [SMALL_STATE(520)] = 20297,
  [SMALL_STATE(521)] = 20340,
  [SMALL_STATE(522)] = 20389,
  [SMALL_STATE(523)] = 20434,
  [SMALL_STATE(524)] = 20477,
  [SMALL_STATE(525)] = 20520,
  [SMALL_STATE(526)] = 20593,
  [SMALL_STATE(527)] = 20636,
  [SMALL_STATE(528)] = 20709,
  [SMALL_STATE(529)] = 20752,
  [SMALL_STATE(530)] = 20795,
  [SMALL_STATE(531)] = 20838,
  [SMALL_STATE(532)] = 20881,
  [SMALL_STATE(533)] = 20924,
  [SMALL_STATE(534)] = 20967,
  [SMALL_STATE(535)] = 21040,
  [SMALL_STATE(536)] = 21083,
  [SMALL_STATE(537)] = 21156,
  [SMALL_STATE(538)] = 21199,
  [SMALL_STATE(539)] = 21242,
  [SMALL_STATE(540)] = 21285,
  [SMALL_STATE(541)] = 21335,
  [SMALL_STATE(542)] = 21405,
  [SMALL_STATE(543)] = 21473,
  [SMALL_STATE(544)] = 21533,
  [SMALL_STATE(545)] = 21583,
  [SMALL_STATE(546)] = 21639,
  [SMALL_STATE(547)] = 21693,
  [SMALL_STATE(548)] = 21751,
  [SMALL_STATE(549)] = 21815,
  [SMALL_STATE(550)] = 21881,
  [SMALL_STATE(551)] = 21933,
  [SMALL_STATE(552)] = 22003,
  [SMALL_STATE(553)] = 22071,
  [SMALL_STATE(554)] = 22141,
  [SMALL_STATE(555)] = 22213,
  [SMALL_STATE(556)] = 22283,
  [SMALL_STATE(557)] = 22355,
  [SMALL_STATE(558)] = 22396,
  [SMALL_STATE(559)] = 22437,
  [SMALL_STATE(560)] = 22478,
  [SMALL_STATE(561)] = 22519,
  [SMALL_STATE(562)] = 22560,
  [SMALL_STATE(563)] = 22601,
  [SMALL_STATE(564)] = 22644,
  [SMALL_STATE(565)] = 22685,
  [SMALL_STATE(566)] = 22726,
  [SMALL_STATE(567)] = 22767,
  [SMALL_STATE(568)] = 22808,
  [SMALL_STATE(569)] = 22849,
  [SMALL_STATE(570)] = 22890,
  [SMALL_STATE(571)] = 22931,
  [SMALL_STATE(572)] = 22972,
  [SMALL_STATE(573)] = 23013,
  [SMALL_STATE(574)] = 23054,
  [SMALL_STATE(575)] = 23095,
  [SMALL_STATE(576)] = 23136,
  [SMALL_STATE(577)] = 23177,
  [SMALL_STATE(578)] = 23246,
  [SMALL_STATE(579)] = 23315,
  [SMALL_STATE(580)] = 23358,
  [SMALL_STATE(581)] = 23399,
  [SMALL_STATE(582)] = 23442,
  [SMALL_STATE(583)] = 23487,
  [SMALL_STATE(584)] = 23528,
  [SMALL_STATE(585)] = 23569,
  [SMALL_STATE(586)] = 23610,
  [SMALL_STATE(587)] = 23653,
  [SMALL_STATE(588)] = 23694,
  [SMALL_STATE(589)] = 23735,
  [SMALL_STATE(590)] = 23776,
  [SMALL_STATE(591)] = 23817,
  [SMALL_STATE(592)] = 23858,
  [SMALL_STATE(593)] = 23899,
  [SMALL_STATE(594)] = 23940,
  [SMALL_STATE(595)] = 23981,
  [SMALL_STATE(596)] = 24022,
  [SMALL_STATE(597)] = 24063,
  [SMALL_STATE(598)] = 24104,
  [SMALL_STATE(599)] = 24145,
  [SMALL_STATE(600)] = 24186,
  [SMALL_STATE(601)] = 24227,
  [SMALL_STATE(602)] = 24268,
  [SMALL_STATE(603)] = 24309,
  [SMALL_STATE(604)] = 24350,
  [SMALL_STATE(605)] = 24391,
  [SMALL_STATE(606)] = 24432,
  [SMALL_STATE(607)] = 24473,
  [SMALL_STATE(608)] = 24514,
  [SMALL_STATE(609)] = 24555,
  [SMALL_STATE(610)] = 24596,
  [SMALL_STATE(611)] = 24637,
  [SMALL_STATE(612)] = 24678,
  [SMALL_STATE(613)] = 24719,
  [SMALL_STATE(614)] = 24760,
  [SMALL_STATE(615)] = 24801,
  [SMALL_STATE(616)] = 24842,
  [SMALL_STATE(617)] = 24883,
  [SMALL_STATE(618)] = 24924,
  [SMALL_STATE(619)] = 24965,
  [SMALL_STATE(620)] = 25006,
  [SMALL_STATE(621)] = 25047,
  [SMALL_STATE(622)] = 25088,
  [SMALL_STATE(623)] = 25129,
  [SMALL_STATE(624)] = 25170,
  [SMALL_STATE(625)] = 25211,
  [SMALL_STATE(626)] = 25252,
  [SMALL_STATE(627)] = 25293,
  [SMALL_STATE(628)] = 25334,
  [SMALL_STATE(629)] = 25375,
  [SMALL_STATE(630)] = 25416,
  [SMALL_STATE(631)] = 25457,
  [SMALL_STATE(632)] = 25498,
  [SMALL_STATE(633)] = 25545,
  [SMALL_STATE(634)] = 25586,
  [SMALL_STATE(635)] = 25627,
  [SMALL_STATE(636)] = 25668,
  [SMALL_STATE(637)] = 25709,
  [SMALL_STATE(638)] = 25750,
  [SMALL_STATE(639)] = 25791,
  [SMALL_STATE(640)] = 25832,
  [SMALL_STATE(641)] = 25873,
  [SMALL_STATE(642)] = 25914,
  [SMALL_STATE(643)] = 25955,
  [SMALL_STATE(644)] = 25996,
  [SMALL_STATE(645)] = 26062,
  [SMALL_STATE(646)] = 26106,
  [SMALL_STATE(647)] = 26172,
  [SMALL_STATE(648)] = 26240,
  [SMALL_STATE(649)] = 26280,
  [SMALL_STATE(650)] = 26324,
  [SMALL_STATE(651)] = 26400,
  [SMALL_STATE(652)] = 26440,
  [SMALL_STATE(653)] = 26480,
  [SMALL_STATE(654)] = 26556,
  [SMALL_STATE(655)] = 26596,
  [SMALL_STATE(656)] = 26636,
  [SMALL_STATE(657)] = 26702,
  [SMALL_STATE(658)] = 26746,
  [SMALL_STATE(659)] = 26786,
  [SMALL_STATE(660)] = 26852,
  [SMALL_STATE(661)] = 26920,
  [SMALL_STATE(662)] = 26960,
  [SMALL_STATE(663)] = 27026,
  [SMALL_STATE(664)] = 27092,
  [SMALL_STATE(665)] = 27136,
  [SMALL_STATE(666)] = 27202,
  [SMALL_STATE(667)] = 27242,
  [SMALL_STATE(668)] = 27282,
  [SMALL_STATE(669)] = 27348,
  [SMALL_STATE(670)] = 27388,
  [SMALL_STATE(671)] = 27454,
  [SMALL_STATE(672)] = 27520,
  [SMALL_STATE(673)] = 27586,
  [SMALL_STATE(674)] = 27652,
  [SMALL_STATE(675)] = 27694,
  [SMALL_STATE(676)] = 27734,
  [SMALL_STATE(677)] = 27810,
  [SMALL_STATE(678)] = 27876,
  [SMALL_STATE(679)] = 27918,
  [SMALL_STATE(680)] = 27994,
  [SMALL_STATE(681)] = 28038,
  [SMALL_STATE(682)] = 28101,
  [SMALL_STATE(683)] = 28164,
  [SMALL_STATE(684)] = 28227,
  [SMALL_STATE(685)] = 28290,
  [SMALL_STATE(686)] = 28353,
  [SMALL_STATE(687)] = 28416,
  [SMALL_STATE(688)] = 28479,
  [SMALL_STATE(689)] = 28542,
  [SMALL_STATE(690)] = 28605,
  [SMALL_STATE(691)] = 28668,
  [SMALL_STATE(692)] = 28731,
  [SMALL_STATE(693)] = 28794,
  [SMALL_STATE(694)] = 28867,
  [SMALL_STATE(695)] = 28930,
  [SMALL_STATE(696)] = 28993,
  [SMALL_STATE(697)] = 29034,
  [SMALL_STATE(698)] = 29097,
  [SMALL_STATE(699)] = 29138,
  [SMALL_STATE(700)] = 29179,
  [SMALL_STATE(701)] = 29222,
  [SMALL_STATE(702)] = 29263,
  [SMALL_STATE(703)] = 29326,
  [SMALL_STATE(704)] = 29389,
  [SMALL_STATE(705)] = 29452,
  [SMALL_STATE(706)] = 29515,
  [SMALL_STATE(707)] = 29556,
  [SMALL_STATE(708)] = 29597,
  [SMALL_STATE(709)] = 29636,
  [SMALL_STATE(710)] = 29675,
  [SMALL_STATE(711)] = 29738,
  [SMALL_STATE(712)] = 29811,
  [SMALL_STATE(713)] = 29874,
  [SMALL_STATE(714)] = 29937,
  [SMALL_STATE(715)] = 30000,
  [SMALL_STATE(716)] = 30063,
  [SMALL_STATE(717)] = 30126,
  [SMALL_STATE(718)] = 30189,
  [SMALL_STATE(719)] = 30252,
  [SMALL_STATE(720)] = 30315,
  [SMALL_STATE(721)] = 30388,
  [SMALL_STATE(722)] = 30451,
  [SMALL_STATE(723)] = 30490,
  [SMALL_STATE(724)] = 30529,
  [SMALL_STATE(725)] = 30568,
  [SMALL_STATE(726)] = 30631,
  [SMALL_STATE(727)] = 30694,
  [SMALL_STATE(728)] = 30757,
  [SMALL_STATE(729)] = 30830,
  [SMALL_STATE(730)] = 30893,
  [SMALL_STATE(731)] = 30966,
  [SMALL_STATE(732)] = 31039,
  [SMALL_STATE(733)] = 31102,
  [SMALL_STATE(734)] = 31165,
  [SMALL_STATE(735)] = 31228,
  [SMALL_STATE(736)] = 31269,
  [SMALL_STATE(737)] = 31332,
  [SMALL_STATE(738)] = 31395,
  [SMALL_STATE(739)] = 31458,
  [SMALL_STATE(740)] = 31521,
  [SMALL_STATE(741)] = 31584,
  [SMALL_STATE(742)] = 31647,
  [SMALL_STATE(743)] = 31710,
  [SMALL_STATE(744)] = 31773,
  [SMALL_STATE(745)] = 31836,
  [SMALL_STATE(746)] = 31899,
  [SMALL_STATE(747)] = 31962,
  [SMALL_STATE(748)] = 32025,
  [SMALL_STATE(749)] = 32088,
  [SMALL_STATE(750)] = 32151,
  [SMALL_STATE(751)] = 32214,
  [SMALL_STATE(752)] = 32277,
  [SMALL_STATE(753)] = 32340,
  [SMALL_STATE(754)] = 32403,
  [SMALL_STATE(755)] = 32466,
  [SMALL_STATE(756)] = 32529,
  [SMALL_STATE(757)] = 32568,
  [SMALL_STATE(758)] = 32636,
  [SMALL_STATE(759)] = 32674,
  [SMALL_STATE(760)] = 32712,
  [SMALL_STATE(761)] = 32750,
  [SMALL_STATE(762)] = 32788,
  [SMALL_STATE(763)] = 32826,
  [SMALL_STATE(764)] = 32870,
  [SMALL_STATE(765)] = 32908,
  [SMALL_STATE(766)] = 32946,
  [SMALL_STATE(767)] = 33010,
  [SMALL_STATE(768)] = 33076,
  [SMALL_STATE(769)] = 33114,
  [SMALL_STATE(770)] = 33180,
  [SMALL_STATE(771)] = 33224,
  [SMALL_STATE(772)] = 33262,
  [SMALL_STATE(773)] = 33300,
  [SMALL_STATE(774)] = 33368,
  [SMALL_STATE(775)] = 33436,
  [SMALL_STATE(776)] = 33474,
  [SMALL_STATE(777)] = 33512,
  [SMALL_STATE(778)] = 33550,
  [SMALL_STATE(779)] = 33618,
  [SMALL_STATE(780)] = 33656,
  [SMALL_STATE(781)] = 33694,
  [SMALL_STATE(782)] = 33732,
  [SMALL_STATE(783)] = 33770,
  [SMALL_STATE(784)] = 33808,
  [SMALL_STATE(785)] = 33876,
  [SMALL_STATE(786)] = 33920,
  [SMALL_STATE(787)] = 33958,
  [SMALL_STATE(788)] = 34026,
  [SMALL_STATE(789)] = 34096,
  [SMALL_STATE(790)] = 34162,
  [SMALL_STATE(791)] = 34206,
  [SMALL_STATE(792)] = 34262,
  [SMALL_STATE(793)] = 34308,
  [SMALL_STATE(794)] = 34360,
  [SMALL_STATE(795)] = 34410,
  [SMALL_STATE(796)] = 34464,
  [SMALL_STATE(797)] = 34524,
  [SMALL_STATE(798)] = 34586,
  [SMALL_STATE(799)] = 34634,
  [SMALL_STATE(800)] = 34700,
  [SMALL_STATE(801)] = 34764,
  [SMALL_STATE(802)] = 34802,
  [SMALL_STATE(803)] = 34840,
  [SMALL_STATE(804)] = 34878,
  [SMALL_STATE(805)] = 34916,
  [SMALL_STATE(806)] = 34954,
  [SMALL_STATE(807)] = 34992,
  [SMALL_STATE(808)] = 35030,
  [SMALL_STATE(809)] = 35068,
  [SMALL_STATE(810)] = 35106,
  [SMALL_STATE(811)] = 35144,
  [SMALL_STATE(812)] = 35214,
  [SMALL_STATE(813)] = 35252,
  [SMALL_STATE(814)] = 35290,
  [SMALL_STATE(815)] = 35358,
  [SMALL_STATE(816)] = 35396,
  [SMALL_STATE(817)] = 35434,
  [SMALL_STATE(818)] = 35472,
  [SMALL_STATE(819)] = 35510,
  [SMALL_STATE(820)] = 35548,
  [SMALL_STATE(821)] = 35586,
  [SMALL_STATE(822)] = 35624,
  [SMALL_STATE(823)] = 35662,
  [SMALL_STATE(824)] = 35700,
  [SMALL_STATE(825)] = 35738,
  [SMALL_STATE(826)] = 35776,
  [SMALL_STATE(827)] = 35814,
  [SMALL_STATE(828)] = 35852,
  [SMALL_STATE(829)] = 35890,
  [SMALL_STATE(830)] = 35928,
  [SMALL_STATE(831)] = 35966,
  [SMALL_STATE(832)] = 36036,
  [SMALL_STATE(833)] = 36106,
  [SMALL_STATE(834)] = 36174,
  [SMALL_STATE(835)] = 36240,
  [SMALL_STATE(836)] = 36296,
  [SMALL_STATE(837)] = 36342,
  [SMALL_STATE(838)] = 36394,
  [SMALL_STATE(839)] = 36444,
  [SMALL_STATE(840)] = 36498,
  [SMALL_STATE(841)] = 36558,
  [SMALL_STATE(842)] = 36620,
  [SMALL_STATE(843)] = 36668,
  [SMALL_STATE(844)] = 36734,
  [SMALL_STATE(845)] = 36798,
  [SMALL_STATE(846)] = 36836,
  [SMALL_STATE(847)] = 36874,
  [SMALL_STATE(848)] = 36942,
  [SMALL_STATE(849)] = 37012,
  [SMALL_STATE(850)] = 37080,
  [SMALL_STATE(851)] = 37148,
  [SMALL_STATE(852)] = 37186,
  [SMALL_STATE(853)] = 37224,
  [SMALL_STATE(854)] = 37292,
  [SMALL_STATE(855)] = 37330,
  [SMALL_STATE(856)] = 37400,
  [SMALL_STATE(857)] = 37470,
  [SMALL_STATE(858)] = 37540,
  [SMALL_STATE(859)] = 37610,
  [SMALL_STATE(860)] = 37674,
  [SMALL_STATE(861)] = 37740,
  [SMALL_STATE(862)] = 37810,
  [SMALL_STATE(863)] = 37876,
  [SMALL_STATE(864)] = 37946,
  [SMALL_STATE(865)] = 38014,
  [SMALL_STATE(866)] = 38082,
  [SMALL_STATE(867)] = 38152,
  [SMALL_STATE(868)] = 38222,
  [SMALL_STATE(869)] = 38290,
  [SMALL_STATE(870)] = 38360,
  [SMALL_STATE(871)] = 38430,
  [SMALL_STATE(872)] = 38500,
  [SMALL_STATE(873)] = 38570,
  [SMALL_STATE(874)] = 38640,
  [SMALL_STATE(875)] = 38708,
  [SMALL_STATE(876)] = 38778,
  [SMALL_STATE(877)] = 38848,
  [SMALL_STATE(878)] = 38918,
  [SMALL_STATE(879)] = 38988,
  [SMALL_STATE(880)] = 39058,
  [SMALL_STATE(881)] = 39128,
  [SMALL_STATE(882)] = 39198,
  [SMALL_STATE(883)] = 39268,
  [SMALL_STATE(884)] = 39338,
  [SMALL_STATE(885)] = 39408,
  [SMALL_STATE(886)] = 39478,
  [SMALL_STATE(887)] = 39546,
  [SMALL_STATE(888)] = 39616,
  [SMALL_STATE(889)] = 39686,
  [SMALL_STATE(890)] = 39756,
  [SMALL_STATE(891)] = 39794,
  [SMALL_STATE(892)] = 39832,
  [SMALL_STATE(893)] = 39899,
  [SMALL_STATE(894)] = 39966,
  [SMALL_STATE(895)] = 40033,
  [SMALL_STATE(896)] = 40100,
  [SMALL_STATE(897)] = 40167,
  [SMALL_STATE(898)] = 40234,
  [SMALL_STATE(899)] = 40301,
  [SMALL_STATE(900)] = 40368,
  [SMALL_STATE(901)] = 40435,
  [SMALL_STATE(902)] = 40502,
  [SMALL_STATE(903)] = 40569,
  [SMALL_STATE(904)] = 40636,
  [SMALL_STATE(905)] = 40691,
  [SMALL_STATE(906)] = 40758,
  [SMALL_STATE(907)] = 40825,
  [SMALL_STATE(908)] = 40862,
  [SMALL_STATE(909)] = 40929,
  [SMALL_STATE(910)] = 40996,
  [SMALL_STATE(911)] = 41063,
  [SMALL_STATE(912)] = 41130,
  [SMALL_STATE(913)] = 41197,
  [SMALL_STATE(914)] = 41264,
  [SMALL_STATE(915)] = 41331,
  [SMALL_STATE(916)] = 41398,
  [SMALL_STATE(917)] = 41465,
  [SMALL_STATE(918)] = 41532,
  [SMALL_STATE(919)] = 41599,
  [SMALL_STATE(920)] = 41666,
  [SMALL_STATE(921)] = 41733,
  [SMALL_STATE(922)] = 41800,
  [SMALL_STATE(923)] = 41867,
  [SMALL_STATE(924)] = 41934,
  [SMALL_STATE(925)] = 42001,
  [SMALL_STATE(926)] = 42068,
  [SMALL_STATE(927)] = 42120,
  [SMALL_STATE(928)] = 42172,
  [SMALL_STATE(929)] = 42221,
  [SMALL_STATE(930)] = 42270,
  [SMALL_STATE(931)] = 42319,
  [SMALL_STATE(932)] = 42368,
  [SMALL_STATE(933)] = 42417,
  [SMALL_STATE(934)] = 42454,
  [SMALL_STATE(935)] = 42485,
  [SMALL_STATE(936)] = 42527,
  [SMALL_STATE(937)] = 42566,
  [SMALL_STATE(938)] = 42605,
  [SMALL_STATE(939)] = 42644,
  [SMALL_STATE(940)] = 42683,
  [SMALL_STATE(941)] = 42722,
  [SMALL_STATE(942)] = 42761,
  [SMALL_STATE(943)] = 42800,
  [SMALL_STATE(944)] = 42839,
  [SMALL_STATE(945)] = 42878,
  [SMALL_STATE(946)] = 42917,
  [SMALL_STATE(947)] = 42956,
  [SMALL_STATE(948)] = 42992,
  [SMALL_STATE(949)] = 43028,
  [SMALL_STATE(950)] = 43051,
  [SMALL_STATE(951)] = 43074,
  [SMALL_STATE(952)] = 43097,
  [SMALL_STATE(953)] = 43122,
  [SMALL_STATE(954)] = 43145,
  [SMALL_STATE(955)] = 43170,
  [SMALL_STATE(956)] = 43195,
  [SMALL_STATE(957)] = 43220,
  [SMALL_STATE(958)] = 43257,
  [SMALL_STATE(959)] = 43280,
  [SMALL_STATE(960)] = 43303,
  [SMALL_STATE(961)] = 43326,
  [SMALL_STATE(962)] = 43349,
  [SMALL_STATE(963)] = 43369,
  [SMALL_STATE(964)] = 43389,
  [SMALL_STATE(965)] = 43409,
  [SMALL_STATE(966)] = 43429,
  [SMALL_STATE(967)] = 43449,
  [SMALL_STATE(968)] = 43469,
  [SMALL_STATE(969)] = 43489,
  [SMALL_STATE(970)] = 43508,
  [SMALL_STATE(971)] = 43527,
  [SMALL_STATE(972)] = 43558,
  [SMALL_STATE(973)] = 43579,
  [SMALL_STATE(974)] = 43600,
  [SMALL_STATE(975)] = 43621,
  [SMALL_STATE(976)] = 43640,
  [SMALL_STATE(977)] = 43659,
  [SMALL_STATE(978)] = 43677,
  [SMALL_STATE(979)] = 43695,
  [SMALL_STATE(980)] = 43735,
  [SMALL_STATE(981)] = 43757,
  [SMALL_STATE(982)] = 43775,
  [SMALL_STATE(983)] = 43797,
  [SMALL_STATE(984)] = 43815,
  [SMALL_STATE(985)] = 43833,
  [SMALL_STATE(986)] = 43851,
  [SMALL_STATE(987)] = 43873,
  [SMALL_STATE(988)] = 43913,
  [SMALL_STATE(989)] = 43935,
  [SMALL_STATE(990)] = 43957,
  [SMALL_STATE(991)] = 43985,
  [SMALL_STATE(992)] = 44007,
  [SMALL_STATE(993)] = 44029,
  [SMALL_STATE(994)] = 44047,
  [SMALL_STATE(995)] = 44065,
  [SMALL_STATE(996)] = 44087,
  [SMALL_STATE(997)] = 44104,
  [SMALL_STATE(998)] = 44139,
  [SMALL_STATE(999)] = 44170,
  [SMALL_STATE(1000)] = 44205,
  [SMALL_STATE(1001)] = 44222,
  [SMALL_STATE(1002)] = 44239,
  [SMALL_STATE(1003)] = 44258,
  [SMALL_STATE(1004)] = 44289,
  [SMALL_STATE(1005)] = 44305,
  [SMALL_STATE(1006)] = 44325,
  [SMALL_STATE(1007)] = 44345,
  [SMALL_STATE(1008)] = 44361,
  [SMALL_STATE(1009)] = 44381,
  [SMALL_STATE(1010)] = 44401,
  [SMALL_STATE(1011)] = 44425,
  [SMALL_STATE(1012)] = 44447,
  [SMALL_STATE(1013)] = 44467,
  [SMALL_STATE(1014)] = 44499,
  [SMALL_STATE(1015)] = 44531,
  [SMALL_STATE(1016)] = 44559,
  [SMALL_STATE(1017)] = 44589,
  [SMALL_STATE(1018)] = 44609,
  [SMALL_STATE(1019)] = 44641,
  [SMALL_STATE(1020)] = 44665,
  [SMALL_STATE(1021)] = 44685,
  [SMALL_STATE(1022)] = 44705,
  [SMALL_STATE(1023)] = 44733,
  [SMALL_STATE(1024)] = 44749,
  [SMALL_STATE(1025)] = 44765,
  [SMALL_STATE(1026)] = 44793,
  [SMALL_STATE(1027)] = 44809,
  [SMALL_STATE(1028)] = 44837,
  [SMALL_STATE(1029)] = 44857,
  [SMALL_STATE(1030)] = 44872,
  [SMALL_STATE(1031)] = 44889,
  [SMALL_STATE(1032)] = 44904,
  [SMALL_STATE(1033)] = 44919,
  [SMALL_STATE(1034)] = 44948,
  [SMALL_STATE(1035)] = 44963,
  [SMALL_STATE(1036)] = 44988,
  [SMALL_STATE(1037)] = 45003,
  [SMALL_STATE(1038)] = 45018,
  [SMALL_STATE(1039)] = 45033,
  [SMALL_STATE(1040)] = 45062,
  [SMALL_STATE(1041)] = 45091,
  [SMALL_STATE(1042)] = 45106,
  [SMALL_STATE(1043)] = 45121,
  [SMALL_STATE(1044)] = 45136,
  [SMALL_STATE(1045)] = 45165,
  [SMALL_STATE(1046)] = 45180,
  [SMALL_STATE(1047)] = 45195,
  [SMALL_STATE(1048)] = 45214,
  [SMALL_STATE(1049)] = 45233,
  [SMALL_STATE(1050)] = 45248,
  [SMALL_STATE(1051)] = 45263,
  [SMALL_STATE(1052)] = 45278,
  [SMALL_STATE(1053)] = 45293,
  [SMALL_STATE(1054)] = 45308,
  [SMALL_STATE(1055)] = 45337,
  [SMALL_STATE(1056)] = 45352,
  [SMALL_STATE(1057)] = 45381,
  [SMALL_STATE(1058)] = 45396,
  [SMALL_STATE(1059)] = 45425,
  [SMALL_STATE(1060)] = 45440,
  [SMALL_STATE(1061)] = 45455,
  [SMALL_STATE(1062)] = 45470,
  [SMALL_STATE(1063)] = 45485,
  [SMALL_STATE(1064)] = 45500,
  [SMALL_STATE(1065)] = 45515,
  [SMALL_STATE(1066)] = 45530,
  [SMALL_STATE(1067)] = 45545,
  [SMALL_STATE(1068)] = 45568,
  [SMALL_STATE(1069)] = 45583,
  [SMALL_STATE(1070)] = 45598,
  [SMALL_STATE(1071)] = 45627,
  [SMALL_STATE(1072)] = 45642,
  [SMALL_STATE(1073)] = 45661,
  [SMALL_STATE(1074)] = 45680,
  [SMALL_STATE(1075)] = 45695,
  [SMALL_STATE(1076)] = 45710,
  [SMALL_STATE(1077)] = 45739,
  [SMALL_STATE(1078)] = 45754,
  [SMALL_STATE(1079)] = 45780,
  [SMALL_STATE(1080)] = 45804,
  [SMALL_STATE(1081)] = 45830,
  [SMALL_STATE(1082)] = 45856,
  [SMALL_STATE(1083)] = 45882,
  [SMALL_STATE(1084)] = 45908,
  [SMALL_STATE(1085)] = 45934,
  [SMALL_STATE(1086)] = 45958,
  [SMALL_STATE(1087)] = 45984,
  [SMALL_STATE(1088)] = 46010,
  [SMALL_STATE(1089)] = 46036,
  [SMALL_STATE(1090)] = 46054,
  [SMALL_STATE(1091)] = 46080,
  [SMALL_STATE(1092)] = 46104,
  [SMALL_STATE(1093)] = 46127,
  [SMALL_STATE(1094)] = 46150,
  [SMALL_STATE(1095)] = 46175,
  [SMALL_STATE(1096)] = 46196,
  [SMALL_STATE(1097)] = 46219,
  [SMALL_STATE(1098)] = 46242,
  [SMALL_STATE(1099)] = 46265,
  [SMALL_STATE(1100)] = 46288,
  [SMALL_STATE(1101)] = 46307,
  [SMALL_STATE(1102)] = 46320,
  [SMALL_STATE(1103)] = 46341,
  [SMALL_STATE(1104)] = 46354,
  [SMALL_STATE(1105)] = 46367,
  [SMALL_STATE(1106)] = 46392,
  [SMALL_STATE(1107)] = 46405,
  [SMALL_STATE(1108)] = 46428,
  [SMALL_STATE(1109)] = 46453,
  [SMALL_STATE(1110)] = 46476,
  [SMALL_STATE(1111)] = 46501,
  [SMALL_STATE(1112)] = 46522,
  [SMALL_STATE(1113)] = 46547,
  [SMALL_STATE(1114)] = 46567,
  [SMALL_STATE(1115)] = 46587,
  [SMALL_STATE(1116)] = 46607,
  [SMALL_STATE(1117)] = 46627,
  [SMALL_STATE(1118)] = 46647,
  [SMALL_STATE(1119)] = 46667,
  [SMALL_STATE(1120)] = 46687,
  [SMALL_STATE(1121)] = 46707,
  [SMALL_STATE(1122)] = 46727,
  [SMALL_STATE(1123)] = 46747,
  [SMALL_STATE(1124)] = 46767,
  [SMALL_STATE(1125)] = 46787,
  [SMALL_STATE(1126)] = 46807,
  [SMALL_STATE(1127)] = 46827,
  [SMALL_STATE(1128)] = 46847,
  [SMALL_STATE(1129)] = 46867,
  [SMALL_STATE(1130)] = 46889,
  [SMALL_STATE(1131)] = 46909,
  [SMALL_STATE(1132)] = 46929,
  [SMALL_STATE(1133)] = 46951,
  [SMALL_STATE(1134)] = 46971,
  [SMALL_STATE(1135)] = 46991,
  [SMALL_STATE(1136)] = 47011,
  [SMALL_STATE(1137)] = 47031,
  [SMALL_STATE(1138)] = 47053,
  [SMALL_STATE(1139)] = 47073,
  [SMALL_STATE(1140)] = 47093,
  [SMALL_STATE(1141)] = 47113,
  [SMALL_STATE(1142)] = 47128,
  [SMALL_STATE(1143)] = 47147,
  [SMALL_STATE(1144)] = 47166,
  [SMALL_STATE(1145)] = 47177,
  [SMALL_STATE(1146)] = 47196,
  [SMALL_STATE(1147)] = 47215,
  [SMALL_STATE(1148)] = 47234,
  [SMALL_STATE(1149)] = 47253,
  [SMALL_STATE(1150)] = 47264,
  [SMALL_STATE(1151)] = 47279,
  [SMALL_STATE(1152)] = 47290,
  [SMALL_STATE(1153)] = 47301,
  [SMALL_STATE(1154)] = 47316,
  [SMALL_STATE(1155)] = 47333,
  [SMALL_STATE(1156)] = 47344,
  [SMALL_STATE(1157)] = 47361,
  [SMALL_STATE(1158)] = 47380,
  [SMALL_STATE(1159)] = 47391,
  [SMALL_STATE(1160)] = 47406,
  [SMALL_STATE(1161)] = 47423,
  [SMALL_STATE(1162)] = 47434,
  [SMALL_STATE(1163)] = 47451,
  [SMALL_STATE(1164)] = 47468,
  [SMALL_STATE(1165)] = 47487,
  [SMALL_STATE(1166)] = 47498,
  [SMALL_STATE(1167)] = 47513,
  [SMALL_STATE(1168)] = 47524,
  [SMALL_STATE(1169)] = 47535,
  [SMALL_STATE(1170)] = 47552,
  [SMALL_STATE(1171)] = 47569,
  [SMALL_STATE(1172)] = 47586,
  [SMALL_STATE(1173)] = 47597,
  [SMALL_STATE(1174)] = 47616,
  [SMALL_STATE(1175)] = 47635,
  [SMALL_STATE(1176)] = 47646,
  [SMALL_STATE(1177)] = 47661,
  [SMALL_STATE(1178)] = 47678,
  [SMALL_STATE(1179)] = 47697,
  [SMALL_STATE(1180)] = 47712,
  [SMALL_STATE(1181)] = 47723,
  [SMALL_STATE(1182)] = 47738,
  [SMALL_STATE(1183)] = 47757,
  [SMALL_STATE(1184)] = 47776,
  [SMALL_STATE(1185)] = 47793,
  [SMALL_STATE(1186)] = 47804,
  [SMALL_STATE(1187)] = 47823,
  [SMALL_STATE(1188)] = 47842,
  [SMALL_STATE(1189)] = 47859,
  [SMALL_STATE(1190)] = 47870,
  [SMALL_STATE(1191)] = 47889,
  [SMALL_STATE(1192)] = 47900,
  [SMALL_STATE(1193)] = 47914,
  [SMALL_STATE(1194)] = 47930,
  [SMALL_STATE(1195)] = 47944,
  [SMALL_STATE(1196)] = 47960,
  [SMALL_STATE(1197)] = 47976,
  [SMALL_STATE(1198)] = 47992,
  [SMALL_STATE(1199)] = 48008,
  [SMALL_STATE(1200)] = 48024,
  [SMALL_STATE(1201)] = 48040,
  [SMALL_STATE(1202)] = 48056,
  [SMALL_STATE(1203)] = 48072,
  [SMALL_STATE(1204)] = 48088,
  [SMALL_STATE(1205)] = 48102,
  [SMALL_STATE(1206)] = 48114,
  [SMALL_STATE(1207)] = 48130,
  [SMALL_STATE(1208)] = 48144,
  [SMALL_STATE(1209)] = 48158,
  [SMALL_STATE(1210)] = 48172,
  [SMALL_STATE(1211)] = 48184,
  [SMALL_STATE(1212)] = 48198,
  [SMALL_STATE(1213)] = 48214,
  [SMALL_STATE(1214)] = 48230,
  [SMALL_STATE(1215)] = 48244,
  [SMALL_STATE(1216)] = 48256,
  [SMALL_STATE(1217)] = 48268,
  [SMALL_STATE(1218)] = 48284,
  [SMALL_STATE(1219)] = 48298,
  [SMALL_STATE(1220)] = 48310,
  [SMALL_STATE(1221)] = 48322,
  [SMALL_STATE(1222)] = 48334,
  [SMALL_STATE(1223)] = 48348,
  [SMALL_STATE(1224)] = 48364,
  [SMALL_STATE(1225)] = 48380,
  [SMALL_STATE(1226)] = 48396,
  [SMALL_STATE(1227)] = 48408,
  [SMALL_STATE(1228)] = 48424,
  [SMALL_STATE(1229)] = 48434,
  [SMALL_STATE(1230)] = 48446,
  [SMALL_STATE(1231)] = 48456,
  [SMALL_STATE(1232)] = 48466,
  [SMALL_STATE(1233)] = 48482,
  [SMALL_STATE(1234)] = 48494,
  [SMALL_STATE(1235)] = 48510,
  [SMALL_STATE(1236)] = 48526,
  [SMALL_STATE(1237)] = 48542,
  [SMALL_STATE(1238)] = 48554,
  [SMALL_STATE(1239)] = 48570,
  [SMALL_STATE(1240)] = 48580,
  [SMALL_STATE(1241)] = 48596,
  [SMALL_STATE(1242)] = 48612,
  [SMALL_STATE(1243)] = 48628,
  [SMALL_STATE(1244)] = 48644,
  [SMALL_STATE(1245)] = 48660,
  [SMALL_STATE(1246)] = 48676,
  [SMALL_STATE(1247)] = 48692,
  [SMALL_STATE(1248)] = 48708,
  [SMALL_STATE(1249)] = 48724,
  [SMALL_STATE(1250)] = 48740,
  [SMALL_STATE(1251)] = 48756,
  [SMALL_STATE(1252)] = 48772,
  [SMALL_STATE(1253)] = 48784,
  [SMALL_STATE(1254)] = 48800,
  [SMALL_STATE(1255)] = 48814,
  [SMALL_STATE(1256)] = 48830,
  [SMALL_STATE(1257)] = 48844,
  [SMALL_STATE(1258)] = 48860,
  [SMALL_STATE(1259)] = 48876,
  [SMALL_STATE(1260)] = 48892,
  [SMALL_STATE(1261)] = 48908,
  [SMALL_STATE(1262)] = 48924,
  [SMALL_STATE(1263)] = 48940,
  [SMALL_STATE(1264)] = 48954,
  [SMALL_STATE(1265)] = 48970,
  [SMALL_STATE(1266)] = 48986,
  [SMALL_STATE(1267)] = 49000,
  [SMALL_STATE(1268)] = 49012,
  [SMALL_STATE(1269)] = 49028,
  [SMALL_STATE(1270)] = 49044,
  [SMALL_STATE(1271)] = 49060,
  [SMALL_STATE(1272)] = 49076,
  [SMALL_STATE(1273)] = 49092,
  [SMALL_STATE(1274)] = 49108,
  [SMALL_STATE(1275)] = 49122,
  [SMALL_STATE(1276)] = 49138,
  [SMALL_STATE(1277)] = 49154,
  [SMALL_STATE(1278)] = 49170,
  [SMALL_STATE(1279)] = 49186,
  [SMALL_STATE(1280)] = 49202,
  [SMALL_STATE(1281)] = 49216,
  [SMALL_STATE(1282)] = 49228,
  [SMALL_STATE(1283)] = 49242,
  [SMALL_STATE(1284)] = 49258,
  [SMALL_STATE(1285)] = 49274,
  [SMALL_STATE(1286)] = 49290,
  [SMALL_STATE(1287)] = 49306,
  [SMALL_STATE(1288)] = 49322,
  [SMALL_STATE(1289)] = 49338,
  [SMALL_STATE(1290)] = 49354,
  [SMALL_STATE(1291)] = 49370,
  [SMALL_STATE(1292)] = 49386,
  [SMALL_STATE(1293)] = 49400,
  [SMALL_STATE(1294)] = 49416,
  [SMALL_STATE(1295)] = 49432,
  [SMALL_STATE(1296)] = 49446,
  [SMALL_STATE(1297)] = 49460,
  [SMALL_STATE(1298)] = 49472,
  [SMALL_STATE(1299)] = 49488,
  [SMALL_STATE(1300)] = 49504,
  [SMALL_STATE(1301)] = 49514,
  [SMALL_STATE(1302)] = 49530,
  [SMALL_STATE(1303)] = 49546,
  [SMALL_STATE(1304)] = 49560,
  [SMALL_STATE(1305)] = 49574,
  [SMALL_STATE(1306)] = 49590,
  [SMALL_STATE(1307)] = 49606,
  [SMALL_STATE(1308)] = 49622,
  [SMALL_STATE(1309)] = 49638,
  [SMALL_STATE(1310)] = 49654,
  [SMALL_STATE(1311)] = 49670,
  [SMALL_STATE(1312)] = 49686,
  [SMALL_STATE(1313)] = 49702,
  [SMALL_STATE(1314)] = 49718,
  [SMALL_STATE(1315)] = 49734,
  [SMALL_STATE(1316)] = 49750,
  [SMALL_STATE(1317)] = 49764,
  [SMALL_STATE(1318)] = 49780,
  [SMALL_STATE(1319)] = 49794,
  [SMALL_STATE(1320)] = 49810,
  [SMALL_STATE(1321)] = 49826,
  [SMALL_STATE(1322)] = 49842,
  [SMALL_STATE(1323)] = 49858,
  [SMALL_STATE(1324)] = 49874,
  [SMALL_STATE(1325)] = 49890,
  [SMALL_STATE(1326)] = 49906,
  [SMALL_STATE(1327)] = 49919,
  [SMALL_STATE(1328)] = 49930,
  [SMALL_STATE(1329)] = 49943,
  [SMALL_STATE(1330)] = 49952,
  [SMALL_STATE(1331)] = 49965,
  [SMALL_STATE(1332)] = 49976,
  [SMALL_STATE(1333)] = 49989,
  [SMALL_STATE(1334)] = 49998,
  [SMALL_STATE(1335)] = 50007,
  [SMALL_STATE(1336)] = 50020,
  [SMALL_STATE(1337)] = 50033,
  [SMALL_STATE(1338)] = 50046,
  [SMALL_STATE(1339)] = 50057,
  [SMALL_STATE(1340)] = 50070,
  [SMALL_STATE(1341)] = 50083,
  [SMALL_STATE(1342)] = 50096,
  [SMALL_STATE(1343)] = 50105,
  [SMALL_STATE(1344)] = 50114,
  [SMALL_STATE(1345)] = 50127,
  [SMALL_STATE(1346)] = 50140,
  [SMALL_STATE(1347)] = 50151,
  [SMALL_STATE(1348)] = 50164,
  [SMALL_STATE(1349)] = 50177,
  [SMALL_STATE(1350)] = 50188,
  [SMALL_STATE(1351)] = 50201,
  [SMALL_STATE(1352)] = 50214,
  [SMALL_STATE(1353)] = 50227,
  [SMALL_STATE(1354)] = 50240,
  [SMALL_STATE(1355)] = 50253,
  [SMALL_STATE(1356)] = 50266,
  [SMALL_STATE(1357)] = 50277,
  [SMALL_STATE(1358)] = 50290,
  [SMALL_STATE(1359)] = 50303,
  [SMALL_STATE(1360)] = 50314,
  [SMALL_STATE(1361)] = 50323,
  [SMALL_STATE(1362)] = 50332,
  [SMALL_STATE(1363)] = 50341,
  [SMALL_STATE(1364)] = 50350,
  [SMALL_STATE(1365)] = 50359,
  [SMALL_STATE(1366)] = 50372,
  [SMALL_STATE(1367)] = 50381,
  [SMALL_STATE(1368)] = 50390,
  [SMALL_STATE(1369)] = 50403,
  [SMALL_STATE(1370)] = 50416,
  [SMALL_STATE(1371)] = 50429,
  [SMALL_STATE(1372)] = 50442,
  [SMALL_STATE(1373)] = 50455,
  [SMALL_STATE(1374)] = 50468,
  [SMALL_STATE(1375)] = 50481,
  [SMALL_STATE(1376)] = 50492,
  [SMALL_STATE(1377)] = 50503,
  [SMALL_STATE(1378)] = 50516,
  [SMALL_STATE(1379)] = 50529,
  [SMALL_STATE(1380)] = 50540,
  [SMALL_STATE(1381)] = 50553,
  [SMALL_STATE(1382)] = 50566,
  [SMALL_STATE(1383)] = 50579,
  [SMALL_STATE(1384)] = 50592,
  [SMALL_STATE(1385)] = 50605,
  [SMALL_STATE(1386)] = 50616,
  [SMALL_STATE(1387)] = 50629,
  [SMALL_STATE(1388)] = 50642,
  [SMALL_STATE(1389)] = 50655,
  [SMALL_STATE(1390)] = 50668,
  [SMALL_STATE(1391)] = 50681,
  [SMALL_STATE(1392)] = 50694,
  [SMALL_STATE(1393)] = 50707,
  [SMALL_STATE(1394)] = 50720,
  [SMALL_STATE(1395)] = 50733,
  [SMALL_STATE(1396)] = 50746,
  [SMALL_STATE(1397)] = 50759,
  [SMALL_STATE(1398)] = 50772,
  [SMALL_STATE(1399)] = 50785,
  [SMALL_STATE(1400)] = 50798,
  [SMALL_STATE(1401)] = 50811,
  [SMALL_STATE(1402)] = 50820,
  [SMALL_STATE(1403)] = 50829,
  [SMALL_STATE(1404)] = 50842,
  [SMALL_STATE(1405)] = 50851,
  [SMALL_STATE(1406)] = 50860,
  [SMALL_STATE(1407)] = 50873,
  [SMALL_STATE(1408)] = 50882,
  [SMALL_STATE(1409)] = 50895,
  [SMALL_STATE(1410)] = 50904,
  [SMALL_STATE(1411)] = 50917,
  [SMALL_STATE(1412)] = 50930,
  [SMALL_STATE(1413)] = 50943,
  [SMALL_STATE(1414)] = 50956,
  [SMALL_STATE(1415)] = 50969,
  [SMALL_STATE(1416)] = 50982,
  [SMALL_STATE(1417)] = 50991,
  [SMALL_STATE(1418)] = 51004,
  [SMALL_STATE(1419)] = 51017,
  [SMALL_STATE(1420)] = 51030,
  [SMALL_STATE(1421)] = 51043,
  [SMALL_STATE(1422)] = 51056,
  [SMALL_STATE(1423)] = 51069,
  [SMALL_STATE(1424)] = 51082,
  [SMALL_STATE(1425)] = 51091,
  [SMALL_STATE(1426)] = 51104,
  [SMALL_STATE(1427)] = 51113,
  [SMALL_STATE(1428)] = 51126,
  [SMALL_STATE(1429)] = 51137,
  [SMALL_STATE(1430)] = 51150,
  [SMALL_STATE(1431)] = 51163,
  [SMALL_STATE(1432)] = 51176,
  [SMALL_STATE(1433)] = 51189,
  [SMALL_STATE(1434)] = 51202,
  [SMALL_STATE(1435)] = 51215,
  [SMALL_STATE(1436)] = 51228,
  [SMALL_STATE(1437)] = 51241,
  [SMALL_STATE(1438)] = 51254,
  [SMALL_STATE(1439)] = 51265,
  [SMALL_STATE(1440)] = 51278,
  [SMALL_STATE(1441)] = 51291,
  [SMALL_STATE(1442)] = 51302,
  [SMALL_STATE(1443)] = 51311,
  [SMALL_STATE(1444)] = 51324,
  [SMALL_STATE(1445)] = 51337,
  [SMALL_STATE(1446)] = 51350,
  [SMALL_STATE(1447)] = 51363,
  [SMALL_STATE(1448)] = 51372,
  [SMALL_STATE(1449)] = 51385,
  [SMALL_STATE(1450)] = 51398,
  [SMALL_STATE(1451)] = 51411,
  [SMALL_STATE(1452)] = 51420,
  [SMALL_STATE(1453)] = 51429,
  [SMALL_STATE(1454)] = 51442,
  [SMALL_STATE(1455)] = 51451,
  [SMALL_STATE(1456)] = 51464,
  [SMALL_STATE(1457)] = 51477,
  [SMALL_STATE(1458)] = 51488,
  [SMALL_STATE(1459)] = 51501,
  [SMALL_STATE(1460)] = 51514,
  [SMALL_STATE(1461)] = 51527,
  [SMALL_STATE(1462)] = 51540,
  [SMALL_STATE(1463)] = 51553,
  [SMALL_STATE(1464)] = 51566,
  [SMALL_STATE(1465)] = 51575,
  [SMALL_STATE(1466)] = 51588,
  [SMALL_STATE(1467)] = 51601,
  [SMALL_STATE(1468)] = 51614,
  [SMALL_STATE(1469)] = 51625,
  [SMALL_STATE(1470)] = 51638,
  [SMALL_STATE(1471)] = 51651,
  [SMALL_STATE(1472)] = 51660,
  [SMALL_STATE(1473)] = 51671,
  [SMALL_STATE(1474)] = 51680,
  [SMALL_STATE(1475)] = 51693,
  [SMALL_STATE(1476)] = 51706,
  [SMALL_STATE(1477)] = 51719,
  [SMALL_STATE(1478)] = 51732,
  [SMALL_STATE(1479)] = 51741,
  [SMALL_STATE(1480)] = 51754,
  [SMALL_STATE(1481)] = 51763,
  [SMALL_STATE(1482)] = 51772,
  [SMALL_STATE(1483)] = 51781,
  [SMALL_STATE(1484)] = 51790,
  [SMALL_STATE(1485)] = 51799,
  [SMALL_STATE(1486)] = 51808,
  [SMALL_STATE(1487)] = 51821,
  [SMALL_STATE(1488)] = 51832,
  [SMALL_STATE(1489)] = 51841,
  [SMALL_STATE(1490)] = 51854,
  [SMALL_STATE(1491)] = 51867,
  [SMALL_STATE(1492)] = 51876,
  [SMALL_STATE(1493)] = 51889,
  [SMALL_STATE(1494)] = 51902,
  [SMALL_STATE(1495)] = 51915,
  [SMALL_STATE(1496)] = 51928,
  [SMALL_STATE(1497)] = 51941,
  [SMALL_STATE(1498)] = 51950,
  [SMALL_STATE(1499)] = 51963,
  [SMALL_STATE(1500)] = 51974,
  [SMALL_STATE(1501)] = 51987,
  [SMALL_STATE(1502)] = 51996,
  [SMALL_STATE(1503)] = 52007,
  [SMALL_STATE(1504)] = 52020,
  [SMALL_STATE(1505)] = 52033,
  [SMALL_STATE(1506)] = 52042,
  [SMALL_STATE(1507)] = 52051,
  [SMALL_STATE(1508)] = 52060,
  [SMALL_STATE(1509)] = 52073,
  [SMALL_STATE(1510)] = 52082,
  [SMALL_STATE(1511)] = 52091,
  [SMALL_STATE(1512)] = 52100,
  [SMALL_STATE(1513)] = 52111,
  [SMALL_STATE(1514)] = 52120,
  [SMALL_STATE(1515)] = 52131,
  [SMALL_STATE(1516)] = 52144,
  [SMALL_STATE(1517)] = 52153,
  [SMALL_STATE(1518)] = 52166,
  [SMALL_STATE(1519)] = 52175,
  [SMALL_STATE(1520)] = 52184,
  [SMALL_STATE(1521)] = 52197,
  [SMALL_STATE(1522)] = 52210,
  [SMALL_STATE(1523)] = 52221,
  [SMALL_STATE(1524)] = 52234,
  [SMALL_STATE(1525)] = 52243,
  [SMALL_STATE(1526)] = 52256,
  [SMALL_STATE(1527)] = 52265,
  [SMALL_STATE(1528)] = 52274,
  [SMALL_STATE(1529)] = 52287,
  [SMALL_STATE(1530)] = 52300,
  [SMALL_STATE(1531)] = 52313,
  [SMALL_STATE(1532)] = 52326,
  [SMALL_STATE(1533)] = 52339,
  [SMALL_STATE(1534)] = 52348,
  [SMALL_STATE(1535)] = 52359,
  [SMALL_STATE(1536)] = 52372,
  [SMALL_STATE(1537)] = 52385,
  [SMALL_STATE(1538)] = 52396,
  [SMALL_STATE(1539)] = 52405,
  [SMALL_STATE(1540)] = 52418,
  [SMALL_STATE(1541)] = 52427,
  [SMALL_STATE(1542)] = 52435,
  [SMALL_STATE(1543)] = 52445,
  [SMALL_STATE(1544)] = 52453,
  [SMALL_STATE(1545)] = 52463,
  [SMALL_STATE(1546)] = 52473,
  [SMALL_STATE(1547)] = 52483,
  [SMALL_STATE(1548)] = 52493,
  [SMALL_STATE(1549)] = 52503,
  [SMALL_STATE(1550)] = 52513,
  [SMALL_STATE(1551)] = 52523,
  [SMALL_STATE(1552)] = 52533,
  [SMALL_STATE(1553)] = 52543,
  [SMALL_STATE(1554)] = 52553,
  [SMALL_STATE(1555)] = 52561,
  [SMALL_STATE(1556)] = 52571,
  [SMALL_STATE(1557)] = 52579,
  [SMALL_STATE(1558)] = 52589,
  [SMALL_STATE(1559)] = 52599,
  [SMALL_STATE(1560)] = 52609,
  [SMALL_STATE(1561)] = 52619,
  [SMALL_STATE(1562)] = 52627,
  [SMALL_STATE(1563)] = 52635,
  [SMALL_STATE(1564)] = 52645,
  [SMALL_STATE(1565)] = 52653,
  [SMALL_STATE(1566)] = 52663,
  [SMALL_STATE(1567)] = 52671,
  [SMALL_STATE(1568)] = 52681,
  [SMALL_STATE(1569)] = 52689,
  [SMALL_STATE(1570)] = 52697,
  [SMALL_STATE(1571)] = 52707,
  [SMALL_STATE(1572)] = 52715,
  [SMALL_STATE(1573)] = 52725,
  [SMALL_STATE(1574)] = 52733,
  [SMALL_STATE(1575)] = 52741,
  [SMALL_STATE(1576)] = 52749,
  [SMALL_STATE(1577)] = 52757,
  [SMALL_STATE(1578)] = 52767,
  [SMALL_STATE(1579)] = 52777,
  [SMALL_STATE(1580)] = 52787,
  [SMALL_STATE(1581)] = 52797,
  [SMALL_STATE(1582)] = 52807,
  [SMALL_STATE(1583)] = 52815,
  [SMALL_STATE(1584)] = 52823,
  [SMALL_STATE(1585)] = 52833,
  [SMALL_STATE(1586)] = 52841,
  [SMALL_STATE(1587)] = 52849,
  [SMALL_STATE(1588)] = 52859,
  [SMALL_STATE(1589)] = 52867,
  [SMALL_STATE(1590)] = 52877,
  [SMALL_STATE(1591)] = 52887,
  [SMALL_STATE(1592)] = 52895,
  [SMALL_STATE(1593)] = 52905,
  [SMALL_STATE(1594)] = 52915,
  [SMALL_STATE(1595)] = 52923,
  [SMALL_STATE(1596)] = 52933,
  [SMALL_STATE(1597)] = 52941,
  [SMALL_STATE(1598)] = 52951,
  [SMALL_STATE(1599)] = 52961,
  [SMALL_STATE(1600)] = 52971,
  [SMALL_STATE(1601)] = 52981,
  [SMALL_STATE(1602)] = 52991,
  [SMALL_STATE(1603)] = 53001,
  [SMALL_STATE(1604)] = 53011,
  [SMALL_STATE(1605)] = 53021,
  [SMALL_STATE(1606)] = 53031,
  [SMALL_STATE(1607)] = 53041,
  [SMALL_STATE(1608)] = 53049,
  [SMALL_STATE(1609)] = 53059,
  [SMALL_STATE(1610)] = 53067,
  [SMALL_STATE(1611)] = 53077,
  [SMALL_STATE(1612)] = 53087,
  [SMALL_STATE(1613)] = 53097,
  [SMALL_STATE(1614)] = 53107,
  [SMALL_STATE(1615)] = 53115,
  [SMALL_STATE(1616)] = 53123,
  [SMALL_STATE(1617)] = 53133,
  [SMALL_STATE(1618)] = 53141,
  [SMALL_STATE(1619)] = 53149,
  [SMALL_STATE(1620)] = 53157,
  [SMALL_STATE(1621)] = 53165,
  [SMALL_STATE(1622)] = 53175,
  [SMALL_STATE(1623)] = 53185,
  [SMALL_STATE(1624)] = 53195,
  [SMALL_STATE(1625)] = 53203,
  [SMALL_STATE(1626)] = 53211,
  [SMALL_STATE(1627)] = 53221,
  [SMALL_STATE(1628)] = 53231,
  [SMALL_STATE(1629)] = 53241,
  [SMALL_STATE(1630)] = 53249,
  [SMALL_STATE(1631)] = 53259,
  [SMALL_STATE(1632)] = 53267,
  [SMALL_STATE(1633)] = 53275,
  [SMALL_STATE(1634)] = 53285,
  [SMALL_STATE(1635)] = 53293,
  [SMALL_STATE(1636)] = 53303,
  [SMALL_STATE(1637)] = 53313,
  [SMALL_STATE(1638)] = 53321,
  [SMALL_STATE(1639)] = 53331,
  [SMALL_STATE(1640)] = 53341,
  [SMALL_STATE(1641)] = 53351,
  [SMALL_STATE(1642)] = 53359,
  [SMALL_STATE(1643)] = 53369,
  [SMALL_STATE(1644)] = 53379,
  [SMALL_STATE(1645)] = 53389,
  [SMALL_STATE(1646)] = 53399,
  [SMALL_STATE(1647)] = 53407,
  [SMALL_STATE(1648)] = 53417,
  [SMALL_STATE(1649)] = 53427,
  [SMALL_STATE(1650)] = 53437,
  [SMALL_STATE(1651)] = 53447,
  [SMALL_STATE(1652)] = 53455,
  [SMALL_STATE(1653)] = 53465,
  [SMALL_STATE(1654)] = 53475,
  [SMALL_STATE(1655)] = 53483,
  [SMALL_STATE(1656)] = 53493,
  [SMALL_STATE(1657)] = 53503,
  [SMALL_STATE(1658)] = 53513,
  [SMALL_STATE(1659)] = 53523,
  [SMALL_STATE(1660)] = 53533,
  [SMALL_STATE(1661)] = 53543,
  [SMALL_STATE(1662)] = 53553,
  [SMALL_STATE(1663)] = 53563,
  [SMALL_STATE(1664)] = 53573,
  [SMALL_STATE(1665)] = 53581,
  [SMALL_STATE(1666)] = 53589,
  [SMALL_STATE(1667)] = 53597,
  [SMALL_STATE(1668)] = 53605,
  [SMALL_STATE(1669)] = 53615,
  [SMALL_STATE(1670)] = 53625,
  [SMALL_STATE(1671)] = 53635,
  [SMALL_STATE(1672)] = 53645,
  [SMALL_STATE(1673)] = 53655,
  [SMALL_STATE(1674)] = 53663,
  [SMALL_STATE(1675)] = 53673,
  [SMALL_STATE(1676)] = 53681,
  [SMALL_STATE(1677)] = 53689,
  [SMALL_STATE(1678)] = 53697,
  [SMALL_STATE(1679)] = 53705,
  [SMALL_STATE(1680)] = 53715,
  [SMALL_STATE(1681)] = 53723,
  [SMALL_STATE(1682)] = 53731,
  [SMALL_STATE(1683)] = 53741,
  [SMALL_STATE(1684)] = 53751,
  [SMALL_STATE(1685)] = 53759,
  [SMALL_STATE(1686)] = 53769,
  [SMALL_STATE(1687)] = 53779,
  [SMALL_STATE(1688)] = 53789,
  [SMALL_STATE(1689)] = 53797,
  [SMALL_STATE(1690)] = 53805,
  [SMALL_STATE(1691)] = 53815,
  [SMALL_STATE(1692)] = 53823,
  [SMALL_STATE(1693)] = 53831,
  [SMALL_STATE(1694)] = 53839,
  [SMALL_STATE(1695)] = 53849,
  [SMALL_STATE(1696)] = 53857,
  [SMALL_STATE(1697)] = 53865,
  [SMALL_STATE(1698)] = 53873,
  [SMALL_STATE(1699)] = 53883,
  [SMALL_STATE(1700)] = 53893,
  [SMALL_STATE(1701)] = 53903,
  [SMALL_STATE(1702)] = 53913,
  [SMALL_STATE(1703)] = 53921,
  [SMALL_STATE(1704)] = 53929,
  [SMALL_STATE(1705)] = 53937,
  [SMALL_STATE(1706)] = 53947,
  [SMALL_STATE(1707)] = 53955,
  [SMALL_STATE(1708)] = 53963,
  [SMALL_STATE(1709)] = 53973,
  [SMALL_STATE(1710)] = 53981,
  [SMALL_STATE(1711)] = 53991,
  [SMALL_STATE(1712)] = 54001,
  [SMALL_STATE(1713)] = 54009,
  [SMALL_STATE(1714)] = 54019,
  [SMALL_STATE(1715)] = 54029,
  [SMALL_STATE(1716)] = 54037,
  [SMALL_STATE(1717)] = 54045,
  [SMALL_STATE(1718)] = 54053,
  [SMALL_STATE(1719)] = 54063,
  [SMALL_STATE(1720)] = 54071,
  [SMALL_STATE(1721)] = 54079,
  [SMALL_STATE(1722)] = 54087,
  [SMALL_STATE(1723)] = 54097,
  [SMALL_STATE(1724)] = 54107,
  [SMALL_STATE(1725)] = 54115,
  [SMALL_STATE(1726)] = 54125,
  [SMALL_STATE(1727)] = 54135,
  [SMALL_STATE(1728)] = 54145,
  [SMALL_STATE(1729)] = 54155,
  [SMALL_STATE(1730)] = 54163,
  [SMALL_STATE(1731)] = 54171,
  [SMALL_STATE(1732)] = 54181,
  [SMALL_STATE(1733)] = 54191,
  [SMALL_STATE(1734)] = 54201,
  [SMALL_STATE(1735)] = 54211,
  [SMALL_STATE(1736)] = 54219,
  [SMALL_STATE(1737)] = 54229,
  [SMALL_STATE(1738)] = 54239,
  [SMALL_STATE(1739)] = 54249,
  [SMALL_STATE(1740)] = 54259,
  [SMALL_STATE(1741)] = 54267,
  [SMALL_STATE(1742)] = 54275,
  [SMALL_STATE(1743)] = 54283,
  [SMALL_STATE(1744)] = 54290,
  [SMALL_STATE(1745)] = 54297,
  [SMALL_STATE(1746)] = 54304,
  [SMALL_STATE(1747)] = 54311,
  [SMALL_STATE(1748)] = 54318,
  [SMALL_STATE(1749)] = 54325,
  [SMALL_STATE(1750)] = 54332,
  [SMALL_STATE(1751)] = 54339,
  [SMALL_STATE(1752)] = 54346,
  [SMALL_STATE(1753)] = 54353,
  [SMALL_STATE(1754)] = 54360,
  [SMALL_STATE(1755)] = 54367,
  [SMALL_STATE(1756)] = 54374,
  [SMALL_STATE(1757)] = 54381,
  [SMALL_STATE(1758)] = 54388,
  [SMALL_STATE(1759)] = 54395,
  [SMALL_STATE(1760)] = 54402,
  [SMALL_STATE(1761)] = 54409,
  [SMALL_STATE(1762)] = 54416,
  [SMALL_STATE(1763)] = 54423,
  [SMALL_STATE(1764)] = 54430,
  [SMALL_STATE(1765)] = 54437,
  [SMALL_STATE(1766)] = 54444,
  [SMALL_STATE(1767)] = 54451,
  [SMALL_STATE(1768)] = 54458,
  [SMALL_STATE(1769)] = 54465,
  [SMALL_STATE(1770)] = 54472,
  [SMALL_STATE(1771)] = 54479,
  [SMALL_STATE(1772)] = 54486,
  [SMALL_STATE(1773)] = 54493,
  [SMALL_STATE(1774)] = 54500,
  [SMALL_STATE(1775)] = 54507,
  [SMALL_STATE(1776)] = 54514,
  [SMALL_STATE(1777)] = 54521,
  [SMALL_STATE(1778)] = 54528,
  [SMALL_STATE(1779)] = 54535,
  [SMALL_STATE(1780)] = 54542,
  [SMALL_STATE(1781)] = 54549,
  [SMALL_STATE(1782)] = 54556,
  [SMALL_STATE(1783)] = 54563,
  [SMALL_STATE(1784)] = 54570,
  [SMALL_STATE(1785)] = 54577,
  [SMALL_STATE(1786)] = 54584,
  [SMALL_STATE(1787)] = 54591,
  [SMALL_STATE(1788)] = 54598,
  [SMALL_STATE(1789)] = 54605,
  [SMALL_STATE(1790)] = 54612,
  [SMALL_STATE(1791)] = 54619,
  [SMALL_STATE(1792)] = 54626,
  [SMALL_STATE(1793)] = 54633,
  [SMALL_STATE(1794)] = 54640,
  [SMALL_STATE(1795)] = 54647,
  [SMALL_STATE(1796)] = 54654,
  [SMALL_STATE(1797)] = 54661,
  [SMALL_STATE(1798)] = 54668,
  [SMALL_STATE(1799)] = 54675,
  [SMALL_STATE(1800)] = 54682,
  [SMALL_STATE(1801)] = 54689,
  [SMALL_STATE(1802)] = 54696,
  [SMALL_STATE(1803)] = 54703,
  [SMALL_STATE(1804)] = 54710,
  [SMALL_STATE(1805)] = 54717,
  [SMALL_STATE(1806)] = 54724,
  [SMALL_STATE(1807)] = 54731,
  [SMALL_STATE(1808)] = 54738,
  [SMALL_STATE(1809)] = 54745,
  [SMALL_STATE(1810)] = 54752,
  [SMALL_STATE(1811)] = 54759,
  [SMALL_STATE(1812)] = 54766,
  [SMALL_STATE(1813)] = 54773,
  [SMALL_STATE(1814)] = 54780,
  [SMALL_STATE(1815)] = 54787,
  [SMALL_STATE(1816)] = 54794,
  [SMALL_STATE(1817)] = 54801,
  [SMALL_STATE(1818)] = 54808,
  [SMALL_STATE(1819)] = 54815,
  [SMALL_STATE(1820)] = 54822,
  [SMALL_STATE(1821)] = 54829,
  [SMALL_STATE(1822)] = 54836,
  [SMALL_STATE(1823)] = 54843,
  [SMALL_STATE(1824)] = 54850,
  [SMALL_STATE(1825)] = 54857,
  [SMALL_STATE(1826)] = 54864,
  [SMALL_STATE(1827)] = 54871,
  [SMALL_STATE(1828)] = 54878,
  [SMALL_STATE(1829)] = 54885,
  [SMALL_STATE(1830)] = 54892,
  [SMALL_STATE(1831)] = 54899,
  [SMALL_STATE(1832)] = 54906,
  [SMALL_STATE(1833)] = 54913,
  [SMALL_STATE(1834)] = 54920,
  [SMALL_STATE(1835)] = 54927,
  [SMALL_STATE(1836)] = 54934,
  [SMALL_STATE(1837)] = 54941,
  [SMALL_STATE(1838)] = 54948,
  [SMALL_STATE(1839)] = 54955,
  [SMALL_STATE(1840)] = 54962,
  [SMALL_STATE(1841)] = 54969,
  [SMALL_STATE(1842)] = 54976,
  [SMALL_STATE(1843)] = 54983,
  [SMALL_STATE(1844)] = 54990,
  [SMALL_STATE(1845)] = 54997,
  [SMALL_STATE(1846)] = 55004,
  [SMALL_STATE(1847)] = 55011,
  [SMALL_STATE(1848)] = 55018,
  [SMALL_STATE(1849)] = 55025,
  [SMALL_STATE(1850)] = 55032,
  [SMALL_STATE(1851)] = 55039,
  [SMALL_STATE(1852)] = 55046,
  [SMALL_STATE(1853)] = 55053,
  [SMALL_STATE(1854)] = 55060,
  [SMALL_STATE(1855)] = 55067,
  [SMALL_STATE(1856)] = 55074,
  [SMALL_STATE(1857)] = 55081,
  [SMALL_STATE(1858)] = 55088,
  [SMALL_STATE(1859)] = 55095,
  [SMALL_STATE(1860)] = 55102,
  [SMALL_STATE(1861)] = 55109,
  [SMALL_STATE(1862)] = 55116,
  [SMALL_STATE(1863)] = 55123,
  [SMALL_STATE(1864)] = 55130,
  [SMALL_STATE(1865)] = 55137,
  [SMALL_STATE(1866)] = 55144,
  [SMALL_STATE(1867)] = 55151,
  [SMALL_STATE(1868)] = 55158,
  [SMALL_STATE(1869)] = 55165,
  [SMALL_STATE(1870)] = 55172,
  [SMALL_STATE(1871)] = 55179,
  [SMALL_STATE(1872)] = 55186,
  [SMALL_STATE(1873)] = 55193,
  [SMALL_STATE(1874)] = 55200,
  [SMALL_STATE(1875)] = 55207,
  [SMALL_STATE(1876)] = 55214,
  [SMALL_STATE(1877)] = 55221,
  [SMALL_STATE(1878)] = 55228,
  [SMALL_STATE(1879)] = 55235,
  [SMALL_STATE(1880)] = 55242,
  [SMALL_STATE(1881)] = 55249,
  [SMALL_STATE(1882)] = 55256,
  [SMALL_STATE(1883)] = 55263,
  [SMALL_STATE(1884)] = 55270,
  [SMALL_STATE(1885)] = 55277,
  [SMALL_STATE(1886)] = 55284,
  [SMALL_STATE(1887)] = 55291,
  [SMALL_STATE(1888)] = 55298,
  [SMALL_STATE(1889)] = 55305,
  [SMALL_STATE(1890)] = 55312,
  [SMALL_STATE(1891)] = 55319,
  [SMALL_STATE(1892)] = 55326,
  [SMALL_STATE(1893)] = 55333,
  [SMALL_STATE(1894)] = 55340,
  [SMALL_STATE(1895)] = 55347,
  [SMALL_STATE(1896)] = 55354,
  [SMALL_STATE(1897)] = 55361,
  [SMALL_STATE(1898)] = 55368,
  [SMALL_STATE(1899)] = 55375,
  [SMALL_STATE(1900)] = 55382,
  [SMALL_STATE(1901)] = 55389,
  [SMALL_STATE(1902)] = 55396,
  [SMALL_STATE(1903)] = 55403,
  [SMALL_STATE(1904)] = 55410,
  [SMALL_STATE(1905)] = 55417,
  [SMALL_STATE(1906)] = 55424,
  [SMALL_STATE(1907)] = 55431,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1883),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1886),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1773),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1727),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1748),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1774),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1890),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(522),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1589),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(532),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1811),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [97] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1883),
  [103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(300),
  [106] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1886),
  [109] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1773),
  [112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1727),
  [115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1593),
  [121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1748),
  [127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1869),
  [130] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1774),
  [133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1890),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(929),
  [142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1723),
  [145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(522),
  [151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(172),
  [154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(26),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(21),
  [163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(505),
  [166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(474),
  [169] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(132),
  [172] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1507),
  [175] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1589),
  [178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(233),
  [181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1002),
  [184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(22),
  [187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(133),
  [190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(424),
  [193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [196] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1860),
  [199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [202] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(532),
  [205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1708),
  [208] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(459),
  [214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1811),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_expression, 1, 0, 0),
  [245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_expression, 1, 0, 0),
  [247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(135),
  [251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 1, 0, 0),
  [253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_expression, 1, 0, 0),
  [255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 2, 0, 0),
  [263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 2, 0, 0),
  [265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 1, 0, 0),
  [267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 1, 0, 0),
  [269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1546),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(136),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(540),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1547),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(53),
  [350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0),
  [352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(39),
  [355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(76),
  [358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(76),
  [361] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(54),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(55),
  [367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(84),
  [370] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(83),
  [373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(1853),
  [379] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(78),
  [382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(79),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_delim_token_tree_repeat1, 2, 0, 0), SHIFT_REPEAT(39),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(84),
  [404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(83),
  [406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(64),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_delim_token, 1, 0, 0),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_delim_token, 1, 0, 0),
  [514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__non_special_token_repeat1, 2, 0, 0),
  [520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__non_special_token_repeat1, 2, 0, 0),
  [522] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__non_special_token_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__non_special_token_repeat1, 2, 0, 0), SHIFT_REPEAT(77),
  [528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0),
  [530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delim_token_tree, 2, 0, 0),
  [542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delim_token_tree, 2, 0, 0),
  [544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delim_token_tree, 3, 0, 0),
  [546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delim_token_tree, 3, 0, 0),
  [548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__non_special_token_repeat1, 1, 0, 0),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__non_special_token_repeat1, 1, 0, 0),
  [552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__non_special_token_repeat1, 1, 0, 0), SHIFT(85),
  [555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_delim_token, 1, 0, 40),
  [557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_delim_token, 1, 0, 40),
  [559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negative_literal, 2, 0, 0),
  [561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negative_literal, 2, 0, 0),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(482),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(2),
  [600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(232),
  [603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1906),
  [606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(99),
  [609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0),
  [611] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(1723),
  [614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(109),
  [617] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(522),
  [620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(172),
  [623] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(395),
  [626] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(26),
  [629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(21),
  [632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(505),
  [635] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(474),
  [638] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(135),
  [641] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(1589),
  [644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(233),
  [647] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(22),
  [650] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(133),
  [653] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(424),
  [656] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(516),
  [659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(1860),
  [662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(516),
  [665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(532),
  [668] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(1708),
  [671] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(167),
  [674] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(459),
  [677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT(1811),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 4, 0, 63),
  [694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 4, 0, 63),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_block, 2, 0, 0),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_block, 2, 0, 0),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_invocation, 3, 0, 21),
  [716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_invocation, 3, 0, 21),
  [718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_block, 3, 0, 0),
  [720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_block, 3, 0, 0),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_expression, 5, 0, 87),
  [724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_expression, 5, 0, 87),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_block, 4, 0, 0),
  [730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_block, 4, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_expression, 3, 0, 26),
  [734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_expression, 3, 0, 26),
  [736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_expression, 3, 0, 27),
  [738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_expression, 3, 0, 27),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_invocation, 3, 0, 30),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_invocation, 3, 0, 30),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_loop_expression, 2, 0, 4),
  [762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_loop_expression, 2, 0, 4),
  [764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_expression, 3, 0, 25),
  [766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_expression, 3, 0, 25),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1222),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2),
  [799] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(232),
  [802] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [805] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1723),
  [808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(109),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0),
  [813] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(522),
  [816] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(172),
  [819] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(395),
  [822] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(26),
  [825] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(21),
  [828] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(505),
  [831] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(474),
  [834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(135),
  [837] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1589),
  [840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(233),
  [843] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(22),
  [846] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(133),
  [849] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(424),
  [852] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1860),
  [858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(516),
  [861] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(532),
  [864] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1708),
  [867] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [870] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(459),
  [873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1811),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(777),
  [886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_except_range, 1, 0, 0),
  [900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_except_range, 1, 0, 0),
  [902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 0),
  [904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 0),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(529),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(421),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_parameters, 3, 0, 0),
  [926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_parameters, 3, 0, 0),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_parameters, 4, 0, 0),
  [932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_parameters, 4, 0, 0),
  [934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_parameters, 2, 0, 0),
  [936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_parameters, 2, 0, 0),
  [938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_parameters, 5, 0, 0),
  [940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_parameters, 5, 0, 0),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern_type, 6, 0, 118),
  [946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extern_type, 6, 0, 118),
  [948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_item, 7, 0, 124),
  [950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_item, 7, 0, 124),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 5, 0, 0),
  [954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 5, 0, 0),
  [956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_list, 5, 0, 0),
  [958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_list, 5, 0, 0),
  [960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 7, 0, 130),
  [962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 7, 0, 130),
  [964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 6, 0, 110),
  [966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 6, 0, 110),
  [968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 7, 0, 132),
  [970] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 7, 0, 132),
  [972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 7, 0, 133),
  [974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 7, 0, 133),
  [976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_item, 7, 0, 134),
  [978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_item, 7, 0, 134),
  [980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 6, 0, 0),
  [982] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 6, 0, 0),
  [984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_list, 6, 0, 0),
  [986] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_list, 6, 0, 0),
  [988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 8, 0, 140),
  [990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 8, 0, 140),
  [992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_item, 8, 0, 141),
  [994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_item, 8, 0, 141),
  [996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 4, 0, 44),
  [998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 4, 0, 44),
  [1000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_list, 2, 0, 0),
  [1002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_list, 2, 0, 0),
  [1004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_item, 4, 0, 44),
  [1006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_item, 4, 0, 44),
  [1008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 4, 0, 66),
  [1010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 4, 0, 66),
  [1012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 4, 0, 67),
  [1014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 4, 0, 67),
  [1016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mod_item, 4, 0, 68),
  [1018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mod_item, 4, 0, 68),
  [1020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mod_item, 4, 0, 69),
  [1022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mod_item, 4, 0, 69),
  [1024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 4, 0, 66),
  [1026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 4, 0, 66),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 4, 0, 67),
  [1030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 4, 0, 67),
  [1032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_item, 4, 0, 67),
  [1034] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_item, 4, 0, 67),
  [1036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_declaration, 4, 0, 70),
  [1038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_use_declaration, 4, 0, 70),
  [1040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external_function_item, 4, 0, 0),
  [1042] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external_function_item, 4, 0, 0),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern_type, 4, 0, 66),
  [1046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extern_type, 4, 0, 66),
  [1048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 5, 0, 0),
  [1050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 5, 0, 0),
  [1052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 5, 0, 71),
  [1054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 5, 0, 71),
  [1056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_associated_impl, 5, 0, 2),
  [1058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_associated_impl, 5, 0, 2),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_item, 5, 0, 72),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_item, 5, 0, 72),
  [1064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [1066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [1068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_item, 5, 0, 76),
  [1070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_item, 5, 0, 76),
  [1072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inner_attribute_item, 5, 0, 0),
  [1074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inner_attribute_item, 5, 0, 0),
  [1076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [1078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [1080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_item, 1, 0, 0),
  [1082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_item, 1, 0, 0),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [1086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [1088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_list, 3, 0, 0),
  [1090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_list, 3, 0, 0),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 5, 0, 84),
  [1094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 5, 0, 84),
  [1096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 5, 0, 85),
  [1098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 5, 0, 85),
  [1100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 3, 0, 3),
  [1102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 3, 0, 3),
  [1104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 3, 0, 10),
  [1106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 3, 0, 10),
  [1108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_associated_type, 3, 0, 3),
  [1110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_associated_type, 3, 0, 3),
  [1112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 6, 0, 109),
  [1114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 6, 0, 109),
  [1116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [1118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [1120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 6, 0, 0),
  [1122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 6, 0, 0),
  [1124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mod_item, 3, 0, 11),
  [1126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mod_item, 3, 0, 11),
  [1128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 6, 0, 115),
  [1130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 6, 0, 115),
  [1132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 3, 0, 3),
  [1134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 3, 0, 3),
  [1136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_item, 6, 0, 116),
  [1138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_item, 6, 0, 116),
  [1140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_item, 6, 0, 117),
  [1142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_item, 6, 0, 117),
  [1144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 3, 0, 10),
  [1146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 3, 0, 10),
  [1148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_item, 3, 0, 10),
  [1150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_item, 3, 0, 10),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [1162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [1166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [1174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1105),
  [1176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1007),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [1186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [1190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1682),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 3, 0, 15),
  [1194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 3, 0, 15),
  [1196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature_item, 2, 0, 0),
  [1198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature_item, 2, 0, 0),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_declaration, 3, 0, 18),
  [1202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_use_declaration, 3, 0, 18),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 4, 0, 43),
  [1206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 4, 0, 43),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_declaration, 4, 0, 56),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_let_declaration, 4, 0, 56),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_item, 2, 0, 4),
  [1214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_item, 2, 0, 4),
  [1216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_item, 4, 0, 0),
  [1218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_item, 4, 0, 0),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 5, 0, 92),
  [1222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 5, 0, 92),
  [1224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 5, 0, 93),
  [1226] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 5, 0, 93),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 5, 0, 92),
  [1230] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 5, 0, 92),
  [1232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature_item, 3, 0, 0),
  [1234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature_item, 3, 0, 0),
  [1236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_item, 5, 0, 93),
  [1238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_item, 5, 0, 93),
  [1240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_item, 3, 0, 42),
  [1242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_item, 3, 0, 42),
  [1244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_item, 5, 0, 93),
  [1246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_item, 5, 0, 93),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external_function_item, 3, 0, 0),
  [1250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external_function_item, 3, 0, 0),
  [1252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern_type, 5, 0, 94),
  [1254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extern_type, 5, 0, 94),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern_type, 5, 0, 92),
  [1258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extern_type, 5, 0, 92),
  [1260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 6, 0, 96),
  [1262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 6, 0, 96),
  [1264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_impl_item, 6, 0, 97),
  [1266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_impl_item, 6, 0, 97),
  [1268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_item, 6, 0, 98),
  [1270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_item, 6, 0, 98),
  [1272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 4, 0, 0),
  [1278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 4, 0, 0),
  [1280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant_list, 4, 0, 0),
  [1282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_variant_list, 4, 0, 0),
  [1284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [1286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [1288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 4, 0, 43),
  [1290] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 4, 0, 43),
  [1292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trait_item, 4, 0, 44),
  [1294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trait_item, 4, 0, 44),
  [1296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_associated_type, 4, 0, 43),
  [1298] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_associated_type, 4, 0, 43),
  [1300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mod_item, 3, 0, 2),
  [1302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mod_item, 3, 0, 2),
  [1304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [1312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1898),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [1316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1764),
  [1318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [1320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [1322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [1324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [1326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [1328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [1330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [1332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [1334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [1336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1866),
  [1338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [1340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [1342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0),
  [1344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1898),
  [1347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(621),
  [1350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1764),
  [1353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1765),
  [1356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1739),
  [1359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1728),
  [1362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1766),
  [1365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1767),
  [1368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1768),
  [1371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1890),
  [1374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(440),
  [1377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(932),
  [1380] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1741),
  [1383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1866),
  [1386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1655),
  [1389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1507),
  [1392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1002),
  [1395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1656),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_arm, 3, 0, 112),
  [1408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_arm, 3, 0, 112),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [1422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [1428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [1434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_arm, 4, 0, 85),
  [1436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_arm, 4, 0, 85),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [1448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [1452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [1456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1085),
  [1460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [1464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [1466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [1468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [1470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(432),
  [1472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1602),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [1478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [1488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [1490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [1492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [1494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [1496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [1498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1737),
  [1501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(403),
  [1504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1645),
  [1507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(389),
  [1510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1409),
  [1513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1153),
  [1516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1875),
  [1519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(431),
  [1522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1085),
  [1525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1228),
  [1528] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1867),
  [1531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1228),
  [1534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1231),
  [1537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1016),
  [1540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(432),
  [1543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_match_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1602),
  [1546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [1550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [1552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [1556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [1558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1698),
  [1564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [1568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [1572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [1578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1584] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [1622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1292),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1044),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1567),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [1644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [1654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [1666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [1668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1791),
  [1670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [1678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [1680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_tuple_expression_repeat1, 2, 0, 0),
  [1682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [1684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [1688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 33),
  [1690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 3, 0, 33),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 2, 0, 1),
  [1694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 2, 0, 1),
  [1696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [1702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 22),
  [1704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 3, 0, 22),
  [1706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 19),
  [1708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 3, 0, 19),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_identifier, 2, 0, 2),
  [1712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_identifier, 2, 0, 2),
  [1714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [1716] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [1718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [1720] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 5, 0, 0),
  [1722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 2, 0, 0),
  [1724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 2, 0, 0),
  [1726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [1728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [1730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [1732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [1734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [1736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier_in_expression_position, 3, 0, 20),
  [1738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier_in_expression_position, 3, 0, 34),
  [1740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier_in_expression_position, 3, 0, 23),
  [1742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [1744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier_in_expression_position, 2, 0, 3),
  [1746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_except_range, 1, 0, 1),
  [1748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_except_range, 1, 0, 1),
  [1750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [1754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type_with_turbofish, 3, 0, 31),
  [1756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_function, 3, 0, 32),
  [1758] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_function, 3, 0, 32),
  [1760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [1762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [1764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type_with_turbofish, 3, 0, 35),
  [1770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 38),
  [1772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 38),
  [1774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [1776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 39),
  [1778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 39),
  [1780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [1782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [1786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 6, 0, 102),
  [1794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 6, 0, 102),
  [1796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 6, 0, 0),
  [1798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 6, 0, 0),
  [1800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [1802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 4, 0, 0),
  [1806] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 4, 0, 0),
  [1808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 127),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [1812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [1814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [1816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_expression, 2, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_expression, 2, 0, 0),
  [1822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 6, 0, 0),
  [1824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 6, 0, 0),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 74),
  [1828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 7, 0, 0),
  [1830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 7, 0, 0),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [1834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 4, 0, 0),
  [1836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 104),
  [1838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 8),
  [1840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 8),
  [1842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_expression, 2, 0, 9),
  [1844] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_expression, 2, 0, 9),
  [1846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 5, 0, 0),
  [1848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_initializer_list, 5, 0, 0),
  [1850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 0),
  [1852] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 5, 0, 0),
  [1854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 0),
  [1856] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 6, 0, 0),
  [1858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_expression, 1, 0, 0),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_expression, 1, 0, 0),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 2, 0, 7),
  [1864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 2, 0, 7),
  [1866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_expression, 4, 0, 65),
  [1868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_expression, 4, 0, 65),
  [1870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 136),
  [1872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 5, 0, 78),
  [1874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 5, 0, 78),
  [1876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_expression, 3, 0, 28),
  [1878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_expression, 3, 0, 28),
  [1880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 5, 0, 0),
  [1882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 5, 0, 0),
  [1884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_expression, 3, 0, 29),
  [1886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_expression, 3, 0, 29),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 2, 0, 0),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_initializer_list, 2, 0, 0),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 5, 0, 0),
  [1894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 5, 0, 0),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [1898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 37),
  [1902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 37),
  [1904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_expression, 4, 0, 0),
  [1906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_expression, 4, 0, 0),
  [1908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_expression, 2, 0, 5),
  [1910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_expression, 2, 0, 5),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [1914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 0),
  [1916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 2, 0, 0),
  [1918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_expression, 2, 0, 6),
  [1920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_expression, 2, 0, 6),
  [1922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 82),
  [1924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 120),
  [1926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 7, 0, 0),
  [1928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 7, 0, 0),
  [1930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym_negative_literal, 2, 0, 0),
  [1933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym_negative_literal, 2, 0, 0),
  [1936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [1938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments, 3, 0, 0),
  [1940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_closure_expression, 5, 0, 88),
  [1942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_closure_expression, 5, 0, 88),
  [1944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 2, 0, 0),
  [1946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 2, 0, 0),
  [1948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4, 0, 49),
  [1950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 3, 0, 0),
  [1952] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_initializer_list, 3, 0, 0),
  [1954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 101),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 4, 0, 0),
  [1958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_initializer_list, 4, 0, 0),
  [1960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_expression, 3, 0, 0),
  [1962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_expression, 3, 0, 0),
  [1964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit_expression, 2, 0, 0),
  [1966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unit_expression, 2, 0, 0),
  [1968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [1970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [1972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [1974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 36),
  [1976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 36),
  [1978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [1980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [1984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(198),
  [1990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [2000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_assignment_expr, 3, 0, 37),
  [2002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_assignment_expr, 3, 0, 37),
  [2004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 3, 0, 0),
  [2006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 3, 0, 0),
  [2008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_expression, 2, 0, 0),
  [2010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_expression, 2, 0, 0),
  [2012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_expression, 2, 0, 0),
  [2018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_expression, 2, 0, 0),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [2022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [2024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [2028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [2030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [2032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [2034] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_match_arm_repeat1, 2, 0, 0), SHIFT_REPEAT(1737),
  [2037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_match_arm_repeat1, 2, 0, 0),
  [2039] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_match_arm_repeat1, 2, 0, 0),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [2043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [2051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1747),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [2067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [2083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1241),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [2123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [2125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1186),
  [2127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1775),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [2133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [2135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_match_arm, 4, 0, 112),
  [2137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_arm, 4, 0, 112),
  [2139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_arm, 4, 0, 112),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [2151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [2153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1828),
  [2155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_match_arm, 5, 0, 85),
  [2157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_arm, 5, 0, 85),
  [2159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_match_arm, 5, 0, 85),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [2167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [2181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [2193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(222),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 89),
  [2215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 90),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [2223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [2225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(205),
  [2229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_expression_repeat1, 2, 0, 0),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [2253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_argument, 3, 0, 0),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [2257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_field_initializer, 2, 0, 0),
  [2263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_argument, 2, 0, 0),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [2267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_match_arm, 3, 0, 112),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 4, 0, 113),
  [2281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 4, 0, 114),
  [2283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 3, 0, 0),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_expression_repeat1, 3, 0, 0),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [2303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [2309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_last_match_arm, 4, 0, 85),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__condition, 1, 0, 0),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [2317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [2329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 29),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 77),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [2345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [2347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [2349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [2351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_specifier, 1, 0, 0),
  [2357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_specifier, 1, 0, 0),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [2363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_condition, 4, 0, 85),
  [2365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [2371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [2373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [2379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [2395] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1894),
  [2398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [2400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [2402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [2408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [2410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [2412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [2416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1551),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [2420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 3, 0, 23),
  [2422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 3, 0, 34),
  [2424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 3, 0, 20),
  [2426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type_identifier, 2, 0, 3),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [2430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 0),
  [2432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 0),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [2444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type_with_turbofish, 3, 0, 24),
  [2446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 14),
  [2448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 13),
  [2450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pattern, 1, 0, 1),
  [2452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pattern, 1, 0, 1),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 40),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [2464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 0),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [2470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 16),
  [2472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [2474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit_type, 2, 0, 0),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [2496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [2498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 5, 0, 131),
  [2500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 5, 0, 0),
  [2502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 19), REDUCE(sym_scoped_type_identifier, 3, 0, 20),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [2513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [2515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [2517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 22), REDUCE(sym_scoped_type_identifier, 3, 0, 23),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [2526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_scoped_identifier, 3, 0, 33), REDUCE(sym_scoped_type_identifier, 3, 0, 34),
  [2529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 3, 0, 91),
  [2531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_snapshot_type, 2, 0, 64),
  [2533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_scoped_identifier, 2, 0, 2), REDUCE(sym_scoped_type_identifier, 2, 0, 3),
  [2536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type, 1, 0, 41),
  [2538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 41), REDUCE(sym__pattern, 1, 0, 0),
  [2541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [2545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [2547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1780),
  [2553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [2557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visibility_modifier, 1, 0, 0),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [2565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visibility_modifier, 5, 0, 0),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 0),
  [2569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 0),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [2575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal_pattern, 1, 0, 0),
  [2577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 1),
  [2579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 1),
  [2581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 52),
  [2583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 52),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [2587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [2591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [2593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [2595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [2601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1605),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [2627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_pattern, 3, 0, 51),
  [2629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_pattern, 3, 0, 51),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [2633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visibility_modifier, 4, 0, 0),
  [2635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_visibility_modifier, 5, 0, 86),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 3, 0, 53),
  [2643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 5, 0, 57),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 4, 0, 53),
  [2649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 4, 0, 55),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [2655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 5, 0, 55),
  [2657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 2, 0, 0),
  [2659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 6, 0, 53),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [2663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 6, 0, 55),
  [2665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mut_pattern, 2, 0, 0),
  [2667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 3, 0, 55),
  [2669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 4, 0, 57),
  [2671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 6, 0, 57),
  [2673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_pattern, 3, 0, 0),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [2679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [2685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 5, 0, 53),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 5, 0, 55),
  [2691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_pattern, 5, 0, 0),
  [2693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_pattern, 4, 0, 0),
  [2695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 4, 0, 55),
  [2697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 4, 0, 0),
  [2699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_pattern, 2, 0, 0),
  [2701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [2703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_enum_pattern, 3, 0, 57),
  [2705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 5, 0, 0),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [2709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern, 3, 0, 0),
  [2711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 3, 0, 55),
  [2713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern, 2, 0, 0),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [2717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_pattern, 6, 0, 55),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [2731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [2743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [2745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(462),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 1),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [2777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 100),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [2783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 135),
  [2785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 40), REDUCE(sym__pattern, 1, 0, 0),
  [2788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [2790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 137),
  [2792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 138),
  [2794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 139),
  [2796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 142),
  [2798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 143),
  [2800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 144),
  [2802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 10, 0, 145),
  [2804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4, 0, 50),
  [2806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 3, 0, 12),
  [2812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [2816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 121),
  [2818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [2820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 2, 0, 73),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [2824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [2828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 123),
  [2830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 75),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [2834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [2838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [2840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 105),
  [2842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 81),
  [2844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 107),
  [2846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4, 0, 45),
  [2848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [2854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 126),
  [2856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 128),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [2862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2, 0, 0),
  [2864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2, 0, 0), SHIFT_REPEAT(691),
  [2867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1457),
  [2873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1756),
  [2875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [2879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, 0, 95),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [2901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 6, 0, 0),
  [2903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__use_clause, 1, 0, 1),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [2909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, 0, 73),
  [2911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, 0, 0),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [2915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 122),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [2919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 6, 0, 0),
  [2921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 99),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [2929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 73),
  [2931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__use_clause, 1, 0, 0),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [2939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 4, 0, 0),
  [2941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 73),
  [2943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 3, 0, 95),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1905),
  [2949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 6, 0, 95),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [2953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, 0, 73),
  [2955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 3, 0, 0),
  [2957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 106),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [2963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 80),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [2967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 5, 0, 0),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [2973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 5, 0, 0),
  [2975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1896),
  [2978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [2982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 0),
  [2984] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1881),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [2993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1763),
  [2995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 95),
  [2999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [3001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [3003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [3007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [3009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [3011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [3013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [3015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [3017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [3019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [3023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(953),
  [3025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_pattern, 2, 0, 0), REDUCE(sym_unit_type, 2, 0, 0),
  [3028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(960),
  [3030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [3032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [3034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [3036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [3038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [3042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [3044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [3046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [3048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [3050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [3052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [3054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [3056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [3058] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__type, 1, 0, 0), REDUCE(sym__pattern, 1, 0, 0),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [3063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [3065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1104),
  [3067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [3071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [3073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 2, 0, 0),
  [3075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [3077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [3079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [3081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [3083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [3085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [3087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [3089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [3097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [3099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [3103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [3117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(954),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(667),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [3139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [3145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [3149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 3, 0, 0),
  [3151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [3161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(992),
  [3163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [3173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [3175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [3189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [3191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_slice_pattern_repeat1, 2, 0, 0),
  [3193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_slice_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(437),
  [3196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1047),
  [3198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1073),
  [3200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [3202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [3204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [3206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [3208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [3210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [3212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [3214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [3216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [3218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [3220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [3222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [3224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [3226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [3228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [3230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1672),
  [3232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [3234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [3236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [3238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [3240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [3242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [3244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [3246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [3248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [3250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [3252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [3254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [3256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [3258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_list, 5, 0, 0),
  [3260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [3262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_pattern, 1, 0, 0),
  [3264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [3266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant, 1, 0, 48),
  [3268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [3270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [3272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [3274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [3276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shorthand_field_initializer, 2, 0, 0),
  [3278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [3280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(101),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [3287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [3293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [3295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [3297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [3299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [3301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [3303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [3305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [3309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 4, 0, 119),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [3313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [3315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [3319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_wildcard, 1, 0, 0),
  [3321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [3323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [3325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [3327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1724),
  [3329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [3331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 3, 0, 0),
  [3333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [3335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0),
  [3337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1035),
  [3340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0),
  [3342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [3346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [3348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0),
  [3350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1098),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [3409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [3411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [3415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [3419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [3421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [3423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [3429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [3431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [3433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [3435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [3437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [3439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 84),
  [3441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [3443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat2, 2, 0, 0),
  [3445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat2, 2, 0, 0), SHIFT_REPEAT(1082),
  [3448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [3450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [3452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(364),
  [3455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [3457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [3459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [3461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [3463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [3466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 1, 0, 54),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [3470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [3474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [3478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [3482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [3486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(692),
  [3489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [3491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_variant, 2, 0, 79),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [3495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 4, 0, 129),
  [3497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [3499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [3501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_list, 3, 0, 0),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [3505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_wildcard, 3, 0, 0),
  [3507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_use_list, 3, 0, 58),
  [3509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_as_clause, 3, 0, 59),
  [3511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_wildcard, 3, 0, 1),
  [3513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_use_list, 3, 0, 60),
  [3515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [3517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 0),
  [3519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_as_clause, 3, 0, 61),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(670),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [3527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(399),
  [3530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [3534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [3538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 2, 0, 83),
  [3540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [3542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [3544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [3546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [3550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [3552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern, 1, 0, 0),
  [3554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [3556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_closure_parameters_repeat1, 2, 0, 0),
  [3558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_shorthand_field_initializer, 1, 0, 0),
  [3560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [3562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [3564] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_closure_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [3567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 62),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [3571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(456),
  [3574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0),
  [3576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_pattern, 3, 0, 108),
  [3578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [3582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [3584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_list, 4, 0, 0),
  [3586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [3588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_pattern_repeat1, 2, 0, 0),
  [3590] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1474),
  [3593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_use_list_repeat1, 2, 0, 0),
  [3595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_use_list_repeat1, 2, 0, 0), SHIFT_REPEAT(928),
  [3598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [3602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constrained_type_parameter_repeat1, 2, 0, 0),
  [3604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_constrained_type_parameter_repeat1, 2, 0, 0), SHIFT_REPEAT(1895),
  [3607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_list, 2, 0, 0),
  [3609] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_repeat1, 2, 0, 0), SHIFT_REPEAT(754),
  [3612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [3614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [3616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_use_list, 2, 0, 17),
  [3618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1778),
  [3620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1889),
  [3622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 100),
  [3624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [3626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [3628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [3630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1849),
  [3632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [3634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [3636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [3638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [3640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 10, 0, 144),
  [3642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [3646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [3650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(470),
  [3652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [3654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_parameter, 4, 0, 76),
  [3656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 126),
  [3658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(961),
  [3660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [3662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 101),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [3666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 11, 0, 145),
  [3668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 127),
  [3670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [3674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 3, 0, 0),
  [3676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 103),
  [3678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 4, 0, 73),
  [3680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 128),
  [3682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [3684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [3686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [3688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [3690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [3692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 125),
  [3694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 75),
  [3696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_variant_list_repeat2, 3, 0, 0),
  [3698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [3700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 45),
  [3702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [3704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [3706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [3708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [3710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [3714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [3716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [3718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [3722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [3724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 4, 0, 0),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [3728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(586),
  [3730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(669),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [3734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [3736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(956),
  [3738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 104),
  [3740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [3742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 80),
  [3744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [3746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [3750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 105),
  [3752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [3754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 6, 0, 119),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [3758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 106),
  [3760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 81),
  [3762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 107),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [3766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [3768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(959),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [3780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [3782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constrained_type_parameter_repeat1, 3, 0, 41),
  [3784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [3786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 135),
  [3788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [3792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 49),
  [3794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [3798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [3800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5, 0, 50),
  [3802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 82),
  [3804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1048),
  [3806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [3808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [3810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 122),
  [3812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nopanic, 1, 0, 0),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [3818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4, 0, 12),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [3822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [3824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 136),
  [3826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [3828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 123),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [3832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [3834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 137),
  [3836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [3838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [3844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 138),
  [3846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 9, 0, 139),
  [3848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6, 0, 74),
  [3850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [3854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 5, 0, 73),
  [3856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 7, 0, 119),
  [3858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 10, 0, 142),
  [3860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [3862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [3864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constrained_type_parameter, 5, 0, 0),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [3870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1884),
  [3872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [3876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 10, 0, 143),
  [3878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [3884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 120),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [3896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [3898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7, 0, 99),
  [3900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8, 0, 121),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [3908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [3910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [3916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [3920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [3922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [3940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [3944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [3950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [3954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [3960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [3964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [3970] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [3976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [3978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [3980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [3982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [3990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [3992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [3994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [3998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [4000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [4002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [4006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [4008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [4010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [4012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 46),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [4016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_match_pattern, 3, 0, 111),
  [4018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [4020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [4022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 47),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [4042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [4044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [4046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [4048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [4050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [4052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [4072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [4076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [4082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [4100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [4104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [4110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [4116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [4118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [4120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [4122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [4124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [4126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [4128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [4130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [4134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [4136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [4140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [4144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [4146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_cairo(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
